@@ -37,19 +37,29 @@ if ( $wgImgAuthPublicTest
 	wfForbidden('img-auth-accessdenied','img-auth-public');
 }
 
-// Check for bug 28235: QUERY_STRING overriding the correct extension
-if ( isset( $_SERVER['QUERY_STRING'] )
-	&& preg_match( '/\.[^\\/:*?"<>|%]+(#|\?|$)/i', $_SERVER['QUERY_STRING'] ) )
-{
-	wfForbidden( 'img-auth-accessdenied', 'img-auth-bad-query-string' );
+// Extract path and image information
+if( !isset( $_SERVER['PATH_INFO'] ) ) {
+	$path = $wgRequest->getText( 'path' );
+	if( !$path ) {
+        wfForbidden( 'img-auth-accessdenied', 'img-auth-nopathinfo' );
+	}
+	$path = "/$path";
+} else {
+	$path = $_SERVER['PATH_INFO'];
 }
 
-// Extract path and image information
-if( !isset( $_SERVER['PATH_INFO'] ) )
-	wfForbidden('img-auth-accessdenied','img-auth-nopathinfo');
+// Check for bug 28235: QUERY_STRING overriding the correct extension
+$dotPos = strrpos( $path, '.' );
+$whitelist = array();
+if ( $dotPos !== false ) {
+	$whitelist[] = substr( $path, $dotPos + 1 );
+}
+if ( !$wgRequest->checkUrlExtension( $whitelist ) )
+{
+	return;
+}
 
-$path = $_SERVER['PATH_INFO'];
-$filename = realpath( $wgUploadDirectory . $_SERVER['PATH_INFO'] );
+$filename = realpath( $wgUploadDirectory . $path );
 $realUpload = realpath( $wgUploadDirectory );
 
 // Basic directory traversal check
