@@ -7,7 +7,7 @@
  * Handle ajax requests and send them to the proper handler.
  */
 
-if( !(defined( 'MEDIAWIKI' ) && $wgUseAjax ) ) {
+if ( !( defined( 'MEDIAWIKI' ) && $wgUseAjax ) ) {
 	die( 1 );
 }
 
@@ -33,40 +33,36 @@ class AjaxDispatcher {
 
 		$this->mode = "";
 
-		if (! empty($_GET["rs"])) {
+		if ( ! empty( $_GET["rs"] ) ) {
 			$this->mode = "get";
 		}
 
-		if (!empty($_POST["rs"])) {
+		if ( !empty( $_POST["rs"] ) ) {
 			$this->mode = "post";
 		}
 
 		switch( $this->mode ) {
-
-		case 'get':
-			$this->func_name = isset( $_GET["rs"] ) ? $_GET["rs"] : '';
-			if (! empty($_GET["rsargs"])) {
-				$this->args = $_GET["rsargs"];
-			} else {
-				$this->args = array();
-			}
-		break;
-
-		case 'post':
-			$this->func_name = isset( $_POST["rs"] ) ? $_POST["rs"] : '';
-			if (! empty($_POST["rsargs"])) {
-				$this->args = $_POST["rsargs"];
-			} else {
-				$this->args = array();
-			}
-		break;
-
-		default:
-			wfProfileOut( __METHOD__ );
-			return;
-			# Or we could throw an exception:
-			#throw new MWException( __METHOD__ . ' called without any data (mode empty).' );
-
+			case 'get':
+				$this->func_name = isset( $_GET["rs"] ) ? $_GET["rs"] : '';
+				if ( ! empty( $_GET["rsargs"] ) ) {
+					$this->args = $_GET["rsargs"];
+				} else {
+					$this->args = array();
+				}
+				break;
+			case 'post':
+				$this->func_name = isset( $_POST["rs"] ) ? $_POST["rs"] : '';
+				if ( ! empty( $_POST["rsargs"] ) ) {
+					$this->args = $_POST["rsargs"];
+				} else {
+					$this->args = array();
+				}
+				break;
+			default:
+				wfProfileOut( __METHOD__ );
+				return;
+				# Or we could throw an exception:
+				# throw new MWException( __METHOD__ . ' called without any data (mode empty).' );
 		}
 
 		wfProfileOut( __METHOD__ );
@@ -78,18 +74,29 @@ class AjaxDispatcher {
 	 * request.
 	 */
 	function performAction() {
-		global $wgAjaxExportList, $wgOut;
+		global $wgAjaxExportList, $wgOut, $wgUser;
 
 		if ( empty( $this->mode ) ) {
 			return;
 		}
+
 		wfProfileIn( __METHOD__ );
 
-		if (! in_array( $this->func_name, $wgAjaxExportList ) ) {
+		if ( ! in_array( $this->func_name, $wgAjaxExportList ) ) {
 			wfDebug( __METHOD__ . ' Bad Request for unknown function ' . $this->func_name . "\n" );
 
-			wfHttpError( 400, 'Bad Request',
-				"unknown function " . (string) $this->func_name );
+			wfHttpError(
+				400,
+				'Bad Request',
+				"unknown function " . (string) $this->func_name
+			);
+		} elseif ( !in_array( 'read', User::getGroupPermissions( array( '*' ) ), true ) 
+			&& !$wgUser->isAllowed( 'read' ) )
+		{
+			wfHttpError(
+				403,
+				'Forbidden',
+				'You must log in to view pages.' );
 		} else {
 			wfDebug( __METHOD__ . ' dispatching ' . $this->func_name . "\n" );
 
@@ -98,20 +105,20 @@ class AjaxDispatcher {
 			} else {
 				$func = $this->func_name;
 			}
-			try {
-				$result = call_user_func_array($func, $this->args);
 
-				if ( $result === false || $result === NULL ) {
-					wfDebug( __METHOD__ . ' ERROR while dispatching ' 
-							. $this->func_name . "(" . var_export( $this->args, true ) . "): " 
+			try {
+				$result = call_user_func_array( $func, $this->args );
+
+				if ( $result === false || $result === null ) {
+					wfDebug( __METHOD__ . ' ERROR while dispatching '
+							. $this->func_name . "(" . var_export( $this->args, true ) . "): "
 							. "no data returned\n" );
 
 					wfHttpError( 500, 'Internal Error',
 						"{$this->func_name} returned no data" );
-				}
-				else {
+				} else {
 					if ( is_string( $result ) ) {
-						$result= new AjaxResponse( $result );
+						$result = new AjaxResponse( $result );
 					}
 
 					$result->sendHeaders();
@@ -119,13 +126,12 @@ class AjaxDispatcher {
 
 					wfDebug( __METHOD__ . ' dispatch complete for ' . $this->func_name . "\n" );
 				}
+			} catch ( Exception $e ) {
+				wfDebug( __METHOD__ . ' ERROR while dispatching '
+						. $this->func_name . "(" . var_export( $this->args, true ) . "): "
+						. get_class( $e ) . ": " . $e->getMessage() . "\n" );
 
-			} catch (Exception $e) {
-				wfDebug( __METHOD__ . ' ERROR while dispatching ' 
-						. $this->func_name . "(" . var_export( $this->args, true ) . "): " 
-						. get_class($e) . ": " . $e->getMessage() . "\n" );
-
-				if (!headers_sent()) {
+				if ( !headers_sent() ) {
 					wfHttpError( 500, 'Internal Error',
 						$e->getMessage() );
 				} else {
@@ -134,7 +140,7 @@ class AjaxDispatcher {
 			}
 		}
 
-		wfProfileOut( __METHOD__ );
 		$wgOut = null;
+		wfProfileOut( __METHOD__ );
 	}
 }
