@@ -1,13 +1,14 @@
 <?php
 /**
+ * External editors support
+ *
  * License: Public domain
  *
+ * @file
  * @author Erik Moeller <moeller@scireview.de>
  */
 
 /**
- *
- *
  * Support for external editors to modify both text and files
  * in external applications. It works as follows: MediaWiki
  * sends a meta-file with the MIME type 'application/x-external-editor'
@@ -17,7 +18,6 @@
  * and save the modified data back to the server.
  *
  */
-
 class ExternalEdit {
 
 	function __construct( $article, $mode ) {
@@ -53,6 +53,11 @@ class ExternalEdit {
 		}
 		$special=$wgLang->getNsText(NS_SPECIAL);
 		$control = <<<CONTROL
+; You're seeing this file because you're using Mediawiki's External Editor
+; feature. This is probably because you selected use external editor
+; in your preferences. To edit normally, either disable that preference
+; or go to the URL $url .
+; See http://www.mediawiki.org/wiki/Manual:External_editors for details.
 [Process]
 Type=$type
 Engine=MediaWiki
@@ -68,4 +73,3 @@ CONTROL;
 		echo $control;
 	}
 }
-
