@@ -1,68 +1,9 @@
 <?php
 /**
- * Return a rounded pixel equivalent for a labeled CSS/SVG length.
- * http://www.w3.org/TR/SVG11/coords.html#UnitIdentifiers
+ * Global functions related to images
  *
- * @param $length String: CSS/SVG length.
- * @return Integer: length in pixels
+ * @file
  */
-function wfScaleSVGUnit( $length ) {
-	static $unitLength = array(
-		'px' => 1.0,
-		'pt' => 1.25,
-		'pc' => 15.0,
-		'mm' => 3.543307,
-		'cm' => 35.43307,
-		'in' => 90.0,
-		''   => 1.0, // "User units" pixels by default
-		'%'  => 2.0, // Fake it!
-		);
-	$matches = array();
-	if( preg_match( '/^(\d+(?:\.\d+)?)(em|ex|px|pt|pc|cm|mm|in|%|)$/', $length, $matches ) ) {
-		$length = floatval( $matches[1] );
-		$unit = $matches[2];
-		return round( $length * $unitLength[$unit] );
-	} else {
-		// Assume pixels
-		return round( floatval( $length ) );
-	}
-}
-
-/**
- * Compatible with PHP getimagesize()
- * @todo support gzipped SVGZ
- * @todo check XML more carefully
- * @todo sensible defaults
- *
- * @param $filename String: full name of the file (passed to php fopen()).
- * @return array
- */
-function wfGetSVGsize( $filename ) {
-	$width = 256;
-	$height = 256;
-
-	// Read a chunk of the file
-	$f = fopen( $filename, "rt" );
-	if( !$f ) return false;
-	$chunk = fread( $f, 4096 );
-	fclose( $f );
-
-	// Uber-crappy hack! Run through a real XML parser.
-	$matches = array();
-	if( !preg_match( '/<svg\s*([^>]*)\s*>/s', $chunk, $matches ) ) {
-		return false;
-	}
-	$tag = $matches[1];
-	if( preg_match( '/\bwidth\s*=\s*("[^"]+"|\'[^\']+\')/s', $tag, $matches ) ) {
-		$width = wfScaleSVGUnit( trim( substr( $matches[1], 1, -1 ) ) );
-	}
-	if( preg_match( '/\bheight\s*=\s*("[^"]+"|\'[^\']+\')/s', $tag, $matches ) ) {
-		$height = wfScaleSVGUnit( trim( substr( $matches[1], 1, -1 ) ) );
-	}
-
-	return array( $width, $height, 'SVG',
-		"width=\"$width\" height=\"$height\"" );
-}
 
 /**
  * Determine if an image exists on the 'bad image list'.
@@ -73,14 +14,20 @@ function wfGetSVGsize( $filename ) {
  *    * Any subsequent links on the same line are considered to be exceptions,
  *      i.e. articles where the image may occur inline.
  *
- * @param string $name the image name to check
- * @param Title $contextTitle The page on which the image occurs, if known
+ * @param $name string the image name to check
+ * @param $contextTitle Title: the page on which the image occurs, if known
  * @return bool
  */
 function wfIsBadImage( $name, $contextTitle = false ) {
 	static $badImages = false;
 	wfProfileIn( __METHOD__ );
 
+	# Handle redirects
+	$redirectTitle = RepoGroup::singleton()->checkRedirect( Title::makeTitle( NS_FILE, $name ) );
+	if( $redirectTitle ) {
+		$name = $redirectTitle->getDbKey();
+	}
+
 	# Run the extension hook
 	$bad = false;
 	if( !wfRunHooks( 'BadImage', array( $name, &$bad ) ) ) {
@@ -122,7 +69,7 @@ function wfIsBadImage( $name, $contextTitle = false ) {
 			}
 		}
 	}
-	
+
 	$contextKey = $contextTitle ? $contextTitle->getPrefixedDBkey() : false;
 	$bad = isset( $badImages[$name] ) && !isset( $badImages[$name][$contextKey] );
 	wfProfileOut( __METHOD__ );
@@ -145,6 +92,3 @@ function wfFitBoxWidth( $boxWidth, $boxHeight, $maxHeight ) {
 	else
 		return $roundedUp;
 }
-
-
-
