@@ -4,7 +4,7 @@
  * Class representing a list of titles
  * The execute() method checks them all for existence and adds them to a LinkCache object
  *
- * @addtogroup Cache
+ * @ingroup Cache
  */
 class LinkBatch {
 	/**
@@ -12,13 +12,27 @@ class LinkBatch {
 	 */
 	var $data = array();
 
+	/**
+	 * For debugging which method is using this class.
+	 */
+	protected $caller;
+
 	function __construct( $arr = array() ) {
 		foreach( $arr as $item ) {
 			$this->addObj( $item );
 		}
 	}
 
-	function addObj( $title ) {
+	/**
+	 * Use ->setCaller( __METHOD__ ) to indicate which code is using this
+	 * class. Only used in debugging output.
+	 * @since 1.17
+	 */
+	public function setCaller( $caller ) {
+		$this->caller = $caller;
+	}
+
+	public function addObj( $title ) {
 		if ( is_object( $title ) ) {
 			$this->add( $title->getNamespace(), $title->getDBkey() );
 		} else {
@@ -26,7 +40,7 @@ class LinkBatch {
 		}
 	}
 
-	function add( $ns, $dbkey ) {
+	public function add( $ns, $dbkey ) {
 		if ( $ns < 0 ) {
 			return;
 		}
@@ -41,21 +55,21 @@ class LinkBatch {
 	 * Set the link list to a given 2-d array
 	 * First key is the namespace, second is the DB key, value arbitrary
 	 */
-	function setArray( $array ) {
+	public function setArray( $array ) {
 		$this->data = $array;
 	}
 
 	/**
 	 * Returns true if no pages have been added, false otherwise.
 	 */
-	function isEmpty() {
+	public function isEmpty() {
 		return ($this->getSize() == 0);
 	}
 
 	/**
 	 * Returns the size of the batch.
 	 */
-	function getSize() {
+	public function getSize() {
 		return count( $this->data );
 	}
 
@@ -63,8 +77,8 @@ class LinkBatch {
 	 * Do the query and add the results to the LinkCache object
 	 * Return an array mapping PDBK to ID
 	 */
-	 function execute() {
-	 	$linkCache =& LinkCache::singleton();
+	 public function execute() {
+	 	$linkCache = LinkCache::singleton();
 	 	return $this->executeInto( $linkCache );
 	 }
 
@@ -72,13 +86,22 @@ class LinkBatch {
 	 * Do the query and add the results to a given LinkCache object
 	 * Return an array mapping PDBK to ID
 	 */
-	function executeInto( &$cache ) {
-		$fname = 'LinkBatch::executeInto';
-		wfProfileIn( $fname );
-		// Do query
+	protected function executeInto( &$cache ) {
+		wfProfileIn( __METHOD__ );
 		$res = $this->doQuery();
+		$ids = $this->addResultToCache( $cache, $res );
+		wfProfileOut( __METHOD__ );
+		return $ids;
+	}
+
+	/**
+	 * Add a ResultWrapper containing IDs and titles to a LinkCache object.
+	 * As normal, titles will go into the static Title cache field.
+	 * This function *also* stores extra fields of the title used for link
+	 * parsing to avoid extra DB queries.
+	 */
+	public function addResultToCache( $cache, $res ) {
 		if ( !$res ) {
-			wfProfileOut( $fname );
 			return array();
 		}
 
@@ -86,13 +109,12 @@ class LinkBatch {
 
 		$ids = array();
 		$remaining = $this->data;
-		while ( $row = $res->fetchObject() ) {
+		foreach ( $res as $row ) {
 			$title = Title::makeTitle( $row->page_namespace, $row->page_title );
-			$cache->addGoodLinkObj( $row->page_id, $title );
+			$cache->addGoodLinkObj( $row->page_id, $title, $row->page_len, $row->page_is_redirect, $row->page_latest );
 			$ids[$title->getPrefixedDBkey()] = $row->page_id;
 			unset( $remaining[$row->page_namespace][$row->page_title] );
 		}
-		$res->free();
 
 		// The remaining links in $data are bad links, register them as such
 		foreach ( $remaining as $ns => $dbkeys ) {
@@ -102,88 +124,43 @@ class LinkBatch {
 				$ids[$title->getPrefixedDBkey()] = 0;
 			}
 		}
-		wfProfileOut( $fname );
 		return $ids;
 	}
 
 	/**
 	 * Perform the existence test query, return a ResultWrapper with page_id fields
 	 */
-	function doQuery() {
-		$fname = 'LinkBatch::doQuery';
-
+	public function doQuery() {
 		if ( $this->isEmpty() ) {
 			return false;
 		}
-		wfProfileIn( $fname );
+		wfProfileIn( __METHOD__ );
 
-		// Construct query
-		// This is very similar to Parser::replaceLinkHolders
+		// This is similar to LinkHolderArray::replaceInternal
 		$dbr = wfGetDB( DB_SLAVE );
-		$page = $dbr->tableName( 'page' );
-		$set = $this->constructSet( 'page', $dbr );
-		if ( $set === false ) {
-			wfProfileOut( $fname );
-			return false;
-		}
-		$sql = "SELECT page_id, page_namespace, page_title FROM $page WHERE $set";
+		$table = 'page';
+		$fields = array( 'page_id', 'page_namespace', 'page_title', 'page_len',
+			'page_is_redirect', 'page_latest' );
+		$conds = $this->constructSet( 'page', $dbr );
 
 		// Do query
-		$res = new ResultWrapper( $dbr,  $dbr->query( $sql, $fname ) );
-		wfProfileOut( $fname );
+		$caller = __METHOD__;
+		if ( strval( $this->caller ) !== '' ) {
+			$caller .= " (for {$this->caller})";
+		}
+		$res = $dbr->select( $table, $fields, $conds, $caller );
+		wfProfileOut( __METHOD__ );
 		return $res;
 	}
 
 	/**
 	 * Construct a WHERE clause which will match all the given titles.
-	 * Give the appropriate table's field name prefix ('page', 'pl', etc).
 	 *
-	 * @param $prefix String: ??
-	 * @return string
-	 * @public
+	 * @param $prefix String: the appropriate table's field name prefix ('page', 'pl', etc)
+	 * @param $db DatabaseBase object to use
+	 * @return mixed string with SQL where clause fragment, or false if no items.
 	 */
-	function constructSet( $prefix, &$db ) {
-		$first = true;
-		$firstTitle = true;
-		$sql = '';
-		foreach ( $this->data as $ns => $dbkeys ) {
-			if ( !count( $dbkeys ) ) {
-				continue;
-			}
-
-			if ( $first ) {
-				$first = false;
-			} else {
-				$sql .= ' OR ';
-			}
-			
-			if (count($dbkeys)==1) { // avoid multiple-reference syntax if simple equality can be used
-				$singleKey = array_keys($dbkeys);
-				$sql .= "({$prefix}_namespace=$ns AND {$prefix}_title=".
-					$db->addQuotes($singleKey[0]).
-					")";
-			} else {
-				$sql .= "({$prefix}_namespace=$ns AND {$prefix}_title IN (";
-				
-				$firstTitle = true;
-				foreach( $dbkeys as $dbkey => $unused ) {
-					if ( $firstTitle ) {
-						$firstTitle = false;
-					} else {
-						$sql .= ',';
-					}
-					$sql .= $db->addQuotes( $dbkey );
-				}
-				$sql .= '))';
-			}
-		}
-		if ( $first && $firstTitle ) {
-			# No titles added
-			return false;
-		} else {
-			return $sql;
-		}
+	public function constructSet( $prefix, $db ) {
+		return $db->makeWhereFrom2d( $this->data, "{$prefix}_namespace", "{$prefix}_title" );
 	}
 }
-
-
