@@ -1,7 +1,7 @@
 <?php
 /**
  * See docs/deferred.txt
- * 
+ *
  * @todo document (e.g. one-sentence top-level class description).
  */
 class LinksUpdate {
@@ -17,6 +17,7 @@ class LinksUpdate {
 		$mExternals,     //!< URLs of external links, array key only
 		$mCategories,    //!< Map of category names to sort keys
 		$mInterlangs,    //!< Map of language codes to titles
+		$mProperties,    //!< Map of arbitrary name to value
 		$mDb,            //!< Database connection reference
 		$mOptions,       //!< SELECT options to be used (array)
 		$mRecursive;     //!< Whether to queue jobs for recursive updates
@@ -25,11 +26,11 @@ class LinksUpdate {
 	/**
 	 * Constructor
 	 *
-	 * @param Title $title Title of the page we're updating
-	 * @param ParserOutput $parserOutput Output from a full parse of this page
-	 * @param bool $recursive Queue jobs for recursive updates?
+	 * @param $title Title of the page we're updating
+	 * @param $parserOutput ParserOutput: output from a full parse of this page
+	 * @param $recursive Boolean: queue jobs for recursive updates?
 	 */
-	function LinksUpdate( $title, $parserOutput, $recursive = true ) {
+	function __construct( $title, $parserOutput, $recursive = true ) {
 		global $wgAntiLockFlags;
 
 		if ( $wgAntiLockFlags & ALF_NO_LINK_LOCK ) {
@@ -46,15 +47,18 @@ class LinksUpdate {
 		$this->mTitle = $title;
 		$this->mId = $title->getArticleID();
 
+		$this->mParserOutput = $parserOutput;
 		$this->mLinks = $parserOutput->getLinks();
 		$this->mImages = $parserOutput->getImages();
 		$this->mTemplates = $parserOutput->getTemplates();
 		$this->mExternals = $parserOutput->getExternalLinks();
 		$this->mCategories = $parserOutput->getCategories();
+		$this->mProperties = $parserOutput->getProperties();
+		$this->mInterwikis = $parserOutput->getInterwikiLinks();
 
 		# Convert the format of the interlanguage links
-		# I didn't want to change it in the ParserOutput, because that array is passed all 
-		# the way back to the skin, so either a skin API break would be required, or an 
+		# I didn't want to change it in the ParserOutput, because that array is passed all
+		# the way back to the skin, so either a skin API break would be required, or an
 		# inefficient back-conversion.
 		$ill = $parserOutput->getLanguageLinks();
 		$this->mInterlangs = array();
@@ -63,17 +67,28 @@ class LinksUpdate {
 			$this->mInterlangs[$key] = $title;
 		}
 
+		foreach ( $this->mCategories as $cat => &$sortkey ) {
+			# If the sortkey is longer then 255 bytes,
+			# it truncated by DB, and then doesn't get
+			# matched when comparing existing vs current
+			# categories, causing bug 25254.
+			# Also. substr behaves weird when given "".
+			if ( $sortkey !== '' ) {
+				$sortkey = substr( $sortkey, 0, 255 );
+			}
+		}
+
 		$this->mRecursive = $recursive;
-		
+
 		wfRunHooks( 'LinksUpdateConstructed', array( &$this ) );
 	}
 
 	/**
 	 * Update link tables with outgoing links from an updated article
 	 */
-	function doUpdate() {
+	public function doUpdate() {
 		global $wgUseDumbLinkUpdate;
-		
+
 		wfRunHooks( 'LinksUpdate', array( &$this ) );
 		if ( $wgUseDumbLinkUpdate ) {
 			$this->doDumbUpdate();
@@ -81,13 +96,11 @@ class LinksUpdate {
 			$this->doIncrementalUpdate();
 		}
 		wfRunHooks( 'LinksUpdateComplete', array( &$this ) );
-
 	}
 
-	function doIncrementalUpdate() {
-		$fname = 'LinksUpdate::doIncrementalUpdate';
-		wfProfileIn( $fname );
-		
+	protected function doIncrementalUpdate() {
+		wfProfileIn( __METHOD__ );
+
 		# Page links
 		$existing = $this->getExistingLinks();
 		$this->incrTableUpdate( 'pagelinks', 'pl', $this->getLinkDeletions( $existing ),
@@ -95,11 +108,12 @@ class LinksUpdate {
 
 		# Image links
 		$existing = $this->getExistingImages();
-		$this->incrTableUpdate( 'imagelinks', 'il', $this->getImageDeletions( $existing ),
-			$this->getImageInsertions( $existing ) );
+
+		$imageDeletes = $this->getImageDeletions( $existing );
+		$this->incrTableUpdate( 'imagelinks', 'il', $imageDeletes, $this->getImageInsertions( $existing ) );
 
 		# Invalidate all image description pages which had links added or removed
-		$imageUpdates = array_diff_key( $existing, $this->mImages ) + array_diff_key( $this->mImages, $existing );
+		$imageUpdates = $imageDeletes + array_diff_key( $this->mImages, $existing );
 		$this->invalidateImageDescriptions( $imageUpdates );
 
 		# External links
@@ -112,6 +126,11 @@ class LinksUpdate {
 		$this->incrTableUpdate( 'langlinks', 'll', $this->getInterlangDeletions( $existing ),
 			$this->getInterlangInsertions( $existing ) );
 
+		# Inline interwiki links
+		$existing = $this->getExistingInterwikis();
+		$this->incrTableUpdate( 'iwlinks', 'iwl', $this->getInterwikiDeletions( $existing ),
+			$this->getInterwikiInsertions( $existing ) );
+
 		# Template links
 		$existing = $this->getExistingTemplates();
 		$this->incrTableUpdate( 'templatelinks', 'tl', $this->getTemplateDeletions( $existing ),
@@ -119,20 +138,35 @@ class LinksUpdate {
 
 		# Category links
 		$existing = $this->getExistingCategories();
-		$this->incrTableUpdate( 'categorylinks', 'cl', $this->getCategoryDeletions( $existing ),
-			$this->getCategoryInsertions( $existing ) );
+
+		$categoryDeletes = $this->getCategoryDeletions( $existing );
+
+		$this->incrTableUpdate( 'categorylinks', 'cl', $categoryDeletes, $this->getCategoryInsertions( $existing ) );
 
 		# Invalidate all categories which were added, deleted or changed (set symmetric difference)
-		$categoryUpdates = array_diff_assoc( $existing, $this->mCategories ) + array_diff_assoc( $this->mCategories, $existing );
+		$categoryInserts = array_diff_assoc( $this->mCategories, $existing );
+		$categoryUpdates = $categoryInserts + $categoryDeletes;
 		$this->invalidateCategories( $categoryUpdates );
+		$this->updateCategoryCounts( $categoryInserts, $categoryDeletes );
+
+		# Page properties
+		$existing = $this->getExistingProperties();
+
+		$propertiesDeletes = $this->getPropertyDeletions( $existing );
+
+		$this->incrTableUpdate( 'page_props', 'pp', $propertiesDeletes, $this->getPropertyInsertions( $existing ) );
+
+		# Invalidate the necessary pages
+		$changed = $propertiesDeletes + array_diff_assoc( $this->mProperties, $existing );
+		$this->invalidateProperties( $changed );
 
 		# Refresh links of all pages including this page
 		# This will be in a separate transaction
 		if ( $this->mRecursive ) {
 			$this->queueRecursiveJobs();
 		}
-		
-		wfProfileOut( $fname );
+
+		wfProfileOut( __METHOD__ );
 	}
 
 	/**
@@ -140,13 +174,14 @@ class LinksUpdate {
 	 * May be slower or faster depending on level of lock contention and write speed of DB
 	 * Also useful where link table corruption needs to be repaired, e.g. in refreshLinks.php
 	 */
-	function doDumbUpdate() {
-		$fname = 'LinksUpdate::doDumbUpdate';
-		wfProfileIn( $fname );
+	protected function doDumbUpdate() {
+		wfProfileIn( __METHOD__ );
 
 		# Refresh category pages and image description pages
 		$existing = $this->getExistingCategories();
-		$categoryUpdates = array_diff_assoc( $existing, $this->mCategories ) + array_diff_assoc( $this->mCategories, $existing );
+		$categoryInserts = array_diff_assoc( $this->mCategories, $existing );
+		$categoryDeletes = array_diff_assoc( $existing, $this->mCategories );
+		$categoryUpdates = $categoryInserts + $categoryDeletes;
 		$existing = $this->getExistingImages();
 		$imageUpdates = array_diff_key( $existing, $this->mImages ) + array_diff_key( $this->mImages, $existing );
 
@@ -155,10 +190,14 @@ class LinksUpdate {
 		$this->dumbTableUpdate( 'categorylinks', $this->getCategoryInsertions(), 'cl_from' );
 		$this->dumbTableUpdate( 'templatelinks', $this->getTemplateInsertions(), 'tl_from' );
 		$this->dumbTableUpdate( 'externallinks', $this->getExternalInsertions(), 'el_from' );
-		$this->dumbTableUpdate( 'langlinks',     $this->getInterlangInsertions(), 'll_from' );
+		$this->dumbTableUpdate( 'langlinks',     $this->getInterlangInsertions(),'ll_from' );
+		$this->dumbTableUpdate( 'iwlinks',       $this->getInterwikiInsertions(),'iwl_from' );
+		$this->dumbTableUpdate( 'page_props',    $this->getPropertyInsertions(), 'pp_page' );
 
-		# Update the cache of all the category pages and image description pages which were changed
+		# Update the cache of all the category pages and image description
+		# pages which were changed, and fix the category table count
 		$this->invalidateCategories( $categoryUpdates );
+		$this->updateCategoryCounts( $categoryInserts, $categoryDeletes );
 		$this->invalidateImageDescriptions( $imageUpdates );
 
 		# Refresh links of all pages including this page
@@ -167,54 +206,44 @@ class LinksUpdate {
 			$this->queueRecursiveJobs();
 		}
 
-		wfProfileOut( $fname );
+		wfProfileOut( __METHOD__ );
 	}
 
 	function queueRecursiveJobs() {
+		global $wgUpdateRowsPerJob;
 		wfProfileIn( __METHOD__ );
-		
-		$batchSize = 100;
-		$dbr = wfGetDB( DB_SLAVE );
-		$res = $dbr->select( array( 'templatelinks', 'page' ), 
-			array( 'page_namespace', 'page_title' ),
-			array( 
-				'page_id=tl_from', 
-				'tl_namespace' => $this->mTitle->getNamespace(),
-				'tl_title' => $this->mTitle->getDBkey()
-			), __METHOD__
-		);
 
-		$done = false;
-		while ( !$done ) {
-			$jobs = array();
-			for ( $i = 0; $i < $batchSize; $i++ ) {
-				$row = $dbr->fetchObject( $res );
-				if ( !$row ) {
-					$done = true;
-					break;
-				}
-				$title = Title::makeTitle( $row->page_namespace, $row->page_title );
-				$jobs[] = new RefreshLinksJob( $title, '' );
-			}
-			Job::batchInsert( $jobs );
+		$cache = $this->mTitle->getBacklinkCache();
+		$batches = $cache->partition( 'templatelinks', $wgUpdateRowsPerJob );
+		if ( !$batches ) {
+			wfProfileOut( __METHOD__ );
+			return;
 		}
-		$dbr->freeResult( $res );
+		$jobs = array();
+		foreach ( $batches as $batch ) {
+			list( $start, $end ) = $batch;
+			$params = array(
+				'start' => $start,
+				'end' => $end,
+			);
+			$jobs[] = new RefreshLinksJob2( $this->mTitle, $params );
+		}
+		Job::batchInsert( $jobs );
+
 		wfProfileOut( __METHOD__ );
 	}
-	
+
 	/**
 	 * Invalidate the cache of a list of pages from a single namespace
 	 *
-	 * @param integer $namespace
-	 * @param array $dbkeys
+	 * @param $namespace Integer
+	 * @param $dbkeys Array
 	 */
 	function invalidatePages( $namespace, $dbkeys ) {
-		$fname = 'LinksUpdate::invalidatePages';
-		
 		if ( !count( $dbkeys ) ) {
 			return;
 		}
-		
+
 		/**
 		 * Determine which pages need to be updated
 		 * This is necessary to prevent the job queue from smashing the DB with
@@ -222,30 +251,30 @@ class LinksUpdate {
 		 */
 		$now = $this->mDb->timestamp();
 		$ids = array();
-		$res = $this->mDb->select( 'page', array( 'page_id' ), 
-			array( 
+		$res = $this->mDb->select( 'page', array( 'page_id' ),
+			array(
 				'page_namespace' => $namespace,
 				'page_title IN (' . $this->mDb->makeList( $dbkeys ) . ')',
 				'page_touched < ' . $this->mDb->addQuotes( $now )
-			), $fname
+			), __METHOD__
 		);
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			$ids[] = $row->page_id;
 		}
 		if ( !count( $ids ) ) {
 			return;
 		}
-		
+
 		/**
 		 * Do the update
-		 * We still need the page_touched condition, in case the row has changed since 
+		 * We still need the page_touched condition, in case the row has changed since
 		 * the non-locking select above.
 		 */
-		$this->mDb->update( 'page', array( 'page_touched' => $now ), 
-			array( 
+		$this->mDb->update( 'page', array( 'page_touched' => $now ),
+			array(
 				'page_id IN (' . $this->mDb->makeList( $ids ) . ')',
 				'page_touched < ' . $this->mDb->addQuotes( $now )
-			), $fname
+			), __METHOD__
 		);
 	}
 
@@ -253,42 +282,50 @@ class LinksUpdate {
 		$this->invalidatePages( NS_CATEGORY, array_keys( $cats ) );
 	}
 
+	/**
+	 * Update all the appropriate counts in the category table.
+	 * @param $added associative array of category name => sort key
+	 * @param $deleted associative array of category name => sort key
+	 */
+	function updateCategoryCounts( $added, $deleted ) {
+		$a = new Article($this->mTitle);
+		$a->updateCategoryCounts(
+			array_keys( $added ), array_keys( $deleted )
+		);
+	}
+
 	function invalidateImageDescriptions( $images ) {
-		$this->invalidatePages( NS_IMAGE, array_keys( $images ) );
+		$this->invalidatePages( NS_FILE, array_keys( $images ) );
 	}
 
 	function dumbTableUpdate( $table, $insertions, $fromField ) {
-		$fname = 'LinksUpdate::dumbTableUpdate';
-		$this->mDb->delete( $table, array( $fromField => $this->mId ), $fname );
+		$this->mDb->delete( $table, array( $fromField => $this->mId ), __METHOD__ );
 		if ( count( $insertions ) ) {
-			# The link array was constructed without FOR UPDATE, so there may be collisions
-			# This may cause minor link table inconsistencies, which is better than
-			# crippling the site with lock contention.
-			$this->mDb->insert( $table, $insertions, $fname, array( 'IGNORE' ) );
+			# The link array was constructed without FOR UPDATE, so there may
+			# be collisions.  This may cause minor link table inconsistencies,
+			# which is better than crippling the site with lock contention.
+			$this->mDb->insert( $table, $insertions, __METHOD__, array( 'IGNORE' ) );
 		}
 	}
 
-	/**
-	 * Make a WHERE clause from a 2-d NS/dbkey array
-	 *
-	 * @param array $arr 2-d array indexed by namespace and DB key
-	 * @param string $prefix Field name prefix, without the underscore
-	 */
-	function makeWhereFrom2d( &$arr, $prefix ) {
-		$lb = new LinkBatch;
-		$lb->setArray( $arr );
-		return $lb->constructSet( $prefix, $this->mDb );
-	}
-
 	/**
 	 * Update a table by doing a delete query then an insert query
 	 * @private
 	 */
 	function incrTableUpdate( $table, $prefix, $deletions, $insertions ) {
-		$fname = 'LinksUpdate::incrTableUpdate';
-		$where = array( "{$prefix}_from" => $this->mId );
-		if ( $table == 'pagelinks' || $table == 'templatelinks' ) {
-			$clause = $this->makeWhereFrom2d( $deletions, $prefix );
+		if ( $table == 'page_props' ) {
+			$fromField = 'pp_page';
+		} else {
+			$fromField = "{$prefix}_from";
+		}
+		$where = array( $fromField => $this->mId );
+		if ( $table == 'pagelinks' || $table == 'templatelinks' || $table == 'iwlinks' ) {
+			if ( $table == 'iwlinks' ) {
+				$baseKey = 'iwl_prefix';
+			} else {
+				$baseKey = "{$prefix}_namespace";
+			}
+			$clause = $this->mDb->makeWhereFrom2d( $deletions, $baseKey, "{$prefix}_title" );
 			if ( $clause ) {
 				$where[] = $clause;
 			} else {
@@ -297,6 +334,8 @@ class LinksUpdate {
 		} else {
 			if ( $table == 'langlinks' ) {
 				$toField = 'll_lang';
+			} elseif ( $table == 'page_props' ) {
+				$toField = 'pp_propname';
 			} else {
 				$toField = $prefix . '_to';
 			}
@@ -307,10 +346,10 @@ class LinksUpdate {
 			}
 		}
 		if ( $where ) {
-			$this->mDb->delete( $table, $where, $fname );
+			$this->mDb->delete( $table, $where, __METHOD__ );
 		}
 		if ( count( $insertions ) ) {
-			$this->mDb->insert( $table, $insertions, $fname, 'IGNORE' );
+			$this->mDb->insert( $table, $insertions, __METHOD__, 'IGNORE' );
 		}
 	}
 
@@ -323,8 +362,6 @@ class LinksUpdate {
 	function getLinkInsertions( $existing = array() ) {
 		$arr = array();
 		foreach( $this->mLinks as $ns => $dbkeys ) {
-			# array_diff_key() was introduced in PHP 5.1, there is a compatibility function
-			# in GlobalFunctions.php
 			$diffs = isset( $existing[$ns] ) ? array_diff_key( $dbkeys, $existing[$ns] ) : $dbkeys;
 			foreach ( $diffs as $dbk => $id ) {
 				$arr[] = array(
@@ -392,19 +429,42 @@ class LinksUpdate {
 
 	/**
 	 * Get an array of category insertions
-	 * @param array $existing Array mapping existing category names to sort keys. If both
+	 *
+	 * @param $existing Array mapping existing category names to sort keys. If both
 	 * match a link in $this, the link will be omitted from the output
 	 * @private
 	 */
 	function getCategoryInsertions( $existing = array() ) {
+		global $wgContLang, $wgCategoryCollation;
 		$diffs = array_diff_assoc( $this->mCategories, $existing );
 		$arr = array();
-		foreach ( $diffs as $name => $sortkey ) {
+		foreach ( $diffs as $name => $prefix ) {
+			$nt = Title::makeTitleSafe( NS_CATEGORY, $name );
+			$wgContLang->findVariantLink( $name, $nt, true );
+
+			if ( $this->mTitle->getNamespace() == NS_CATEGORY ) {
+				$type = 'subcat';
+			} elseif ( $this->mTitle->getNamespace() == NS_FILE ) {
+				$type = 'file';
+			} else {
+				$type = 'page';
+			}
+
+			# Treat custom sortkeys as a prefix, so that if multiple
+			# things are forced to sort as '*' or something, they'll
+			# sort properly in the category rather than in page_id
+			# order or such.
+			$sortkey = Collation::singleton()->getSortKey(
+				$this->mTitle->getCategorySortkey( $prefix ) );
+
 			$arr[] = array(
 				'cl_from'    => $this->mId,
 				'cl_to'      => $name,
 				'cl_sortkey' => $sortkey,
-				'cl_timestamp' => $this->mDb->timestamp()
+				'cl_timestamp' => $this->mDb->timestamp(),
+				'cl_sortkey_prefix' => $prefix,
+				'cl_collation' => $wgCategoryCollation,
+				'cl_type' => $type,
 			);
 		}
 		return $arr;
@@ -412,7 +472,8 @@ class LinksUpdate {
 
 	/**
 	 * Get an array of interlanguage link insertions
-	 * @param array $existing Array mapping existing language codes to titles	 
+	 *
+	 * @param $existing Array mapping existing language codes to titles
 	 * @private
 	 */
 	function getInterlangInsertions( $existing = array() ) {
@@ -428,6 +489,42 @@ class LinksUpdate {
 	    return $arr;
 	}
 
+	/**
+	 * Get an array of page property insertions
+	 */
+	function getPropertyInsertions( $existing = array() ) {
+		$diffs = array_diff_assoc( $this->mProperties, $existing );
+		$arr = array();
+		foreach ( $diffs as $name => $value ) {
+			$arr[] = array(
+				'pp_page'      => $this->mId,
+				'pp_propname'  => $name,
+				'pp_value'     => $value,
+			);
+		}
+		return $arr;
+	}
+
+	/**
+	 * Get an array of interwiki insertions for passing to the DB
+	 * Skips the titles specified by the 2-D array $existing
+	 * @private
+	 */
+	function getInterwikiInsertions( $existing = array() ) {
+		$arr = array();
+		foreach( $this->mInterwikis as $prefix => $dbkeys ) {
+			$diffs = isset( $existing[$prefix] ) ? array_diff_key( $dbkeys, $existing[$prefix] ) : $dbkeys;
+			foreach ( $diffs as $dbk => $id ) {
+				$arr[] = array(
+					'iwl_from'   => $this->mId,
+					'iwl_prefix' => $prefix,
+					'iwl_title'  => $dbk
+				);
+			}
+		}
+		return $arr;
+	}
+
 	/**
 	 * Given an array of existing links, returns those links which are not in $this
 	 * and thus should be deleted.
@@ -471,7 +568,7 @@ class LinksUpdate {
 		return array_diff_key( $existing, $this->mImages );
 	}
 
-	/** 
+	/**
 	 * Given an array of existing external links, returns those links which are not
 	 * in $this and thus should be deleted.
 	 * @private
@@ -489,7 +586,7 @@ class LinksUpdate {
 		return array_diff_assoc( $existing, $this->mCategories );
 	}
 
-	/** 
+	/**
 	 * Given an array of existing interlanguage links, returns those links which are not
 	 * in $this and thus should be deleted.
 	 * @private
@@ -498,22 +595,45 @@ class LinksUpdate {
 	    return array_diff_assoc( $existing, $this->mInterlangs );
 	}
 
+	/**
+	 * Get array of properties which should be deleted.
+	 * @private
+	 */
+	function getPropertyDeletions( $existing ) {
+		return array_diff_assoc( $existing, $this->mProperties );
+	}
+
+	/**
+	 * Given an array of existing interwiki links, returns those links which are not in $this
+	 * and thus should be deleted.
+	 * @private
+	 */
+	function getInterwikiDeletions( $existing ) {
+		$del = array();
+		foreach ( $existing as $prefix => $dbkeys ) {
+			if ( isset( $this->mInterwikis[$prefix] ) ) {
+				$del[$prefix] = array_diff_key( $existing[$prefix], $this->mInterwikis[$prefix] );
+			} else {
+				$del[$prefix] = $existing[$prefix];
+			}
+		}
+		return $del;
+	}
+
 	/**
 	 * Get an array of existing links, as a 2-D array
 	 * @private
 	 */
 	function getExistingLinks() {
-		$fname = 'LinksUpdate::getExistingLinks';
 		$res = $this->mDb->select( 'pagelinks', array( 'pl_namespace', 'pl_title' ),
-			array( 'pl_from' => $this->mId ), $fname, $this->mOptions );
+			array( 'pl_from' => $this->mId ), __METHOD__, $this->mOptions );
 		$arr = array();
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			if ( !isset( $arr[$row->pl_namespace] ) ) {
 				$arr[$row->pl_namespace] = array();
 			}
 			$arr[$row->pl_namespace][$row->pl_title] = 1;
 		}
-		$this->mDb->freeResult( $res );
 		return $arr;
 	}
 
@@ -522,17 +642,15 @@ class LinksUpdate {
 	 * @private
 	 */
 	function getExistingTemplates() {
-		$fname = 'LinksUpdate::getExistingTemplates';
 		$res = $this->mDb->select( 'templatelinks', array( 'tl_namespace', 'tl_title' ),
-			array( 'tl_from' => $this->mId ), $fname, $this->mOptions );
+			array( 'tl_from' => $this->mId ), __METHOD__, $this->mOptions );
 		$arr = array();
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			if ( !isset( $arr[$row->tl_namespace] ) ) {
 				$arr[$row->tl_namespace] = array();
 			}
 			$arr[$row->tl_namespace][$row->tl_title] = 1;
 		}
-		$this->mDb->freeResult( $res );
 		return $arr;
 	}
 
@@ -541,14 +659,12 @@ class LinksUpdate {
 	 * @private
 	 */
 	function getExistingImages() {
-		$fname = 'LinksUpdate::getExistingImages';
 		$res = $this->mDb->select( 'imagelinks', array( 'il_to' ),
-			array( 'il_from' => $this->mId ), $fname, $this->mOptions );
+			array( 'il_from' => $this->mId ), __METHOD__, $this->mOptions );
 		$arr = array();
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			$arr[$row->il_to] = 1;
 		}
-		$this->mDb->freeResult( $res );
 		return $arr;
 	}
 
@@ -557,14 +673,12 @@ class LinksUpdate {
 	 * @private
 	 */
 	function getExistingExternals() {
-		$fname = 'LinksUpdate::getExistingExternals';
 		$res = $this->mDb->select( 'externallinks', array( 'el_to' ),
-			array( 'el_from' => $this->mId ), $fname, $this->mOptions );
+			array( 'el_from' => $this->mId ), __METHOD__, $this->mOptions );
 		$arr = array();
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			$arr[$row->el_to] = 1;
 		}
-		$this->mDb->freeResult( $res );
 		return $arr;
 	}
 
@@ -573,38 +687,93 @@ class LinksUpdate {
 	 * @private
 	 */
 	function getExistingCategories() {
-		$fname = 'LinksUpdate::getExistingCategories';
-		$res = $this->mDb->select( 'categorylinks', array( 'cl_to', 'cl_sortkey' ),
-			array( 'cl_from' => $this->mId ), $fname, $this->mOptions );
+		$res = $this->mDb->select( 'categorylinks', array( 'cl_to', 'cl_sortkey_prefix' ),
+			array( 'cl_from' => $this->mId ), __METHOD__, $this->mOptions );
 		$arr = array();
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
-			$arr[$row->cl_to] = $row->cl_sortkey;
+		foreach ( $res as $row ) {
+			$arr[$row->cl_to] = $row->cl_sortkey_prefix;
 		}
-		$this->mDb->freeResult( $res );
 		return $arr;
 	}
 
 	/**
-	 * Get an array of existing interlanguage links, with the language code in the key and the 
+	 * Get an array of existing interlanguage links, with the language code in the key and the
 	 * title in the value.
 	 * @private
 	 */
 	function getExistingInterlangs() {
-		$fname = 'LinksUpdate::getExistingInterlangs';
-		$res = $this->mDb->select( 'langlinks', array( 'll_lang', 'll_title' ), 
-			array( 'll_from' => $this->mId ), $fname, $this->mOptions );
+		$res = $this->mDb->select( 'langlinks', array( 'll_lang', 'll_title' ),
+			array( 'll_from' => $this->mId ), __METHOD__, $this->mOptions );
 		$arr = array();
-		while ( $row = $this->mDb->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			$arr[$row->ll_lang] = $row->ll_title;
 		}
 		return $arr;
 	}
-	
+
+	/**
+	 * Get an array of existing inline interwiki links, as a 2-D array
+	 * @return array (prefix => array(dbkey => 1))
+	 */
+	protected function getExistingInterwikis() {
+		$res = $this->mDb->select( 'iwlinks', array( 'iwl_prefix', 'iwl_title' ),
+			array( 'iwl_from' => $this->mId ), __METHOD__, $this->mOptions );
+		$arr = array();
+		foreach ( $res as $row ) {
+			if ( !isset( $arr[$row->iwl_prefix] ) ) {
+				$arr[$row->iwl_prefix] = array();
+			}
+			$arr[$row->iwl_prefix][$row->iwl_title] = 1;
+		}
+		return $arr;
+	}
+
+	/**
+	 * Get an array of existing categories, with the name in the key and sort key in the value.
+	 * @private
+	 */
+	function getExistingProperties() {
+		$res = $this->mDb->select( 'page_props', array( 'pp_propname', 'pp_value' ),
+			array( 'pp_page' => $this->mId ), __METHOD__, $this->mOptions );
+		$arr = array();
+		foreach ( $res as $row ) {
+			$arr[$row->pp_propname] = $row->pp_value;
+		}
+		return $arr;
+	}
+
+
 	/**
 	 * Return the title object of the page being updated
-	 */	
+	 */
 	function getTitle() {
 		return $this->mTitle;
 	}
-}
+	
+	/**
+	 * Return the list of images used as generated by the parser
+	 */
+	public function getImages() {
+		return $this->mImages;
+	}
 
+	/**
+	 * Invalidate any necessary link lists related to page property changes
+	 */
+	function invalidateProperties( $changed ) {
+		global $wgPagePropLinkInvalidations;
+
+		foreach ( $changed as $name => $value ) {
+			if ( isset( $wgPagePropLinkInvalidations[$name] ) ) {
+				$inv = $wgPagePropLinkInvalidations[$name];
+				if ( !is_array( $inv ) ) {
+					$inv = array( $inv );
+				}
+				foreach ( $inv as $table ) {
+					$update = new HTMLCacheUpdate( $this->mTitle, $table );
+					$update->doUpdate();
+				}
+			}
+		}
+	}
+}
