@@ -18,27 +18,38 @@ define( 'MSG_CACHE_VERSION', 1 );
  * @ingroup Cache
  */
 class MessageCache {
-	// Holds loaded messages that are defined in MediaWiki namespace.
-	var $mCache;
+	/**
+	 * Process local cache of loaded messages that are defined in
+	 * MediaWiki namespace. First array level is a language code,
+	 * second level is message key and the values are either message
+	 * content prefixed with space, or !NONEXISTENT for negative
+	 * caching.
+	 */
+	protected $mCache;
 
-	var $mUseCache, $mDisable, $mExpiry;
-	var $mKeys, $mParserOptions, $mParser;
-	var $mExtensionMessages = array();
-	var $mInitialised = false;
-	var $mAllMessagesLoaded = array(); // Extension messages
+	// Should  mean that database cannot be used, but check
+	protected $mDisable;
 
-	// Variable for tracking which variables are loaded
-	var $mLoadedLanguages = array();
+	/// Lifetime for cache, used by object caching
+	protected $mExpiry;
 
-	function __construct( &$memCached, $useDB, $expiry, /*ignored*/ $memcPrefix ) {
-		$this->mUseCache = !is_null( $memCached );
-		$this->mMemc = &$memCached;
+	/**
+	 * Message cache has it's own parser which it uses to transform
+	 * messages.
+	 */
+	protected $mParserOptions, $mParser;
+
+	/// Variable for tracking which variables are already loaded
+	protected $mLoadedLanguages = array();
+
+	function __construct( $memCached, $useDB, $expiry ) {
+		if ( !$memCached ) {
+			$memCached = wfGetCache( CACHE_NONE );
+		}
+
+		$this->mMemc = $memCached;
 		$this->mDisable = !$useDB;
 		$this->mExpiry = $expiry;
-		$this->mDisableTransform = false;
-		$this->mKeys = false; # initialised on demand
-		$this->mInitialised = true;
-		$this->mParser = null;
 	}
 
 
@@ -62,9 +73,9 @@ class MessageCache {
 	 * @return false on failure.
 	 */
 	function loadFromLocal( $hash, $code ) {
-		global $wgLocalMessageCache, $wgLocalMessageCacheSerialized;
+		global $wgCacheDirectory, $wgLocalMessageCacheSerialized;
 
-		$filename = "$wgLocalMessageCache/messages-" . wfWikiID() . "-$code";
+		$filename = "$wgCacheDirectory/messages-" . wfWikiID() . "-$code";
 
 		# Check file existence
 		wfSuppressWarnings();
@@ -106,10 +117,10 @@ class MessageCache {
 	 * Save the cache to a local file.
 	 */
 	function saveToLocal( $serialized, $hash, $code ) {
-		global $wgLocalMessageCache;
+		global $wgCacheDirectory;
 
-		$filename = "$wgLocalMessageCache/messages-" . wfWikiID() . "-$code";
-		wfMkdirParents( $wgLocalMessageCache ); // might fail
+		$filename = "$wgCacheDirectory/messages-" . wfWikiID() . "-$code";
+		wfMkdirParents( $wgCacheDirectory ); // might fail
 
 		wfSuppressWarnings();
 		$file = fopen( $filename, 'w' );
@@ -126,11 +137,11 @@ class MessageCache {
 	}
 
 	function saveToScript( $array, $hash, $code ) {
-		global $wgLocalMessageCache;
+		global $wgCacheDirectory;
 
-		$filename = "$wgLocalMessageCache/messages-" . wfWikiID() . "-$code";
+		$filename = "$wgCacheDirectory/messages-" . wfWikiID() . "-$code";
 		$tempFilename = $filename . '.tmp';
-  		wfMkdirParents( $wgLocalMessageCache ); // might fail
+  		wfMkdirParents( $wgCacheDirectory ); // might fail
 
 		wfSuppressWarnings();
 		$file = fopen( $tempFilename, 'w');
@@ -143,9 +154,9 @@ class MessageCache {
 
 		fwrite($file,"<?php\n//$hash\n\n \$this->mCache = array(");
 
-		foreach ($array as $key => $message) {
+		foreach ( $array as $key => $message ) {
 			$key = $this->escapeForScript($key);
-			$messages = $this->escapeForScript($message);
+			$message = $this->escapeForScript($message);
 			fwrite($file, "'$key' => '$message',\n");
 		}
 
@@ -174,14 +185,14 @@ class MessageCache {
 
 	/**
 	 * Loads messages from caches or from database in this order:
-	 * (1) local message cache (if $wgLocalMessageCache is enabled)
+	 * (1) local message cache (if $wgUseLocalMessageCache is enabled)
 	 * (2) memcached
 	 * (3) from the database.
 	 *
 	 * When succesfully loading from (2) or (3), all higher level caches are
 	 * updated for the newest version.
 	 *
-	 * Nothing is loaded if  member variable mDisabled is true, either manually
+	 * Nothing is loaded if member variable mDisable is true, either manually
 	 * set by calling code or if message loading fails (is this possible?).
 	 *
 	 * Returns true if cache is already populated or it was succesfully populated,
@@ -191,11 +202,7 @@ class MessageCache {
 	 * @param $code String: language to which load messages
 	 */
 	function load( $code = false ) {
-		global $wgLocalMessageCache;
-
-		if ( !$this->mUseCache ) {
-			return true;
-		}
+		global $wgUseLocalMessageCache;
 
 		if( !is_string( $code ) ) {
 			# This isn't really nice, so at least make a note about it and try to
@@ -227,7 +234,7 @@ class MessageCache {
 		# (1) local cache
 		# Hash of the contents is stored in memcache, to detect if local cache goes
 		# out of date (due to update in other thread?)
-		if ( $wgLocalMessageCache !== false ) {
+		if ( $wgUseLocalMessageCache ) {
 			wfProfileIn( __METHOD__ . '-fromlocal' );
 
 			$hash = $this->mMemc->get( wfMemcKey( 'messages', $code, 'hash' ) );
@@ -260,7 +267,7 @@ class MessageCache {
 
 			$this->lock($cacheKey);
 
-			# Limit the concurrency of loadFromDB to a single process 
+			# Limit the concurrency of loadFromDB to a single process
 			# This prevents the site from going down when the cache expires
 			$statusKey = wfMemcKey( 'messages', $code, 'status' );
 			$success = $this->mMemc->add( $statusKey, 'loading', MSG_LOAD_TIMEOUT );
@@ -322,12 +329,11 @@ class MessageCache {
 			# database or in code.
 			if ( $code !== $wgContLanguageCode ) {
 				# Messages for particular language
-				$escapedCode = $dbr->escapeLike( $code );
-				$conds[] = "page_title like '%%/$escapedCode'";
+				$conds[] = 'page_title' . $dbr->buildLike( $dbr->anyString(), "/$code" );
 			} else {
 				# Effectively disallows use of '/' character in NS_MEDIAWIKI for uses
 				# other than language code.
-				$conds[] = "page_title not like '%%/%%'";
+				$conds[] = 'page_title NOT' . $dbr->buildLike( $dbr->anyString(), '/', $dbr->anyString() );
 			}
 		}
 
@@ -336,11 +342,10 @@ class MessageCache {
 		$bigConds[] = 'page_len > ' . intval( $wgMaxMsgCacheEntrySize );
 
 		# Load titles for all oversized pages in the MediaWiki namespace
-		$res = $dbr->select( 'page', 'page_title', $bigConds, __METHOD__ );
-		while ( $row = $dbr->fetchObject( $res ) ) {
+		$res = $dbr->select( 'page', 'page_title', $bigConds, __METHOD__ . "($code)-big" );
+		foreach ( $res as $row ) {
 			$cache[$row->page_title] = '!TOO BIG';
 		}
-		$dbr->freeResult( $res );
 
 		# Conditions to load the remaining pages with their contents
 		$smallConds = $conds;
@@ -350,12 +355,11 @@ class MessageCache {
 
 		$res = $dbr->select( array( 'page', 'revision', 'text' ),
 			array( 'page_title', 'old_text', 'old_flags' ),
-			$smallConds, __METHOD__ );
+			$smallConds, __METHOD__ . "($code)-small" );
 
-		for ( $row = $dbr->fetchObject( $res ); $row; $row = $dbr->fetchObject( $res ) ) {
+		foreach ( $res as $row ) {
 			$cache[$row->page_title] = ' ' . Revision::getRevisionText( $row );
 		}
-		$dbr->freeResult( $res );
 
 		$cache['VERSION'] = MSG_CACHE_VERSION;
 		wfProfileOut( __METHOD__ );
@@ -372,8 +376,12 @@ class MessageCache {
 		global $wgMaxMsgCacheEntrySize;
 		wfProfileIn( __METHOD__ );
 
+		if ( $this->mDisable ) {
+			wfProfileOut( __METHOD__ );
+			return;
+		}
 
-		list( , $code ) = $this->figureMessage( $title );
+		list( $msg, $code ) = $this->figureMessage( $title );
 
 		$cacheKey = wfMemcKey( 'messages', $code );
 		$this->load($code);
@@ -404,8 +412,23 @@ class MessageCache {
 
 		// Also delete cached sidebar... just in case it is affected
 		global $parserMemc;
-		$sidebarKey = wfMemcKey( 'sidebar', $code );
-		$parserMemc->delete( $sidebarKey );
+		$codes = array( $code );
+		if ( $code === 'en'  ) {
+			// Delete all sidebars, like for example on action=purge on the
+			// sidebar messages
+			$codes = array_keys( Language::getLanguageNames() );
+		}
+
+		foreach ( $codes as $code ) {
+			$sidebarKey = wfMemcKey( 'sidebar', $code );
+			$parserMemc->delete( $sidebarKey );
+		}
+		
+		// Update the message in the message blob store
+		global $wgContLang;
+		MessageBlobStore::updateMessage( $wgContLang->lcfirst( $msg ) );
+
+		wfRunHooks( "MessageCacheReplace", array( $title, $text ) );
 
 		wfProfileOut( __METHOD__ );
 	}
@@ -414,31 +437,24 @@ class MessageCache {
 	 * Shortcut to update caches.
 	 *
 	 * @param $cache Array: cached messages with a version.
-	 * @param $cacheKey String: Identifier for the cache.
 	 * @param $memc Bool: Wether to update or not memcache.
 	 * @param $code String: Language code.
 	 * @return False on somekind of error.
 	 */
 	protected function saveToCaches( $cache, $memc = true, $code = false ) {
 		wfProfileIn( __METHOD__ );
-		global $wgLocalMessageCache, $wgLocalMessageCacheSerialized;
+		global $wgUseLocalMessageCache, $wgLocalMessageCacheSerialized;
 
 		$cacheKey = wfMemcKey( 'messages', $code );
 
-		$i = 0;
 		if ( $memc ) {
-			# Save in memcached
-			# Keep trying if it fails, this is kind of important
-
-			for ($i=0; $i<20 &&
-				!$this->mMemc->set( $cacheKey, $cache, $this->mExpiry );
-				$i++ ) {
-				usleep(mt_rand(500000,1500000));
-			}
+			$success = $this->mMemc->set( $cacheKey, $cache, $this->mExpiry );
+		} else {
+			$success = true;
 		}
 
 		# Save to local cache
-		if ( $wgLocalMessageCache !== false ) {
+		if ( $wgUseLocalMessageCache ) {
 			$serialized = serialize( $cache );
 			$hash = md5( $serialized );
 			$this->mMemc->set( wfMemcKey( 'messages', $code, 'hash' ), $hash, $this->mExpiry );
@@ -449,24 +465,16 @@ class MessageCache {
 			}
 		}
 
-		if ( $i == 20 ) {
-			$success = false;
-		} else {
-			$success = true;
-		}
 		wfProfileOut( __METHOD__ );
 		return $success;
 	}
 
 	/**
-	 * Returns success
 	 * Represents a write lock on the messages key
+	 *
+	 * @return Boolean: success
 	 */
 	function lock($key) {
-		if ( !$this->mUseCache ) {
-			return true;
-		}
-
 		$lockKey = $key . ':lock';
 		for ($i=0; $i < MSG_WAIT_TIMEOUT && !$this->mMemc->add( $lockKey, 1, MSG_LOCK_TIMEOUT ); $i++ ) {
 			sleep(1);
@@ -476,10 +484,6 @@ class MessageCache {
 	}
 
 	function unlock($key) {
-		if ( !$this->mUseCache ) {
-			return;
-		}
-
 		$lockKey = $key . ':lock';
 		$this->mMemc->delete( $lockKey );
 	}
@@ -487,53 +491,60 @@ class MessageCache {
 	/**
 	 * Get a message from either the content language or the user language.
 	 *
-	 * @param string $key The message cache key
-	 * @param bool $useDB Get the message from the DB, false to use only the localisation
-	 * @param string $langcode Code of the language to get the message for, if
-	 *                         it is a valid code create a language for that
-	 *                         language, if it is a string but not a valid code
-	 *                         then make a basic language object, if it is a
-	 *                         false boolean then use the current users
-	 *                         language (as a fallback for the old parameter
-	 *                         functionality), or if it is a true boolean then
-	 *                         use the wikis content language (also as a
-	 *                         fallback).
-	 * @param bool $isFullKey Specifies whether $key is a two part key "lang/msg".
+	 * @param $key String: the message cache key
+	 * @param $useDB Boolean: get the message from the DB, false to use only
+	 *               the localisation
+	 * @param $langcode String: code of the language to get the message for, if
+	 *                  it is a valid code create a language for that language,
+	 *                  if it is a string but not a valid code then make a basic
+	 *                  language object, if it is a false boolean then use the
+	 *                  current users language (as a fallback for the old
+	 *                  parameter functionality), or if it is a true boolean
+	 *                  then use the wikis content language (also as a
+	 *                  fallback).
+	 * @param $isFullKey Boolean: specifies whether $key is a two part key
+	 *                   "msg/lang".
 	 */
 	function get( $key, $useDB = true, $langcode = true, $isFullKey = false ) {
-		global $wgContLanguageCode, $wgContLang;
+		global $wgLanguageCode, $wgContLang;
+
+		if ( !is_string( $key ) ) {
+			throw new MWException( "Non-string key given" );
+		}
+
+		if ( strval( $key ) === '' ) {
+			# Shortcut: the empty key is always missing
+			return false;
+		}
 
 		$lang = wfGetLangObj( $langcode );
-		$langcode = $lang->getCode();
-
-		# If uninitialised, someone is trying to call this halfway through Setup.php
-		if( !$this->mInitialised ) {
-			return '&lt;' . htmlspecialchars($key) . '&gt;';
+		if ( !$lang ) {
+			throw new MWException( "Bad lang code $langcode given" );
 		}
 
+		$langcode = $lang->getCode();
+
 		$message = false;
 
-		# Normalise title-case input
-		$lckey = $wgContLang->lcfirst( $key );
-		$lckey = str_replace( ' ', '_', $lckey );
+		# Normalise title-case input (with some inlining)
+		$lckey = str_replace( ' ', '_', $key );
+		if ( ord( $key ) < 128 ) {
+			$lckey[0] = strtolower( $lckey[0] );
+			$uckey = ucfirst( $lckey );
+		} else {
+			$lckey = $wgContLang->lcfirst( $lckey );
+			$uckey = $wgContLang->ucfirst( $lckey );
+		}
 
 		# Try the MediaWiki namespace
 		if( !$this->mDisable && $useDB ) {
-			$title = $wgContLang->ucfirst( $lckey );
-			if(!$isFullKey && ($langcode != $wgContLanguageCode) ) {
+			$title = $uckey;
+			if(!$isFullKey && ( $langcode != $wgLanguageCode ) ) {
 				$title .= '/' . $langcode;
 			}
 			$message = $this->getMsgFromNamespace( $title, $langcode );
 		}
 
-		# Try the extension array
-		if ( $message === false && isset( $this->mExtensionMessages[$langcode][$lckey] ) ) {
-			$message = $this->mExtensionMessages[$langcode][$lckey];
-		}
-		if ( $message === false && isset( $this->mExtensionMessages['en'][$lckey] ) ) {
-			$message = $this->mExtensionMessages['en'][$lckey];
-		}
-
 		# Try the array in the language object
 		if ( $message === false ) {
 			$message = $lang->getMessage( $lckey );
@@ -543,19 +554,15 @@ class MessageCache {
 		}
 
 		# Try the array of another language
-		$pos = strrpos( $lckey, '/' );
-		if( $message === false && $pos !== false) {
-			$mkey = substr( $lckey, 0, $pos );
-			$code = substr( $lckey, $pos+1 );
-			if ( $code ) {
-				# We may get calls for things that are http-urls from sidebar
-				# Let's not load nonexistent languages for those
-				$validCodes = array_keys( Language::getLanguageNames() );
-				if ( in_array( $code, $validCodes ) ) {
-					$message = Language::getMessageFor( $mkey, $code );
-					if ( is_null( $message ) ) {
-						$message = false;
-					}
+		if( $message === false ) {
+			$parts = explode( '/', $lckey );
+			# We may get calls for things that are http-urls from sidebar
+			# Let's not load nonexistent languages for those
+			# They usually have more than one slash.
+			if ( count( $parts ) == 2 && $parts[1] !== '' ) {
+				$message = Language::getMessageFor( $parts[0], $parts[1] );
+				if ( is_null( $message ) ) {
+					$message = false;
 				}
 			}
 		}
@@ -563,14 +570,25 @@ class MessageCache {
 		# Is this a custom message? Try the default language in the db...
 		if( ($message === false || $message === '-' ) &&
 			!$this->mDisable && $useDB &&
-			!$isFullKey && ($langcode != $wgContLanguageCode) ) {
-			$message = $this->getMsgFromNamespace( $wgContLang->ucfirst( $lckey ), $wgContLanguageCode );
+			!$isFullKey && ($langcode != $wgLanguageCode) ) {
+			$message = $this->getMsgFromNamespace( $uckey, $wgLanguageCode );
 		}
 
 		# Final fallback
 		if( $message === false ) {
-			return '&lt;' . htmlspecialchars($key) . '&gt;';
+			return false;
 		}
+
+		# Fix whitespace
+		$message = strtr( $message,
+			array(
+				# Fix for trailing whitespace, removed by textarea
+				'&#32;' => ' ',
+				# Fix for NBSP, converted to space by firefox
+				'&nbsp;' => "\xc2\xa0",
+				'&#160;' => "\xc2\xa0",
+			) );
+
 		return $message;
 	}
 
@@ -585,14 +603,12 @@ class MessageCache {
 		$type = false;
 		$message = false;
 
-		if ( $this->mUseCache ) {
-			$this->load( $code );
-			if (isset( $this->mCache[$code][$title] ) ) {
-				$entry = $this->mCache[$code][$title];
-				$type = substr( $entry, 0, 1 );
-				if ( $type == ' ' ) {
-					return substr( $entry, 1 );
-				}
+		$this->load( $code );
+		if ( isset( $this->mCache[$code][$title] ) ) {
+			$entry = $this->mCache[$code][$title];
+			$type = substr( $entry, 0, 1 );
+			if ( $type == ' ' ) {
+				return substr( $entry, 1 );
 			}
 		}
 
@@ -602,31 +618,23 @@ class MessageCache {
 			return $message;
 		}
 
-		# If there is no cache entry and no placeholder, it doesn't exist
-		if ( $type !== '!' ) {
-			return false;
-		}
-
 		$titleKey = wfMemcKey( 'messages', 'individual', $title );
 
 		# Try the individual message cache
-		if ( $this->mUseCache ) {
-			$entry = $this->mMemc->get( $titleKey );
-			if ( $entry ) {
-				$type = substr( $entry, 0, 1 );
-
-				if ( $type === ' ' ) {
-					# Ok!
-					$message = substr( $entry, 1 );
-					$this->mCache[$code][$title] = $entry;
-					return $message;
-				} elseif ( $entry === '!NONEXISTENT' ) {
-					return false;
-				} else {
-					# Corrupt/obsolete entry, delete it
-					$this->mMemc->delete( $titleKey );
-				}
+		$entry = $this->mMemc->get( $titleKey );
+		if ( $entry ) {
+			$type = substr( $entry, 0, 1 );
 
+			if ( $type === ' ' ) {
+				# Ok!
+				$message = substr( $entry, 1 );
+				$this->mCache[$code][$title] = $entry;
+				return $message;
+			} elseif ( $entry === '!NONEXISTENT' ) {
+				return false;
+			} else {
+				# Corrupt/obsolete entry, delete it
+				$this->mMemc->delete( $titleKey );
 			}
 		}
 
@@ -634,10 +642,8 @@ class MessageCache {
 		$revision = Revision::newFromTitle( Title::makeTitle( NS_MEDIAWIKI, $title ) );
 		if( $revision ) {
 			$message = $revision->getText();
-			if ($this->mUseCache) {
-				$this->mCache[$code][$title] = ' ' . $message;
-				$this->mMemc->set( $titleKey, $message, $this->mExpiry );
-			}
+			$this->mCache[$code][$title] = ' ' . $message;
+			$this->mMemc->set( $titleKey, ' ' . $message, $this->mExpiry );
 		} else {
 			# Negative caching
 			# Use some special text instead of false, because false gets converted to '' somewhere
@@ -648,7 +654,7 @@ class MessageCache {
 	}
 
 	function transform( $message, $interface = false, $language = null ) {
-		// Avoid creating parser if nothing to transfrom
+		// Avoid creating parser if nothing to transform
 		if( strpos( $message, '{{' ) === false ) {
 			return $message;
 		}
@@ -671,14 +677,16 @@ class MessageCache {
 			$popts = $this->getParserOptions();
 			$popts->setInterfaceMessage( $interface );
 			$popts->setTargetLanguage( $language );
+			$userlang = $popts->setUserLang( $language );
 			$message = $this->mParser->transformMsg( $message, $popts );
+			$popts->setUserLang( $userlang );
 		}
 		return $message;
 	}
 
 	function disable() { $this->mDisable = true; }
 	function enable() { $this->mDisable = false; }
- 
+
 	/** @deprecated */
 	function disableTransform(){
 		wfDeprecated( __METHOD__ );
@@ -695,172 +703,87 @@ class MessageCache {
 	}
 
 	/**
+	 * Clear all stored messages. Mainly used after a mass rebuild.
+	 */
+	function clear() {
+		$langs = Language::getLanguageNames( false );
+		foreach ( array_keys($langs) as $code ) {
+			# Global cache
+			$this->mMemc->delete( wfMemcKey( 'messages', $code ) );
+			# Invalidate all local caches
+			$this->mMemc->delete( wfMemcKey( 'messages', $code, 'hash' ) );
+		}
+		$this->mLoadedLanguages = array();
+	}
+
+ 	/**
 	 * Add a message to the cache
+	 * @deprecated Use $wgExtensionMessagesFiles
 	 *
-	 * @param mixed $key
-	 * @param mixed $value
-	 * @param string $lang The messages language, English by default
+	 * @param $key Mixed
+	 * @param $value Mixed
+	 * @param $lang String: the messages language, English by default
 	 */
 	function addMessage( $key, $value, $lang = 'en' ) {
-		global $wgContLang;
-		# Normalise title-case input
-		$lckey = str_replace( ' ', '_', $wgContLang->lcfirst( $key ) );
-		$this->mExtensionMessages[$lang][$lckey] = $value;
+		wfDeprecated( __METHOD__ );
+		$lc = Language::getLocalisationCache();
+		$lc->addLegacyMessages( array( $lang => array( $key => $value ) ) );
 	}
 
 	/**
 	 * Add an associative array of message to the cache
+	 * @deprecated Use $wgExtensionMessagesFiles
 	 *
-	 * @param array $messages An associative array of key => values to be added
-	 * @param string $lang The messages language, English by default
+	 * @param $messages Array: an associative array of key => values to be added
+	 * @param $lang String: the messages language, English by default
 	 */
 	function addMessages( $messages, $lang = 'en' ) {
-		wfProfileIn( __METHOD__ );
-		if ( !is_array( $messages ) ) {
-			throw new MWException( __METHOD__.': Invalid message array' );
-		}
-		if ( isset( $this->mExtensionMessages[$lang] ) ) {
-			$this->mExtensionMessages[$lang] = $messages + $this->mExtensionMessages[$lang];
-		} else {
-			$this->mExtensionMessages[$lang] = $messages;
-		}
-		wfProfileOut( __METHOD__ );
+		wfDeprecated( __METHOD__ );
+		$lc = Language::getLocalisationCache();
+		$lc->addLegacyMessages( array( $lang => $messages ) );
 	}
 
 	/**
 	 * Add a 2-D array of messages by lang. Useful for extensions.
+	 * @deprecated Use $wgExtensionMessagesFiles
 	 *
-	 * @param array $messages The array to be added
+	 * @param $messages Array: the array to be added
 	 */
 	function addMessagesByLang( $messages ) {
-		wfProfileIn( __METHOD__ );
-		foreach ( $messages as $key => $value ) {
-			$this->addMessages( $value, $key );
-		}
-		wfProfileOut( __METHOD__ );
+		wfDeprecated( __METHOD__ );
+		$lc = Language::getLocalisationCache();
+		$lc->addLegacyMessages( $messages );
 	}
 
 	/**
-	 * Get the extension messages for a specific language. Only English, interface
-	 * and content language are guaranteed to be loaded.
-	 *
-	 * @param string $lang The messages language, English by default
+	 * Set a hook for addMessagesByLang()
 	 */
-	function getExtensionMessagesFor( $lang = 'en' ) {
-		wfProfileIn( __METHOD__ );
-		$messages = array();
-		if ( isset( $this->mExtensionMessages[$lang] ) ) {
-			$messages = $this->mExtensionMessages[$lang];
-		}
-		if ( $lang != 'en' ) {
-			$messages = $messages + $this->mExtensionMessages['en'];
-		}
-		wfProfileOut( __METHOD__ );
-		return $messages;
+	function setExtensionMessagesHook( $callback ) {
+		$this->mAddMessagesHook = $callback;
 	}
 
 	/**
-	 * Clear all stored messages. Mainly used after a mass rebuild.
+	 * @deprecated
 	 */
-	function clear() {
-		if( $this->mUseCache ) {
-			$langs = Language::getLanguageNames( false );
-			foreach ( array_keys($langs) as $code ) {
-				# Global cache
-				$this->mMemc->delete( wfMemcKey( 'messages', $code ) );
-				# Invalidate all local caches
-				$this->mMemc->delete( wfMemcKey( 'messages', $code, 'hash' ) );
-			}
-		}
-	}
-
 	function loadAllMessages( $lang = false ) {
-		global $wgExtensionMessagesFiles;
-		$key = $lang === false ? '*' : $lang;
-		if ( isset( $this->mAllMessagesLoaded[$key] ) ) {
-			return;
-		}
-		$this->mAllMessagesLoaded[$key] = true;
-
-		# Some extensions will load their messages when you load their class file
-		wfLoadAllExtensions();
-		# Others will respond to this hook
-		wfRunHooks( 'LoadAllMessages' );
-		# Some register their messages in $wgExtensionMessagesFiles
-		foreach ( $wgExtensionMessagesFiles as $name => $file ) {
-			wfLoadExtensionMessages( $name, $lang );
-		}
-		# Still others will respond to neither, they are EVIL. We sometimes need to know!
 	}
 
 	/**
-	 * Load messages from a given file
-	 * 
-	 * @param string $filename Filename of file to load.
-	 * @param string $langcode Language to load messages for, or false for 
-     *                         default behvaiour (en, content language and user
-     *                         language).
+	 * @deprecated
 	 */
 	function loadMessagesFile( $filename, $langcode = false ) {
-		global $wgLang, $wgContLang;
-		wfProfileIn( __METHOD__ );
-		$messages = $magicWords = false;
-		require( $filename );
-
-		$validCodes = Language::getLanguageNames();
-		if( is_string( $langcode ) && array_key_exists( $langcode, $validCodes ) ) {
-			# Load messages for given language code.
-			$this->processMessagesArray( $messages, $langcode );
-		} elseif( is_string( $langcode ) && !array_key_exists( $langcode, $validCodes ) ) {
-			wfDebug( "Invalid language '$langcode' code passed to MessageCache::loadMessagesFile()" );
-		} else {
-			# Load only languages that are usually used, and merge all
-			# fallbacks, except English.
-			$langs = array_unique( array( 'en', $wgContLang->getCode(), $wgLang->getCode() ) );
-			foreach( $langs as $code ) {
-				$this->processMessagesArray( $messages, $code );
-			}
-		}
-
-		if ( $magicWords !== false ) {
-			global $wgContLang;
-			$wgContLang->addMagicWordsByLang( $magicWords );
-		}
-		wfProfileOut( __METHOD__ );
-	}
-
-	/**
-	 * Process an array of messages, loading it into the message cache.
-	 *
-	 * @param array $messages Messages array.
-	 * @param string $langcode Language code to process.
-	 */
-	function processMessagesArray( $messages, $langcode ) {
-		wfProfileIn( __METHOD__ );
-		$fallbackCode = $langcode;
-		$mergedMessages = array();
-		do {
-			if ( isset($messages[$fallbackCode]) ) {
-				$mergedMessages += $messages[$fallbackCode];
-			}
-			$fallbackCode = Language::getFallbackfor( $fallbackCode );
-		} while( $fallbackCode && $fallbackCode !== 'en' );
-		
-		if ( !empty($mergedMessages) )
-			$this->addMessages( $mergedMessages, $langcode );
-		wfProfileOut( __METHOD__ );
 	}
 
 	public function figureMessage( $key ) {
-		global $wgContLanguageCode;
+		global $wgLanguageCode;
 		$pieces = explode( '/', $key );
 		if( count( $pieces ) < 2 )
-			return array( $key, $wgContLanguageCode );
+			return array( $key, $wgLanguageCode );
 
 		$lang = array_pop( $pieces );
 		$validCodes = Language::getLanguageNames();
 		if( !array_key_exists( $lang, $validCodes ) )
-			return array( $key, $wgContLanguageCode );
+			return array( $key, $wgLanguageCode );
 
 		$message = implode( '/', $pieces );
 		return array( $message, $lang );
