@@ -16,8 +16,8 @@ $wgCanonicalNamespaceNames = array(
 	NS_USER_TALK        => 'User_talk',
 	NS_PROJECT          => 'Project',
 	NS_PROJECT_TALK     => 'Project_talk',
-	NS_IMAGE            => 'Image',
-	NS_IMAGE_TALK       => 'Image_talk',
+	NS_FILE             => 'File',
+	NS_FILE_TALK        => 'File_talk',
 	NS_MEDIAWIKI        => 'MediaWiki',
 	NS_MEDIAWIKI_TALK   => 'MediaWiki_talk',
 	NS_TEMPLATE         => 'Template',
@@ -28,6 +28,7 @@ $wgCanonicalNamespaceNames = array(
 	NS_CATEGORY_TALK    => 'Category_talk',
 );
 
+/// @todo UGLY UGLY
 if( is_array( $wgExtraNamespaces ) ) {
 	$wgCanonicalNamespaceNames = $wgCanonicalNamespaceNames + $wgExtraNamespaces;
 }
@@ -45,6 +46,13 @@ if( is_array( $wgExtraNamespaces ) ) {
 
 class MWNamespace {
 
+	/**
+	 * These namespaces should always be first-letter capitalized, now and
+	 * forevermore. Historically, they could've probably been lowercased too,
+	 * but some things are just too ingrained now. :)
+	 */
+	private static $alwaysCapitalizedNamespaces = array( NS_SPECIAL, NS_USER, NS_MEDIAWIKI );
+
 	/**
 	 * Can pages in the given namespace be moved?
 	 *
@@ -53,7 +61,7 @@ class MWNamespace {
 	 */
 	public static function isMovable( $index ) {
 		global $wgAllowImageMoving;
-		return !( $index < NS_MAIN || ($index == NS_IMAGE && !$wgAllowImageMoving)  || $index == NS_CATEGORY );
+		return !( $index < NS_MAIN || ($index == NS_FILE && !$wgAllowImageMoving)  || $index == NS_CATEGORY );
 	}
 
 	/**
@@ -102,14 +110,46 @@ class MWNamespace {
 	}
 
 	/**
-	 * Returns the canonical (English Wikipedia) name for a given index
+	 * Returns whether the specified namespace exists
+	 */
+	public static function exists( $index ) {
+		$nslist = self::getCanonicalNamespaces();
+		return isset( $nslist[$index] );
+	}
+
+	/**
+	 * Returns array of all defined namespaces with their canonical
+	 * (English) names.
+	 *
+	 * @return \array
+	 * @since 1.17
+	 */
+	public static function getCanonicalNamespaces() {
+		static $namespaces = null;
+		if ( $namespaces === null ) {
+			global $wgExtraNamespaces, $wgCanonicalNamespaceNames;
+			$namespaces = array( NS_MAIN => '' ) + $wgCanonicalNamespaceNames;
+			if ( is_array( $wgExtraNamespaces ) ) {
+				$namespaces += $wgExtraNamespaces;
+			}
+			wfRunHooks( 'CanonicalNamespaces', array( &$namespaces ) );
+		}
+		return $namespaces;
+	}
+
+	/**
+	 * Returns the canonical (English) name for a given index
 	 *
 	 * @param $index Int: namespace index
-	 * @return string
+	 * @return string or false if no canonical definition.
 	 */
 	public static function getCanonicalName( $index ) {
-		global $wgCanonicalNamespaceNames;
-		return $wgCanonicalNamespaceNames[$index];
+		$nslist = self::getCanonicalNamespaces();
+		if( isset( $nslist[$index] ) ) {
+			return $nslist[$index];
+		} else {
+			return false;
+		}
 	}
 
 	/**
@@ -120,21 +160,39 @@ class MWNamespace {
 	 * @return int
 	 */
 	public static function getCanonicalIndex( $name ) {
-		global $wgCanonicalNamespaceNames;
 		static $xNamespaces = false;
 		if ( $xNamespaces === false ) {
 			$xNamespaces = array();
-			foreach ( $wgCanonicalNamespaceNames as $i => $text ) {
+			foreach ( self::getCanonicalNamespaces() as $i => $text ) {
 				$xNamespaces[strtolower($text)] = $i;
 			}
 		}
 		if ( array_key_exists( $name, $xNamespaces ) ) {
 			return $xNamespaces[$name];
 		} else {
-			return NULL;
+			return null;
 		}
 	}
 
+	/**
+	 * Returns an array of the namespaces (by integer id) that exist on the
+	 * wiki. Used primarily by the api in help documentation.
+	 * @return array
+	 */
+	public static function getValidNamespaces() {
+		static $mValidNamespaces = null;
+
+		if ( is_null( $mValidNamespaces ) ) {
+			foreach ( array_keys( self::getCanonicalNamespaces() ) as $ns ) {
+				if ( $ns >= 0 ) {
+					$mValidNamespaces[] = $ns;
+				}
+			}
+		}
+
+		return $mValidNamespaces;
+	}
+
 	/**
 	 * Can this namespace ever have a talk namespace?
 	 *
@@ -142,7 +200,7 @@ class MWNamespace {
 	 * @return bool
 	 */
 	 public static function canTalk( $index ) {
-	 	return $index >= NS_MAIN;
+		return $index >= NS_MAIN;
 	 }
 
 	/**
@@ -178,4 +236,29 @@ class MWNamespace {
 		return !empty( $wgNamespacesWithSubpages[$index] );
 	}
 
+	/**
+	 * Is the namespace first-letter capitalized?
+	 *
+	 * @param $index int Index to check
+	 * @return bool
+	 */
+	public static function isCapitalized( $index ) {
+		global $wgCapitalLinks, $wgCapitalLinkOverrides;
+		// Turn NS_MEDIA into NS_FILE
+		$index = $index === NS_MEDIA ? NS_FILE : $index;
+
+		// Make sure to get the subject of our namespace
+		$index = self::getSubject( $index );
+
+		// Some namespaces are special and should always be upper case
+		if ( in_array( $index, self::$alwaysCapitalizedNamespaces ) ) {
+			return true;
+		}
+		if ( isset( $wgCapitalLinkOverrides[ $index ] ) ) {
+			// $wgCapitalLinkOverrides is explicitly set
+			return $wgCapitalLinkOverrides[ $index ];
+		}
+		// Default to the global setting
+		return $wgCapitalLinks;
+	}
 }
