@@ -1,18 +1,24 @@
 <?php
+/**
+ * @file
+ * @ingroup Profiler
+ */
 
-require_once(dirname(__FILE__).'/Profiler.php');
+if ( !class_exists( 'Profiler' ) ) {
+	require_once(dirname(__FILE__).'/Profiler.php');
+}
 
 /**
  * Simple profiler base class.
  * @todo document methods (?)
- * @addtogroup Profiler
+ * @ingroup Profiler
  */
 class ProfilerSimple extends Profiler {
 	var $mMinimumTime = 0;
 	var $mProfileID = false;
 
 	function __construct() {
-		global $wgRequestTime,$wgRUstart;
+		global $wgRequestTime, $wgRUstart;
 		if (!empty($wgRequestTime) && !empty($wgRUstart)) {
 			$this->mWorkStack[] = array( '-total', 0, $wgRequestTime,$this->getCpuTime($wgRUstart));
 
@@ -103,9 +109,10 @@ class ProfilerSimple extends Profiler {
 
 	function getCpuTime($ru=null) {
 		if ( function_exists( 'getrusage' ) ) {
-			if ( $ru == null )
+			if ( $ru == null ) {
 				$ru = getrusage();
-			return ($ru['ru_utime.tv_sec'] + $ru['ru_stime.tv_sec'] + ($ru['ru_utime.tv_usec'] + 
+			}
+			return ($ru['ru_utime.tv_sec'] + $ru['ru_stime.tv_sec'] + ($ru['ru_utime.tv_usec'] +
 				$ru['ru_stime.tv_usec']) * 1e-6);
 		} else {
 			return 0;
@@ -114,16 +121,10 @@ class ProfilerSimple extends Profiler {
 
 	/* If argument is passed, it assumes that it is dual-format time string, returns proper float time value */
 	function getTime($time=null) {
-		if ($time==null)
+		if ($time==null) {
 			return microtime(true);
+		}
 		list($a,$b)=explode(" ",$time);
 		return (float)($a+$b);
 	}
-
-	function debug( $s ) {
-		if (function_exists( 'wfDebug' ) ) {
-			wfDebug( $s );
-		}
-	}
 }
-
