@@ -1,7 +1,4 @@
 <?php
-/**
- * @todo document
- */
 
 /**
  * @todo document
@@ -11,14 +8,19 @@ class Revision {
 	const DELETED_COMMENT = 2;
 	const DELETED_USER = 4;
 	const DELETED_RESTRICTED = 8;
+	// Convenience field
+	const SUPPRESSED_USER = 12;
+	// Audience options for Revision::getText()
+	const FOR_PUBLIC = 1;
+	const FOR_THIS_USER = 2;
+	const RAW = 3;
 
 	/**
 	 * Load a page revision from a given revision ID number.
 	 * Returns null if no such revision can be found.
 	 *
-	 * @param int $id
-	 * @access public
-	 * @static
+	 * @param $id Integer
+	 * @return Revision or null
 	 */
 	public static function newFromId( $id ) {
 		return Revision::newFromConds(
@@ -31,35 +33,71 @@ class Revision {
 	 * that's attached to a given title. If not attached
 	 * to that title, will return null.
 	 *
-	 * @param Title $title
-	 * @param int $id
-	 * @return Revision
-	 * @access public
-	 * @static
+	 * @param $title Title
+	 * @param $id Integer
+	 * @return Revision or null
 	 */
-	public static function newFromTitle( &$title, $id = 0 ) {
-		if( $id ) {
-			$matchId = intval( $id );
+	public static function newFromTitle( $title, $id = 0 ) {
+		$conds = array( 
+			'page_namespace' => $title->getNamespace(), 
+			'page_title' => $title->getDBkey()
+		);
+		if ( $id ) {
+			// Use the specified ID
+			$conds['rev_id'] = $id;
+		} elseif ( wfGetLB()->getServerCount() > 1 ) {
+			// Get the latest revision ID from the master
+			$dbw = wfGetDB( DB_MASTER );
+			$latest = $dbw->selectField( 'page', 'page_latest', $conds, __METHOD__ );
+			if ( $latest === false ) {
+				// Page does not exist
+				return null;
+			}
+			$conds['rev_id'] = $latest;
 		} else {
-			$matchId = 'page_latest';
+			// Use a join to get the latest revision
+			$conds[] = 'rev_id=page_latest';
 		}
-		return Revision::newFromConds(
-			array( "rev_id=$matchId",
-			       'page_id=rev_page',
-			       'page_namespace' => $title->getNamespace(),
-			       'page_title'     => $title->getDBkey() ) );
+		$conds[] = 'page_id=rev_page';
+		return Revision::newFromConds( $conds );
+	}
+
+	/**
+	 * Make a fake revision object from an archive table row. This is queried
+	 * for permissions or even inserted (as in Special:Undelete)
+	 * @todo Fixme: should be a subclass for RevisionDelete. [TS]
+	 */
+	public static function newFromArchiveRow( $row, $overrides = array() ) {
+		$attribs = $overrides + array(
+			'page'       => isset( $row->page_id ) ? $row->page_id : null,
+			'id'         => isset( $row->ar_rev_id ) ? $row->ar_rev_id : null,
+			'comment'    => $row->ar_comment,
+			'user'       => $row->ar_user,
+			'user_text'  => $row->ar_user_text,
+			'timestamp'  => $row->ar_timestamp,
+			'minor_edit' => $row->ar_minor_edit,
+			'text_id'    => isset( $row->ar_text_id ) ? $row->ar_text_id : null,
+			'deleted'    => $row->ar_deleted,
+			'len'        => $row->ar_len);
+		if ( isset( $row->ar_text ) && !$row->ar_text_id ) {
+			// Pre-1.5 ar_text row
+			$attribs['text'] = self::getRevisionText( $row, 'ar_' );
+			if ( $attribs['text'] === false ) {
+				throw new MWException( 'Unable to load text from archive row (possibly bug 22624)' );
+			}
+		}
+		return new self( $attribs );
 	}
 
 	/**
 	 * Load a page revision from a given revision ID number.
 	 * Returns null if no such revision can be found.
 	 *
-	 * @param Database $db
-	 * @param int $id
-	 * @access public
-	 * @static
+	 * @param $db DatabaseBase
+	 * @param $id Integer
+	 * @return Revision or null
 	 */
-	public static function loadFromId( &$db, $id ) {
+	public static function loadFromId( $db, $id ) {
 		return Revision::loadFromConds( $db,
 			array( 'page_id=rev_page',
 			       'rev_id' => intval( $id ) ) );
@@ -70,19 +108,17 @@ class Revision {
 	 * that's attached to a given page. If not attached
 	 * to that page, will return null.
 	 *
-	 * @param Database $db
-	 * @param int $pageid
-	 * @param int $id
-	 * @return Revision
-	 * @access public
-	 * @static
+	 * @param $db DatabaseBase
+	 * @param $pageid Integer
+	 * @param $id Integer
+	 * @return Revision or null
 	 */
 	public static function loadFromPageId( $db, $pageid, $id = 0 ) {
-		$conds=array('page_id=rev_page','rev_page'=>intval( $pageid ), 'page_id'=>intval( $pageid ));
+		$conds = array( 'page_id=rev_page','rev_page' => intval( $pageid ), 'page_id'=>intval( $pageid ) );
 		if( $id ) {
-			$conds['rev_id']=intval($id);
+			$conds['rev_id'] = intval( $id );
 		} else {
-			$conds[]='rev_id=page_latest';
+			$conds[] = 'rev_id=page_latest';
 		}
 		return Revision::loadFromConds( $db, $conds );
 	}
@@ -92,14 +128,12 @@ class Revision {
 	 * that's attached to a given page. If not attached
 	 * to that page, will return null.
 	 *
-	 * @param Database $db
-	 * @param Title $title
-	 * @param int $id
-	 * @return Revision
-	 * @access public
-	 * @static
+	 * @param $db DatabaseBase
+	 * @param $title Title
+	 * @param $id Integer
+	 * @return Revision or null
 	 */
-	public static function loadFromTitle( &$db, $title, $id = 0 ) {
+	public static function loadFromTitle( $db, $title, $id = 0 ) {
 		if( $id ) {
 			$matchId = intval( $id );
 		} else {
@@ -118,14 +152,12 @@ class Revision {
 	 * WARNING: Timestamps may in some circumstances not be unique,
 	 * so this isn't the best key to use.
 	 *
-	 * @param Database $db
-	 * @param Title $title
-	 * @param string $timestamp
-	 * @return Revision
-	 * @access public
-	 * @static
+	 * @param $db Database
+	 * @param $title Title
+	 * @param $timestamp String
+	 * @return Revision or null
 	 */
-	public static function loadFromTimestamp( &$db, &$title, $timestamp ) {
+	public static function loadFromTimestamp( $db, $title, $timestamp ) {
 		return Revision::loadFromConds(
 			$db,
 			array( 'rev_timestamp'  => $db->timestamp( $timestamp ),
@@ -137,15 +169,13 @@ class Revision {
 	/**
 	 * Given a set of conditions, fetch a revision.
 	 *
-	 * @param array $conditions
-	 * @return Revision
-	 * @access private
-	 * @static
+	 * @param $conditions Array
+	 * @return Revision or null
 	 */
-	private static function newFromConds( $conditions ) {
+	public static function newFromConds( $conditions ) {
 		$db = wfGetDB( DB_SLAVE );
 		$row = Revision::loadFromConds( $db, $conditions );
-		if( is_null( $row ) ) {
+		if( is_null( $row ) && wfGetLB()->getServerCount() > 1 ) {
 			$dbw = wfGetDB( DB_MASTER );
 			$row = Revision::loadFromConds( $dbw, $conditions );
 		}
@@ -156,11 +186,9 @@ class Revision {
 	 * Given a set of conditions, fetch a revision from
 	 * the given database connection.
 	 *
-	 * @param Database $db
-	 * @param array $conditions
-	 * @return Revision
-	 * @access private
-	 * @static
+	 * @param $db Database
+	 * @param $conditions Array
+	 * @return Revision or null
 	 */
 	private static function loadFromConds( $db, $conditions ) {
 		$res = Revision::fetchFromConds( $db, $conditions );
@@ -181,30 +209,10 @@ class Revision {
 	 * fetch all of a given page's revisions in turn.
 	 * Each row can be fed to the constructor to get objects.
 	 *
-	 * @param Title $title
+	 * @param $title Title
 	 * @return ResultWrapper
-	 * @access public
-	 * @static
 	 */
-	public static function fetchAllRevisions( &$title ) {
-		return Revision::fetchFromConds(
-			wfGetDB( DB_SLAVE ),
-			array( 'page_namespace' => $title->getNamespace(),
-			       'page_title'     => $title->getDBkey(),
-			       'page_id=rev_page' ) );
-	}
-
-	/**
-	 * Return a wrapper for a series of database rows to
-	 * fetch all of a given page's revisions in turn.
-	 * Each row can be fed to the constructor to get objects.
-	 *
-	 * @param Title $title
-	 * @return ResultWrapper
-	 * @access public
-	 * @static
-	 */
-	public static function fetchRevision( &$title ) {
+	public static function fetchRevision( $title ) {
 		return Revision::fetchFromConds(
 			wfGetDB( DB_SLAVE ),
 			array( 'rev_id=page_latest',
@@ -218,59 +226,74 @@ class Revision {
 	 * which will return matching database rows with the
 	 * fields necessary to build Revision objects.
 	 *
-	 * @param Database $db
-	 * @param array $conditions
+	 * @param $db Database
+	 * @param $conditions Array
 	 * @return ResultWrapper
-	 * @access private
-	 * @static
 	 */
 	private static function fetchFromConds( $db, $conditions ) {
+		$fields = self::selectFields();
+		$fields[] = 'page_namespace';
+		$fields[] = 'page_title';
+		$fields[] = 'page_latest';
 		$res = $db->select(
 			array( 'page', 'revision' ),
-			array( 'page_namespace',
-			       'page_title',
-			       'page_latest',
-			       'rev_id',
-			       'rev_page',
-			       'rev_text_id',
-			       'rev_comment',
-			       'rev_user_text',
-			       'rev_user',
-			       'rev_minor_edit',
-			       'rev_timestamp',
-			       'rev_deleted',
-			       'rev_len' ),
+			$fields,
 			$conditions,
-			'Revision::fetchRow',
+			__METHOD__,
 			array( 'LIMIT' => 1 ) );
 		$ret = $db->resultObject( $res );
 		return $ret;
 	}
 
 	/**
-	 * Return the list of revision fields that should be selected to create 
+	 * Return the list of revision fields that should be selected to create
 	 * a new revision.
 	 */
 	static function selectFields() {
-		return array( 
+		return array(
 			'rev_id',
 			'rev_page',
 			'rev_text_id',
 			'rev_timestamp',
 			'rev_comment',
-			'rev_minor_edit',
-			'rev_user',
 			'rev_user_text,'.
+			'rev_user',
+			'rev_minor_edit',
 			'rev_deleted',
-			'rev_len'
+			'rev_len',
+			'rev_parent_id'
+		);
+	}
+	
+	/**
+	 * Return the list of text fields that should be selected to read the 
+	 * revision text
+	 */
+	static function selectTextFields() {
+		return array(
+			'old_text',
+			'old_flags'
 		);
 	}
 
 	/**
-	 * @param object $row
+	 * Return the list of page fields that should be selected from page table
+	 */
+	static function selectPageFields() {
+		return array(
+			'page_namespace',
+			'page_title',
+			'page_latest'
+		);
+	}
+
+	/**
+	 * Constructor
+	 *
+	 * @param $row Mixed: either a database row or an array
 	 * @access private
 	 */
-	function Revision( $row ) {
+	function __construct( $row ) {
 		if( is_object( $row ) ) {
 			$this->mId        = intval( $row->rev_id );
 			$this->mPage      = intval( $row->rev_page );
@@ -281,16 +304,20 @@ class Revision {
 			$this->mMinorEdit = intval( $row->rev_minor_edit );
 			$this->mTimestamp =         $row->rev_timestamp;
 			$this->mDeleted   = intval( $row->rev_deleted );
-			
+
+			if( !isset( $row->rev_parent_id ) )
+				$this->mParentId = is_null($row->rev_parent_id) ? null : 0;
+			else
+				$this->mParentId  = intval( $row->rev_parent_id );
+
 			if( !isset( $row->rev_len ) || is_null( $row->rev_len ) )
 				$this->mSize = null;
 			else
-				$this->mSize = intval( $row->rev_len ); 
+				$this->mSize = intval( $row->rev_len );
 
 			if( isset( $row->page_latest ) ) {
-				$this->mCurrent   = ( $row->rev_id == $row->page_latest );
-				$this->mTitle     = Title::makeTitle( $row->page_namespace,
-				                                      $row->page_title );
+				$this->mCurrent = ( $row->rev_id == $row->page_latest );
+				$this->mTitle = Title::newFromRow( $row );
 			} else {
 				$this->mCurrent = false;
 				$this->mTitle = null;
@@ -317,7 +344,8 @@ class Revision {
 			$this->mTimestamp = isset( $row['timestamp']  ) ? strval( $row['timestamp']  ) : wfTimestamp( TS_MW );
 			$this->mDeleted   = isset( $row['deleted']    ) ? intval( $row['deleted']    ) : 0;
 			$this->mSize      = isset( $row['len']        ) ? intval( $row['len']        ) : null;
-			
+			$this->mParentId  = isset( $row['parent_id']  ) ? intval( $row['parent_id']  ) : null;
+
 			// Enforce spacing trimming on supplied text
 			$this->mComment   = isset( $row['comment']    ) ?  trim( strval( $row['comment'] ) ) : null;
 			$this->mText      = isset( $row['text']       ) ? rtrim( strval( $row['text']    ) ) : null;
@@ -327,42 +355,55 @@ class Revision {
 			$this->mCurrent   = false;
 			# If we still have no len_size, see it we have the text to figure it out
 			if ( !$this->mSize )
-				$this->mSize      = is_null($this->mText) ? null : strlen($this->mText);
+				$this->mSize      = is_null( $this->mText ) ? null : strlen( $this->mText );
 		} else {
 			throw new MWException( 'Revision constructor passed invalid row format.' );
 		}
+		$this->mUnpatrolled = null;
 	}
 
-	/**#@+
-	 * @access public
-	 */
-
 	/**
-	 * @return int
+	 * Get revision ID
+	 *
+	 * @return Integer
 	 */
-	function getId() {
+	public function getId() {
 		return $this->mId;
 	}
 
 	/**
-	 * @return int
+	 * Get text row ID
+	 *
+	 * @return Integer
 	 */
-	function getTextId() {
+	public function getTextId() {
 		return $this->mTextId;
 	}
 
 	/**
-	 * Returns the length of the text in this revision, or null if unknown.
+	 * Get parent revision ID (the original previous page revision)
+	 *
+	 * @return Integer
 	 */
-	function getSize() {
+	public function getParentId() {
+		return $this->mParentId;
+	}
+
+	/**
+	 * Returns the length of the text in this revision, or null if unknown.
+	 *
+	 * @return Integer
+	 */
+	public function getSize() {
 		return $this->mSize;
 	}
 
 	/**
 	 * Returns the title of the page associated with this entry.
+	 *
 	 * @return Title
 	 */
-	function getTitle() {
+	public function getTitle() {
 		if( isset( $this->mTitle ) ) {
 			return $this->mTitle;
 		}
@@ -375,32 +416,46 @@ class Revision {
 			'Revision::getTitle' );
 		if( $row ) {
 			$this->mTitle = Title::makeTitle( $row->page_namespace,
-			                                   $row->page_title );
+			                                  $row->page_title );
 		}
 		return $this->mTitle;
 	}
 
 	/**
 	 * Set the title of the revision
-	 * @param Title $title
+	 *
+	 * @param $title Title
 	 */
-	function setTitle( $title ) {
+	public function setTitle( $title ) {
 		$this->mTitle = $title;
 	}
 
 	/**
-	 * @return int
+	 * Get the page ID
+	 *
+	 * @return Integer
 	 */
-	function getPage() {
+	public function getPage() {
 		return $this->mPage;
 	}
 
 	/**
-	 * Fetch revision's user id if it's available to all users
-	 * @return int
+	 * Fetch revision's user id if it's available to the specified audience.
+	 * If the specified audience does not have access to it, zero will be 
+	 * returned.
+	 *
+	 * @param $audience Integer: one of:
+	 *      Revision::FOR_PUBLIC       to be displayed to all users
+	 *      Revision::FOR_THIS_USER    to be displayed to $wgUser
+	 *      Revision::RAW              get the ID regardless of permissions
+	 *
+	 *
+	 * @return Integer
 	 */
-	function getUser() {
-		if( $this->isDeleted( self::DELETED_USER ) ) {
+	public function getUser( $audience = self::FOR_PUBLIC ) {
+		if( $audience == self::FOR_PUBLIC && $this->isDeleted( self::DELETED_USER ) ) {
+			return 0;
+		} elseif( $audience == self::FOR_THIS_USER && !$this->userCan( self::DELETED_USER ) ) {
 			return 0;
 		} else {
 			return $this->mUser;
@@ -409,19 +464,30 @@ class Revision {
 
 	/**
 	 * Fetch revision's user id without regard for the current user's permissions
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function getRawUser() {
+	public function getRawUser() {
 		return $this->mUser;
 	}
 
 	/**
-	 * Fetch revision's username if it's available to all users
+	 * Fetch revision's username if it's available to the specified audience.
+	 * If the specified audience does not have access to the username, an 
+	 * empty string will be returned.
+	 *
+	 * @param $audience Integer: one of:
+	 *      Revision::FOR_PUBLIC       to be displayed to all users
+	 *      Revision::FOR_THIS_USER    to be displayed to $wgUser
+	 *      Revision::RAW              get the text regardless of permissions
+	 *
 	 * @return string
 	 */
-	function getUserText() {
-		if( $this->isDeleted( self::DELETED_USER ) ) {
-			return "";
+	public function getUserText( $audience = self::FOR_PUBLIC ) {
+		if( $audience == self::FOR_PUBLIC && $this->isDeleted( self::DELETED_USER ) ) {
+			return '';
+		} elseif( $audience == self::FOR_THIS_USER && !$this->userCan( self::DELETED_USER ) ) {
+			return '';
 		} else {
 			return $this->mUserText;
 		}
@@ -429,19 +495,30 @@ class Revision {
 
 	/**
 	 * Fetch revision's username without regard for view restrictions
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function getRawUserText() {
+	public function getRawUserText() {
 		return $this->mUserText;
 	}
-	
+
 	/**
-	 * Fetch revision comment if it's available to all users
-	 * @return string
+	 * Fetch revision comment if it's available to the specified audience.
+	 * If the specified audience does not have access to the comment, an 
+	 * empty string will be returned.
+	 *
+	 * @param $audience Integer: one of:
+	 *      Revision::FOR_PUBLIC       to be displayed to all users
+	 *      Revision::FOR_THIS_USER    to be displayed to $wgUser
+	 *      Revision::RAW              get the text regardless of permissions
+	 *
+	 * @return String
 	 */
-	function getComment() {
-		if( $this->isDeleted( self::DELETED_COMMENT ) ) {
-			return "";
+	function getComment( $audience = self::FOR_PUBLIC ) {
+		if( $audience == self::FOR_PUBLIC && $this->isDeleted( self::DELETED_COMMENT ) ) {
+			return '';
+		} elseif( $audience == self::FOR_THIS_USER && !$this->userCan( self::DELETED_COMMENT ) ) {
+			return '';
 		} else {
 			return $this->mComment;
 		}
@@ -449,114 +526,183 @@ class Revision {
 
 	/**
 	 * Fetch revision comment without regard for the current user's permissions
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function getRawComment() {
+	public function getRawComment() {
 		return $this->mComment;
 	}
 
 	/**
-	 * @return bool
+	 * @return Boolean
 	 */
-	function isMinor() {
+	public function isMinor() {
 		return (bool)$this->mMinorEdit;
 	}
+	
+	/**
+	 * @return Integer rcid of the unpatrolled row, zero if there isn't one
+	 */
+	public function isUnpatrolled() {
+		if( $this->mUnpatrolled !== null ) {
+			return $this->mUnpatrolled;
+		}
+		$dbr = wfGetDB( DB_SLAVE );
+		$this->mUnpatrolled = $dbr->selectField( 'recentchanges',
+			'rc_id',
+			array( // Add redundant user,timestamp condition so we can use the existing index
+				'rc_user_text'  => $this->getRawUserText(),
+				'rc_timestamp'  => $dbr->timestamp( $this->getTimestamp() ),
+				'rc_this_oldid' => $this->getId(),
+				'rc_patrolled'  => 0
+			),
+			__METHOD__
+		);
+		return (int)$this->mUnpatrolled;
+	}
 
 	/**
 	 * int $field one of DELETED_* bitfield constants
-	 * @return bool
+	 *
+	 * @return Boolean
 	 */
-	function isDeleted( $field ) {
-		return ($this->mDeleted & $field) == $field;
+	public function isDeleted( $field ) {
+		return ( $this->mDeleted & $field ) == $field;
 	}
 
 	/**
-	 * Fetch revision text if it's available to all users
-	 * @return string
+	 * Get the deletion bitfield of the revision
 	 */
-	function getText() {
-		if( $this->isDeleted( self::DELETED_TEXT ) ) {
-			return "";
+	public function getVisibility() {
+		return (int)$this->mDeleted;
+	}
+
+	/**
+	 * Fetch revision text if it's available to the specified audience.
+	 * If the specified audience does not have the ability to view this 
+	 * revision, an empty string will be returned.
+	 *
+	 * @param $audience Integer: one of:
+	 *      Revision::FOR_PUBLIC       to be displayed to all users
+	 *      Revision::FOR_THIS_USER    to be displayed to $wgUser
+	 *      Revision::RAW              get the text regardless of permissions
+	 *
+	 *
+	 * @return String
+	 */
+	public function getText( $audience = self::FOR_PUBLIC ) {
+		if( $audience == self::FOR_PUBLIC && $this->isDeleted( self::DELETED_TEXT ) ) {
+			return '';
+		} elseif( $audience == self::FOR_THIS_USER && !$this->userCan( self::DELETED_TEXT ) ) {
+			return '';
 		} else {
 			return $this->getRawText();
 		}
 	}
-	
+
+	/**
+	 * Alias for getText(Revision::FOR_THIS_USER)
+	 *
+	 * @deprecated
+	 * @return String
+	 */
+	public function revText() {
+		return $this->getText( self::FOR_THIS_USER );
+	}
+
 	/**
 	 * Fetch revision text without regard for view restrictions
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function getRawText() {
+	public function getRawText() {
 		if( is_null( $this->mText ) ) {
 			// Revision text is immutable. Load on demand:
 			$this->mText = $this->loadText();
 		}
 		return $this->mText;
 	}
-	
+
 	/**
-	 * Fetch revision text if it's available to THIS user
-	 * @return string
+	 * @return String
 	 */
-	function revText() {
-		if( !$this->userCan( self::DELETED_TEXT ) ) {
-			return "";
-		} else {
-			return $this->getRawText();
-		}
+	public function getTimestamp() {
+		return wfTimestamp( TS_MW, $this->mTimestamp );
 	}
 
 	/**
-	 * @return string
+	 * @return Boolean
 	 */
-	function getTimestamp() {
-		return wfTimestamp(TS_MW, $this->mTimestamp);
-	}
-
-	/**
-	 * @return bool
-	 */
-	function isCurrent() {
+	public function isCurrent() {
 		return $this->mCurrent;
 	}
 
 	/**
-	 * @return Revision
+	 * Get previous revision for this title
+	 *
+	 * @return Revision or null
 	 */
-	function getPrevious() {
-		$prev = $this->mTitle->getPreviousRevisionID( $this->mId );
-		if ( $prev ) {
-			return Revision::newFromTitle( $this->mTitle, $prev );
-		} else {
-			return null;
+	public function getPrevious() {
+		if( $this->getTitle() ) {
+			$prev = $this->getTitle()->getPreviousRevisionID( $this->getId() );
+			if( $prev ) {
+				return Revision::newFromTitle( $this->getTitle(), $prev );
+			}
 		}
+		return null;
 	}
 
 	/**
-	 * @return Revision
+	 * Get next revision for this title
+	 *
+	 * @return Revision or null
 	 */
-	function getNext() {
-		$next = $this->mTitle->getNextRevisionID( $this->mId );
-		if ( $next ) {
-			return Revision::newFromTitle( $this->mTitle, $next );
-		} else {
-			return null;
+	public function getNext() {
+		if( $this->getTitle() ) {
+			$next = $this->getTitle()->getNextRevisionID( $this->getId() );
+			if ( $next ) {
+				return Revision::newFromTitle( $this->getTitle(), $next );
+			}
 		}
+		return null;
+	}
+
+	/**
+	 * Get previous revision Id for this page_id
+	 * This is used to populate rev_parent_id on save
+	 *
+	 * @param $db DatabaseBase
+	 * @return Integer
+	 */
+	private function getPreviousRevisionId( $db ) {
+		if( is_null( $this->mPage ) ) {
+			return 0;
+		}
+		# Use page_latest if ID is not given
+		if( !$this->mId ) {
+			$prevId = $db->selectField( 'page', 'page_latest',
+				array( 'page_id' => $this->mPage ),
+				__METHOD__ );
+		} else {
+			$prevId = $db->selectField( 'revision', 'rev_id',
+				array( 'rev_page' => $this->mPage, 'rev_id < ' . $this->mId ),
+				__METHOD__,
+				array( 'ORDER BY' => 'rev_id DESC' ) );
+		}
+		return intval( $prevId );
 	}
-	/**#@-*/
 
 	/**
 	  * Get revision text associated with an old or archive row
 	  * $row is usually an object from wfFetchRow(), both the flags and the text
 	  * field must be included
-	  * @static
-	  * @param integer $row Id of a row
-	  * @param string $prefix table prefix (default 'old_')
-	  * @return string $text|false the text requested
+	  *
+	  * @param $row Object: the text data
+	  * @param $prefix String: table prefix (default 'old_')
+	  * @return String: text the text requested or false on failure
 	  */
 	public static function getRevisionText( $row, $prefix = 'old_' ) {
-		$fname = 'Revision::getRevisionText';
-		wfProfileIn( $fname );
+		wfProfileIn( __METHOD__ );
 
 		# Get data
 		$textField = $prefix . 'text';
@@ -571,19 +717,19 @@ class Revision {
 		if( isset( $row->$textField ) ) {
 			$text = $row->$textField;
 		} else {
-			wfProfileOut( $fname );
+			wfProfileOut( __METHOD__ );
 			return false;
 		}
 
 		# Use external methods for external objects, text in table is URL-only then
 		if ( in_array( 'external', $flags ) ) {
-			$url=$text;
-			@list(/* $proto */,$path)=explode('://',$url,2);
-			if ($path=="") {
-				wfProfileOut( $fname );
+			$url = $text;
+			@list(/* $proto */, $path ) = explode( '://', $url, 2 );
+			if( $path == '' ) {
+				wfProfileOut( __METHOD__ );
 				return false;
 			}
-			$text=ExternalStore::fetchFromURL($url);
+			$text = ExternalStore::fetchFromURL( $url );
 		}
 
 		// If the text was fetched without an error, convert it
@@ -600,21 +746,25 @@ class Revision {
 				$obj = unserialize( $text );
 				if ( !is_object( $obj ) ) {
 					// Invalid object
-					wfProfileOut( $fname );
+					wfProfileOut( __METHOD__ );
 					return false;
 				}
 				$text = $obj->getText();
 			}
 
 			global $wgLegacyEncoding;
-			if( $wgLegacyEncoding && !in_array( 'utf-8', $flags ) ) {
+			if( $text !== false && $wgLegacyEncoding 
+				&& !in_array( 'utf-8', $flags ) && !in_array( 'utf8', $flags ) ) 
+			{
 				# Old revisions kept around in a legacy encoding?
 				# Upconvert on demand.
+				# ("utf8" checked for compatibility with some broken
+				#  conversion scripts 2008-12-30)
 				global $wgInputEncoding, $wgContLang;
 				$text = $wgContLang->iconv( $wgLegacyEncoding, $wgInputEncoding, $text );
 			}
 		}
-		wfProfileOut( $fname );
+		wfProfileOut( __METHOD__ );
 		return $text;
 	}
 
@@ -625,11 +775,10 @@ class Revision {
 	 * data is compressed, and 'utf-8' if we're saving in UTF-8
 	 * mode.
 	 *
-	 * @static
-	 * @param mixed $text reference to a text
-	 * @return string
+	 * @param $text Mixed: reference to a text
+	 * @return String
 	 */
-	function compressRevisionText( &$text ) {
+	public static function compressRevisionText( &$text ) {
 		global $wgCompressRevisions;
 		$flags = array();
 
@@ -652,33 +801,25 @@ class Revision {
 	 * Insert a new revision into the database, returning the new revision ID
 	 * number on success and dies horribly on failure.
 	 *
-	 * @param Database $dbw
-	 * @return int
+	 * @param $dbw DatabaseBase: (master connection)
+	 * @return Integer
 	 */
-	function insertOn( &$dbw ) {
+	public function insertOn( $dbw ) {
 		global $wgDefaultExternalStore;
-		
-		$fname = 'Revision::insertOn';
-		wfProfileIn( $fname );
+
+		wfProfileIn( __METHOD__ );
 
 		$data = $this->mText;
 		$flags = Revision::compressRevisionText( $data );
 
 		# Write to external storage if required
-		if ( $wgDefaultExternalStore ) {
-			if ( is_array( $wgDefaultExternalStore ) ) {
-				// Distribute storage across multiple clusters
-				$store = $wgDefaultExternalStore[mt_rand(0, count( $wgDefaultExternalStore ) - 1)];
-			} else {
-				$store = $wgDefaultExternalStore;
-			}
+		if( $wgDefaultExternalStore ) {
 			// Store and get the URL
-			$data = ExternalStore::insert( $store, $data );
-			if ( !$data ) {
-				# This should only happen in the case of a configuration error, where the external store is not valid
-				throw new MWException( "Unable to store text to external storage $store" );
+			$data = ExternalStore::insertToDefault( $data );
+			if( !$data ) {
+				throw new MWException( "Unable to store text to external storage" );
 			}
-			if ( $flags ) {
+			if( $flags ) {
 				$flags .= ',';
 			}
 			$flags .= 'external';
@@ -686,21 +827,23 @@ class Revision {
 
 		# Record the text (or external storage URL) to the text table
 		if( !isset( $this->mTextId ) ) {
-			$old_id = $dbw->nextSequenceValue( 'text_old_id_val' );
+			$old_id = $dbw->nextSequenceValue( 'text_old_id_seq' );
 			$dbw->insert( 'text',
 				array(
 					'old_id'    => $old_id,
 					'old_text'  => $data,
 					'old_flags' => $flags,
-				), $fname
+				), __METHOD__
 			);
 			$this->mTextId = $dbw->insertId();
 		}
 
+		if ( $this->mComment === null ) $this->mComment = "";
+
 		# Record the edit in revisions
 		$rev_id = isset( $this->mId )
 			? $this->mId
-			: $dbw->nextSequenceValue( 'rev_rev_id_val' );
+			: $dbw->nextSequenceValue( 'revision_rev_id_seq' );
 		$dbw->insert( 'revision',
 			array(
 				'rev_id'         => $rev_id,
@@ -712,12 +855,17 @@ class Revision {
 				'rev_user_text'  => $this->mUserText,
 				'rev_timestamp'  => $dbw->timestamp( $this->mTimestamp ),
 				'rev_deleted'    => $this->mDeleted,
-				'rev_len'	     => $this->mSize,
-			), $fname
+				'rev_len'        => $this->mSize,
+				'rev_parent_id'  => is_null($this->mParentId) ?
+					$this->getPreviousRevisionId( $dbw ) : $this->mParentId
+			), __METHOD__
 		);
 
-		$this->mId = !is_null($rev_id) ? $rev_id : $dbw->insertId();
-		wfProfileOut( $fname );
+		$this->mId = !is_null( $rev_id ) ? $rev_id : $dbw->insertId();
+
+		wfRunHooks( 'RevisionInsertComplete', array( &$this, $data, $flags ) );
+
+		wfProfileOut( __METHOD__ );
 		return $this->mId;
 	}
 
@@ -725,24 +873,24 @@ class Revision {
 	 * Lazy-load the revision's text.
 	 * Currently hardcoded to the 'text' table storage engine.
 	 *
-	 * @return string
-	 * @access private
+	 * @return String
 	 */
-	function loadText() {
-		$fname = 'Revision::loadText';
-		wfProfileIn( $fname );
-		
+	protected function loadText() {
+		wfProfileIn( __METHOD__ );
+
 		// Caching may be beneficial for massive use of external storage
 		global $wgRevisionCacheExpiry, $wgMemc;
-		$key = wfMemcKey( 'revisiontext', 'textid', $this->getTextId() );
+		$textId = $this->getTextId();
+		$key = wfMemcKey( 'revisiontext', 'textid', $textId );
 		if( $wgRevisionCacheExpiry ) {
 			$text = $wgMemc->get( $key );
 			if( is_string( $text ) ) {
-				wfProfileOut( $fname );
+				wfDebug( __METHOD__ . ": got id $textId from cache\n" );
+				wfProfileOut( __METHOD__ );
 				return $text;
 			}
 		}
-		
+
 		// If we kept data for lazy extraction, use it now...
 		if ( isset( $this->mTextRow ) ) {
 			$row = $this->mTextRow;
@@ -750,32 +898,33 @@ class Revision {
 		} else {
 			$row = null;
 		}
-		
+
 		if( !$row ) {
 			// Text data is immutable; check slaves first.
 			$dbr = wfGetDB( DB_SLAVE );
 			$row = $dbr->selectRow( 'text',
 				array( 'old_text', 'old_flags' ),
 				array( 'old_id' => $this->getTextId() ),
-				$fname);
+				__METHOD__ );
 		}
 
-		if( !$row ) {
+		if( !$row && wfGetLB()->getServerCount() > 1 ) {
 			// Possible slave lag!
 			$dbw = wfGetDB( DB_MASTER );
 			$row = $dbw->selectRow( 'text',
 				array( 'old_text', 'old_flags' ),
 				array( 'old_id' => $this->getTextId() ),
-				$fname);
+				__METHOD__ );
 		}
 
-		$text = Revision::getRevisionText( $row );
-		
-		if( $wgRevisionCacheExpiry ) {
+		$text = self::getRevisionText( $row );
+
+		# No negative caching -- negative hits on text rows may be due to corrupted slave servers
+		if( $wgRevisionCacheExpiry && $text !== false ) {
 			$wgMemc->set( $key, $text, $wgRevisionCacheExpiry );
 		}
-		
-		wfProfileOut( $fname );
+
+		wfProfileOut( __METHOD__ );
 
 		return $text;
 	}
@@ -788,18 +937,18 @@ class Revision {
 	 * Such revisions can for instance identify page rename
 	 * operations and other such meta-modifications.
 	 *
-	 * @param Database $dbw
-	 * @param int      $pageId ID number of the page to read from
-	 * @param string   $summary
-	 * @param bool     $minor
-	 * @return Revision
+	 * @param $dbw DatabaseBase
+	 * @param $pageId Integer: ID number of the page to read from
+	 * @param $summary String: revision's summary
+	 * @param $minor Boolean: whether the revision should be considered as minor
+	 * @return Mixed: Revision, or null on error
 	 */
-	public static function newNullRevision( &$dbw, $pageId, $summary, $minor ) {
+	public static function newNullRevision( $dbw, $pageId, $summary, $minor ) {
 		wfProfileIn( __METHOD__ );
 
 		$current = $dbw->selectRow(
 			array( 'page', 'revision' ),
-			array( 'page_latest', 'rev_text_id' ),
+			array( 'page_latest', 'rev_text_id', 'rev_len' ),
 			array(
 				'page_id' => $pageId,
 				'page_latest=rev_id',
@@ -812,6 +961,8 @@ class Revision {
 				'comment'    => $summary,
 				'minor_edit' => $minor,
 				'text_id'    => $current->rev_text_id,
+				'parent_id'  => $current->page_latest,
+				'len'        => $current->rev_len
 				) );
 		} else {
 			$revision = null;
@@ -820,46 +971,79 @@ class Revision {
 		wfProfileOut( __METHOD__ );
 		return $revision;
 	}
-	
+
 	/**
 	 * Determine if the current user is allowed to view a particular
 	 * field of this revision, if it's marked as deleted.
-	 * @param int $field one of self::DELETED_TEXT,
-	 *                          self::DELETED_COMMENT,
-	 *                          self::DELETED_USER
-	 * @return bool
+	 *
+	 * @param $field Integer:one of self::DELETED_TEXT,
+	 *                              self::DELETED_COMMENT,
+	 *                              self::DELETED_USER
+	 * @return Boolean
 	 */
-	function userCan( $field ) {
-		if( ( $this->mDeleted & $field ) == $field ) {
+	public function userCan( $field ) {
+		return self::userCanBitfield( $this->mDeleted, $field );
+	}
+
+	/**
+	 * Determine if the current user is allowed to view a particular
+	 * field of this revision, if it's marked as deleted. This is used
+	 * by various classes to avoid duplication.
+	 *
+	 * @param $bitfield Integer: current field
+	 * @param $field Integer: one of self::DELETED_TEXT = File::DELETED_FILE,
+	 *                               self::DELETED_COMMENT = File::DELETED_COMMENT,
+	 *                               self::DELETED_USER = File::DELETED_USER
+	 * @return Boolean
+	 */
+	public static function userCanBitfield( $bitfield, $field ) {
+		if( $bitfield & $field ) { // aspect is deleted
 			global $wgUser;
-			$permission = ( $this->mDeleted & self::DELETED_RESTRICTED ) == self::DELETED_RESTRICTED
-				? 'hiderevision'
-				: 'deleterevision';
-			wfDebug( "Checking for $permission due to $field match on $this->mDeleted\n" );
+			if ( $bitfield & self::DELETED_RESTRICTED ) {
+				$permission = 'suppressrevision';
+			} elseif ( $field & self::DELETED_TEXT ) {
+				$permission = 'deletedtext';
+			} else {
+				$permission = 'deletedhistory';
+			}
+			wfDebug( "Checking for $permission due to $field match on $bitfield\n" );
 			return $wgUser->isAllowed( $permission );
 		} else {
 			return true;
 		}
 	}
 
-
 	/**
 	 * Get rev_timestamp from rev_id, without loading the rest of the row
-	 * @param integer $id
+	 *
+	 * @param $title Title
+	 * @param $id Integer
+	 * @return String
 	 */
-	static function getTimestampFromID( $id ) {
+	static function getTimestampFromId( $title, $id ) {
 		$dbr = wfGetDB( DB_SLAVE );
-		$timestamp = $dbr->selectField( 'revision', 'rev_timestamp', 
-			array( 'rev_id' => $id ), __METHOD__ );
-		if ( $timestamp === false ) {
+		// Casting fix for DB2
+		if ( $id == '' ) {
+			$id = 0;
+		}
+		$conds = array( 'rev_id' => $id );
+		$conds['rev_page'] = $title->getArticleId();
+		$timestamp = $dbr->selectField( 'revision', 'rev_timestamp', $conds, __METHOD__ );
+		if ( $timestamp === false && wfGetLB()->getServerCount() > 1 ) {
 			# Not in slave, try master
 			$dbw = wfGetDB( DB_MASTER );
-			$timestamp = $dbw->selectField( 'revision', 'rev_timestamp', 
-				array( 'rev_id' => $id ), __METHOD__ );
+			$timestamp = $dbw->selectField( 'revision', 'rev_timestamp', $conds, __METHOD__ );
 		}
-		return $timestamp;
+		return wfTimestamp( TS_MW, $timestamp );
 	}
-	
+
+	/**
+	 * Get count of revisions per page...not very efficient
+	 *
+	 * @param $db DatabaseBase
+	 * @param $id Integer: page id
+	 * @return Integer
+	 */
 	static function countByPageId( $db, $id ) {
 		$row = $db->selectRow( 'revision', 'COUNT(*) AS revCount',
 			array( 'rev_page' => $id ), __METHOD__ );
@@ -868,7 +1052,14 @@ class Revision {
 		}
 		return 0;
 	}
-	
+
+	/**
+	 * Get count of revisions per page...not very efficient
+	 *
+	 * @param $db DatabaseBase
+	 * @param $title Title
+	 * @return Integer
+	 */
 	static function countByTitle( $db, $title ) {
 		$id = $title->getArticleId();
 		if( $id ) {
@@ -885,6 +1076,3 @@ define( 'MW_REV_DELETED_TEXT', Revision::DELETED_TEXT );
 define( 'MW_REV_DELETED_COMMENT', Revision::DELETED_COMMENT );
 define( 'MW_REV_DELETED_USER', Revision::DELETED_USER );
 define( 'MW_REV_DELETED_RESTRICTED', Revision::DELETED_RESTRICTED );
-
-
-
