@@ -1,6 +1,8 @@
 <?php
 /**
  * Include most things that's need to customize the site
+ *
+ * @file
  */
 
 /**
@@ -8,7 +10,6 @@
  * MEDIAWIKI is defined
  */
 if( !defined( 'MEDIAWIKI' ) ) {
-	echo "This file is part of MediaWiki, it is not a valid entry point.\n";
 	exit( 1 );
 }
 
@@ -30,6 +31,7 @@ if ( !isset( $wgVersion ) ) {
 // Set various default paths sensibly...
 if( $wgScript === false ) $wgScript = "$wgScriptPath/index$wgScriptExtension";
 if( $wgRedirectScript === false ) $wgRedirectScript = "$wgScriptPath/redirect$wgScriptExtension";
+if( $wgLoadScript === false ) $wgLoadScript = "$wgScriptPath/load$wgScriptExtension";
 
 if( $wgArticlePath === false ) {
 	if( $wgUsePathInfo ) {
@@ -40,7 +42,9 @@ if( $wgArticlePath === false ) {
 }
 
 if( $wgStylePath === false ) $wgStylePath = "$wgScriptPath/skins";
+if( $wgLocalStylePath === false ) $wgLocalStylePath = "$wgScriptPath/skins";
 if( $wgStyleDirectory === false) $wgStyleDirectory   = "$IP/skins";
+if( $wgExtensionAssetsPath === false ) $wgExtensionAssetsPath = "$wgScriptPath/extensions";
 
 if( $wgLogo === false ) $wgLogo = "$wgStylePath/common/images/wiki.png";
 
@@ -53,16 +57,39 @@ if( $wgTmpDirectory === false ) $wgTmpDirectory = "{$wgUploadDirectory}/tmp";
 
 if( $wgReadOnlyFile === false ) $wgReadOnlyFile = "{$wgUploadDirectory}/lock_yBgMBwiR";
 if( $wgFileCacheDirectory === false ) $wgFileCacheDirectory = "{$wgUploadDirectory}/cache";
+if( $wgDeletedDirectory === false ) $wgDeletedDirectory = "{$wgUploadDirectory}/deleted";
 
-if ( empty( $wgFileStore['deleted']['directory'] ) ) {
-	$wgFileStore['deleted']['directory'] = "{$wgUploadDirectory}/deleted";
+if( isset( $wgFileStore['deleted']['directory'] ) ) {
+	$wgDeletedDirectory = $wgFileStore['deleted']['directory'];
+}
+
+if( isset($wgFooterIcons["copyright"]) &&
+  isset($wgFooterIcons["copyright"]["copyright"]) &&
+  $wgFooterIcons["copyright"]["copyright"] === array() ) {
+	if ( isset( $wgCopyrightIcon ) && $wgCopyrightIcon ) {
+		$wgFooterIcons["copyright"]["copyright"] = $wgCopyrightIcon;
+	} elseif ( $wgRightsIcon || $wgRightsText ) {
+		$wgFooterIcons["copyright"]["copyright"] = array(
+			"url" => $wgRightsUrl,
+			"src" => $wgRightsIcon,
+			"alt" => $wgRightsText,
+		);
+	} else {
+		unset($wgFooterIcons["copyright"]["copyright"]);
+	}
+}
+
+if( isset($wgFooterIcons["poweredby"]) &&
+  isset($wgFooterIcons["poweredby"]["mediawiki"]) &&
+  $wgFooterIcons["poweredby"]["mediawiki"]["src"] === null ) {
+	$wgFooterIcons["poweredby"]["mediawiki"]["src"] = "$wgStylePath/common/images/poweredby_mediawiki_88x31.png";
 }
 
 /**
- * Unconditional protection for NS_MEDIAWIKI since otherwise it's too easy for a 
- * sysadmin to set $wgNamespaceProtection incorrectly and leave the wiki insecure. 
+ * Unconditional protection for NS_MEDIAWIKI since otherwise it's too easy for a
+ * sysadmin to set $wgNamespaceProtection incorrectly and leave the wiki insecure.
  *
- * Note that this is the definition of editinterface and it can be granted to 
+ * Note that this is the definition of editinterface and it can be granted to
  * all users if desired.
  */
 $wgNamespaceProtection[NS_MEDIAWIKI] = 'editinterface';
@@ -79,17 +106,23 @@ $wgNamespaceAliases['Image_talk'] = NS_FILE_TALK;
  * Initialise $wgLocalFileRepo from backwards-compatible settings
  */
 if ( !$wgLocalFileRepo ) {
+	if( isset( $wgFileStore['deleted']['hash'] ) ) {
+		$deletedHashLevel = $wgFileStore['deleted']['hash'];
+	} else {
+		$deletedHashLevel = $wgHashedUploadDirectory ? 3 : 0;
+	}
 	$wgLocalFileRepo = array(
 		'class' => 'LocalRepo',
 		'name' => 'local',
 		'directory' => $wgUploadDirectory,
+		'scriptDirUrl' => $wgScriptPath,
+		'scriptExtension' => $wgScriptExtension,
 		'url' => $wgUploadBaseUrl ? $wgUploadBaseUrl . $wgUploadPath : $wgUploadPath,
 		'hashLevels' => $wgHashedUploadDirectory ? 2 : 0,
 		'thumbScriptUrl' => $wgThumbnailScriptPath,
 		'transformVia404' => !$wgGenerateThumbnailOnParse,
-		'initialCapital' => $wgCapitalLinks,
-		'deletedDir' => $wgFileStore['deleted']['directory'],
-		'deletedHashLevels' => $wgFileStore['deleted']['hash']
+		'deletedDir' => $wgDeletedDirectory,
+		'deletedHashLevels' => $deletedHashLevel
 	);
 }
 /**
@@ -130,6 +163,18 @@ if ( $wgUseSharedUploads ) {
 		);
 	}
 }
+if( $wgUseInstantCommons ) {
+	$wgForeignFileRepos[] = array(
+		'class'                   => 'ForeignAPIRepo',
+		'name'                    => 'wikimediacommons',
+		'apibase'                 => 'http://commons.wikimedia.org/w/api.php',
+		'hashLevels'              => 2,
+		'fetchDescription'        => true,
+		'descriptionCacheExpiry'  => 43200,
+		'apiThumbCacheExpiry'     => 86400,
+	);
+}
+
 if ( !class_exists( 'AutoLoader' ) ) {
 	require_once( "$IP/includes/AutoLoader.php" );
 }
@@ -146,28 +191,55 @@ require_once( "$IP/includes/Namespace.php" );
 require_once( "$IP/includes/ProxyTools.php" );
 require_once( "$IP/includes/ObjectCache.php" );
 require_once( "$IP/includes/ImageFunctions.php" );
-require_once( "$IP/includes/StubObject.php" );
 wfProfileOut( $fname.'-includes' );
 wfProfileIn( $fname.'-misc1' );
 
+# Raise the memory limit if it's too low
+wfMemoryLimit();
+
+/**
+ * Set up the timezone, suppressing the pseudo-security warning in PHP 5.1+
+ * that happens whenever you use a date function without the timezone being
+ * explicitly set. Inspired by phpMyAdmin's treatment of the problem.
+ */
+wfSuppressWarnings();
+date_default_timezone_set( date_default_timezone_get() );
+wfRestoreWarnings();
 
-$wgIP = false; # Load on demand
 # Can't stub this one, it sets up $_GET and $_REQUEST in its constructor
 $wgRequest = new WebRequest;
 
 # Useful debug output
+global $wgCommandLineMode;
 if ( $wgCommandLineMode ) {
 	wfDebug( "\n\nStart command line script $self\n" );
-} elseif ( function_exists( 'getallheaders' ) ) {
-	wfDebug( "\n\nStart request\n" );
-	wfDebug( $_SERVER['REQUEST_METHOD'] . ' ' . $_SERVER['REQUEST_URI'] . "\n" );
-	$headers = getallheaders();
-	foreach ($headers as $name => $value) {
-		wfDebug( "$name: $value\n" );
+} else {
+	wfDebug( "Start request\n\n" );
+	# Output the REQUEST_URI. This is not supported by IIS in rewrite mode,
+	# so use an alternative
+	$requestUri = isset( $_SERVER['REQUEST_URI'] ) ? $_SERVER['REQUEST_URI'] :
+		( isset( $_SERVER['HTTP_X_ORIGINAL_URL'] ) ? $_SERVER['HTTP_X_ORIGINAL_URL'] :
+		$_SERVER['PHP_SELF'] );
+	wfDebug( "{$_SERVER['REQUEST_METHOD']} {$requestUri}\n" );
+
+	if ( $wgDebugPrintHttpHeaders ) {
+		$headerOut = "HTTP HEADERS:\n";
+
+		if ( function_exists( 'getallheaders' ) ) {
+			$headers = getallheaders();
+			foreach ( $headers as $name => $value ) {
+				$headerOut .= "$name: $value\n";
+			}
+		} else {
+			$headers = $_SERVER;
+			foreach ( $headers as $name => $value ) {
+				if ( substr( $name, 0, 5 ) !== 'HTTP_' ) continue;
+				$name = substr( $name, 5 );
+				$headerOut .= "$name: $value\n";
+			}
+		}
+		wfDebug( "$headerOut\n" );
 	}
-	wfDebug( "\n" );
-} elseif( isset( $_SERVER['REQUEST_URI'] ) ) {
-	wfDebug( $_SERVER['REQUEST_METHOD'] . ' ' . $_SERVER['REQUEST_URI'] . "\n" );
 }
 
 if( $wgRCFilterByAge ) {
@@ -201,6 +273,29 @@ $wgContLanguageCode = $wgLanguageCode;
 # If file cache or squid cache is on, just disable this (DWIMD).
 if( $wgUseFileCache || $wgUseSquid ) $wgShowIPinHeader = false;
 
+# $wgAllowRealName and $wgAllowUserSkin were removed in 1.16
+# in favor of $wgHiddenPrefs, handle b/c here
+if( !$wgAllowRealName ) {
+	$wgHiddenPrefs[] = 'realname';
+}
+
+if( !$wgAllowUserSkin ) {
+	$wgHiddenPrefs[] = 'skin';
+}
+
+if ( !$wgHtml5Version && $wgHtml5 && $wgAllowRdfaAttributes ) {
+	# see http://www.w3.org/TR/rdfa-in-html/#document-conformance
+	if ( $wgMimeType == 'application/xhtml+xml' ) $wgHtml5Version = 'XHTML+RDFa 1.0';
+	else $wgHtml5Version = 'HTML+RDFa 1.0';
+}
+
+if ( $wgInvalidateCacheOnLocalSettingsChange ) {
+	$wgCacheEpoch = max( $wgCacheEpoch, gmdate( 'YmdHis', @filemtime( "$IP/LocalSettings.php" ) ) );
+}
+
+# Blacklisted file extensions shouldn't appear on the "allowed" list
+$wgFileExtensions = array_diff ( $wgFileExtensions, $wgFileBlacklist );
+
 wfProfileOut( $fname.'-misc1' );
 wfProfileIn( $fname.'-memcached' );
 
@@ -208,9 +303,9 @@ $wgMemc =& wfGetMainCache();
 $messageMemc =& wfGetMessageCacheStorage();
 $parserMemc =& wfGetParserCacheStorage();
 
-wfDebug( 'Main cache: ' . get_class( $wgMemc ) .
-	"\nMessage cache: " . get_class( $messageMemc ) .
-	"\nParser cache: " . get_class( $parserMemc ) . "\n" );
+wfDebug( 'CACHES: ' . get_class( $wgMemc ) . '[main] ' .
+	get_class( $messageMemc ) . '[message] ' .
+	get_class( $parserMemc ) . "[parser]\n" );
 
 wfProfileOut( $fname.'-memcached' );
 
@@ -240,13 +335,15 @@ $wgCookiePrefix = strtr($wgCookiePrefix, "=,; +.\"'\\[", "__________");
 if( !wfIniGetBool( 'session.auto_start' ) )
 	session_name( $wgSessionName ? $wgSessionName : $wgCookiePrefix . '_session' );
 
-if( !$wgCommandLineMode && ( $wgRequest->checkSessionCookie() || isset( $_COOKIE[$wgCookiePrefix.'Token'] ) ) ) {
-	wfIncrStats( 'request_with_session' );
-	wfSetupSession();
-	$wgSessionStarted = true;
-} else {
-	wfIncrStats( 'request_without_session' );
-	$wgSessionStarted = false;
+if( !defined( 'MW_NO_SESSION' ) && !$wgCommandLineMode ) {
+	if( $wgRequest->checkSessionCookie() || isset( $_COOKIE[$wgCookiePrefix.'Token'] ) ) {
+		wfIncrStats( 'request_with_session' );
+		wfSetupSession();
+		$wgSessionStarted = true;
+	} else {
+		wfIncrStats( 'request_without_session' );
+		$wgSessionStarted = false;
+	}
 }
 
 wfProfileOut( $fname.'-SetupSession' );
@@ -256,14 +353,13 @@ $wgContLang = new StubContLang;
 
 // Now that variant lists may be available...
 $wgRequest->interpolateTitle();
-
-$wgUser = new StubUser;
+$wgUser = $wgCommandLineMode ? new User : User::newFromSession();
 $wgLang = new StubUserLang;
 $wgOut = new StubObject( 'wgOut', 'OutputPage' );
 $wgParser = new StubObject( 'wgParser', $wgParserConf['class'], array( $wgParserConf ) );
 
 $wgMessageCache = new StubObject( 'wgMessageCache', 'MessageCache',
-	array( $messageMemc, $wgUseDatabaseMessages, $wgMsgCacheExpiry, wfWikiID() ) );
+	array( $messageMemc, $wgUseDatabaseMessages, $wgMsgCacheExpiry ) );
 
 wfProfileOut( $fname.'-globals' );
 wfProfileIn( $fname.'-User' );
@@ -286,12 +382,8 @@ wfProfileOut( $fname.'-User' );
 wfProfileIn( $fname.'-misc2' );
 
 $wgDeferredUpdateList = array();
-$wgPostCommitUpdateList = array();
 
-if ( $wgAjaxWatch ) $wgAjaxExportList[] = 'wfAjaxWatch';
-if ( $wgAjaxUploadDestCheck ) $wgAjaxExportList[] = 'UploadForm::ajaxGetExistsWarning';
-if( $wgAjaxLicensePreview )
-	$wgAjaxExportList[] = 'UploadForm::ajaxGetLicensePreview';
+if ( $wgAjaxUploadDestCheck ) $wgAjaxExportList[] = 'SpecialUpload::ajaxGetExistsWarning';
 
 # Placeholders in case of DB error
 $wgTitle = null;
@@ -305,7 +397,18 @@ wfProfileIn( $fname.'-extensions' );
 # of the extension file. This allows the extension to perform
 # any necessary initialisation in the fully initialised environment
 foreach ( $wgExtensionFunctions as $func ) {
-	$profName = $fname.'-extensions-'.strval( $func );
+	# Allow closures in PHP 5.3+
+	if ( is_object( $func ) && $func instanceof Closure ) {
+		$profName = $fname.'-extensions-closure';
+	} elseif( is_array( $func ) ) {
+		if ( is_object( $func[0] ) )
+			$profName = $fname.'-extensions-'.get_class( $func[0] ).'::'.$func[1];
+		else
+			$profName = $fname.'-extensions-'.implode( '::', $func );
+	} else {
+		$profName = $fname.'-extensions-'.strval( $func );
+	}
+
 	wfProfileIn( $profName );
 	call_user_func( $func );
 	wfProfileOut( $profName );
