@@ -1,35 +1,28 @@
 <?php
 /**
  * Deal with importing all those nasssty globals and things
+ *
+ * Copyright © 2003 Brion Vibber <brion@pobox.com>
+ * http://www.mediawiki.org/
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-# Copyright (C) 2003 Brion Vibber <brion@pobox.com>
-# http://www.mediawiki.org/
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-# http://www.gnu.org/copyleft/gpl.html
-
-
-/**
- * Some entry points may use this file without first enabling the
- * autoloader.
- */
-if ( !function_exists( '__autoload' ) ) {
-	require_once( dirname(__FILE__) . '/normal/UtfNormal.php' );
-}
-
 /**
  * The WebRequest class encapsulates getting at data passed in the
  * URL or via a POSTed form, handling remove of "magic quotes" slashes,
@@ -40,21 +33,26 @@ if ( !function_exists( '__autoload' ) ) {
  * you want to pass arbitrary data to some function in place of the web
  * input.
  *
+ * @ingroup HTTP
  */
 class WebRequest {
-	var $data = array();
-	var $headers;
-	private $_response;
+	protected $data, $headers = array();
 
-	function __construct() {
-		/// @fixme This preemptive de-quoting can interfere with other web libraries
+	/**
+	 * Lazy-init response object
+	 * @var WebResponse
+	 */
+	private $response;
+
+	public function __construct() {
+		/// @todo Fixme: this preemptive de-quoting can interfere with other web libraries
 		///        and increases our memory footprint. It would be cleaner to do on
 		///        demand; but currently we have no wrapper for $_SERVER etc.
 		$this->checkMagicQuotes();
 
 		// POST overrides GET data
 		// We don't use $_REQUEST here to avoid interference from cookies...
-		$this->data = wfArrayMerge( $_GET, $_POST );
+		$this->data = $_POST + $_GET;
 	}
 
 	/**
@@ -64,13 +62,20 @@ class WebRequest {
 	 * as we may need the list of language variants to determine
 	 * available variant URLs.
 	 */
-	function interpolateTitle() {
+	public function interpolateTitle() {
 		global $wgUsePathInfo;
+
+		// bug 16019: title interpolation on API queries is useless and possible harmful
+		if ( defined( 'MW_API' ) ) {
+			return;
+		}
+
 		if ( $wgUsePathInfo ) {
 			// PATH_INFO is mangled due to http://bugs.php.net/bug.php?id=31892
 			// And also by Apache 2.x, double slashes are converted to single slashes.
 			// So we will use REQUEST_URI if possible.
 			$matches = array();
+
 			if ( !empty( $_SERVER['REQUEST_URI'] ) ) {
 				// Slurp out the path portion to examine...
 				$url = $_SERVER['REQUEST_URI'];
@@ -158,11 +163,11 @@ class WebRequest {
 	/**
 	 * Recursively strips slashes from the given array;
 	 * used for undoing the evil that is magic_quotes_gpc.
+	 *
 	 * @param $arr array: will be modified
 	 * @return array the original array
-	 * @private
 	 */
-	function &fix_magic_quotes( &$arr ) {
+	private function &fix_magic_quotes( &$arr ) {
 		foreach( $arr as $key => $val ) {
 			if( is_array( $val ) ) {
 				$this->fix_magic_quotes( $arr[$key] );
@@ -178,10 +183,11 @@ class WebRequest {
 	 * through fix_magic_quotes to strip out the stupid slashes.
 	 * WARNING: This should only be done once! Running a second
 	 * time could damage the values.
-	 * @private
 	 */
-	function checkMagicQuotes() {
-		if ( function_exists( 'get_magic_quotes_gpc' ) && get_magic_quotes_gpc() ) {
+	private function checkMagicQuotes() {
+		$mustFixQuotes = function_exists( 'get_magic_quotes_gpc' )
+			&& get_magic_quotes_gpc();
+		if( $mustFixQuotes ) {
 			$this->fix_magic_quotes( $_COOKIE );
 			$this->fix_magic_quotes( $_ENV );
 			$this->fix_magic_quotes( $_GET );
@@ -193,6 +199,7 @@ class WebRequest {
 
 	/**
 	 * Recursively normalizes UTF-8 strings in the given array.
+	 *
 	 * @param $data string or array
 	 * @return cleaned-up version of the given
 	 * @private
@@ -203,7 +210,8 @@ class WebRequest {
 				$data[$key] = $this->normalizeUnicode( $val );
 			}
 		} else {
-			$data = UtfNormal::cleanUp( $data );
+			global $wgContLang;
+			$data = $wgContLang->normalize( $data );
 		}
 		return $data;
 	}
@@ -211,13 +219,16 @@ class WebRequest {
 	/**
 	 * Fetch a value from the given array or return $default if it's not set.
 	 *
-	 * @param $arr array
-	 * @param $name string
-	 * @param $default mixed
+	 * @param $arr Array
+	 * @param $name String
+	 * @param $default Mixed
 	 * @return mixed
-	 * @private
 	 */
-	function getGPCVal( $arr, $name, $default ) {
+	private function getGPCVal( $arr, $name, $default ) {
+		# PHP is so nice to not touch input data, except sometimes:
+		# http://us2.php.net/variables.external#language.variables.external.dot-in-names
+		# Work around PHP *feature* to avoid *bugs* elsewhere.
+		$name = strtr( $name, '.', '_' );
 		if( isset( $arr[$name] ) ) {
 			global $wgContLang;
 			$data = $arr[$name];
@@ -230,6 +241,7 @@ class WebRequest {
 			$data = $this->normalizeUnicode( $data );
 			return $data;
 		} else {
+			taint( $default );
 			return $default;
 		}
 	}
@@ -240,32 +252,45 @@ class WebRequest {
 	 * non-freeform text inputs (e.g. predefined internal text keys
 	 * selected by a drop-down menu). For freeform input, see getText().
 	 *
-	 * @param $name string
-	 * @param $default string: optional default (or NULL)
-	 * @return string
+	 * @param $name String
+	 * @param $default String: optional default (or NULL)
+	 * @return String
 	 */
-	function getVal( $name, $default = NULL ) {
+	public function getVal( $name, $default = null ) {
 		$val = $this->getGPCVal( $this->data, $name, $default );
 		if( is_array( $val ) ) {
 			$val = $default;
 		}
 		if( is_null( $val ) ) {
-			return null;
+			return $val;
 		} else {
 			return (string)$val;
 		}
 	}
 
+	/**
+	 * Set an aribtrary value into our get/post data.
+	 *
+	 * @param $key String: key name to use
+	 * @param $value Mixed: value to set
+	 * @return Mixed: old value if one was present, null otherwise
+	 */
+	public function setVal( $key, $value ) {
+		$ret = isset( $this->data[$key] ) ? $this->data[$key] : null;
+		$this->data[$key] = $value;
+		return $ret;
+	}
+
 	/**
 	 * Fetch an array from the input or return $default if it's not set.
 	 * If source was scalar, will return an array with a single element.
 	 * If no source and no default, returns NULL.
 	 *
-	 * @param $name string
-	 * @param $default array: optional default (or NULL)
-	 * @return array
+	 * @param $name String
+	 * @param $default Array: optional default (or NULL)
+	 * @return Array
 	 */
-	function getArray( $name, $default = NULL ) {
+	public function getArray( $name, $default = null ) {
 		$val = $this->getGPCVal( $this->data, $name, $default );
 		if( is_null( $val ) ) {
 			return null;
@@ -280,11 +305,11 @@ class WebRequest {
 	 * If no source and no default, returns NULL.
 	 * If an array is returned, contents are guaranteed to be integers.
 	 *
-	 * @param $name string
-	 * @param $default array: option default (or NULL)
-	 * @return array of ints
+	 * @param $name String
+	 * @param $default Array: option default (or NULL)
+	 * @return Array of ints
 	 */
-	function getIntArray( $name, $default = NULL ) {
+	public function getIntArray( $name, $default = null ) {
 		$val = $this->getArray( $name, $default );
 		if( is_array( $val ) ) {
 			$val = array_map( 'intval', $val );
@@ -296,11 +321,12 @@ class WebRequest {
 	 * Fetch an integer value from the input or return $default if not set.
 	 * Guaranteed to return an integer; non-numeric input will typically
 	 * return 0.
-	 * @param $name string
-	 * @param $default int
-	 * @return int
+	 *
+	 * @param $name String
+	 * @param $default Integer
+	 * @return Integer
 	 */
-	function getInt( $name, $default = 0 ) {
+	public function getInt( $name, $default = 0 ) {
 		return intval( $this->getVal( $name, $default ) );
 	}
 
@@ -308,10 +334,11 @@ class WebRequest {
 	 * Fetch an integer value from the input or return null if empty.
 	 * Guaranteed to return an integer or null; non-numeric input will
 	 * typically return null.
-	 * @param $name string
-	 * @return int
+	 *
+	 * @param $name String
+	 * @return Integer
 	 */
-	function getIntOrNull( $name ) {
+	public function getIntOrNull( $name ) {
 		$val = $this->getVal( $name );
 		return is_numeric( $val )
 			? intval( $val )
@@ -322,41 +349,56 @@ class WebRequest {
 	 * Fetch a boolean value from the input or return $default if not set.
 	 * Guaranteed to return true or false, with normal PHP semantics for
 	 * boolean interpretation of strings.
-	 * @param $name string
-	 * @param $default bool
-	 * @return bool
+	 *
+	 * @param $name String
+	 * @param $default Boolean
+	 * @return Boolean
 	 */
-	function getBool( $name, $default = false ) {
-		return $this->getVal( $name, $default ) ? true : false;
+	public function getBool( $name, $default = false ) {
+		return (bool)$this->getVal( $name, $default );
+	}
+	
+	/**
+	 * Fetch a boolean value from the input or return $default if not set.
+	 * Unlike getBool, the string "false" will result in boolean false, which is
+	 * useful when interpreting information sent from JavaScript.
+	 *
+	 * @param $name String
+	 * @param $default Boolean
+	 * @return Boolean
+	 */
+	public function getFuzzyBool( $name, $default = false ) {
+		return $this->getBool( $name, $default ) && strcasecmp( $this->getVal( $name ), 'false' ) !== 0;
 	}
 
 	/**
 	 * Return true if the named value is set in the input, whatever that
 	 * value is (even "0"). Return false if the named value is not set.
 	 * Example use is checking for the presence of check boxes in forms.
-	 * @param $name string
-	 * @return bool
+	 *
+	 * @param $name String
+	 * @return Boolean
 	 */
-	function getCheck( $name ) {
+	public function getCheck( $name ) {
 		# Checkboxes and buttons are only present when clicked
 		# Presence connotes truth, abscense false
-		$val = $this->getVal( $name, NULL );
+		$val = $this->getVal( $name, null );
 		return isset( $val );
 	}
 
 	/**
 	 * Fetch a text string from the given array or return $default if it's not
-	 * set. \r is stripped from the text, and with some language modules there
-	 * is an input transliteration applied. This should generally be used for
-	 * form <textarea> and <input> fields. Used for user-supplied freeform text
-	 * input (for which input transformations may be required - e.g. Esperanto
-	 * x-coding).
+	 * set. Carriage returns are stripped from the text, and with some language
+	 * modules there is an input transliteration applied. This should generally
+	 * be used for form <textarea> and <input> fields. Used for user-supplied
+	 * freeform text input (for which input transformations may be required - e.g.
+	 * Esperanto x-coding).
 	 *
-	 * @param $name string
-	 * @param $default string: optional
-	 * @return string
+	 * @param $name String
+	 * @param $default String: optional
+	 * @return String
 	 */
-	function getText( $name, $default = '' ) {
+	public function getText( $name, $default = '' ) {
 		global $wgContLang;
 		$val = $this->getVal( $name, $default );
 		return str_replace( "\r\n", "\n",
@@ -368,7 +410,7 @@ class WebRequest {
 	 * If no arguments are given, returns all input values.
 	 * No transformation is performed on the values.
 	 */
-	function getValues() {
+	public function getValues() {
 		$names = func_get_args();
 		if ( count( $names ) == 0 ) {
 			$names = array_keys( $this->data );
@@ -391,9 +433,9 @@ class WebRequest {
 	 * Note that values retrieved by the object may come from the
 	 * GET URL etc even on a POST request.
 	 *
-	 * @return bool
+	 * @return Boolean
 	 */
-	function wasPosted() {
+	public function wasPosted() {
 		return $_SERVER['REQUEST_METHOD'] == 'POST';
 	}
 
@@ -406,18 +448,35 @@ class WebRequest {
 	 * during the current request (in which case the cookie will
 	 * be sent back to the client at the end of the script run).
 	 *
-	 * @return bool
+	 * @return Boolean
 	 */
-	function checkSessionCookie() {
-		return isset( $_COOKIE[session_name()] );
+	public function checkSessionCookie() {
+		return isset( $_COOKIE[ session_name() ] );
+	}
+
+	/**
+	 * Get a cookie from the $_COOKIE jar
+	 *
+	 * @param $key String: the name of the cookie
+	 * @param $prefix String: a prefix to use for the cookie name, if not $wgCookiePrefix
+	 * @param $default Mixed: what to return if the value isn't found
+	 * @return Mixed: cookie value or $default if the cookie not set
+	 */
+	public function getCookie( $key, $prefix = null, $default = null ) {
+		if( $prefix === null ) {
+			global $wgCookiePrefix;
+			$prefix = $wgCookiePrefix;
+		}
+		return $this->getGPCVal( $_COOKIE, $prefix . $key , $default );
 	}
 
 	/**
 	 * Return the path portion of the request URI.
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function getRequestURL() {
-		if( isset( $_SERVER['REQUEST_URI'] ) ) {
+	public function getRequestURL() {
+		if( isset( $_SERVER['REQUEST_URI']) && strlen($_SERVER['REQUEST_URI']) ) {
 			$base = $_SERVER['REQUEST_URI'];
 		} elseif( isset( $_SERVER['SCRIPT_NAME'] ) ) {
 			// Probably IIS; doesn't set REQUEST_URI
@@ -449,9 +508,10 @@ class WebRequest {
 
 	/**
 	 * Return the request URI with the canonical service and hostname.
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function getFullRequestURL() {
+	public function getFullRequestURL() {
 		global $wgServer;
 		return $wgServer . $this->getRequestURL();
 	}
@@ -459,9 +519,10 @@ class WebRequest {
 	/**
 	 * Take an arbitrary query and rewrite the present URL to include it
 	 * @param $query String: query string fragment; do not include initial '?'
-	 * @return string
+	 *
+	 * @return String
 	 */
-	function appendQuery( $query ) {
+	public function appendQuery( $query ) {
 		global $wgTitle;
 		$basequery = '';
 		foreach( $_GET as $var => $val ) {
@@ -483,31 +544,33 @@ class WebRequest {
 
 	/**
 	 * HTML-safe version of appendQuery().
+	 *
 	 * @param $query String: query string fragment; do not include initial '?'
-	 * @return string
+	 * @return String
 	 */
-	function escapeAppendQuery( $query ) {
+	public function escapeAppendQuery( $query ) {
 		return htmlspecialchars( $this->appendQuery( $query ) );
 	}
 
-	function appendQueryValue( $key, $value, $onlyquery = false ) {
+	public function appendQueryValue( $key, $value, $onlyquery = false ) {
 		return $this->appendQueryArray( array( $key => $value ), $onlyquery );
 	}
 
 	/**
 	 * Appends or replaces value of query variables.
+	 *
 	 * @param $array Array of values to replace/add to query
 	 * @param $onlyquery Bool: whether to only return the query string and not
 	 *                   the complete URL
-	 * @return string
+	 * @return String
 	 */
-	function appendQueryArray( $array, $onlyquery = false ) {
+	public function appendQueryArray( $array, $onlyquery = false ) {
 		global $wgTitle;
 		$newquery = $_GET;
 		unset( $newquery['title'] );
 		$newquery = array_merge( $newquery, $array );
 		$query = wfArrayToCGI( $newquery );
-		return $onlyquery ? $query : $wgTitle->getLocalURL( $basequery );
+		return $onlyquery ? $query : $wgTitle->getLocalURL( $query );
 	}
 
 	/**
@@ -519,57 +582,63 @@ class WebRequest {
 	 * @param $optionname String: to specify an option other than rclimit to pull from.
 	 * @return array first element is limit, second is offset
 	 */
-	function getLimitOffset( $deflimit = 50, $optionname = 'rclimit' ) {
+	public function getLimitOffset( $deflimit = 50, $optionname = 'rclimit' ) {
 		global $wgUser;
 
 		$limit = $this->getInt( 'limit', 0 );
-		if( $limit < 0 ) $limit = 0;
+		if( $limit < 0 ) {
+			$limit = 0;
+		}
 		if( ( $limit == 0 ) && ( $optionname != '' ) ) {
 			$limit = (int)$wgUser->getOption( $optionname );
 		}
-		if( $limit <= 0 ) $limit = $deflimit;
-		if( $limit > 5000 ) $limit = 5000; # We have *some* limits...
+		if( $limit <= 0 ) {
+			$limit = $deflimit;
+		}
+		if( $limit > 5000 ) {
+			$limit = 5000; # We have *some* limits...
+		}
 
 		$offset = $this->getInt( 'offset', 0 );
-		if( $offset < 0 ) $offset = 0;
+		if( $offset < 0 ) {
+			$offset = 0;
+		}
 
 		return array( $limit, $offset );
 	}
 
 	/**
 	 * Return the path to the temporary file where PHP has stored the upload.
+	 *
 	 * @param $key String:
 	 * @return string or NULL if no such file.
 	 */
-	function getFileTempname( $key ) {
-		if( !isset( $_FILES[$key] ) ) {
-			return NULL;
-		}
-		return $_FILES[$key]['tmp_name'];
+	public function getFileTempname( $key ) {
+		$file = new WebRequestUpload( $this, $key );
+		return $file->getTempName();
 	}
 
 	/**
 	 * Return the size of the upload, or 0.
+	 *
+	 * @deprecated
 	 * @param $key String:
 	 * @return integer
 	 */
-	function getFileSize( $key ) {
-		if( !isset( $_FILES[$key] ) ) {
-			return 0;
-		}
-		return $_FILES[$key]['size'];
+	public function getFileSize( $key ) {
+		$file = new WebRequestUpload( $this, $key );
+		return $file->getSize();
 	}
 
 	/**
 	 * Return the upload error or 0
+	 *
 	 * @param $key String:
 	 * @return integer
 	 */
-	function getUploadError( $key ) {
-		if( !isset( $_FILES[$key] ) || !isset( $_FILES[$key]['error'] ) ) {
-			return 0/*UPLOAD_ERR_OK*/;
-		}
-		return $_FILES[$key]['error'];
+	public function getUploadError( $key ) {
+		$file = new WebRequestUpload( $this, $key );
+		return $file->getError();
 	}
 
 	/**
@@ -583,41 +652,44 @@ class WebRequest {
 	 * @param $key String:
 	 * @return string or NULL if no such file.
 	 */
-	function getFileName( $key ) {
-		if( !isset( $_FILES[$key] ) ) {
-			return NULL;
-		}
-		$name = $_FILES[$key]['name'];
+	public function getFileName( $key ) {
+		$file = new WebRequestUpload( $this, $key );
+		return $file->getName();
+	}
 
-		# Safari sends filenames in HTML-encoded Unicode form D...
-		# Horrid and evil! Let's try to make some kind of sense of it.
-		$name = Sanitizer::decodeCharReferences( $name );
-		$name = UtfNormal::cleanUp( $name );
-		wfDebug( "WebRequest::getFileName() '" . $_FILES[$key]['name'] . "' normalized to '$name'\n" );
-		return $name;
+	/**
+	 * Return a WebRequestUpload object corresponding to the key
+	 *
+	 * @param @key string
+	 * @return WebRequestUpload
+	 */
+	public function getUpload( $key ) {
+		return new WebRequestUpload( $this, $key );
 	}
 
 	/**
 	 * Return a handle to WebResponse style object, for setting cookies,
 	 * headers and other stuff, for Request being worked on.
+	 *
+	 * @return WebResponse
 	 */
-	function response() {
+	public function response() {
 		/* Lazy initialization of response object for this request */
-		if (!is_object($this->_response)) {
-			$this->_response = new WebResponse;
+		if ( !is_object( $this->response ) ) {
+			$class = ( $this instanceof FauxRequest ) ? 'FauxResponse' : 'WebResponse';
+			$this->response = new $class();
 		}
-		return $this->_response;
+		return $this->response;
 	}
 
 	/**
 	 * Get a request header, or false if it isn't set
 	 * @param $name String: case-insensitive header name
 	 */
-	function getHeader( $name ) {
+	public function getHeader( $name ) {
 		$name = strtoupper( $name );
 		if ( function_exists( 'apache_request_headers' ) ) {
-			if ( !isset( $this->headers ) ) {
-				$this->headers = array();
+			if ( !$this->headers ) {
 				foreach ( apache_request_headers() as $tempName => $tempValue ) {
 					$this->headers[ strtoupper( $tempName ) ] = $tempValue;
 				}
@@ -629,6 +701,9 @@ class WebRequest {
 			}
 		} else {
 			$name = 'HTTP_' . str_replace( '-', '_', $name );
+			if ( $name === 'HTTP_CONTENT_LENGTH' && !isset( $_SERVER[$name] ) ) {
+				$name = 'CONTENT_LENGTH';
+			}
 			if ( isset( $_SERVER[$name] ) ) {
 				return $_SERVER[$name];
 			} else {
@@ -636,57 +711,359 @@ class WebRequest {
 			}
 		}
 	}
+
+	/**
+	 * Get data from $_SESSION
+	 *
+	 * @param $key String: name of key in $_SESSION
+	 * @return Mixed
+	 */
+	public function getSessionData( $key ) {
+		if( !isset( $_SESSION[$key] ) ) {
+			return null;
+		}
+		return $_SESSION[$key];
+	}
+
+	/**
+	 * Set session data
+	 *
+	 * @param $key String: name of key in $_SESSION
+	 * @param $data Mixed
+	 */
+	public function setSessionData( $key, $data ) {
+		$_SESSION[$key] = $data;
+	}
+
+	/**
+	 * Check if Internet Explorer will detect an incorrect cache extension in 
+	 * PATH_INFO or QUERY_STRING. If the request can't be allowed, show an error
+	 * message or redirect to a safer URL. Returns true if the URL is OK, and
+	 * false if an error message has been shown and the request should be aborted.
+	 */
+	public function checkUrlExtension( $extWhitelist = array() ) {
+		global $wgScriptExtension;
+		$extWhitelist[] = ltrim( $wgScriptExtension, '.' );
+		if ( IEUrlExtension::areServerVarsBad( $_SERVER, $extWhitelist ) ) {
+			if ( !$this->wasPosted() ) {
+				$newUrl = IEUrlExtension::fixUrlForIE6(
+					$this->getFullRequestURL(), $extWhitelist );
+				if ( $newUrl !== false ) {
+					$this->doSecurityRedirect( $newUrl );
+					return false;
+				}
+			}
+			wfHttpError( 403, 'Forbidden',
+				'Invalid file extension found in the path info or query string.' );
+			
+			return false;
+		}
+		return true;
+	}
+
+	/**
+	 * Attempt to redirect to a URL with a QUERY_STRING that's not dangerous in 
+	 * IE 6. Returns true if it was successful, false otherwise.
+	 */
+	protected function doSecurityRedirect( $url ) {
+		header( 'Location: ' . $url );
+		header( 'Content-Type: text/html' );
+		$encUrl = htmlspecialchars( $url );
+		echo <<<HTML
+<html>
+<head>
+<title>Security redirect</title>
+</head>
+<body>
+<h1>Security redirect</h1>
+<p>
+We can't serve non-HTML content from the URL you have requested, because 
+Internet Explorer would interpret it as an incorrect and potentially dangerous
+content type.</p>
+<p>Instead, please use <a href="$encUrl">this URL</a>, which is the same as the URL you have requested, except that 
+"&amp;*" is appended. This prevents Internet Explorer from seeing a bogus file 
+extension.
+</p>
+</body>
+</html>
+HTML;
+		echo "\n";
+		return true;
+	}
+
+	/**
+	 * Returns true if the PATH_INFO ends with an extension other than a script
+	 * extension. This could confuse IE for scripts that send arbitrary data which
+	 * is not HTML but may be detected as such.
+	 *
+	 * Various past attempts to use the URL to make this check have generally
+	 * run up against the fact that CGI does not provide a standard method to
+	 * determine the URL. PATH_INFO may be mangled (e.g. if cgi.fix_pathinfo=0),
+	 * but only by prefixing it with the script name and maybe some other stuff,
+	 * the extension is not mangled. So this should be a reasonably portable
+	 * way to perform this security check.
+	 *
+	 * Also checks for anything that looks like a file extension at the end of
+	 * QUERY_STRING, since IE 6 and earlier will use this to get the file type
+	 * if there was no dot before the question mark (bug 28235).
+	 */
+	public function isPathInfoBad() {
+		global $wgScriptExtension;
+		$extWhitelist[] = ltrim( $wgScriptExtension, '.' );
+		return IEUrlExtension::areServerVarsBad( $_SERVER, $extWhitelist );
+	}
+
+	/**
+	 * Parse the Accept-Language header sent by the client into an array
+	 * @return array( languageCode => q-value ) sorted by q-value in descending order
+	 * May contain the "language" '*', which applies to languages other than those explicitly listed.
+	 * This is aligned with rfc2616 section 14.4
+	 */
+	public function getAcceptLang() {
+		// Modified version of code found at http://www.thefutureoftheweb.com/blog/use-accept-language-header
+		$acceptLang = $this->getHeader( 'Accept-Language' );
+		if ( !$acceptLang ) {
+			return array();
+		}
+
+		// Return the language codes in lower case
+		$acceptLang = strtolower( $acceptLang );
+
+		// Break up string into pieces (languages and q factors)
+		$lang_parse = null;
+		preg_match_all( '/([a-z]{1,8}(-[a-z]{1,8})?|\*)\s*(;\s*q\s*=\s*(1|0(\.[0-9]+)?)?)?/',
+			$acceptLang, $lang_parse );
+
+		if ( !count( $lang_parse[1] ) ) {
+			return array();
+		}
+
+		// Create a list like "en" => 0.8
+		$langs = array_combine( $lang_parse[1], $lang_parse[4] );
+		// Set default q factor to 1
+		foreach ( $langs as $lang => $val ) {
+			if ( $val === '' ) {
+				$langs[$lang] = 1;
+			} else if ( $val == 0 ) {
+				unset($langs[$lang]);
+			}
+		}
+
+		// Sort list
+		arsort( $langs, SORT_NUMERIC );
+		return $langs;
+	}
+}
+
+/**
+ * Object to access the $_FILES array
+ */
+class WebRequestUpload {
+	protected $request;
+	protected $doesExist;
+	protected $fileInfo;
+
+	/**
+	 * Constructor. Should only be called by WebRequest
+	 *
+	 * @param $request WebRequest The associated request
+	 * @param $key string Key in $_FILES array (name of form field)
+	 */
+	public function __construct( $request, $key ) {
+		$this->request = $request;
+		$this->doesExist = isset( $_FILES[$key] );
+		if ( $this->doesExist ) {
+			$this->fileInfo = $_FILES[$key];
+		}
+	}
+
+	/**
+	 * Return whether a file with this name was uploaded.
+	 *
+	 * @return bool
+	 */
+	public function exists() {
+		return $this->doesExist;
+	}
+
+	/**
+	 * Return the original filename of the uploaded file
+	 *
+	 * @return mixed Filename or null if non-existent
+	 */
+	public function getName() {
+		if ( !$this->exists() ) {
+			return null;
+		}
+
+		global $wgContLang;
+		$name = $this->fileInfo['name'];
+
+		# Safari sends filenames in HTML-encoded Unicode form D...
+		# Horrid and evil! Let's try to make some kind of sense of it.
+		$name = Sanitizer::decodeCharReferences( $name );
+		$name = $wgContLang->normalize( $name );
+		wfDebug( __METHOD__ . ": {$this->fileInfo['name']} normalized to '$name'\n" );
+		return $name;
+	}
+
+	/**
+	 * Return the file size of the uploaded file
+	 *
+	 * @return int File size or zero if non-existent
+	 */
+	public function getSize() {
+		if ( !$this->exists() ) {
+			return 0;
+		}
+
+		return $this->fileInfo['size'];
+	}
+
+	/**
+	 * Return the path to the temporary file
+	 *
+	 * @return mixed Path or null if non-existent
+	 */
+	public function getTempName() {
+		if ( !$this->exists() ) {
+			return null;
+		}
+
+		return $this->fileInfo['tmp_name'];
+	}
+
+	/**
+	 * Return the upload error. See link for explanation
+	 * http://www.php.net/manual/en/features.file-upload.errors.php
+	 *
+	 * @return int One of the UPLOAD_ constants, 0 if non-existent
+	 */
+	public function getError() {
+		if ( !$this->exists() ) {
+			return 0; # UPLOAD_ERR_OK
+		}
+
+		return $this->fileInfo['error'];
+	}
+
+	/**
+	 * Returns whether this upload failed because of overflow of a maximum set
+	 * in php.ini
+	 *
+	 * @return bool
+	 */
+	public function isIniSizeOverflow() {
+		if ( $this->getError() == UPLOAD_ERR_INI_SIZE ) {
+			# PHP indicated that upload_max_filesize is exceeded
+			return true;
+		}
+
+		$contentLength = $this->request->getHeader( 'CONTENT_LENGTH' );
+		if ( $contentLength > wfShorthandToInteger( ini_get( 'post_max_size' ) ) ) {
+			# post_max_size is exceeded
+			return true;
+		}
+
+		return false;
+	}
 }
 
 /**
  * WebRequest clone which takes values from a provided array.
  *
+ * @ingroup HTTP
  */
 class FauxRequest extends WebRequest {
-	var $wasPosted = false;
+	private $wasPosted = false;
+	private $session = array();
 
 	/**
 	 * @param $data Array of *non*-urlencoded key => value pairs, the
 	 *   fake GET/POST values
 	 * @param $wasPosted Bool: whether to treat the data as POST
+	 * @param $session Mixed: session array or null
 	 */
-	function FauxRequest( $data, $wasPosted = false ) {
+	public function __construct( $data, $wasPosted = false, $session = null ) {
 		if( is_array( $data ) ) {
 			$this->data = $data;
 		} else {
 			throw new MWException( "FauxRequest() got bogus data" );
 		}
 		$this->wasPosted = $wasPosted;
-		$this->headers = array();
+		if( $session )
+			$this->session = $session;
 	}
 
-	function getText( $name, $default = '' ) {
+	private function notImplemented( $method ) {
+		throw new MWException( "{$method}() not implemented" );
+	}
+
+	public function getText( $name, $default = '' ) {
 		# Override; don't recode since we're using internal data
 		return (string)$this->getVal( $name, $default );
 	}
 
-	function getValues() {
+	public function getValues() {
 		return $this->data;
 	}
 
-	function wasPosted() {
+	public function wasPosted() {
 		return $this->wasPosted;
 	}
 
-	function checkSessionCookie() {
+	public function checkSessionCookie() {
 		return false;
 	}
 
-	function getRequestURL() {
-		throw new MWException( 'FauxRequest::getRequestURL() not implemented' );
+	public function getRequestURL() {
+		$this->notImplemented( __METHOD__ );
 	}
 
-	function appendQuery( $query ) {
-		throw new MWException( 'FauxRequest::appendQuery() not implemented' );
+	public function appendQuery( $query ) {
+		global $wgTitle;
+		$basequery = '';
+		foreach( $this->data as $var => $val ) {
+			if ( $var == 'title' ) {
+				continue;
+			}
+			if ( is_array( $val ) ) {
+				/* This will happen given a request like
+				 * http://en.wikipedia.org/w/index.php?title[]=Special:Userlogin&returnto[]=Main_Page
+				 */
+				continue;
+			}
+			$basequery .= '&' . urlencode( $var ) . '=' . urlencode( $val );
+		}
+		$basequery .= '&' . $query;
+
+		# Trim the extra &
+		$basequery = substr( $basequery, 1 );
+		return $wgTitle->getLocalURL( $basequery );
 	}
 
-	function getHeader( $name ) {
+	public function getHeader( $name ) {
 		return isset( $this->headers[$name] ) ? $this->headers[$name] : false;
 	}
 
+	public function setHeader( $name, $val ) {
+		$this->headers[$name] = $val;
+	}
+
+	public function getSessionData( $key ) {
+		if( isset( $this->session[$key] ) )
+			return $this->session[$key];
+	}
+
+	public function setSessionData( $key, $data ) {
+		$this->session[$key] = $data;
+	}
+
+	public function isPathInfoBad( $extWhitelist = array() ) {
+		return false;
+	}
+
+	public function checkUrlExtension( $extWhitelist = array() ) {
+		return true;
+	}
 }
