@@ -1,16 +1,14 @@
 <?php
 /**
  * MediaWiki is the to-be base class for this whole project
+ *
+ * @internal documentation reviewed 15 Mar 2010
  */
 class MediaWiki {
-
-	var $GET; /* Stores the $_GET variables at time of creation, can be changed */
 	var $params = array();
 
-	/** Constructor. It just save the $_GET variable */
-	function __construct() {
-		$this->GET = $_GET;
-	}
+	/** Constructor */
+	function __construct() {}
 
 	/**
 	 * Stores key/value pairs to circumvent global variables
@@ -29,7 +27,8 @@ class MediaWiki {
 	 * Note that keys are case-insensitive!
 	 *
 	 * @param $key String: key to get
-	 * @param $default Mixed: default value if if the key doesn't exist
+	 * @param $default string default value, defaults to empty string
+	 * @return $default Mixed: default value if if the key doesn't exist
 	 */
 	function getVal( $key, $default = '' ) {
 		$key = strtolower( $key );
@@ -42,7 +41,6 @@ class MediaWiki {
 	/**
 	 * Initialization of ... everything
 	 * Performs the request too
-	 * FIXME: why is this crap called "initialize" when it performs everything?
 	 *
 	 * @param $title Title ($wgTitle)
 	 * @param $article Article
@@ -50,14 +48,22 @@ class MediaWiki {
 	 * @param $user User
 	 * @param $request WebRequest
 	 */
-	function initialize( &$title, &$article, &$output, &$user, $request ) {
+	function performRequestForTitle( &$title, &$article, &$output, &$user, $request ) {
 		wfProfileIn( __METHOD__ );
-		if( !$this->preliminaryChecks( $title, $output, $request ) ) {
+
+		$output->setTitle( $title );
+
+		wfRunHooks( 'BeforeInitialize', array( &$title, &$article, &$output, &$user, $request, $this ) );
+
+		if( !$this->preliminaryChecks( $title, $output ) ) {
 			wfProfileOut( __METHOD__ );
 			return;
 		}
-		if( !$this->initializeSpecialCases( $title, $output, $request ) ) {
-			$new_article = $this->initializeArticle( $title, $request );
+		// Call handleSpecialCases() to deal with all special requests...
+		if( !$this->handleSpecialCases( $title, $output, $request ) ) {
+			// ...otherwise treat it as an article view. The article
+			// may be a redirect to another article or URL.
+			$new_article = $this->initializeArticle( $title, $output, $request );
 			if( is_object( $new_article ) ) {
 				$article = $new_article;
 				$this->performAction( $output, $article, $title, $user, $request );
@@ -102,11 +108,17 @@ class MediaWiki {
 		if( $wgRequest->getVal( 'printable' ) === 'yes' ) {
 			$wgOut->setPrintable();
 		}
-		$ret = NULL;
-		if( $curid = $wgRequest->getInt( 'curid' ) ) {
-			# URLs like this are generated by RC, because rc_title isn't always accurate
+
+		$curid = $wgRequest->getInt( 'curid' );
+		if( $wgRequest->getCheck( 'search' ) ) {
+			// Compatibility with old search URLs which didn't use Special:Search
+			// Just check for presence here, so blank requests still
+			// show the search page when using ugly URLs (bug 8054).
+			$ret = SpecialPage::getTitleFor( 'Search' );
+		} elseif( $curid ) {
+			// URLs like this are generated by RC, because rc_title isn't always accurate
 			$ret = Title::newFromID( $curid );
-		} elseif( '' == $title && 'delete' != $action ) {
+		} elseif( $title == '' && $action != 'delete' ) {
 			$ret = Title::newMainPage();
 		} else {
 			$ret = Title::newFromURL( $title );
@@ -115,7 +127,7 @@ class MediaWiki {
 			if( count( $wgContLang->getVariants() ) > 1 && !is_null( $ret ) && $ret->getArticleID() == 0 )
 				$wgContLang->findVariantLink( $title, $ret );
 		}
-		# For non-special titles, check for implicit titles
+		// For non-special titles, check for implicit titles
 		if( is_null( $ret ) || $ret->getNamespace() != NS_SPECIAL ) {
 			// We can have urls with just ?diff=,?oldid= or even just ?diff=
 			$oldid = $wgRequest->getInt( 'oldid' );
@@ -130,27 +142,30 @@ class MediaWiki {
 	}
 
 	/**
-	 * Checks for search query and anon-cannot-read case
+	 * Checks for anon-cannot-read case
 	 *
 	 * @param $title Title
 	 * @param $output OutputPage
-	 * @param $request WebRequest
+	 * @return boolean true if successful
 	 */
-	function preliminaryChecks( &$title, &$output, $request ) {
-		if( $request->getCheck( 'search' ) ) {
-			// Compatibility with old search URLs which didn't use Special:Search
-			// Just check for presence here, so blank requests still
-			// show the search page when using ugly URLs (bug 8054).
-
-			// Do this above the read whitelist check for security...
-			$title = SpecialPage::getTitleFor( 'Search' );
-		}
-		# If the user is not logged in, the Namespace:title of the article must be in
-		# the Read array in order for the user to see it. (We have to check here to
-		# catch special pages etc. We check again in Article::view())
+	function preliminaryChecks( &$title, &$output ) {
+		global $wgTitle;
+		// If the user is not logged in, the Namespace:title of the article must be in
+		// the Read array in order for the user to see it. (We have to check here to
+		// catch special pages etc. We check again in Article::view())
 		if( !is_null( $title ) && !$title->userCanRead() ) {
+			// Bug 32276: allowing the skin to generate output with $wgTitle 
+			// set to the input title would allow anonymous users to 
+			// determine whether a page exists, potentially leaking private data. In fact, the 
+			// curid and oldid request  parameters would allow page titles to be enumerated even 
+			// when they are not guessable. So we reset the title to Special:Badtitle before the 
+			// permissions error is displayed.
+			$badtitle = SpecialPage::getTitleFor( 'Badtitle' );
+			$output->setTitle( $badtitle );
+			$wgTitle = $badtitle;
+
 			$output->loginToUse();
-			$output->output();
+			$this->finalCleanup( $output );
 			$output->disable();
 			return false;
 		}
@@ -164,38 +179,54 @@ class MediaWiki {
 	 * - redirect loop
 	 * - special pages
 	 *
-	 * FIXME: why is this crap called "initialize" when it performs everything?
-	 *
 	 * @param $title Title
 	 * @param $output OutputPage
 	 * @param $request WebRequest
 	 * @return bool true if the request is already executed
 	 */
-	function initializeSpecialCases( &$title, &$output, $request ) {
+	function handleSpecialCases( &$title, &$output, $request ) {
 		wfProfileIn( __METHOD__ );
 
 		$action = $this->getVal( 'Action' );
-		if( is_null($title) || $title->getDBkey() == '' ) {
+
+		// Invalid titles. Bug 21776: The interwikis must redirect even if the page name is empty.
+		if( is_null($title) || ( ( $title->getDBkey() == '' ) && ( $title->getInterwiki() == '' ) ) ) {
 			$title = SpecialPage::getTitleFor( 'Badtitle' );
-			# Die now before we mess up $wgArticle and the skin stops working
+			$output->setTitle( $title ); // bug 21456
+			// Die now before we mess up $wgArticle and the skin stops working
 			throw new ErrorPageError( 'badtitle', 'badtitletext' );
+
+		// Interwiki redirects
 		} else if( $title->getInterwiki() != '' ) {
-			if( $rdfrom = $request->getVal( 'rdfrom' ) ) {
+			$rdfrom = $request->getVal( 'rdfrom' );
+			if( $rdfrom ) {
 				$url = $title->getFullURL( 'rdfrom=' . urlencode( $rdfrom ) );
 			} else {
-				$url = $title->getFullURL();
+				$query = $request->getValues();
+				unset( $query['title'] );
+				$url = $title->getFullURL( $query );
 			}
 			/* Check for a redirect loop */
 			if( !preg_match( '/^' . preg_quote( $this->getVal('Server'), '/' ) . '/', $url ) && $title->isLocal() ) {
-				$output->redirect( $url );
+				// 301 so google et al report the target as the actual url.
+				$output->redirect( $url, 301 );
 			} else {
 				$title = SpecialPage::getTitleFor( 'Badtitle' );
+				$output->setTitle( $title ); // bug 21456
+				wfProfileOut( __METHOD__ );
 				throw new ErrorPageError( 'badtitle', 'badtitletext' );
 			}
-		} else if( $action == 'view' && !$request->wasPosted() &&
-			( !isset($this->GET['title']) || $title->getPrefixedDBKey() != $this->GET['title'] ) &&
-			!count( array_diff( array_keys( $this->GET ), array( 'action', 'title' ) ) ) )
+		// Redirect loops, no title in URL, $wgUsePathInfo URLs, and URLs with a variant
+		} else if ( $action == 'view' && !$request->wasPosted()
+			&& ( $request->getVal( 'title' ) === null || $title->getPrefixedDBKey() != $request->getVal( 'title' ) )
+			&& !count( array_diff( array_keys( $request->getValues() ), array( 'action', 'title' ) ) ) )
 		{
+			if ( $title->getNamespace() == NS_SPECIAL ) {
+				list( $name, $subpage ) = SpecialPage::resolveAliasWithSubpage( $title->getDBkey() );
+				if ( $name ) {
+					$title = SpecialPage::getTitleFor( $name, $subpage );
+				}
+			}
 			$targetUrl = $title->getFullURL();
 			// Redirect to canonical url, make it a 301 to allow caching
 			if( $targetUrl == $request->getFullRequestURL() ) {
@@ -219,11 +250,13 @@ class MediaWiki {
 						"to true.";
 				}
 				wfHttpError( 500, "Internal error", $message );
+				wfProfileOut( __METHOD__ );
 				return false;
 			} else {
 				$output->setSquidMaxage( 1200 );
 				$output->redirect( $targetUrl, '301' );
 			}
+		// Special pages
 		} else if( NS_SPECIAL == $title->getNamespace() ) {
 			/* actions that need to be made when we have a special pages */
 			SpecialPage::executePath( $title );
@@ -270,16 +303,17 @@ class MediaWiki {
 	 * Create an Article object for the page, following redirects if needed.
 	 *
 	 * @param $title Title ($wgTitle)
-	 * @param $request WebRequest
+	 * @param $output OutputPage ($wgOut)
+	 * @param $request WebRequest ($wgRequest)
 	 * @return mixed an Article, or a string to redirect to another URL
 	 */
-	function initializeArticle( &$title, $request ) {
+	function initializeArticle( &$title, &$output, $request ) {
 		wfProfileIn( __METHOD__ );
 
 		$action = $this->getVal( 'action', 'view' );
 		$article = self::articleFromTitle( $title );
-		# NS_MEDIAWIKI has no redirects.
-		# It is also used for CSS/JS, so performance matters here...
+		// NS_MEDIAWIKI has no redirects.
+		// It is also used for CSS/JS, so performance matters here...
 		if( $title->getNamespace() == NS_MEDIAWIKI ) {
 			wfProfileOut( __METHOD__ );
 			return $article;
@@ -289,26 +323,29 @@ class MediaWiki {
 		$file = ($title->getNamespace() == NS_FILE) ? $article->getFile() : null;
 		if( ( $action == 'view' || $action == 'render' ) 	// ... for actions that show content
 			&& !$request->getVal( 'oldid' ) &&    // ... and are not old revisions
+			!$request->getVal( 'diff' ) &&    // ... and not when showing diff
 			$request->getVal( 'redirect' ) != 'no' &&	// ... unless explicitly told not to
 			// ... and the article is not a non-redirect image page with associated file
 			!( is_object( $file ) && $file->exists() && !$file->getRedirected() ) )
 		{
-			# Give extensions a change to ignore/handle redirects as needed
+			// Give extensions a change to ignore/handle redirects as needed
 			$ignoreRedirect = $target = false;
-			
+
 			$dbr = wfGetDB( DB_SLAVE );
 			$article->loadPageData( $article->pageDataFromTitle( $dbr, $title ) );
 
-			wfRunHooks( 'InitializeArticleMaybeRedirect', 
+			wfRunHooks( 'InitializeArticleMaybeRedirect',
 				array(&$title,&$request,&$ignoreRedirect,&$target,&$article) );
 
-			// Follow redirects only for... redirects
-			if( !$ignoreRedirect && $article->isRedirect() ) {
-				# Is the target already set by an extension?
+			// Follow redirects only for... redirects.
+			// If $target is set, then a hook wanted to redirect.
+			if( !$ignoreRedirect && ($target || $article->isRedirect()) ) {
+				// Is the target already set by an extension?
 				$target = $target ? $target : $article->followRedirect();
 				if( is_string( $target ) ) {
 					if( !$this->getVal( 'DisableHardRedirects' ) ) {
 						// we'll need to redirect
+						wfProfileOut( __METHOD__ );
 						return $target;
 					}
 				}
@@ -320,6 +357,7 @@ class MediaWiki {
 						$rarticle->setRedirectedFrom( $title );
 						$article = $rarticle;
 						$title = $target;
+						$output->setTitle( $title );
 					}
 				}
 			} else {
@@ -331,51 +369,22 @@ class MediaWiki {
 	}
 
 	/**
-	 * Cleaning up by doing deferred updates, calling LBFactory and doing the output
+	 * Cleaning up request by doing:
+	 ** deferred updates, DB transaction, and the output
 	 *
-	 * @param $deferredUpdates array of updates to do
 	 * @param $output OutputPage
 	 */
-	function finalCleanup( &$deferredUpdates, &$output ) {
+	function finalCleanup( &$output ) {
 		wfProfileIn( __METHOD__ );
-		# Now commit any transactions, so that unreported errors after output() don't roll back the whole thing
+		// Now commit any transactions, so that unreported errors after
+		// output() don't roll back the whole DB transaction
 		$factory = wfGetLBFactory();
 		$factory->commitMasterChanges();
-		# Output everything!
+		// Output everything!
 		$output->output();
-		# Do any deferred jobs
-		$this->doUpdates( $deferredUpdates );
+		// Do any deferred jobs
+		wfDoUpdates( true );
 		$this->doJobs();
-		# Commit and close up!
-		$factory->shutdown();
-		wfProfileOut( __METHOD__ );
-	}
-
-	/**
-	 * Deferred updates aren't really deferred anymore. It's important to report
-	 * errors to the user, and that means doing this before OutputPage::output().
-	 * Note that for page saves, the client will wait until the script exits
-	 * anyway before following the redirect.
-	 *
-	 * @param $updates array of objects that hold an update to do
-	 */
-	function doUpdates( &$updates ) {
-		wfProfileIn( __METHOD__ );
-		/* No need to get master connections in case of empty updates array */
-		if (!$updates) {
-			wfProfileOut( __METHOD__ );
-			return;
-		}
-
-		$dbw = wfGetDB( DB_MASTER );
-		foreach( $updates as $up ) {
-			$up->doUpdate();
-
-			# Commit after every update to prevent lock contention
-			if( $dbw->trxLevel() ) {
-				$dbw->commit();
-			}
-		}
 		wfProfileOut( __METHOD__ );
 	}
 
@@ -418,6 +427,10 @@ class MediaWiki {
 	 */
 	function restInPeace() {
 		wfLogProfilingData();
+		// Commit and close up!
+		$factory = wfGetLBFactory();
+		$factory->commitMasterChanges();
+		$factory->shutdown();
 		wfDebug( "Request ended normally\n" );
 	}
 
@@ -444,6 +457,16 @@ class MediaWiki {
 			$action = 'nosuchaction';
 		}
 
+		// Workaround for bug #20966: inability of IE to provide an action dependent
+		// on which submit button is clicked.
+		if ( $action === 'historysubmit' ) {
+			if ( $request->getBool( 'revisiondelete' ) ) {
+				$action = 'revisiondelete';
+			} else {
+				$action = 'view';
+			}
+		}
+
 		switch( $action ) {
 			case 'view':
 				$output->setSquidMaxage( $this->getVal( 'SquidMaxage' ) );
@@ -519,9 +542,14 @@ class MediaWiki {
 				if( $request->getFullRequestURL() == $title->getInternalURL( 'action=history' ) ) {
 					$output->setSquidMaxage( $this->getVal( 'SquidMaxage' ) );
 				}
-				$history = new PageHistory( $article );
+				$history = new HistoryPage( $article );
 				$history->history();
 				break;
+			case 'revisiondelete':
+				// For show/hide submission from history page
+				$special = SpecialPage::getPage( 'Revisiondelete' );
+				$special->execute( '' );
+				break;
 			default:
 				if( wfRunHooks( 'UnknownAction', array( $action, $article ) ) ) {
 					$output->showErrorPage( 'nosuchaction', 'nosuchactiontext' );
@@ -531,4 +559,4 @@ class MediaWiki {
 
 	}
 
-}; /* End of class MediaWiki */
+}
