@@ -1,10 +1,10 @@
 <?php
-
-/*
- * Created on Sep 25, 2008
+/**
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2008 Roan Kattouw <Firstname>.<Lastname>@home.nl
+ * Created on Sep 25, 2008
+ *
+ * Copyright © 2008 Roan Kattouw <Firstname>.<Lastname>@home.nl
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,16 +18,17 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-if (!defined('MEDIAWIKI')) {
+if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ("ApiBase.php");
+	require_once( "ApiBase.php" );
 }
 
-
 /**
  * API module that dies with an error immediately.
  *
@@ -40,12 +41,12 @@ if (!defined('MEDIAWIKI')) {
  */
 class ApiDisabled extends ApiBase {
 
-	public function __construct($main, $action) {
-		parent :: __construct($main, $action);
+	public function __construct( $main, $action ) {
+		parent::__construct( $main, $action );
 	}
 
 	public function execute() {
-		$this->dieUsage("The ``{$this->getModuleName()}'' module has been disabled.", 'moduledisabled');
+		$this->dieUsage( "The ``{$this->getModuleName()}'' module has been disabled.", 'moduledisabled' );
 	}
 
 	public function isReadMode() {
@@ -53,24 +54,22 @@ class ApiDisabled extends ApiBase {
 	}
 
 	public function getAllowedParams() {
-		return array ();
+		return array();
 	}
 
 	public function getParamDescription() {
-		return array ();
+		return array();
 	}
 
 	public function getDescription() {
-		return array(
-			'This module has been disabled.'
-		);
+		return 'This module has been disabled';
 	}
 
 	protected function getExamples() {
-		return array ();
+		return array();
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiDisabled.php 48091 2009-03-06 13:49:44Z catrope $';
+		return __CLASS__ . ': $Id$';
 	}
 }
