@@ -1,11 +1,10 @@
 <?php
-
-/*
- * Created on Sep 19, 2006
- *
+/**
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ * Created on Sep 19, 2006
+ *
+ * Copyright © 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,28 +18,36 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-if (!defined('MEDIAWIKI')) {
+if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ('ApiFormatBase.php');
+	require_once( 'ApiFormatBase.php' );
 }
 
 /**
+ * API JSON output formatter
  * @ingroup API
  */
 class ApiFormatJson extends ApiFormatBase {
 
 	private $mIsRaw;
 
-	public function __construct($main, $format) {
-		parent :: __construct($main, $format);
-		$this->mIsRaw = ($format === 'rawfm');
+	public function __construct( $main, $format ) {
+		parent::__construct( $main, $format );
+		$this->mIsRaw = ( $format === 'rawfm' );
 	}
 
 	public function getMimeType() {
+		$params = $this->extractRequestParams();
+		// callback:
+		if ( $params['callback'] ) {
+			return 'text/javascript';
+		}
 		return 'application/json';
 	}
 
@@ -48,47 +55,48 @@ class ApiFormatJson extends ApiFormatBase {
 		return $this->mIsRaw;
 	}
 
+	public function getWantsHelp() {
+		// Help is always ugly in JSON
+		return false;
+	}
+
 	public function execute() {
-		$prefix = $suffix = "";
+		$prefix = $suffix = '';
 
 		$params = $this->extractRequestParams();
 		$callback = $params['callback'];
-		if(!is_null($callback)) {
-			$prefix = preg_replace("/[^][.\\'\\\"_A-Za-z0-9]/", "", $callback ) . "(";
-			$suffix = ")";
-		}
-
-		// Some versions of PHP have a broken json_encode, see PHP bug 
-		// 46944. Test encoding an affected character (U+20000) to 
-		// avoid this.
-		if (!function_exists('json_encode') || $this->getIsHtml() || strtolower(json_encode("\xf0\xa0\x80\x80")) != '\ud840\udc00') {
-			$json = new Services_JSON();
-			$this->printText($prefix . $json->encode($this->getResultData(), $this->getIsHtml()) . $suffix);
-		} else {
-			$this->printText($prefix . json_encode($this->getResultData()) . $suffix);
+		if ( !is_null( $callback ) ) {
+			$prefix = preg_replace( "/[^][.\\'\\\"_A-Za-z0-9]/", '', $callback ) . '(';
+			$suffix = ')';
 		}
+		$this->printText(
+			$prefix .
+			FormatJson::encode( $this->getResultData(), $this->getIsHtml() ) .
+			$suffix
+		);
 	}
 
 	public function getAllowedParams() {
-		return array (
-			'callback' => null
+		return array(
+			'callback'  => null,
 		);
 	}
 
 	public function getParamDescription() {
-		return array (
+		return array(
 			'callback' => 'If specified, wraps the output into a given function call. For safety, all user-specific data will be restricted.',
 		);
 	}
 
 	public function getDescription() {
-		if ($this->mIsRaw)
-			return 'Output data with the debuging elements in JSON format' . parent :: getDescription();
-		else
-			return 'Output data in JSON format' . parent :: getDescription();
+		if ( $this->mIsRaw ) {
+			return 'Output data with the debuging elements in JSON format' . parent::getDescription();
+		} else {
+			return 'Output data in JSON format' . parent::getDescription();
+		}
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiFormatJson.php 45682 2009-01-12 19:06:33Z raymond $';
+		return __CLASS__ . ': $Id$';
 	}
 }
