@@ -1,11 +1,10 @@
 <?php
-
-/*
- * Created on Jan 4, 2008
- *
+/**
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2008 Yuri Astrakhan <Firstname><Lastname>@gmail.com,
+ * Created on Jan 4, 2008
+ *
+ * Copyright © 2008 Yuri Astrakhan <Firstname><Lastname>@gmail.com,
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,13 +18,15 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
 if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ( 'ApiBase.php' );
+	require_once( 'ApiBase.php' );
 }
 
 /**
@@ -37,14 +38,14 @@ if ( !defined( 'MEDIAWIKI' ) ) {
 class ApiLogout extends ApiBase {
 
 	public function __construct( $main, $action ) {
-		parent :: __construct( $main, $action );
+		parent::__construct( $main, $action );
 	}
 
 	public function execute() {
 		global $wgUser;
 		$oldName = $wgUser->getName();
 		$wgUser->logout();
-		
+
 		// Give extensions to do something after user logout
 		$injected_html = '';
 		wfRunHooks( 'UserLogoutComplete', array( &$wgUser, &$injected_html, $oldName ) );
@@ -55,17 +56,15 @@ class ApiLogout extends ApiBase {
 	}
 
 	public function getAllowedParams() {
-		return array ();
+		return array();
 	}
 
 	public function getParamDescription() {
-		return array ();
+		return array();
 	}
 
 	public function getDescription() {
-		return array (
-			'This module is used to logout and clear session data'
-		);
+		return 'This module is used to logout and clear session data';
 	}
 
 	protected function getExamples() {
@@ -75,6 +74,6 @@ class ApiLogout extends ApiBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiLogout.php 69578 2010-07-20 02:46:20Z tstarling $';
+		return __CLASS__ . ': $Id$';
 	}
 }
