@@ -1,11 +1,10 @@
 <?php
-
-/*
- * Created on Sep 2, 2008
- *
+/**
  * API for MediaWiki 1.14+
  *
- * Copyright (C) 2008 Soxred93 soxred93@gmail.com,
+ * Created on Sep 2, 2008
+ *
+ * Copyright © 2008 Soxred93 soxred93@gmail.com,
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,12 +18,14 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-if (!defined('MEDIAWIKI')) {
-	require_once ('ApiBase.php');
+if ( !defined( 'MEDIAWIKI' ) ) {
+	require_once ( 'ApiBase.php' );
 }
 
 /**
@@ -33,35 +34,33 @@ if (!defined('MEDIAWIKI')) {
  */
 class ApiPatrol extends ApiBase {
 
-	public function __construct($main, $action) {
-		parent :: __construct($main, $action);
+	public function __construct( $main, $action ) {
+		parent::__construct( $main, $action );
 	}
 
 	/**
 	 * Patrols the article or provides the reason the patrol failed.
 	 */
 	public function execute() {
-		global $wgUser, $wgUseRCPatrol, $wgUseNPPatrol;
 		$params = $this->extractRequestParams();
-		
-		if(!isset($params['token']))
-			$this->dieUsageMsg(array('missingparam', 'token'));
-		if(!isset($params['rcid']))
-			$this->dieUsageMsg(array('missingparam', 'rcid'));
-		if(!$wgUser->matchEditToken($params['token']))
-			$this->dieUsageMsg(array('sessionfailure'));
 
-		$rc = RecentChange::newFromID($params['rcid']);
-		if(!$rc instanceof RecentChange)
-			$this->dieUsageMsg(array('nosuchrcid', $params['rcid']));
-		$retval = RecentChange::markPatrolled($params['rcid']);
-			
-		if($retval)
-			$this->dieUsageMsg(reset($retval));
-		
-		$result = array('rcid' => intval($rc->getAttribute('rc_id')));
-		ApiQueryBase::addTitleInfo($result, $rc->getTitle());
-		$this->getResult()->addValue(null, $this->getModuleName(), $result);
+		$rc = RecentChange::newFromID( $params['rcid'] );
+		if ( !$rc instanceof RecentChange ) {
+			$this->dieUsageMsg( array( 'nosuchrcid', $params['rcid'] ) );
+		}
+		$retval = RecentChange::markPatrolled( $params['rcid'] );
+
+		if ( $retval ) {
+			$this->dieUsageMsg( reset( $retval ) );
+		}
+
+		$result = array( 'rcid' => intval( $rc->getAttribute( 'rc_id' ) ) );
+		ApiQueryBase::addTitleInfo( $result, $rc->getTitle() );
+		$this->getResult()->addValue( null, $this->getModuleName(), $result );
+	}
+
+	public function mustBePosted() {
+		return true;
 	}
 
 	public function isWriteMode() {
@@ -69,25 +68,38 @@ class ApiPatrol extends ApiBase {
 	}
 
 	public function getAllowedParams() {
-		return array (
+		return array(
 			'token' => null,
 			'rcid' => array(
-				ApiBase :: PARAM_TYPE => 'integer'
+				ApiBase::PARAM_TYPE => 'integer',
+				ApiBase::PARAM_REQUIRED => true
 			),
 		);
 	}
 
 	public function getParamDescription() {
-		return array (
+		return array(
 			'token' => 'Patrol token obtained from list=recentchanges',
 			'rcid' => 'Recentchanges ID to patrol',
 		);
 	}
 
 	public function getDescription() {
-		return array (
-			'Patrol a page or revision. '
-		);
+		return 'Patrol a page or revision';
+	}
+
+	public function getPossibleErrors() {
+		return array_merge( parent::getPossibleErrors(), array(
+			array( 'nosuchrcid', 'rcid' ),
+		) );
+	}
+
+	public function needsToken() {
+		return true;
+	}
+
+	public function getTokenSalt() {
+		return 'patrol';
 	}
 
 	protected function getExamples() {
@@ -97,6 +109,6 @@ class ApiPatrol extends ApiBase {
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiPatrol.php 69579 2010-07-20 02:49:55Z tstarling $';
+		return __CLASS__ . ': $Id$';
 	}
 }
