@@ -1,11 +1,10 @@
 <?php
-
-/*
- * Created on Dec 1, 2007
- *
+/**
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ * Created on Dec 1, 2007
+ *
+ * Copyright © 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,13 +18,15 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
 if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ( 'ApiQueryBase.php' );
+	require_once( 'ApiQueryBase.php' );
 }
 
 /**
@@ -36,22 +37,23 @@ if ( !defined( 'MEDIAWIKI' ) ) {
 class ApiQueryAllmessages extends ApiQueryBase {
 
 	public function __construct( $query, $moduleName ) {
-		parent :: __construct( $query, $moduleName, 'am' );
+		parent::__construct( $query, $moduleName, 'am' );
 	}
 
 	public function execute() {
 		$params = $this->extractRequestParams();
 
-		if ( !is_null( $params['lang'] ) )
-		{
-			global $wgLang;
+		global $wgLang;
+
+		$oldLang = null;
+		if ( !is_null( $params['lang'] ) ) {
+			$oldLang = $wgLang; // Keep $wgLang for restore later
 			$wgLang = Language::factory( $params['lang'] );
 		}
-		
+
 		$prop = array_flip( (array)$params['prop'] );
 
 		// Determine which messages should we print
-		$messages_target = array();
 		if ( in_array( '*', $params['messages'] ) ) {
 			$message_names = array_keys( Language::getMessagesFor( 'en' ) );
 			sort( $message_names );
@@ -64,7 +66,8 @@ class ApiQueryAllmessages extends ApiQueryBase {
 		if ( isset( $params['filter'] ) ) {
 			$messages_filtered = array();
 			foreach ( $messages_target as $message ) {
-				if ( strpos( $message, $params['filter'] ) !== false ) {	// !== is used because filter can be at the beginnig of the string
+				// !== is used because filter can be at the beginning of the string
+				if ( strpos( $message, $params['filter'] ) !== false ) {
 					$messages_filtered[] = $message;
 				}
 			}
@@ -72,13 +75,18 @@ class ApiQueryAllmessages extends ApiQueryBase {
 		}
 
 		// Get all requested messages and print the result
-		$messages = array();
 		$skip = !is_null( $params['from'] );
+		$useto = !is_null( $params['to'] );
 		$result = $this->getResult();
 		foreach ( $messages_target as $message ) {
 			// Skip all messages up to $params['from']
-			if ( $skip && $message === $params['from'] )
+			if ( $skip && $message === $params['from'] ) {
 				$skip = false;
+			}
+			
+			if( $useto && $message > $params['to'] ) {
+				break;
+			}
 
 			if ( !$skip ) {
 				$a = array( 'name' => $message );
@@ -89,35 +97,40 @@ class ApiQueryAllmessages extends ApiQueryBase {
 				// Check if the parser is enabled:
 				if ( $params['enableparser'] ) {
 					$msg = wfMsgExt( $message, array( 'parsemag' ), $args );
-				} else if ( $args ) {
+				} elseif ( $args ) {
 					$msgString = wfMsgGetKey( $message, true, false, false );
 					$msg = wfMsgReplaceArgs( $msgString, $args );
 				} else {
 					$msg = wfMsgGetKey( $message, true, false, false );
 				}
 
-				if ( wfEmptyMsg( $message, $msg ) )
+				if ( wfEmptyMsg( $message, $msg ) ) {
 					$a['missing'] = '';
-				else {
+				} else {
 					ApiResult::setContent( $a, $msg );
 					if ( isset( $prop['default'] ) ) {
 						$default = wfMsgGetKey( $message, false, false, false );
 						if ( $default !== $msg ) {
-							if ( wfEmptyMsg( $message, $default ) )
+							if ( wfEmptyMsg( $message, $default ) ) {
 								$a['defaultmissing'] = '';
-							else
+							} else {
 								$a['default'] = $default;
+							}
 						}
 					}
 				}
 				$fit = $result->addValue( array( 'query', $this->getModuleName() ), null, $a );
 				if ( !$fit ) {
-					$this->setContinueEnumParameter( 'from', $name );
+					$this->setContinueEnumParameter( 'from', $message );
 					break;
 				}
 			}
 		}
 		$result->setIndexedTagName_internal( array( 'query', $this->getModuleName() ), 'message' );
+
+		if ( !is_null( $oldLang ) ) {
+			$wgLang = $oldLang; // Restore $oldLang
+		}
 	}
 
 	public function getCacheMode( $params ) {
@@ -134,29 +147,30 @@ class ApiQueryAllmessages extends ApiQueryBase {
 	}
 
 	public function getAllowedParams() {
-		return array (
-			'messages' => array (
-				ApiBase :: PARAM_DFLT => '*',
-				ApiBase :: PARAM_ISMULTI => true,
+		return array(
+			'messages' => array(
+				ApiBase::PARAM_DFLT => '*',
+				ApiBase::PARAM_ISMULTI => true,
 			),
 			'prop' => array(
-				ApiBase :: PARAM_ISMULTI => true,
-				ApiBase :: PARAM_TYPE => array(
+				ApiBase::PARAM_ISMULTI => true,
+				ApiBase::PARAM_TYPE => array(
 					'default'
 				)
 			),
 			'enableparser' => false,
 			'args' => array(
-				ApiBase :: PARAM_ISMULTI => true
+				ApiBase::PARAM_ISMULTI => true
 			),
 			'filter' => array(),
 			'lang' => null,
 			'from' => null,
+			'to' => null,
 		);
 	}
 
 	public function getParamDescription() {
-		return array (
+		return array(
 			'messages' => 'Which messages to output. "*" means all messages',
 			'prop' => 'Which properties to get',
 			'enableparser' => array( 'Set to enable parser, will preprocess the wikitext of message',
@@ -165,21 +179,22 @@ class ApiQueryAllmessages extends ApiQueryBase {
 			'filter' => 'Return only messages that contain this string',
 			'lang' => 'Return messages in this language',
 			'from' => 'Return messages starting at this message',
+			'to' => 'Return messages ending at this message',
 		);
 	}
 
 	public function getDescription() {
-		return 'Return messages from this site.';
+		return 'Return messages from this site';
 	}
 
 	protected function getExamples() {
 		return array(
 			'api.php?action=query&meta=allmessages&amfilter=ipb-',
 			'api.php?action=query&meta=allmessages&ammessages=august|mainpage&amlang=de',
-			);
+		);
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiQueryAllmessages.php 69932 2010-07-26 08:03:21Z tstarling $';
+		return __CLASS__ . ': $Id$';
 	}
 }
