@@ -1,11 +1,10 @@
 <?php
-
-/*
- * Created on Sep 25, 2006
- *
+/**
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
+ * Created on Sep 25, 2006
+ *
+ * Copyright © 2006 Yuri Astrakhan <Firstname><Lastname>@gmail.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +18,13 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
-if( !defined('MEDIAWIKI') ) {
+if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
 	require_once( 'ApiQueryBase.php' );
 }
@@ -36,16 +37,14 @@ if( !defined('MEDIAWIKI') ) {
 class ApiQuerySiteinfo extends ApiQueryBase {
 
 	public function __construct( $query, $moduleName ) {
-		parent :: __construct( $query, $moduleName, 'si' );
+		parent::__construct( $query, $moduleName, 'si' );
 	}
 
 	public function execute() {
 		$params = $this->extractRequestParams();
 		$done = array();
-		foreach( $params['prop'] as $p )
-		{
-			switch ( $p )
-			{
+		foreach ( $params['prop'] as $p ) {
+			switch ( $p ) {
 				case 'general':
 					$fit = $this->appendGeneralInfo( $p );
 					break;
@@ -72,7 +71,7 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 					$fit = $this->appendStatistics( $p );
 					break;
 				case 'usergroups':
-					$fit = $this->appendUserGroups( $p );
+					$fit = $this->appendUserGroups( $p, $params['numberingroup'] );
 					break;
 				case 'extensions':
 					$fit = $this->appendExtensions( $p );
@@ -83,15 +82,17 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 				case 'rightsinfo':
 					$fit = $this->appendRightsInfo( $p );
 					break;
-				default :
-					ApiBase :: dieDebug( __METHOD__, "Unknown prop=$p" );
+				case 'languages':
+					$fit = $this->appendLanguages( $p );
+					break;
+				default:
+					ApiBase::dieDebug( __METHOD__, "Unknown prop=$p" );
 			}
-			if(!$fit)
-			{
-				# Abuse siprop as a query-continue parameter
-				# and set it to all unprocessed props
-				$this->setContinueEnumParameter('prop', implode('|',
-						array_diff($params['prop'], $done)));
+			if ( !$fit ) {
+				// Abuse siprop as a query-continue parameter
+				// and set it to all unprocessed props
+				$this->setContinueEnumParameter( 'prop', implode( '|',
+						array_diff( $params['prop'], $done ) ) );
 				break;
 			}
 			$done[] = $p;
@@ -99,45 +100,62 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 	}
 
 	protected function appendGeneralInfo( $property ) {
-		global $wgSitename, $wgVersion, $wgCapitalLinks, $wgRightsCode, $wgRightsText, $wgContLang;
-		global $wgLanguageCode, $IP, $wgEnableWriteAPI, $wgLang, $wgLocaltimezone, $wgLocalTZoffset;
+		global $wgContLang;
 
 		$data = array();
-		$mainPage = Title :: newFromText(wfMsgForContent('mainpage'));
+		$mainPage = Title::newMainPage();
 		$data['mainpage'] = $mainPage->getPrefixedText();
 		$data['base'] = $mainPage->getFullUrl();
-		$data['sitename'] = $wgSitename;
-		$data['generator'] = "MediaWiki $wgVersion";
+		$data['sitename'] = $GLOBALS['wgSitename'];
+		$data['generator'] = "MediaWiki {$GLOBALS['wgVersion']}";
+		$data['phpversion'] = phpversion();
+		$data['phpsapi'] = php_sapi_name();
+		$data['dbtype'] = $GLOBALS['wgDBtype'];
+		$data['dbversion'] = $this->getDB()->getServerVersion();
 
-		$svn = SpecialVersion::getSvnRevision( $IP );
-		if( $svn )
+		$svn = SpecialVersion::getSvnRevision( $GLOBALS['IP'] );
+		if ( $svn ) {
 			$data['rev'] = $svn;
+		}
 
-		$data['case'] = $wgCapitalLinks ? 'first-letter' : 'case-sensitive'; // 'case-insensitive' option is reserved for future
+		// 'case-insensitive' option is reserved for future
+		$data['case'] = $GLOBALS['wgCapitalLinks'] ? 'first-letter' : 'case-sensitive';
 
-		if( isset( $wgRightsCode ) )
-			$data['rightscode'] = $wgRightsCode;
-		$data['rights'] = $wgRightsText;
-		$data['lang'] = $wgLanguageCode;
-		if( $wgContLang->isRTL() ) 
+		if ( isset( $GLOBALS['wgRightsCode'] ) ) {
+			$data['rightscode'] = $GLOBALS['wgRightsCode'];
+		}
+		$data['rights'] = $GLOBALS['wgRightsText'];
+		$data['lang'] = $GLOBALS['wgLanguageCode'];
+		if ( $wgContLang->isRTL() ) {
 			$data['rtl'] = '';
-		$data['fallback8bitEncoding'] = $wgLang->fallback8bitEncoding();
-		
-		if( wfReadOnly() )
-			$data['readonly'] = '';
-		if( $wgEnableWriteAPI )
-			$data['writeapi'] = '';
+		}
+		$data['fallback8bitEncoding'] = $wgContLang->fallback8bitEncoding();
 
-		$tz = $wgLocaltimezone;
-		$offset = $wgLocalTZoffset;
-		if( is_null( $tz ) ) {
+		if ( wfReadOnly() ) {
+			$data['readonly'] = '';
+			$data['readonlyreason'] = wfReadOnlyReason();
+		}
+		if ( $GLOBALS['wgEnableWriteAPI'] ) {
+			$data['writeapi'] = '';
+		}
+
+		$tz = $GLOBALS['wgLocaltimezone'];
+		$offset = $GLOBALS['wgLocalTZoffset'];
+		if ( is_null( $tz ) ) {
 			$tz = 'UTC';
 			$offset = 0;
-		} elseif( is_null( $offset ) ) {
+		} elseif ( is_null( $offset ) ) {
 			$offset = 0;
 		}
 		$data['timezone'] = $tz;
-		$data['timeoffset'] = intval($offset);
+		$data['timeoffset'] = intval( $offset );
+		$data['articlepath'] = $GLOBALS['wgArticlePath'];
+		$data['scriptpath'] = $GLOBALS['wgScriptPath'];
+		$data['script'] = $GLOBALS['wgScript'];
+		$data['variantarticlepath'] = $GLOBALS['wgVariantArticlePath'];
+		$data['server'] = $GLOBALS['wgServer'];
+		$data['wikiid'] = wfWikiID();
+		$data['time'] = wfTimestamp( TS_ISO_8601, time() );
 
 		return $this->getResult()->addValue( 'query', $property, $data );
 	}
@@ -145,19 +163,25 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 	protected function appendNamespaces( $property ) {
 		global $wgContLang;
 		$data = array();
-		foreach( $wgContLang->getFormattedNamespaces() as $ns => $title )
-		{
+		foreach ( $wgContLang->getFormattedNamespaces() as $ns => $title ) {
 			$data[$ns] = array(
-				'id' => intval($ns)
+				'id' => intval( $ns ),
+				'case' => MWNamespace::isCapitalized( $ns ) ? 'first-letter' : 'case-sensitive',
 			);
-			ApiResult :: setContent( $data[$ns], $title );
+			ApiResult::setContent( $data[$ns], $title );
 			$canonical = MWNamespace::getCanonicalName( $ns );
-			
-			if( MWNamespace::hasSubpages( $ns ) )
+
+			if ( MWNamespace::hasSubpages( $ns ) ) {
 				$data[$ns]['subpages'] = '';
-			
-			if( $canonical ) 
-				$data[$ns]['canonical'] = strtr($canonical, '_', ' ');
+			}
+
+			if ( $canonical ) {
+				$data[$ns]['canonical'] = strtr( $canonical, '_', ' ' );
+			}
+
+			if ( MWNamespace::isContent( $ns ) ) {
+				$data[$ns]['content'] = '';
+			}
 		}
 
 		$this->getResult()->setIndexedTagName( $data, 'ns' );
@@ -166,19 +190,18 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 
 	protected function appendNamespaceAliases( $property ) {
 		global $wgNamespaceAliases, $wgContLang;
-		$wgContLang->load();
-		$aliases = array_merge( $wgNamespaceAliases, $wgContLang->namespaceAliases );
+		$aliases = array_merge( $wgNamespaceAliases, $wgContLang->getNamespaceAliases() );
 		$namespaces = $wgContLang->getNamespaces();
 		$data = array();
-		foreach( $aliases as $title => $ns ) {
-			if( $namespaces[$ns] == $title ) {
+		foreach ( $aliases as $title => $ns ) {
+			if ( $namespaces[$ns] == $title ) {
 				// Don't list duplicates
 				continue;
 			}
 			$item = array(
-				'id' => intval($ns)
+				'id' => intval( $ns )
 			);
-			ApiResult :: setContent( $item, strtr( $title, '_', ' ' ) );
+			ApiResult::setContent( $item, strtr( $title, '_', ' ' ) );
 			$data[] = $item;
 		}
 
@@ -187,9 +210,9 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 	}
 
 	protected function appendSpecialPageAliases( $property ) {
-		global $wgLang;
+		global $wgContLang;
 		$data = array();
-		foreach( $wgLang->getSpecialPageAliases() as $specialpage => $aliases )
+		foreach ( $wgContLang->getSpecialPageAliases() as $specialpage => $aliases )
 		{
 			$arr = array( 'realname' => $specialpage, 'aliases' => $aliases );
 			$this->getResult()->setIndexedTagName( $arr['aliases'], 'alias' );
@@ -198,20 +221,20 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 		$this->getResult()->setIndexedTagName( $data, 'specialpage' );
 		return $this->getResult()->addValue( 'query', $property, $data );
 	}
-	
+
 	protected function appendMagicWords( $property ) {
 		global $wgContLang;
 		$data = array();
-		foreach($wgContLang->getMagicWords() as $magicword => $aliases)
-		{
-			$caseSensitive = array_shift($aliases);
-			$arr = array('name' => $magicword, 'aliases' => $aliases);
-			if($caseSensitive)
+		foreach ( $wgContLang->getMagicWords() as $magicword => $aliases ) {
+			$caseSensitive = array_shift( $aliases );
+			$arr = array( 'name' => $magicword, 'aliases' => $aliases );
+			if ( $caseSensitive ) {
 				$arr['case-sensitive'] = '';
-			$this->getResult()->setIndexedTagName($arr['aliases'], 'alias');
+			}
+			$this->getResult()->setIndexedTagName( $arr['aliases'], 'alias' );
 			$data[] = $arr;
 		}
-		$this->getResult()->setIndexedTagName($data, 'magicword');
+		$this->getResult()->setIndexedTagName( $data, 'magicword' );
 		return $this->getResult()->addValue( 'query', $property, $data );
 	}
 
@@ -220,34 +243,34 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 		$this->addTables( 'interwiki' );
 		$this->addFields( array( 'iw_prefix', 'iw_local', 'iw_url' ) );
 
-		if( $filter === 'local' )
+		if ( $filter === 'local' ) {
 			$this->addWhere( 'iw_local = 1' );
-		elseif( $filter === '!local' )
+		} elseif ( $filter === '!local' ) {
 			$this->addWhere( 'iw_local = 0' );
-		elseif( $filter )
-			ApiBase :: dieDebug( __METHOD__, "Unknown filter=$filter" );
+		} elseif ( $filter ) {
+			ApiBase::dieDebug( __METHOD__, "Unknown filter=$filter" );
+		}
 
 		$this->addOption( 'ORDER BY', 'iw_prefix' );
 
-		$db = $this->getDB();
 		$res = $this->select( __METHOD__ );
 
 		$data = array();
 		$langNames = Language::getLanguageNames();
-		while( $row = $db->fetchObject($res) )
-		{
+		foreach ( $res as $row ) {
 			$val = array();
 			$val['prefix'] = $row->iw_prefix;
-			if( $row->iw_local == '1' )
+			if ( $row->iw_local == '1' ) {
 				$val['local'] = '';
-//			$val['trans'] = intval($row->iw_trans);	// should this be exposed?
-			if( isset( $langNames[$row->iw_prefix] ) )
+			}
+			// $val['trans'] = intval( $row->iw_trans ); // should this be exposed?
+			if ( isset( $langNames[$row->iw_prefix] ) ) {
 				$val['language'] = $langNames[$row->iw_prefix];
+			}
 			$val['url'] = $row->iw_url;
 
 			$data[] = $val;
 		}
-		$db->freeResult( $res );
 
 		$this->getResult()->setIndexedTagName( $data, 'iw' );
 		return $this->getResult()->addValue( 'query', $property, $data );
@@ -256,13 +279,14 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 	protected function appendDbReplLagInfo( $property, $includeAll ) {
 		global $wgShowHostnames;
 		$data = array();
-		if( $includeAll ) {
-			if ( !$wgShowHostnames )
-				$this->dieUsage('Cannot view all servers info unless $wgShowHostnames is true', 'includeAllDenied');
+		if ( $includeAll ) {
+			if ( !$wgShowHostnames ) {
+				$this->dieUsage( 'Cannot view all servers info unless $wgShowHostnames is true', 'includeAllDenied' );
+			}
 
 			$lb = wfGetLB();
 			$lags = $lb->getLagTimes();
-			foreach( $lags as $i => $lag ) {
+			foreach ( $lags as $i => $lag ) {
 				$data[] = array(
 					'host' => $lb->getServerName( $i ),
 					'lag' => $lag
@@ -293,29 +317,60 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 		$data['images'] = intval( SiteStats::images() );
 		$data['users'] = intval( SiteStats::users() );
 		$data['activeusers'] = intval( SiteStats::activeUsers() );
-		$data['admins'] = intval( SiteStats::numberingroup('sysop') );
+		$data['admins'] = intval( SiteStats::numberingroup( 'sysop' ) );
 		$data['jobs'] = intval( SiteStats::jobs() );
 		return $this->getResult()->addValue( 'query', $property, $data );
 	}
 
-	protected function appendUserGroups( $property ) {
-		global $wgGroupPermissions;
+	protected function appendUserGroups( $property, $numberInGroup ) {
+		global $wgGroupPermissions, $wgAddGroups, $wgRemoveGroups, $wgGroupsAddToSelf, $wgGroupsRemoveFromSelf;
+		
 		$data = array();
-		foreach( $wgGroupPermissions as $group => $permissions ) {
-			$arr = array( 'name' => $group, 'rights' => array_keys( $permissions, true ) );
+		foreach ( $wgGroupPermissions as $group => $permissions ) {
+			$arr = array(
+				'name' => $group,
+				'rights' => array_keys( $permissions, true ),
+			);
+			
+			if ( $numberInGroup ) {
+				global $wgAutopromote;
+			
+				if ( $group == 'user' ) {
+					$arr['number'] = SiteStats::users();
+					
+				// '*' and autopromote groups have no size
+				} elseif ( $group !== '*' && !isset( $wgAutopromote[$group] ) ) {
+					$arr['number'] = SiteStats::numberInGroup( $group );
+				}
+			}
+			
+			$groupArr = array(
+				'add' => $wgAddGroups,
+				'remove' => $wgRemoveGroups,
+				'add-self' => $wgGroupsAddToSelf,
+				'remove-self' => $wgGroupsRemoveFromSelf
+			);
+			
+			foreach( $groupArr as $type => $rights ) {
+				if( isset( $rights[$group] ) ) {
+					$arr[$type] = $rights[$group];
+					$this->getResult()->setIndexedTagName( $arr[$type], 'group' );
+				}
+			}
+			
 			$this->getResult()->setIndexedTagName( $arr['rights'], 'permission' );
 			$data[] = $arr;
 		}
-
+		
 		$this->getResult()->setIndexedTagName( $data, 'group' );
 		return $this->getResult()->addValue( 'query', $property, $data );
 	}
-	
+
 	protected function appendFileExtensions( $property ) {
 		global $wgFileExtensions;
-		
+
 		$data = array();
-		foreach( $wgFileExtensions as $ext ) {
+		foreach ( $wgFileExtensions as $ext ) {
 			$data[] = array( 'ext' => $ext );
 		}
 		$this->getResult()->setIndexedTagName( $data, 'fe' );
@@ -329,21 +384,34 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 			foreach ( $extensions as $ext ) {
 				$ret = array();
 				$ret['type'] = $type;
-				if ( isset( $ext['name'] ) ) 
+				if ( isset( $ext['name'] ) ) {
 					$ret['name'] = $ext['name'];
-				if ( isset( $ext['description'] ) ) 
+				}
+				if ( isset( $ext['description'] ) ) {
 					$ret['description'] = $ext['description'];
-				if ( isset( $ext['descriptionmsg'] ) ) 
-					$ret['descriptionmsg'] = $ext['descriptionmsg'];
+				}
+				if ( isset( $ext['descriptionmsg'] ) ) {
+					// Can be a string or array( key, param1, param2, ... )
+					if ( is_array( $ext['descriptionmsg'] ) ) {
+						$ret['descriptionmsg'] = $ext['descriptionmsg'][0];
+						$ret['descriptionmsgparams'] = array_slice( $ext['descriptionmsg'], 1 );
+						$this->getResult()->setIndexedTagName( $ret['descriptionmsgparams'], 'param' );
+					} else {
+						$ret['descriptionmsg'] = $ext['descriptionmsg'];
+					}
+				}
 				if ( isset( $ext['author'] ) ) {
-					$ret['author'] = is_array( $ext['author'] ) ? 
+					$ret['author'] = is_array( $ext['author'] ) ?
 						implode( ', ', $ext['author' ] ) : $ext['author'];
 				}
+				if ( isset( $ext['url'] ) ) {
+					$ret['url'] = $ext['url'];
+				}
 				if ( isset( $ext['version'] ) ) {
 						$ret['version'] = $ext['version'];
-				} elseif ( isset( $ext['svn-revision'] ) && 
-					preg_match( '/\$(?:Rev|LastChangedRevision|Revision): *(\d+)/', 
-						$ext['svn-revision'], $m ) )  
+				} elseif ( isset( $ext['svn-revision'] ) &&
+					preg_match( '/\$(?:Rev|LastChangedRevision|Revision): *(\d+)/',
+						$ext['svn-revision'], $m ) )
 				{
 						$ret['version'] = 'r' . $m[1];
 				}
@@ -361,7 +429,7 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 		$title = Title::newFromText( $wgRightsPage );
 		$url = $title ? $title->getFullURL() : $wgRightsUrl;
 		$text = $wgRightsText;
-		if( !$text && $title ) {
+		if ( !$text && $title ) {
 			$text = $title->getPrefixedText();
 		}
 
@@ -373,6 +441,17 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 		return $this->getResult()->addValue( 'query', $property, $data );
 	}
 
+	public function appendLanguages( $property ) {
+		$data = array();
+		foreach ( Language::getLanguageNames() as $code => $name ) {
+			$lang = array( 'code' => $code );
+			ApiResult::setContent( $lang, $name );
+			$data[] = $lang;
+		}
+		$this->getResult()->setIndexedTagName( $data, 'lang' );
+		return $this->getResult()->addValue( 'query', $property, $data );
+	}
+
 	public function getCacheMode( $params ) {
 		return 'public';
 	}
@@ -380,9 +459,9 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 	public function getAllowedParams() {
 		return array(
 			'prop' => array(
-				ApiBase :: PARAM_DFLT => 'general',
-				ApiBase :: PARAM_ISMULTI => true,
-				ApiBase :: PARAM_TYPE => array(
+				ApiBase::PARAM_DFLT => 'general',
+				ApiBase::PARAM_ISMULTI => true,
+				ApiBase::PARAM_TYPE => array(
 					'general',
 					'namespaces',
 					'namespacealiases',
@@ -395,15 +474,17 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 					'extensions',
 					'fileextensions',
 					'rightsinfo',
+					'languages',
 				)
 			),
 			'filteriw' => array(
-				ApiBase :: PARAM_TYPE => array(
+				ApiBase::PARAM_TYPE => array(
 					'local',
 					'!local',
 				)
 			),
 			'showalldb' => false,
+			'numberingroup' => false,
 		);
 	}
 
@@ -411,37 +492,45 @@ class ApiQuerySiteinfo extends ApiQueryBase {
 		return array(
 			'prop' => array(
 				'Which sysinfo properties to get:',
-				' general      - Overall system information',
-				' namespaces   - List of registered namespaces and their canonical names',
-				' namespacealiases - List of registered namespace aliases',
-				' specialpagealiases - List of special page aliases',
-				' magicwords   - List of magic words and their aliases',
-				' statistics   - Returns site statistics',
-				' interwikimap - Returns interwiki map (optionally filtered)',
-				' dbrepllag    - Returns database server with the highest replication lag',
-				' usergroups   - Returns user groups and the associated permissions',
-				' extensions   - Returns extensions installed on the wiki',
-				' fileextensions - Returns list of file extensions allowed to be uploaded',
-				' rightsinfo   - Returns wiki rights (license) information if available',
+				' general               - Overall system information',
+				' namespaces            - List of registered namespaces and their canonical names',
+				' namespacealiases      - List of registered namespace aliases',
+				' specialpagealiases    - List of special page aliases',
+				' magicwords            - List of magic words and their aliases',
+				' statistics            - Returns site statistics',
+				' interwikimap          - Returns interwiki map (optionally filtered)',
+				' dbrepllag             - Returns database server with the highest replication lag',
+				' usergroups            - Returns user groups and the associated permissions',
+				' extensions            - Returns extensions installed on the wiki',
+				' fileextensions        - Returns list of file extensions allowed to be uploaded',
+				' rightsinfo            - Returns wiki rights (license) information if available',
+				' languages             - Returns a list of languages MediaWiki supports',
 			),
 			'filteriw' =>  'Return only local or only nonlocal entries of the interwiki map',
 			'showalldb' => 'List all database servers, not just the one lagging the most',
+			'numberingroup' => 'Lists the number of users in user groups',
 		);
 	}
 
 	public function getDescription() {
-		return 'Return general information about the site.';
+		return 'Return general information about the site';
+	}
+
+	public function getPossibleErrors() {
+		return array_merge( parent::getPossibleErrors(), array(
+			array( 'code' => 'includeAllDenied', 'info' => 'Cannot view all servers info unless $wgShowHostnames is true' ),
+		) );
 	}
 
 	protected function getExamples() {
 		return array(
 			'api.php?action=query&meta=siteinfo&siprop=general|namespaces|namespacealiases|statistics',
 			'api.php?action=query&meta=siteinfo&siprop=interwikimap&sifilteriw=local',
-			'api.php?action=query&meta=siteinfo&siprop=dbrepllag&sishowalldb',
-			);
+			'api.php?action=query&meta=siteinfo&siprop=dbrepllag&sishowalldb=',
+		);
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiQuerySiteinfo.php 69986 2010-07-27 03:57:39Z tstarling $';
+		return __CLASS__ . ': $Id$';
 	}
 }
