@@ -1,10 +1,11 @@
 <?php
 
-/*
- * Created on Mar 24, 2009
+/**
  * API for MediaWiki 1.8+
  *
- * Copyright (C) 2009 Roan Kattouw <Firstname>.<Lastname>@home.nl
+ * Created on Mar 24, 2009
+ *
+ * Copyright © 2009 Roan Kattouw <Firstname>.<Lastname>@home.nl
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +19,15 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
  */
 
 if ( !defined( 'MEDIAWIKI' ) ) {
 	// Eclipse helper - will be ignored in production
-	require_once ( "ApiBase.php" );
+	require_once( "ApiBase.php" );
 }
 
 /**
@@ -33,16 +36,17 @@ if ( !defined( 'MEDIAWIKI' ) ) {
 class ApiUserrights extends ApiBase {
 
 	public function __construct( $main, $action ) {
-		parent :: __construct( $main, $action );
+		parent::__construct( $main, $action );
 	}
 
+	private $mUser = null;
+
 	public function execute() {
 		$params = $this->extractRequestParams();
-		
-		// User already validated in call to getTokenSalt from Main
+
+		$user = $this->getUser();
+
 		$form = new UserrightsPage;
-		$user = $form->fetchUser( $params['user'] );
-		
 		$r['user'] = $user->getName();
 		list( $r['added'], $r['removed'] ) =
 			$form->doSaveUserGroups(
@@ -54,6 +58,29 @@ class ApiUserrights extends ApiBase {
 		$this->getResult()->addValue( null, $this->getModuleName(), $r );
 	}
 
+	/**
+	 * @return User
+	 */
+	private function getUser() {
+		if ( $this->mUser !== null ) {
+			return $this->mUser;
+		}
+
+		$params = $this->extractRequestParams();
+
+		$form = new UserrightsPage;
+		$status = $form->fetchUser( $params['user'] );
+		if ( !$status->isOK() ) {
+			$errors = $status->getErrorsArray();
+			$this->dieUsageMsg( $errors[0] );
+		} else {
+			$user = $status->value;
+		}
+
+		$this->mUser = $user;
+		return $user;
+	}
+
 	public function mustBePosted() {
 		return true;
 	}
@@ -64,24 +91,27 @@ class ApiUserrights extends ApiBase {
 
 	public function getAllowedParams() {
 		return array (
-			'user' => null,
+			'user' => array(
+				ApiBase::PARAM_TYPE => 'string',
+				ApiBase::PARAM_REQUIRED => true
+			),
 			'add' => array(
-				ApiBase :: PARAM_TYPE => User::getAllGroups(),
-				ApiBase :: PARAM_ISMULTI => true
+				ApiBase::PARAM_TYPE => User::getAllGroups(),
+				ApiBase::PARAM_ISMULTI => true
 			),
 			'remove' => array(
-				ApiBase :: PARAM_TYPE => User::getAllGroups(),
-				ApiBase :: PARAM_ISMULTI => true
+				ApiBase::PARAM_TYPE => User::getAllGroups(),
+				ApiBase::PARAM_ISMULTI => true
 			),
 			'token' => null,
 			'reason' => array(
-				ApiBase :: PARAM_DFLT => ''
+				ApiBase::PARAM_DFLT => ''
 			)
 		);
 	}
 
 	public function getParamDescription() {
-		return array (
+		return array(
 			'user' => 'User name',
 			'add' => 'Add the user to these groups',
 			'remove' => 'Remove the user from these groups',
@@ -91,42 +121,24 @@ class ApiUserrights extends ApiBase {
 	}
 
 	public function getDescription() {
-		return array(
-			'Add/remove a user to/from groups',
-		);
-	}
-	
-    public function getPossibleErrors() {
-		return array_merge( parent::getPossibleErrors(), array(
-			array( 'missingparam', 'user' ),
-        ) );
+		return 'Add/remove a user to/from groups';
 	}
 
 	public function needsToken() {
 		return true;
 	}
-	
+
 	public function getTokenSalt() {
-		$params = $this->extractRequestParams();
-		if ( is_null( $params['user'] ) )
-			$this->dieUsageMsg( array( 'missingparam', 'user' ) );
-
-		$form = new UserrightsPage;
-		$user = $form->fetchUser( $params['user'] );
-		if ( $user instanceof WikiErrorMsg )
-			$this->dieUsageMsg( array_merge(
-				(array)$user->getMessageKey(), $user->getMessageArgs() ) );
-
-		return $user->getName();
+		return $this->getUser()->getName();
 	}
 
 	protected function getExamples() {
-		return array (
+		return array(
 			'api.php?action=userrights&user=FooBot&add=bot&remove=sysop|bureaucrat&token=123ABC'
 		);
 	}
 
 	public function getVersion() {
-		return __CLASS__ . ': $Id: ApiUserrights.php 74217 2010-10-03 15:53:07Z reedy $';
+		return __CLASS__ . ': $Id$';
 	}
 }
