@@ -1,6 +1,14 @@
 <?php
+/**
+ * Foreign file with an accessible MediaWiki database
+ *
+ * @file
+ * @ingroup FileRepo
+ */
 
 /**
+ * Foreign file with an accessible MediaWiki database
+ *
  * @ingroup FileRepo
  */
 class ForeignDBFile extends LocalFile {
@@ -19,16 +27,6 @@ class ForeignDBFile extends LocalFile {
 		return $file;
 	}
 
-	function getCacheKey() {
-		if ( $this->repo->hasSharedCache() ) {
-			$hashedName = md5($this->name);
-			return wfForeignMemcKey( $this->repo->dbName, $this->repo->tablePrefix,
-				'file', $hashedName );
-		} else {
-			return false;
-		}
-	}
-
 	function publish( $srcPath, $flags = 0 ) {
 		$this->readOnlyError();
 	}
