@@ -1,17 +1,25 @@
 <?php
+/**
+ * A foreign repository with an accessible MediaWiki database
+ *
+ * @file
+ * @ingroup FileRepo
+ */
 
 /**
  * A foreign repository with an accessible MediaWiki database
+ *
+ * @ingroup FileRepo
  */
-
 class ForeignDBRepo extends LocalRepo {
 	# Settings
-	var $dbType, $dbServer, $dbUser, $dbPassword, $dbName, $dbFlags, 
+	var $dbType, $dbServer, $dbUser, $dbPassword, $dbName, $dbFlags,
 		$tablePrefix, $hasSharedCache;
-	
+
 	# Other stuff
 	var $dbConn;
 	var $fileFactory = array( 'ForeignDBFile', 'newFromTitle' );
+	var $fileFromRowFactory = array( 'ForeignDBFile', 'newFromRow' );
 
 	function __construct( $info ) {
 		parent::__construct( $info );
@@ -27,10 +35,16 @@ class ForeignDBRepo extends LocalRepo {
 
 	function getMasterDB() {
 		if ( !isset( $this->dbConn ) ) {
-			$class = 'Database' . ucfirst( $this->dbType );
-			$this->dbConn = new $class( $this->dbServer, $this->dbUser, 
-				$this->dbPassword, $this->dbName, false, $this->dbFlags, 
-				$this->tablePrefix );
+			$this->dbConn = DatabaseBase::newFromType( $this->dbType,
+				array(
+					'host' => $this->dbServer,
+					'user'   => $this->dbUser,
+					'password' => $this->dbPassword,
+					'dbname' => $this->dbName,
+					'flags' => $this->dbFlags,
+					'tableprefix' => $this->tablePrefix
+				)
+			);
 		}
 		return $this->dbConn;
 	}
@@ -43,15 +57,28 @@ class ForeignDBRepo extends LocalRepo {
 		return $this->hasSharedCache;
 	}
 
+	/**
+	 * Get a key on the primary cache for this repository.
+	 * Returns false if the repository's cache is not accessible at this site. 
+	 * The parameters are the parts of the key, as for wfMemcKey().
+	 */
+	function getSharedCacheKey( /*...*/ ) {
+		if ( $this->hasSharedCache() ) {
+			$args = func_get_args();
+			array_unshift( $args, $this->dbName, $this->tablePrefix );
+			return call_user_func_array( 'wfForeignMemcKey', $args );
+		} else {
+			return false;
+		}
+	}
+
 	function store( $srcPath, $dstZone, $dstRel, $flags = 0 ) {
 		throw new MWException( get_class($this) . ': write operations are not supported' );
 	}
 	function publish( $srcPath, $dstRel, $archiveRel, $flags = 0 ) {
 		throw new MWException( get_class($this) . ': write operations are not supported' );
 	}
-	function deleteBatch( $fileMap ) {
+	function deleteBatch( $sourceDestPairs ) {
 		throw new MWException( get_class($this) . ': write operations are not supported' );
 	}
 }
-
-
