@@ -1,5 +1,7 @@
 <?php
 /**
+ * Handler for Microsoft's bitmap format
+ *
  * @file
  * @ingroup Media
  */
@@ -17,7 +19,7 @@ class BmpHandler extends BitmapHandler {
 	}
 
 	// Render files as PNG
-	function getThumbType( $text, $mime ) {
+	function getThumbType( $text, $mime, $params = null ) {
 		return array( 'png', 'image/png' );
 	}
 
