@@ -1,34 +1,35 @@
 <?php
-# Copyright (C) 2004 Brion Vibber <brion@pobox.com>
-# http://www.mediawiki.org/
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-# http://www.gnu.org/copyleft/gpl.html
+/**
+ * Unicode normalization routines
+ *
+ * Copyright © 2004 Brion Vibber <brion@pobox.com>
+ * http://www.mediawiki.org/
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
+ * @file
+ * @ingroup UtfNormal
+ */
+
+/**
+ * @defgroup UtfNormal UtfNormal
+ */
 
-/** */
 require_once dirname(__FILE__).'/UtfNormalUtil.php';
 
-global $utfCombiningClass, $utfCanonicalComp, $utfCanonicalDecomp;
-$utfCombiningClass = NULL;
-$utfCanonicalComp = NULL;
-$utfCanonicalDecomp = NULL;
-
-# Load compatibility decompositions on demand if they are needed.
-global $utfCompatibilityDecomp;
-$utfCompatibilityDecomp = NULL;
-
 /**
  * For using the ICU wrapper
  */
@@ -41,6 +42,7 @@ define( 'UNORM_NFKC', 5 );
 define( 'UNORM_FCD',  6 );
 
 define( 'NORMALIZE_ICU', function_exists( 'utf8_normalize' ) );
+define( 'NORMALIZE_INTL', function_exists( 'normalizer_normalize' ) );
 
 /**
  * Unicode normalization routines for working with UTF-8 strings.
@@ -54,9 +56,18 @@ define( 'NORMALIZE_ICU', function_exists( 'utf8_normalize' ) );
  *
  * See description of forms at http://www.unicode.org/reports/tr15/
  *
- * @addtogroup UtfNormal
+ * @ingroup UtfNormal
  */
 class UtfNormal {
+	static $utfCombiningClass = null;
+	static $utfCanonicalComp = null;
+	static $utfCanonicalDecomp = null;
+
+	# Load compatibility decompositions on demand if they are needed.
+	static $utfCompatibilityDecomp = null;
+
+	static $utfCheckNFC;
+
 	/**
 	 * The ultimate convenience function! Clean up invalid UTF-8 sequences,
 	 * and convert to normal form C, canonical composition.
@@ -64,23 +75,34 @@ class UtfNormal {
 	 * Fast return for pure ASCII strings; some lesser optimizations for
 	 * strings containing only known-good characters. Not as fast as toNFC().
 	 *
-	 * @param string $string a UTF-8 string
+	 * @param $string String: a UTF-8 string
 	 * @return string a clean, shiny, normalized UTF-8 string
-	 * @static
 	 */
 	static function cleanUp( $string ) {
 		if( NORMALIZE_ICU ) {
-			# We exclude a few chars that ICU would not.
-			$string = preg_replace(
-				'/[\x00-\x08\x0b\x0c\x0e-\x1f]/',
-				UTF8_REPLACEMENT,
-				$string );
-			$string = str_replace( UTF8_FFFE, UTF8_REPLACEMENT, $string );
-			$string = str_replace( UTF8_FFFF, UTF8_REPLACEMENT, $string );
+			$string = self::replaceForNativeNormalize( $string );
 
 			# UnicodeString constructor fails if the string ends with a
 			# head byte. Add a junk char at the end, we'll strip it off.
 			return rtrim( utf8_normalize( $string . "\x01", UNORM_NFC ), "\x01" );
+		} elseif( NORMALIZE_INTL ) {
+			$string = self::replaceForNativeNormalize( $string );
+			$norm = normalizer_normalize( $string, Normalizer::FORM_C );
+			if( $norm === null || $norm === false ) {
+				# normalizer_normalize will either return false or null
+				# (depending on which doc you read) if invalid utf8 string.
+				# quickIsNFCVerify cleans up invalid sequences.
+
+				if( UtfNormal::quickIsNFCVerify( $string ) ) {
+					# if that's true, the string is actually already normal.
+					return $string;
+				} else {
+					# Now we are valid but non-normal
+					return normalizer_normalize( $string, Normalizer::FORM_C );
+				}
+			} else {
+				return $norm;
+			}
 		} elseif( UtfNormal::quickIsNFCVerify( $string ) ) {
 			# Side effect -- $string has had UTF-8 errors cleaned up.
 			return $string;
@@ -94,12 +116,13 @@ class UtfNormal {
 	 * Fast return for pure ASCII strings; some lesser optimizations for
 	 * strings containing only known-good characters.
 	 *
-	 * @param string $string a valid UTF-8 string. Input is not validated.
+	 * @param $string String: a valid UTF-8 string. Input is not validated.
 	 * @return string a UTF-8 string in normal form C
-	 * @static
 	 */
 	static function toNFC( $string ) {
-		if( NORMALIZE_ICU )
+		if( NORMALIZE_INTL )
+			return normalizer_normalize( $string, Normalizer::FORM_C );
+		elseif( NORMALIZE_ICU )
 			return utf8_normalize( $string, UNORM_NFC );
 		elseif( UtfNormal::quickIsNFC( $string ) )
 			return $string;
@@ -111,12 +134,13 @@ class UtfNormal {
 	 * Convert a UTF-8 string to normal form D, canonical decomposition.
 	 * Fast return for pure ASCII strings.
 	 *
-	 * @param string $string a valid UTF-8 string. Input is not validated.
+	 * @param $string String: a valid UTF-8 string. Input is not validated.
 	 * @return string a UTF-8 string in normal form D
-	 * @static
 	 */
 	static function toNFD( $string ) {
-		if( NORMALIZE_ICU )
+		if( NORMALIZE_INTL )
+			return normalizer_normalize( $string, Normalizer::FORM_D );
+		elseif( NORMALIZE_ICU )
 			return utf8_normalize( $string, UNORM_NFD );
 		elseif( preg_match( '/[\x80-\xff]/', $string ) )
 			return UtfNormal::NFD( $string );
@@ -129,12 +153,13 @@ class UtfNormal {
 	 * This may cause irreversible information loss, use judiciously.
 	 * Fast return for pure ASCII strings.
 	 *
-	 * @param string $string a valid UTF-8 string. Input is not validated.
+	 * @param $string String: a valid UTF-8 string. Input is not validated.
 	 * @return string a UTF-8 string in normal form KC
-	 * @static
 	 */
 	static function toNFKC( $string ) {
-		if( NORMALIZE_ICU )
+		if( NORMALIZE_INTL )
+			return normalizer_normalize( $string, Normalizer::FORM_KC );
+		elseif( NORMALIZE_ICU )
 			return utf8_normalize( $string, UNORM_NFKC );
 		elseif( preg_match( '/[\x80-\xff]/', $string ) )
 			return UtfNormal::NFKC( $string );
@@ -147,12 +172,13 @@ class UtfNormal {
 	 * This may cause irreversible information loss, use judiciously.
 	 * Fast return for pure ASCII strings.
 	 *
-	 * @param string $string a valid UTF-8 string. Input is not validated.
+	 * @param $string String: a valid UTF-8 string. Input is not validated.
 	 * @return string a UTF-8 string in normal form KD
-	 * @static
 	 */
 	static function toNFKD( $string ) {
-		if( NORMALIZE_ICU )
+		if( NORMALIZE_INTL )
+			return normalizer_normalize( $string, Normalizer::FORM_KD );
+		elseif( NORMALIZE_ICU )
 			return utf8_normalize( $string, UNORM_NFKD );
 		elseif( preg_match( '/[\x80-\xff]/', $string ) )
 			return UtfNormal::NFKD( $string );
@@ -163,11 +189,9 @@ class UtfNormal {
 	/**
 	 * Load the basic composition data if necessary
 	 * @private
-	 * @static
 	 */
 	static function loadData() {
-		global $utfCombiningClass;
-		if( !isset( $utfCombiningClass ) ) {
+		if( !isset( self::$utfCombiningClass ) ) {
 			require_once( dirname(__FILE__) . '/UtfNormalData.inc' );
 		}
 	}
@@ -175,9 +199,8 @@ class UtfNormal {
 	/**
 	 * Returns true if the string is _definitely_ in NFC.
 	 * Returns false if not or uncertain.
-	 * @param string $string a valid UTF-8 string. Input is not validated.
+	 * @param $string String: a valid UTF-8 string. Input is not validated.
 	 * @return bool
-	 * @static
 	 */
 	static function quickIsNFC( $string ) {
 		# ASCII is always valid NFC!
@@ -185,7 +208,6 @@ class UtfNormal {
 		if( !preg_match( '/[\x80-\xff]/', $string ) ) return true;
 
 		UtfNormal::loadData();
-		global $utfCheckNFC, $utfCombiningClass;
 		$len = strlen( $string );
 		for( $i = 0; $i < $len; $i++ ) {
 			$c = $string{$i};
@@ -202,11 +224,11 @@ class UtfNormal {
 				$c = substr( $string, $i, 2 );
 				$i++;
 			}
-			if( isset( $utfCheckNFC[$c] ) ) {
+			if( isset( self::$utfCheckNFC[$c] ) ) {
 				# If it's NO or MAYBE, bail and do the slow check.
 				return false;
 			}
-			if( isset( $utfCombiningClass[$c] ) ) {
+			if( isset( self::$utfCombiningClass[$c] ) ) {
 				# Combining character? We might have to do sorting, at least.
 				return false;
 			}
@@ -217,8 +239,7 @@ class UtfNormal {
 	/**
 	 * Returns true if the string is _definitely_ in NFC.
 	 * Returns false if not or uncertain.
-	 * @param string $string a UTF-8 string, altered on output to be valid UTF-8 safe for XML.
-	 * @static
+	 * @param $string String: a UTF-8 string, altered on output to be valid UTF-8 safe for XML.
 	 */
 	static function quickIsNFCVerify( &$string ) {
 		# Screen out some characters that eg won't be allowed in XML
@@ -233,9 +254,8 @@ class UtfNormal {
 		if( !isset( $checkit ) ) {
 			# Load/build some scary lookup tables...
 			UtfNormal::loadData();
-			global $utfCheckNFC, $utfCombiningClass;
 
-			$utfCheckOrCombining = array_merge( $utfCheckNFC, $utfCombiningClass );
+			$utfCheckOrCombining = array_merge( self::$utfCheckNFC, self::$utfCombiningClass );
 
 			# Head bytes for sequences which we should do further validity checks
 			$checkit = array_flip( array_map( 'chr',
@@ -299,7 +319,8 @@ class UtfNormal {
 			$len = $chunk + 1; # Counting down is faster. I'm *so* sorry.
 
 			for( $i = -1; --$len; ) {
-				if( $remaining = $tailBytes[$c = $str{++$i}] ) {
+				$remaining = $tailBytes[$c = $str{++$i}];
+				if( $remaining ) {
 					# UTF-8 head byte!
 					$sequence = $head = $c;
 					do {
@@ -435,51 +456,46 @@ class UtfNormal {
 	# checking for validity or any optimization etc. Input must be
 	# VALID UTF-8!
 	/**
-	 * @param string $string
+	 * @param $string string
 	 * @return string
 	 * @private
-	 * @static
 	 */
 	static function NFC( $string ) {
 		return UtfNormal::fastCompose( UtfNormal::NFD( $string ) );
 	}
 
 	/**
-	 * @param string $string
+	 * @param $string string
 	 * @return string
 	 * @private
-	 * @static
 	 */
 	static function NFD( $string ) {
 		UtfNormal::loadData();
-		global $utfCanonicalDecomp;
+
 		return UtfNormal::fastCombiningSort(
-			UtfNormal::fastDecompose( $string, $utfCanonicalDecomp ) );
+			UtfNormal::fastDecompose( $string, self::$utfCanonicalDecomp ) );
 	}
 
 	/**
-	 * @param string $string
+	 * @param $string string
 	 * @return string
 	 * @private
-	 * @static
 	 */
 	static function NFKC( $string ) {
 		return UtfNormal::fastCompose( UtfNormal::NFKD( $string ) );
 	}
 
 	/**
-	 * @param string $string
+	 * @param $string string
 	 * @return string
 	 * @private
-	 * @static
 	 */
 	static function NFKD( $string ) {
-		global $utfCompatibilityDecomp;
-		if( !isset( $utfCompatibilityDecomp ) ) {
+		if( !isset( self::$utfCompatibilityDecomp ) ) {
 			require_once( 'UtfNormalDataK.inc' );
 		}
-		return UtfNormal::fastCombiningSort(
-			UtfNormal::fastDecompose( $string, $utfCompatibilityDecomp ) );
+		return self::fastCombiningSort(
+			self::fastDecompose( $string, self::$utfCompatibilityDecomp ) );
 	}
 
 
@@ -488,10 +504,9 @@ class UtfNormal {
 	 * (depending on which decomposition map is passed to us).
 	 * Input is assumed to be *valid* UTF-8. Invalid code will break.
 	 * @private
-	 * @param string $string Valid UTF-8 string
-	 * @param array $map hash of expanded decomposition map
+	 * @param $string String: valid UTF-8 string
+	 * @param $map Array: hash of expanded decomposition map
 	 * @return string a UTF-8 string decomposed, not yet normalized (needs sorting)
-	 * @static
 	 */
 	static function fastDecompose( $string, $map ) {
 		UtfNormal::loadData();
@@ -550,13 +565,11 @@ class UtfNormal {
 	 * Sorts combining characters into canonical order. This is the
 	 * final step in creating decomposed normal forms D and KD.
 	 * @private
-	 * @param string $string a valid, decomposed UTF-8 string. Input is not validated.
+	 * @param $string String: a valid, decomposed UTF-8 string. Input is not validated.
 	 * @return string a UTF-8 string with combining characters sorted in canonical order
-	 * @static
 	 */
 	static function fastCombiningSort( $string ) {
 		UtfNormal::loadData();
-		global $utfCombiningClass;
 		$len = strlen( $string );
 		$out = '';
 		$combiners = array();
@@ -575,8 +588,8 @@ class UtfNormal {
 					$c = substr( $string, $i, 2 );
 					$i++;
 				}
-				if( isset( $utfCombiningClass[$c] ) ) {
-					$lastClass = $utfCombiningClass[$c];
+				if( isset( self::$utfCombiningClass[$c] ) ) {
+					$lastClass = self::$utfCombiningClass[$c];
 					if( isset( $combiners[$lastClass] ) ) {
 						$combiners[$lastClass] .= $c;
 					} else {
@@ -604,13 +617,11 @@ class UtfNormal {
 	 * Produces canonically composed sequences, i.e. normal form C or KC.
 	 *
 	 * @private
-	 * @param string $string a valid UTF-8 string in sorted normal form D or KD. Input is not validated.
+	 * @param $string String: a valid UTF-8 string in sorted normal form D or KD. Input is not validated.
 	 * @return string a UTF-8 string with canonical precomposed characters used where possible
-	 * @static
 	 */
 	static function fastCompose( $string ) {
 		UtfNormal::loadData();
-		global $utfCanonicalComp, $utfCombiningClass;
 		$len = strlen( $string );
 		$out = '';
 		$lastClass = -1;
@@ -642,14 +653,14 @@ class UtfNormal {
 			}
 			$pair = $startChar . $c;
 			if( $n > 0x80 ) {
-				if( isset( $utfCombiningClass[$c] ) ) {
+				if( isset( self::$utfCombiningClass[$c] ) ) {
 					# A combining char; see what we can do with it
-					$class = $utfCombiningClass[$c];
+					$class = self::$utfCombiningClass[$c];
 					if( !empty( $startChar ) &&
 						$lastClass < $class &&
 						$class > 0 &&
-						isset( $utfCanonicalComp[$pair] ) ) {
-						$startChar = $utfCanonicalComp[$pair];
+						isset( self::$utfCanonicalComp[$pair] ) ) {
+						$startChar = self::$utfCanonicalComp[$pair];
 						$class = 0;
 					} else {
 						$combining .= $c;
@@ -661,8 +672,8 @@ class UtfNormal {
 			}
 			# New start char
 			if( $lastClass == 0 ) {
-				if( isset( $utfCanonicalComp[$pair] ) ) {
-					$startChar = $utfCanonicalComp[$pair];
+				if( isset( self::$utfCanonicalComp[$pair] ) ) {
+					$startChar = self::$utfCanonicalComp[$pair];
 					$lastHangul = 0;
 					continue;
 				}
@@ -737,9 +748,8 @@ class UtfNormal {
 	/**
 	 * This is just used for the benchmark, comparing how long it takes to
 	 * interate through a string without really doing anything of substance.
-	 * @param string $string
+	 * @param $string string
 	 * @return string
-	 * @static
 	 */
 	static function placebo( $string ) {
 		$len = strlen( $string );
@@ -749,6 +759,20 @@ class UtfNormal {
 		}
 		return $out;
 	}
+	/**
+	 * Function to replace some characters that we don't want
+	 * but most of the native normalize functions keep.
+	 *
+	 * @param $string String The string
+	 * @return String String with the character codes replaced.
+	 */
+	private static function replaceForNativeNormalize( $string ) { 
+		$string = preg_replace(
+			'/[\x00-\x08\x0b\x0c\x0e-\x1f]/',
+			UTF8_REPLACEMENT,
+			$string );
+		$string = str_replace( UTF8_FFFE, UTF8_REPLACEMENT, $string );
+		$string = str_replace( UTF8_FFFF, UTF8_REPLACEMENT, $string );
+		return $string;
+	}
 }
-
-
