@@ -1,11 +1,29 @@
 <?php
 /**
+ * Implements Special:Ancientpages
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
  * @file
  * @ingroup SpecialPage
  */
 
 /**
  * Implements Special:Ancientpages
+ *
  * @ingroup SpecialPage
  */
 class AncientPagesPage extends QueryPage {
@@ -21,12 +39,11 @@ class AncientPagesPage extends QueryPage {
 	function isSyndicated() { return false; }
 
 	function getSQL() {
-		global $wgDBtype;
 		$db = wfGetDB( DB_SLAVE );
 		$page = $db->tableName( 'page' );
 		$revision = $db->tableName( 'revision' );
-		$epoch = $wgDBtype == 'mysql' ? 'UNIX_TIMESTAMP(rev_timestamp)' :
-			'EXTRACT(epoch FROM rev_timestamp)';
+		$epoch = $db->unixTimestamp( 'rev_timestamp' );
+
 		return
 			"SELECT 'Ancientpages' as type,
 					page_namespace as namespace,
@@ -46,8 +63,11 @@ class AncientPagesPage extends QueryPage {
 
 		$d = $wgLang->timeanddate( wfTimestamp( TS_MW, $result->value ), true );
 		$title = Title::makeTitle( $result->namespace, $result->title );
-		$link = $skin->makeKnownLinkObj( $title, htmlspecialchars( $wgContLang->convert( $title->getPrefixedText() ) ) );
-		return wfSpecialList($link, $d);
+		$link = $skin->linkKnown(
+			$title,
+			htmlspecialchars( $wgContLang->convert( $title->getPrefixedText() ) )
+		);
+		return wfSpecialList($link, htmlspecialchars($d) );
 	}
 }
 
