@@ -1,27 +1,57 @@
 <?php
 /**
+ * Implements Special:Categories
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
  * @file
  * @ingroup SpecialPage
  */
 
-function wfSpecialCategories( $par=null ) {
-	global $wgOut, $wgRequest;
+/**
+ * @ingroup SpecialPage
+ */
+class SpecialCategories extends SpecialPage {
 
-	if( $par == '' ) {
-		$from = $wgRequest->getText( 'from' );
-	} else {
-		$from = $par;
+	function __construct() {
+		parent::__construct( 'Categories' );
+	}
+
+	function execute( $par ) {
+		global $wgOut, $wgRequest;
+
+		$this->setHeaders();
+		$this->outputHeader();
+		$wgOut->allowClickjacking();
+
+		$from = $wgRequest->getText( 'from', $par );
+
+		$cap = new CategoryPager( $from );
+		$cap->doQuery();
+
+		$wgOut->addHTML(
+			Html::openElement( 'div', array( 'class' => 'mw-spcontent' ) ) .
+			wfMsgExt( 'categoriespagetext', array( 'parse' ), $cap->getNumRows() ) .
+			$cap->getStartForm( $from ) .
+			$cap->getNavigationBar() .
+			'<ul>' . $cap->getBody() . '</ul>' .
+			$cap->getNavigationBar() .
+			Html::closeElement( 'div' )
+		);
 	}
-	$cap = new CategoryPager( $from );
-	$wgOut->addHTML(
-		XML::openElement( 'div', array('class' => 'mw-spcontent') ) .
-		wfMsgExt( 'categoriespagetext', array( 'parse' ) ) .
-		$cap->getStartForm( $from ) .
-		$cap->getNavigationBar() .
-		'<ul>' . $cap->getBody() . '</ul>' .
-		$cap->getNavigationBar() .
-		XML::closeElement( 'div' )
-	);
 }
 
 /**
@@ -35,10 +65,7 @@ class CategoryPager extends AlphabeticPager {
 		parent::__construct();
 		$from = str_replace( ' ', '_', $from );
 		if( $from !== '' ) {
-			global $wgCapitalLinks, $wgContLang;
-			if( $wgCapitalLinks ) {
-				$from = $wgContLang->ucfirst( $from );
-			}
+			$from = Title::capitalize( $from, NS_CATEGORY );
 			$this->mOffset = $from;
 		}
 	}
@@ -74,14 +101,11 @@ class CategoryPager extends AlphabeticPager {
 
 	/* Override getBody to apply LinksBatch on resultset before actually outputting anything. */
 	public function getBody() {
-		if (!$this->mQueryDone) {
-			$this->doQuery();
-		}
 		$batch = new LinkBatch;
 
 		$this->mResult->rewind();
 
-		while ( $row = $this->mResult->fetchObject() ) {
+		foreach ( $this->mResult as $row ) {
 			$batch->addObj( Title::makeTitleSafe( NS_CATEGORY, $row->cat_title ) );
 		}
 		$batch->execute();
@@ -92,7 +116,7 @@ class CategoryPager extends AlphabeticPager {
 	function formatRow($result) {
 		global $wgLang;
 		$title = Title::makeTitle( NS_CATEGORY, $result->cat_title );
-		$titleText = $this->getSkin()->makeLinkObj( $title, htmlspecialchars( $title->getText() ) );
+		$titleText = $this->getSkin()->link( $title, htmlspecialchars( $title->getText() ) );
 		$count = wfMsgExt( 'nmembers', array( 'parsemag', 'escape' ),
 				$wgLang->formatNum( $result->cat_pages ) );
 		return Xml::tags('li', null, "$titleText ($count)" ) . "\n";
@@ -104,7 +128,7 @@ class CategoryPager extends AlphabeticPager {
 	
 		return
 			Xml::tags( 'form', array( 'method' => 'get', 'action' => $wgScript ),
-				Xml::hidden( 'title', $t->getPrefixedText() ) .
+				Html::hidden( 'title', $t->getPrefixedText() ) .
 				Xml::fieldset( wfMsg( 'categories' ),
 					Xml::inputLabel( wfMsg( 'categoriesfrom' ),
 						'from', 'from', 20, $from ) .
