@@ -1,97 +1,111 @@
 <?php
 /**
+ * Implements Special:Movepage
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
  * @file
  * @ingroup SpecialPage
  */
 
 /**
- * Constructor
- */
-function wfSpecialMovepage( $par = null ) {
-	global $wgUser, $wgOut, $wgRequest, $action;
-
-	# Check for database lock
-	if ( wfReadOnly() ) {
-		$wgOut->readOnlyPage();
-		return;
-	}
-
-	$target = isset( $par ) ? $par : $wgRequest->getVal( 'target' );
-	$oldTitleText = $wgRequest->getText( 'wpOldTitle', $target );
-	$newTitleText = $wgRequest->getText( 'wpNewTitle' );
-
-	$oldTitle = Title::newFromText( $oldTitleText );
-	$newTitle = Title::newFromText( $newTitleText );
-
-	if( is_null( $oldTitle ) ) {
-		$wgOut->showErrorPage( 'notargettitle', 'notargettext' );
-		return;
-	}
-	if( !$oldTitle->exists() ) {
-		$wgOut->showErrorPage( 'nopagetitle', 'nopagetext' );
-		return;
-	}
-
-	# Check rights
-	$permErrors = $oldTitle->getUserPermissionsErrors( 'move', $wgUser );
-	if( !empty( $permErrors ) ) {
-		$wgOut->showPermissionsErrorPage( $permErrors );
-		return;
-	}
-
-	$form = new MovePageForm( $oldTitle, $newTitle );
-
-	if ( 'submit' == $action && $wgRequest->wasPosted()
-		&& $wgUser->matchEditToken( $wgRequest->getVal( 'wpEditToken' ) ) ) {
-		$form->doSubmit();
-	} else {
-		$form->showForm( '' );
-	}
-}
-
-/**
- * HTML form for Special:Movepage
+ * A special page that allows users to change page titles
+ *
  * @ingroup SpecialPage
  */
-class MovePageForm {
+class MovePageForm extends UnlistedSpecialPage {
 	var $oldTitle, $newTitle; # Objects
 	var $reason; # Text input
-	var $moveTalk, $deleteAndMove, $moveSubpages, $fixRedirects, $leaveRedirect; # Checks
+	var $moveTalk, $deleteAndMove, $moveSubpages, $fixRedirects, $leaveRedirect, $moveOverShared; # Checks
 
 	private $watch = false;
 
-	function __construct( $oldTitle, $newTitle ) {
-		global $wgRequest;
-		$target = isset($par) ? $par : $wgRequest->getVal( 'target' );
-		$this->oldTitle = $oldTitle;
-		$this->newTitle = $newTitle;
-		$this->reason = $wgRequest->getText( 'wpReason' );
-		if ( $wgRequest->wasPosted() ) {
-			$this->moveTalk = $wgRequest->getBool( 'wpMovetalk', false );
-			$this->fixRedirects = $wgRequest->getBool( 'wpFixRedirects', false );
-			$this->leaveRedirect = $wgRequest->getBool( 'wpLeaveRedirect', false );
-		} else {
-			$this->moveTalk = $wgRequest->getBool( 'wpMovetalk', true );
-			$this->fixRedirects = $wgRequest->getBool( 'wpFixRedirects', true );
-			$this->leaveRedirect = $wgRequest->getBool( 'wpLeaveRedirect', true );
+	public function __construct() {
+		parent::__construct( 'Movepage' );
+	}
+
+	public function execute( $par ) {
+		global $wgUser, $wgOut, $wgRequest;
+
+		# Check for database lock
+		if ( wfReadOnly() ) {
+			$wgOut->readOnlyPage();
+			return;
 		}
+
+		$this->setHeaders();
+		$this->outputHeader();
+
+		$target = !is_null( $par ) ? $par : $wgRequest->getVal( 'target' );
+
+		// Yes, the use of getVal() and getText() is wanted, see bug 20365
+		$oldTitleText = $wgRequest->getVal( 'wpOldTitle', $target );
+		$newTitleText = $wgRequest->getText( 'wpNewTitle' );
+
+		$this->oldTitle = Title::newFromText( $oldTitleText );
+		$this->newTitle = Title::newFromText( $newTitleText );
+
+		if( is_null( $this->oldTitle ) ) {
+			$wgOut->showErrorPage( 'notargettitle', 'notargettext' );
+			return;
+		}
+		if( !$this->oldTitle->exists() ) {
+			$wgOut->showErrorPage( 'nopagetitle', 'nopagetext' );
+			return;
+		}
+
+		# Check rights
+		$permErrors = $this->oldTitle->getUserPermissionsErrors( 'move', $wgUser );
+		if( !empty( $permErrors ) ) {
+			$wgOut->showPermissionsErrorPage( $permErrors );
+			return;
+		}
+
+		$def = !$wgRequest->wasPosted();
+
+		$this->reason = $wgRequest->getText( 'wpReason' );
+		$this->moveTalk = $wgRequest->getBool( 'wpMovetalk', $def );
+		$this->fixRedirects = $wgRequest->getBool( 'wpFixRedirects', $def );
+		$this->leaveRedirect = $wgRequest->getBool( 'wpLeaveRedirect', $def );
 		$this->moveSubpages = $wgRequest->getBool( 'wpMovesubpages', false );
 		$this->deleteAndMove = $wgRequest->getBool( 'wpDeleteAndMove' ) && $wgRequest->getBool( 'wpConfirm' );
-		$this->watch = $wgRequest->getCheck( 'wpWatch' );
+		$this->moveOverShared = $wgRequest->getBool( 'wpMoveOverSharedFile', false );
+		$this->watch = $wgRequest->getCheck( 'wpWatch' ) && $wgUser->isLoggedIn();
+
+		if ( 'submit' == $wgRequest->getVal( 'action' ) && $wgRequest->wasPosted()
+			&& $wgUser->matchEditToken( $wgRequest->getVal( 'wpEditToken' ) ) ) {
+			$this->doSubmit();
+		} else {
+			$this->showForm( '' );
+		}
 	}
 
 	/**
 	 * Show the form
-	 * @param mixed $err Error message. May either be a string message name or 
-	 *    array message name and parameters, like the second argument to 
-	 *    OutputPage::wrapWikiMsg(). 
+	 *
+	 * @param $err Mixed: error message. May either be a string message name or
+	 *    array message name and parameters, like the second argument to
+	 *    OutputPage::wrapWikiMsg().
 	 */
 	function showForm( $err ) {
-		global $wgOut, $wgUser, $wgFixDoubleRedirects;
+		global $wgOut, $wgUser, $wgContLang, $wgFixDoubleRedirects;
 
 		$skin = $wgUser->getSkin();
 
-		$oldTitleLink = $skin->makeLinkObj( $this->oldTitle );
+		$oldTitleLink = $skin->link( $this->oldTitle );
 
 		$wgOut->setPagetitle( wfMsg( 'move-page', $this->oldTitle->getPrefixedText() ) );
 		$wgOut->setSubtitle( wfMsg( 'move-page-backlink', $oldTitleLink ) );
@@ -128,19 +142,29 @@ class MovePageForm {
 				</tr>";
 			$err = '';
 		} else {
-			$wgOut->addWikiMsg( 'movepagetext' );
+			if ($this->oldTitle->getNamespace() == NS_USER && !$this->oldTitle->isSubpage() ) {
+				$wgOut->wrapWikiMsg( "<div class=\"error mw-moveuserpage-warning\">\n$1\n</div>", 'moveuserpage-warning' );
+			}
+			$wgOut->addWikiMsg( $wgFixDoubleRedirects ? 'movepagetext' :
+				'movepagetext-noredirectfixer' );
 			$movepagebtn = wfMsg( 'movepagebtn' );
 			$submitVar = 'wpMove';
 			$confirm = false;
 		}
 
+		if ( !empty($err) && $err[0] == 'file-exists-sharedrepo' && $wgUser->isAllowed( 'reupload-shared' ) ) {
+			$wgOut->addWikiMsg( 'move-over-sharedrepo', $newTitle->getPrefixedText() );
+			$submitVar = 'wpMoveOverSharedFile';
+			$err = '';
+		}
+
 		$oldTalk = $this->oldTitle->getTalkPage();
 		$considerTalk = ( !$this->oldTitle->isTalkPage() && $oldTalk->exists() );
 
 		$dbr = wfGetDB( DB_SLAVE );
 		if ( $wgFixDoubleRedirects ) {
-			$hasRedirects = $dbr->selectField( 'redirect', '1', 
-				array( 
+			$hasRedirects = $dbr->selectField( 'redirect', '1',
+				array(
 					'rd_namespace' => $this->oldTitle->getNamespace(),
 					'rd_title' => $this->oldTitle->getDBkey(),
 				) , __METHOD__ );
@@ -152,7 +176,6 @@ class MovePageForm {
 			$wgOut->addWikiMsg( 'movepagetalktext' );
 		}
 
-		$titleObj = SpecialPage::getTitleFor( 'Movepage' );
 		$token = htmlspecialchars( $wgUser->editToken() );
 
 		if ( !empty($err) ) {
@@ -162,12 +185,28 @@ class MovePageForm {
 				$errMsg = "<p><strong class=\"error\">$hookErr</strong></p>\n";
 				$wgOut->addHTML( $errMsg );
 			} else {
-				$wgOut->wrapWikiMsg( '<p><strong class="error">$1</strong></p>', $err );
+				$wgOut->wrapWikiMsg( "<p><strong class=\"error\">\n$1\n</strong></p>", $err );
 			}
 		}
 
+		if ( $this->oldTitle->isProtected( 'move' ) ) {
+			# Is the title semi-protected?
+			if ( $this->oldTitle->isSemiProtected( 'move' ) ) {
+				$noticeMsg = 'semiprotectedpagemovewarning';
+				$classes[] = 'mw-textarea-sprotected';
+			} else {
+				# Then it must be protected based on static groups (regular)
+				$noticeMsg = 'protectedpagemovewarning';
+				$classes[] = 'mw-textarea-protected';
+			}
+			$wgOut->addHTML( "<div class='mw-warning-with-logexcerpt'>\n" );
+			$wgOut->addWikiMsg( $noticeMsg );
+			LogEventsList::showLogExtract( $wgOut, 'protect', $this->oldTitle->getPrefixedText(), '', array( 'lim' => 1 ) );
+			$wgOut->addHTML( "</div>\n" );
+		}
+
 		$wgOut->addHTML(
-			 Xml::openElement( 'form', array( 'method' => 'post', 'action' => $titleObj->getLocalURL( 'action=submit' ), 'id' => 'movepage' ) ) .
+			 Xml::openElement( 'form', array( 'method' => 'post', 'action' => $this->getTitle()->getLocalURL( 'action=submit' ), 'id' => 'movepage' ) ) .
 			 Xml::openElement( 'fieldset' ) .
 			 Xml::element( 'legend', null, wfMsg( 'move-page-legend' ) ) .
 			 Xml::openElement( 'table', array( 'border' => '0', 'id' => 'mw-movepage-table' ) ) .
@@ -184,8 +223,8 @@ class MovePageForm {
 					Xml::label( wfMsg( 'newtitle' ), 'wpNewTitle' ) .
 				"</td>
 				<td class='mw-input'>" .
-					Xml::input( 'wpNewTitle', 40, $newTitle->getPrefixedText(), array( 'type' => 'text', 'id' => 'wpNewTitle' ) ) .
-					Xml::hidden( 'wpOldTitle', $this->oldTitle->getPrefixedText() ) .
+					Xml::input( 'wpNewTitle', 40, $wgContLang->recodeForEdit( $newTitle->getPrefixedText() ), array( 'type' => 'text', 'id' => 'wpNewTitle' ) ) .
+					Html::hidden( 'wpOldTitle', $this->oldTitle->getPrefixedText() ) .
 				"</td>
 			</tr>
 			<tr>
@@ -193,7 +232,8 @@ class MovePageForm {
 					Xml::label( wfMsg( 'movereason' ), 'wpReason' ) .
 				"</td>
 				<td class='mw-input'>" .
-					Xml::tags( 'textarea', array( 'name' => 'wpReason', 'id' => 'wpReason', 'cols' => 60, 'rows' => 2 ), htmlspecialchars( $this->reason ) ) .
+					Html::element( 'textarea', array( 'name' => 'wpReason', 'id' => 'wpReason', 'cols' => 60, 'rows' => 2,
+					'maxlength' => 200 ), $this->reason ) .
 				"</td>
 			</tr>"
 		);
@@ -214,7 +254,7 @@ class MovePageForm {
 				<tr>
 					<td></td>
 					<td class='mw-input' >" .
-						Xml::checkLabel( wfMsg( 'move-leave-redirect' ), 'wpLeaveRedirect', 
+						Xml::checkLabel( wfMsg( 'move-leave-redirect' ), 'wpLeaveRedirect',
 							'wpLeaveRedirect', $this->leaveRedirect ) .
 					"</td>
 				</tr>"
@@ -226,7 +266,7 @@ class MovePageForm {
 				<tr>
 					<td></td>
 					<td class='mw-input' >" .
-						Xml::checkLabel( wfMsg( 'fix-double-redirects' ), 'wpFixRedirects', 
+						Xml::checkLabel( wfMsg( 'fix-double-redirects' ), 'wpFixRedirects',
 							'wpFixRedirects', $this->fixRedirects ) .
 					"</td>
 				</tr>"
@@ -242,43 +282,52 @@ class MovePageForm {
 				<tr>
 					<td></td>
 					<td class=\"mw-input\">" .
-				Xml::checkLabel( wfMsgExt(
+				Xml::check(
+					'wpMovesubpages',
+					# Don't check the box if we only have talk subpages to
+					# move and we aren't moving the talk page.
+					$this->moveSubpages && ($this->oldTitle->hasSubpages() || $this->moveTalk),
+					array( 'id' => 'wpMovesubpages' )
+				) . '&#160;' .
+				Xml::tags( 'label', array( 'for' => 'wpMovesubpages' ),
+					wfMsgExt(
 						( $this->oldTitle->hasSubpages()
 							? 'move-subpages'
 							: 'move-talk-subpages' ),
-						array( 'parsemag' ),
+						array( 'parseinline' ),
 						$wgLang->formatNum( $wgMaximumMovedPages ),
 						# $2 to allow use of PLURAL in message.
 						$wgMaximumMovedPages
-					),
-					'wpMovesubpages', 'wpMovesubpages',
-					# Don't check the box if we only have talk subpages to
-					# move and we aren't moving the talk page.
-					$this->moveSubpages && ($this->oldTitle->hasSubpages() || $this->moveTalk)
+					)
 				) .
 					"</td>
 				</tr>"
 			);
 		}
 
-		$watchChecked = $this->watch || $wgUser->getBoolOption( 'watchmoves' ) 
-			|| $this->oldTitle->userIsWatching();
-		$wgOut->addHTML( "
+		$watchChecked = $wgUser->isLoggedIn() && ($this->watch || $wgUser->getBoolOption( 'watchmoves' )
+			|| $this->oldTitle->userIsWatching());
+		# Don't allow watching if user is not logged in
+		if( $wgUser->isLoggedIn() ) {
+			$wgOut->addHTML( "
 			<tr>
 				<td></td>
 				<td class='mw-input'>" .
 					Xml::checkLabel( wfMsg( 'move-watch' ), 'wpWatch', 'watch', $watchChecked ) .
 				"</td>
-			</tr>
+			</tr>");
+		}
+
+		$wgOut->addHTML( "
 				{$confirm}
 			<tr>
-				<td>&nbsp;</td>
+				<td>&#160;</td>
 				<td class='mw-submit'>" .
 					Xml::submitButton( $movepagebtn, array( 'name' => $submitVar ) ) .
 				"</td>
 			</tr>" .
 			Xml::closeElement( 'table' ) .
-			Xml::hidden( 'wpEditToken', $token ) .
+			Html::hidden( 'wpEditToken', $token ) .
 			Xml::closeElement( 'fieldset' ) .
 			Xml::closeElement( 'form' ) .
 			"\n"
@@ -290,7 +339,7 @@ class MovePageForm {
 	}
 
 	function doSubmit() {
-		global $wgOut, $wgUser, $wgRequest, $wgMaximumMovedPages, $wgLang;
+		global $wgOut, $wgUser, $wgMaximumMovedPages, $wgLang;
 		global $wgFixDoubleRedirects;
 
 		if ( $wgUser->pingLimiter( 'move' ) ) {
@@ -308,7 +357,7 @@ class MovePageForm {
 			# Disallow deletions of big articles
 			$bigHistory = $article->isBigDeletion();
 			if( $bigHistory && !$nt->userCan( 'bigdelete' ) ) {
-				global $wgLang, $wgDeleteRevisionsLimit;
+				global $wgDeleteRevisionsLimit;
 				$this->showForm( array('delete-toobig', $wgLang->formatNum( $wgDeleteRevisionsLimit ) ) );
 				return;
 			}
@@ -329,12 +378,24 @@ class MovePageForm {
 			return;
 		}
 
+		# Show a warning if the target file exists on a shared repo
+		if ( $nt->getNamespace() == NS_FILE
+			&& !( $this->moveOverShared && $wgUser->isAllowed( 'reupload-shared' ) )
+			&& !RepoGroup::singleton()->getLocalRepo()->findFile( $nt )
+			&& wfFindFile( $nt ) )
+		{
+			$this->showForm( array('file-exists-sharedrepo') );
+			return;
+
+		}
+
 		if ( $wgUser->isAllowed( 'suppressredirect' ) ) {
 			$createRedirect = $this->leaveRedirect;
 		} else {
 			$createRedirect = true;
 		}
 
+		# Do the actual move.
 		$error = $ot->moveTo( $nt, true, $this->reason, $createRedirect );
 		if ( $error !== true ) {
 			# FIXME: show all the errors in a list, not just the first one
@@ -383,7 +444,7 @@ class MovePageForm {
 		# would mean that you couldn't move them back in one operation, which
 		# is bad.  FIXME: A specific error message should be given in this
 		# case.
-		
+
 		// FIXME: Use Title::moveSubpages() here
 		$dbr = wfGetDB( DB_MASTER );
 		if( $this->moveSubpages && (
@@ -393,7 +454,7 @@ class MovePageForm {
 			)
 		) ) {
 			$conds = array(
-				'page_title LIKE '.$dbr->addQuotes( $dbr->escapeLike( $ot->getDBkey() ) . '/%' )
+				'page_title' . $dbr->buildLike( $ot->getDBkey() . '/', $dbr->anyString() )
 					.' OR page_title = ' . $dbr->addQuotes( $ot->getDBkey() )
 			);
 			$conds['page_namespace'] = array();
@@ -406,7 +467,7 @@ class MovePageForm {
 		} elseif( $this->moveTalk ) {
 			$conds = array(
 				'page_namespace' => $ot->getTalkPage()->getNamespace(),
-				'page_title' => $ot->getDBKey()
+				'page_title' => $ot->getDBkey()
 			);
 		} else {
 			# Skip the query
@@ -428,15 +489,15 @@ class MovePageForm {
 		$skin = $wgUser->getSkin();
 		$count = 1;
 		foreach( $extraPages as $oldSubpage ) {
-			if( $oldSubpage->getArticleId() == $ot->getArticleId() ) {
+			if( $ot->equals( $oldSubpage ) ) {
 				# Already did this one.
 				continue;
 			}
 
 			$newPageName = preg_replace(
-				'#^'.preg_quote( $ot->getDBKey(), '#' ).'#',
-				$nt->getDBKey(),
-				$oldSubpage->getDBKey()
+				'#^'.preg_quote( $ot->getDBkey(), '#' ).'#',
+				StringUtils::escapeRegexReplacement( $nt->getDBkey() ), # bug 21234
+				$oldSubpage->getDBkey()
 			);
 			if( $oldSubpage->isTalkPage() ) {
 				$newNs = $nt->getTalkPage()->getNamespace();
@@ -447,7 +508,7 @@ class MovePageForm {
 			# be longer than 255 characters.
 			$newSubpage = Title::makeTitleSafe( $newNs, $newPageName );
 			if( !$newSubpage ) {
-				$oldLink = $skin->makeKnownLinkObj( $oldSubpage );
+				$oldLink = $skin->linkKnown( $oldSubpage );
 				$extraOutput []= wfMsgHtml( 'movepage-page-unmoved', $oldLink,
 					htmlspecialchars(Title::makeName( $newNs, $newPageName )));
 				continue;
@@ -455,7 +516,7 @@ class MovePageForm {
 
 			# This was copy-pasted from Renameuser, bleh.
 			if ( $newSubpage->exists() && !$oldSubpage->isValidMoveTarget( $newSubpage ) ) {
-				$link = $skin->makeKnownLinkObj( $newSubpage );
+				$link = $skin->linkKnown( $newSubpage );
 				$extraOutput []= wfMsgHtml( 'movepage-page-exists', $link );
 			} else {
 				$success = $oldSubpage->moveTo( $newSubpage, true, $this->reason, $createRedirect );
@@ -463,21 +524,26 @@ class MovePageForm {
 					if ( $this->fixRedirects ) {
 						DoubleRedirectJob::fixRedirects( 'move', $oldSubpage, $newSubpage );
 					}
-					$oldLink = $skin->makeKnownLinkObj( $oldSubpage, '', 'redirect=no' );
-					$newLink = $skin->makeKnownLinkObj( $newSubpage );
+					$oldLink = $skin->linkKnown(
+						$oldSubpage,
+						null,
+						array(),
+						array( 'redirect' => 'no' )
+					);
+					$newLink = $skin->linkKnown( $newSubpage );
 					$extraOutput []= wfMsgHtml( 'movepage-page-moved', $oldLink, $newLink );
+					++$count;
+					if( $count >= $wgMaximumMovedPages ) {
+						$extraOutput []= wfMsgExt( 'movepage-max-pages', array( 'parsemag', 'escape' ), $wgLang->formatNum( $wgMaximumMovedPages ) );
+						break;
+					}
 				} else {
-					$oldLink = $skin->makeKnownLinkObj( $oldSubpage );
-					$newLink = $skin->makeLinkObj( $newSubpage );
+					$oldLink = $skin->linkKnown( $oldSubpage );
+					$newLink = $skin->link( $newSubpage );
 					$extraOutput []= wfMsgHtml( 'movepage-page-unmoved', $oldLink, $newLink );
 				}
 			}
 
-			++$count;
-			if( $count >= $wgMaximumMovedPages ) {
-				$extraOutput []= wfMsgExt( 'movepage-max-pages', array( 'parsemag', 'escape' ), $wgLang->formatNum( $wgMaximumMovedPages ) );
-				break;
-			}
 		}
 
 		if( $extraOutput !== array() ) {
@@ -485,17 +551,24 @@ class MovePageForm {
 		}
 
 		# Deal with watches (we don't watch subpages)
-		if( $this->watch ) {
+		if( $this->watch && $wgUser->isLoggedIn() ) {
 			$wgUser->addWatch( $ot );
 			$wgUser->addWatch( $nt );
 		} else {
 			$wgUser->removeWatch( $ot );
 			$wgUser->removeWatch( $nt );
 		}
+
+		# Re-clear the file redirect cache, which may have been polluted by
+		# parsing in messages above. See CR r56745.
+		# FIXME: needs a more robust solution inside FileRepo.
+		if( $ot->getNamespace() == NS_FILE ) {
+			RepoGroup::singleton()->getLocalRepo()->invalidateImageRedirect( $ot );
+		}
 	}
 
 	function showLogFragment( $title, &$out ) {
-		$out->addHTML( Xml::element( 'h2', NULL, LogPage::logName( 'move' ) ) );
+		$out->addHTML( Xml::element( 'h2', null, LogPage::logName( 'move' ) ) );
 		LogEventsList::showLogExtract( $out, 'move', $title->getPrefixedText() );
 	}
 
