@@ -1,5 +1,24 @@
 <?php
 /**
+ * Implements Special:Wantedcategories
+ *
+ * Copyright © 2005 Ævar Arnfjörð Bjarmason
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * http://www.gnu.org/copyleft/gpl.html
+ *
  * @file
  * @ingroup SpecialPage
  */
@@ -8,25 +27,13 @@
  * A querypage to list the most wanted categories - implements Special:Wantedcategories
  *
  * @ingroup SpecialPage
- *
- * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
- * @copyright Copyright © 2005, Ævar Arnfjörð Bjarmason
- * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License 2.0 or later
  */
-class WantedCategoriesPage extends QueryPage {
+class WantedCategoriesPage extends WantedQueryPage {
 
 	function getName() {
 		return 'Wantedcategories';
 	}
 
-	function isExpensive() {
-		return true;
-	}
-
-	function isSyndicated() {
-		return false;
-	}
-
 	function getSQL() {
 		$dbr = wfGetDB( DB_SLAVE );
 		list( $categorylinks, $page ) = $dbr->tableNamesN( 'categorylinks', 'page' );
@@ -45,32 +52,21 @@ class WantedCategoriesPage extends QueryPage {
 			";
 	}
 
-	function sortDescending() { return true; }
-
-	/**
-	 * Fetch user page links and cache their existence
-	 */
-	function preprocessResults( $db, $res ) {
-		$batch = new LinkBatch;
-		while ( $row = $db->fetchObject( $res ) )
-			$batch->add( $row->namespace, $row->title );
-		$batch->execute();
-
-		// Back to start for display
-		if ( $db->numRows( $res ) > 0 )
-			// If there are no rows we get an error seeking.
-			$db->dataSeek( $res, 0 );
-	}
-
 	function formatResult( $skin, $result ) {
 		global $wgLang, $wgContLang;
 
 		$nt = Title::makeTitle( $result->namespace, $result->title );
-		$text = $wgContLang->convert( $nt->getText() );
+		$text = htmlspecialchars( $wgContLang->convert( $nt->getText() ) );
 
 		$plink = $this->isCached() ?
-			$skin->makeLinkObj( $nt, htmlspecialchars( $text ) ) :
-			$skin->makeBrokenLinkObj( $nt, htmlspecialchars( $text ) );
+			$skin->link( $nt, $text ) :
+			$skin->link(
+				$nt,
+				$text,
+				array(),
+				array(),
+				array( 'broken' )
+			);
 
 		$nlinks = wfMsgExt( 'nmembers', array( 'parsemag', 'escape'),
 			$wgLang->formatNum( $result->value ) );
