@@ -1,9 +1,15 @@
 <?php
 /**
- * @defgroup Templates Templates
+ * Html forms for user login and account creation
+ *
  * @file
  * @ingroup Templates
  */
+
+/**
+ * @defgroup Templates Templates
+ */
+
 if( !defined( 'MEDIAWIKI' ) ) die( -1 );
 
 /**
@@ -16,7 +22,7 @@ class UserloginTemplate extends QuickTemplate {
 ?>
 	<div class="<?php $this->text('messagetype') ?>box">
 		<?php if ( $this->data['messagetype'] == 'error' ) { ?>
-			<h2><?php $this->msg('loginerror') ?></h2>
+			<strong><?php $this->msg( 'loginerror' )?></strong><br />
 		<?php } ?>
 		<?php $this->html('message') ?>
 	</div>
@@ -35,20 +41,33 @@ class UserloginTemplate extends QuickTemplate {
 		<tr>
 			<td class="mw-label"><label for='wpName1'><?php $this->msg('yourname') ?></label></td>
 			<td class="mw-input">
-				<input type='text' class='loginText' name="wpName" id="wpName1"
-					tabindex="1"
-					value="<?php $this->text('name') ?>" size='20' />
+				<?php
+			echo Html::input( 'wpName', $this->data['name'], 'text', array(
+				'class' => 'loginText',
+				'id' => 'wpName1',
+				'tabindex' => '1',
+				'size' => '20',
+				'required'
+				# Can't do + array( 'autofocus' ) because + for arrays in PHP
+				# only works right for associative arrays!  Thanks, PHP.
+			) + ( $this->data['name'] ? array() : array( 'autofocus' => '' ) ) ); ?>
+
 			</td>
 		</tr>
 		<tr>
 			<td class="mw-label"><label for='wpPassword1'><?php $this->msg('yourpassword') ?></label></td>
 			<td class="mw-input">
-				<input type='password' class='loginPassword' name="wpPassword" id="wpPassword1"
-					tabindex="2"
-					value="" size='20' />
+				<?php
+			echo Html::input( 'wpPassword', null, 'password', array(
+				'class' => 'loginPassword',
+				'id' => 'wpPassword1',
+				'tabindex' => '2',
+				'size' => '20'
+			) + ( $this->data['name'] ? array( 'autofocus' ) : array() ) ); ?>
+
 			</td>
 		</tr>
-	<?php if( $this->data['usedomain'] ) {
+	<?php if( isset( $this->data['usedomain'] ) && $this->data['usedomain'] ) {
 		$doms = "";
 		foreach( $this->data['domainnames'] as $dom ) {
 			$doms .= "<option>" . htmlspecialchars( $dom ) . "</option>";
@@ -64,25 +83,60 @@ class UserloginTemplate extends QuickTemplate {
 			</td>
 		</tr>
 	<?php }
+
+	if( $this->haveData( 'extrafields' ) ) {
+		echo $this->data['extrafields'];
+	}
+
 	if( $this->data['canremember'] ) { ?>
 		<tr>
 			<td></td>
 			<td class="mw-input">
-				<input type='checkbox' name="wpRemember"
-					tabindex="4"
-					value="1" id="wpRemember"
-					<?php if( $this->data['remember'] ) { ?>checked="checked"<?php } ?>
-					/> <label for="wpRemember"><?php $this->msg('remembermypassword') ?></label>
+				<?php
+				global $wgCookieExpiration, $wgLang;
+				echo Xml::checkLabel(
+					wfMsgExt( 'remembermypassword', 'parsemag', $wgLang->formatNum( ceil( $wgCookieExpiration / ( 3600 * 24 ) ) ) ),
+					'wpRemember',
+					'wpRemember',
+					$this->data['remember'],
+					array( 'tabindex' => '8' )
+				)
+				?>
 			</td>
 		</tr>
-		<?php } ?>
+<?php } ?>
+<?php if( $this->data['cansecurelogin'] ) { ?>
+		<tr>
+			<td></td>
+			<td class="mw-input">
+			<?php
+			echo Xml::checkLabel(
+				wfMsg( 'securelogin-stick-https' ),
+				'wpStickHTTPS',
+				'wpStickHTTPS',
+				$this->data['stickHTTPS'],
+				array( 'tabindex' => '9' )
+			);
+		?>
+			</td>
+		</tr>
+<?php } ?>
 		<tr>
 			<td></td>
 			<td class="mw-submit">
-				<input type='submit' name="wpLoginattempt" id="wpLoginattempt" tabindex="5" value="<?php $this->msg('login') ?>" />&nbsp;<?php if( $this->data['useemail'] && $this->data['canreset']) { ?><input type='submit' name="wpMailmypassword" id="wpMailmypassword"
-					tabindex="6"
-									value="<?php $this->msg('mailmypassword') ?>" />
-				<?php } ?>
+				<?php
+		echo Html::input( 'wpLoginAttempt', wfMsg( 'login' ), 'submit', array(
+			'id' => 'wpLoginAttempt',
+			'tabindex' => '9'
+		) );
+		if ( $this->data['useemail'] && $this->data['canreset'] ) {
+			echo '&#160;';
+			echo Html::input( 'wpMailmypassword', wfMsg( 'mailmypassword' ), 'submit', array(
+				'id' => 'wpMailmypassword',
+				'tabindex' => '10'
+			) );
+		} ?>
+
 			</td>
 		</tr>
 	</table>
@@ -100,12 +154,13 @@ class UserloginTemplate extends QuickTemplate {
  * @ingroup Templates
  */
 class UsercreateTemplate extends QuickTemplate {
-	function addInputItem( $name, $value, $type, $msg ) {
+	function addInputItem( $name, $value, $type, $msg, $helptext = false ) {
 		$this->data['extraInput'][] = array(
 			'name' => $name,
 			'value' => $value,
 			'type' => $type,
 			'msg' => $msg,
+			'helptext' => $helptext,
 		);
 	}
 	
@@ -114,12 +169,14 @@ class UsercreateTemplate extends QuickTemplate {
 ?>
 	<div class="<?php $this->text('messagetype') ?>box">
 		<?php if ( $this->data['messagetype'] == 'error' ) { ?>
-			<h2><?php $this->msg('loginerror') ?></h2>
+			<strong><?php $this->msg( 'loginerror' )?></strong><br />
 		<?php } ?>
 		<?php $this->html('message') ?>
 	</div>
 	<div class="visualClear"></div>
 <?php } ?>
+
+<div id="signupstart"><?php $this->msgWiki( 'signupstart' ); ?></div>
 <div id="userlogin">
 
 <form name="userlogin2" id="userlogin2" method="post" action="<?php $this->text('action') ?>">
@@ -131,17 +188,27 @@ class UsercreateTemplate extends QuickTemplate {
 		<tr>
 			<td class="mw-label"><label for='wpName2'><?php $this->msg('yourname') ?></label></td>
 			<td class="mw-input">
-				<input type='text' class='loginText' name="wpName" id="wpName2"
-					tabindex="1"
-					value="<?php $this->text('name') ?>" size='20' />
+				<?php
+			echo Html::input( 'wpName', $this->data['name'], 'text', array(
+				'class' => 'loginText',
+				'id' => 'wpName2',
+				'tabindex' => '1',
+				'size' => '20',
+				'required',
+				'autofocus'
+			) ); ?>
 			</td>
 		</tr>
 		<tr>
 			<td class="mw-label"><label for='wpPassword2'><?php $this->msg('yourpassword') ?></label></td>
 			<td class="mw-input">
-				<input type='password' class='loginPassword' name="wpPassword" id="wpPassword2"
-					tabindex="2"
-					value="" size='20' />
+<?php
+			echo Html::input( 'wpPassword', null, 'password', array(
+				'class' => 'loginPassword',
+				'id' => 'wpPassword2',
+				'tabindex' => '2',
+				'size' => '20'
+			) + User::passwordChangeInputAttribs() ); ?>
 			</td>
 		</tr>
 	<?php if( $this->data['usedomain'] ) {
@@ -163,19 +230,26 @@ class UsercreateTemplate extends QuickTemplate {
 		<tr>
 			<td class="mw-label"><label for='wpRetype'><?php $this->msg('yourpasswordagain') ?></label></td>
 			<td class="mw-input">
-				<input type='password' class='loginPassword' name="wpRetype" id="wpRetype"
-					tabindex="4"
-					value=""
-					size='20' />
+				<?php
+		echo Html::input( 'wpRetype', null, 'password', array(
+			'class' => 'loginPassword',
+			'id' => 'wpRetype',
+			'tabindex' => '4',
+			'size' => '20'
+		) + User::passwordChangeInputAttribs() ); ?>
 			</td>
 		</tr>
 		<tr>
 			<?php if( $this->data['useemail'] ) { ?>
 				<td class="mw-label"><label for='wpEmail'><?php $this->msg('youremail') ?></label></td>
 				<td class="mw-input">
-					<input type='text' class='loginText' name="wpEmail" id="wpEmail"
-						tabindex="5"
-						value="<?php $this->text('email') ?>" size='20' />
+					<?php
+		echo Html::input( 'wpEmail', $this->data['email'], 'email', array(
+			'class' => 'loginText',
+			'id' => 'wpEmail',
+			'tabindex' => '5',
+			'size' => '20'
+		) ); ?>
 					<div class="prefsectiontip">
 						<?php if( $this->data['emailrequired'] ) {
 									$this->msgWiki('prefs-help-email-required');
@@ -198,21 +272,36 @@ class UsercreateTemplate extends QuickTemplate {
 						</div>
 					</td>
 			<?php } ?>
+			<?php if( $this->data['usereason'] ) { ?>
+				</tr>
+				<tr>
+					<td class="mw-label"><label for='wpReason'><?php $this->msg('createaccountreason') ?></label></td>
+					<td class="mw-input">
+						<input type='text' class='loginText' name="wpReason" id="wpReason"
+							tabindex="7"
+							value="<?php $this->text('reason') ?>" size='20' />
+					</td>
+			<?php } ?>
 		</tr>
 		<?php if( $this->data['canremember'] ) { ?>
 		<tr>
 			<td></td>
 			<td class="mw-input">
-				<input type='checkbox' name="wpRemember"
-					tabindex="7"
-					value="1" id="wpRemember"
-					<?php if( $this->data['remember'] ) { ?>checked="checked"<?php } ?>
-					/> <label for="wpRemember"><?php $this->msg('remembermypassword') ?></label>
+				<?php
+				global $wgCookieExpiration, $wgLang;
+				echo Xml::checkLabel(
+					wfMsgExt( 'remembermypassword', 'parsemag', $wgLang->formatNum( ceil( $wgCookieExpiration / ( 3600 * 24 ) ) ) ),
+					'wpRemember',
+					'wpRemember',
+					$this->data['remember'],
+					array( 'tabindex' => '8' )
+				)
+				?>
 			</td>
 		</tr>
 <?php   }
 
-		$tabIndex = 8;
+		$tabIndex = 9;
 		if ( isset( $this->data['extraInput'] ) && is_array( $this->data['extraInput'] ) ) {
 			foreach ( $this->data['extraInput'] as $inputItem ) { ?>
 		<tr>
@@ -245,7 +334,12 @@ class UsercreateTemplate extends QuickTemplate {
 				<label for="<?php echo htmlspecialchars( $inputItem['name'] ); ?>"><?php
 					$this->msgHtml( $inputItem['msg'] ) ?></label><?php
 					}
+				if( $inputItem['helptext'] !== false ) {
 				?>
+				<div class="prefsectiontip">
+					<?php $this->msgWiki( $inputItem['helptext'] ); ?>
+				</div>
+				<?php } ?>
 			</td>
 		</tr>
 <?php				
@@ -268,6 +362,7 @@ class UsercreateTemplate extends QuickTemplate {
 		</tr>
 	</table>
 <?php if( @$this->haveData( 'uselang' ) ) { ?><input type="hidden" name="uselang" value="<?php $this->text( 'uselang' ); ?>" /><?php } ?>
+<?php if( @$this->haveData( 'token' ) ) { ?><input type="hidden" name="wpCreateaccountToken" value="<?php $this->text( 'token' ); ?>" /><?php } ?>
 </form>
 </div>
 <div id="signupend"><?php $this->msgWiki( 'signupend' ); ?></div>
