@@ -19,6 +19,7 @@
 	'ar' => 'العربية',	# Arabic
 	'arc' => 'ܐܪܡܝܐ',	# Aramaic
 	'arn' => 'Mapudungun',	# Mapuche, Mapudungu, Araucanian (Araucano)
+	'ary' => 'Maġribi',	# Moroccan Spoken Arabic
 	'arz' => 'مصرى',	# Egyptian Spoken Arabic
 	'as' => 'অসমীয়া',	# Assamese
 	'ast' => 'Asturianu',	# Asturian
@@ -26,17 +27,18 @@
 	'avk' => 'Kotava', # Kotava
 	'ay' => 'Aymar aru',	# Aymara
 	'az' => 'Azərbaycanca',	# Azerbaijani
-	'ba' => 'Башҡорт',	# Bashkir
+	'ba' => 'Башҡортса',	# Bashkir
 	'bar' => 'Boarisch',	# Bavarian (Austro-Bavarian and South Tyrolean)
-	'bat-smg' => 'Žemaitėška', # Samogitian
+	'bat-smg' => 'Žemaitėška', # Samogitian (deprecated code, 'sgs' in ISO 693-3 since 2010-06-30 )
 	'bcc' => 'بلوچی مکرانی', # Southern Balochi
 	'bcl' => 'Bikol Central', # Bikol: Central Bicolano language
 	'be' => 'Беларуская',	#  Belarusian normative
-	'be-tarask' => 'Беларуская (тарашкевіца)',	# Belarusian in Taraskievica orthography
-	'be-x-old' => 'Беларуская (тарашкевіца)',	# Belarusian in Taraskievica orthography; compat link
+	'be-tarask' => "\xE2\x80\xAAБеларуская (тарашкевіца)\xE2\x80\xAC",	# Belarusian in Taraskievica orthography
+	'be-x-old' => "\xE2\x80\xAAБеларуская (тарашкевіца)\xE2\x80\xAC",	# Belarusian in Taraskievica orthography; compat link
 	'bg' => 'Български',	# Bulgarian
 	'bh' => 'भोजपुरी',	# Bhojpuri
 	'bi' => 'Bislama',		# Bislama
+	'bjn' => 'Bahasa Banjar',	# Banjarese
 	'bm' => 'Bamanankan',	# Bambara
 	'bn' => 'বাংলা',	# Bengali
 	'bo' => 'བོད་ཡིག',	# Tibetan
@@ -55,13 +57,11 @@
 	'cho' => 'Choctaw',		# Choctaw
 	'chr' => 'ᏣᎳᎩ', # Cherokee
 	'chy' => 'Tsetsêhestâhese',	# Cheyenne
-	'ckb' => 'Soranî / کوردی',	# Sorani
-	'ckb-latn' => "\xE2\x80\xAASoranî (latînî)\xE2\x80\xAC", # Central Kurdish Latin script
-	'ckb-arab' => "\xE2\x80\xABکوردی (عەرەبی)\xE2\x80\xAC", # Central Kurdish Arabic script
+	'ckb' => 'کوردی',	# Sorani
 	'co' => 'Corsu',		# Corsican
 	'cps' => 'Capiceño', # Capiznon
 	'cr' => 'Nēhiyawēwin / ᓀᐦᐃᔭᐍᐏᐣ',		# Cree
-	'crh' => 'Qırımtatarca',   # Crimean Tatar
+	'crh' => 'Qırımtatarca',   # Crimean Tatar (multiple scripts - defaults to Latin)
 	'crh-latn' => "\xE2\x80\xAAQırımtatarca (Latin)\xE2\x80\xAC",       # Crimean Tatar (Latin)
 	'crh-cyrl' => "\xE2\x80\xAAКъырымтатарджа (Кирилл)\xE2\x80\xAC",       # Crimean Tatar (Cyrillic)
 	'cs' => 'Česky',	# Czech
@@ -73,9 +73,8 @@
 	'de' => 'Deutsch',		# German ("Du")
 	'de-at' => 'Österreichisches Deutsch',		# Austrian German
 	'de-ch' => 'Schweizer Hochdeutsch',		# Swiss Standard German
-	'de-formal' => 'Deutsch (Sie-Form)',		# German - formal address ("Sie")
+	'de-formal' => "\xE2\x80\xAADeutsch (Sie-Form)\xE2\x80\xAC",		# German - formal address ("Sie")
 	'diq' => 'Zazaki',		# Zazaki
-	'dk' => 'Dansk (deprecated:da)',		# Unused code currently falls back to Danish, 'da' is correct for the language
 	'dsb' => 'Dolnoserbski', # Lower Sorbian
 	'dv' => 'ދިވެހިބަސް',		# Dhivehi
 	'dz' => 'ཇོང་ཁ',		# Bhutani
@@ -98,14 +97,14 @@
 	'fr' => 'Français',	# French
 	'frc' => 'Français cadien', # Cajun French
 	'frp' => 'Arpetan',	# Franco-Provençal/Arpitan
-	'frr' => 'Frasch',	# North Frisian
+	'frr' => 'Nordfriisk',	# North Frisian
 	'fur' => 'Furlan',		# Friulian
 	'fy' => 'Frysk',		# Frisian
 	'ga' => 'Gaeilge',		# Irish
 	'gag' => 'Gagauz',		# Gagauz
-	'gan' => '贛語',		# Gan
-	'gan-hans' => '赣语(简体)',	# Gan (Simplified Han)
-	'gan-hant' => '贛語(繁體)',	# Gan (Traditional Han)
+	'gan' => '贛語',		# Gan (multiple scripts - defaults to Traditional)
+	'gan-hans' => "\xE2\x80\xAA赣语(简体)\xE2\x80\xAC",	# Gan (Simplified Han)
+	'gan-hant' => "\xE2\x80\xAA贛語(繁體)\xE2\x80\xAC",	# Gan (Traditional Han)
 	'gd' => 'Gàidhlig',	# Scots Gaelic
 	'gl' => 'Galego',		# Galician
 	'glk' => 'گیلکی',	# Gilaki
@@ -120,8 +119,7 @@
 	'haw' => 'Hawai`i',		# Hawaiian
 	'he' => 'עברית',	# Hebrew
 	'hi' => 'हिन्दी',	# Hindi
-	'hif' => 'Fiji Hindi',	# Fijian Hindi (falls back to hif-latn)
-	'hif-deva' => 'फ़ीजी हिन्दी',	# Fiji Hindi (devangari)
+	'hif' => 'Fiji Hindi',	# Fijian Hindi (multiple scripts - defaults to Latin)
 	'hif-latn' => 'Fiji Hindi',	# Fiji Hindi (latin)
 	'hil' => 'Ilonggo',	# Hiligaynon
 	'ho' => 'Hiri Motu',	# Hiri Motu
@@ -152,11 +150,13 @@
 	'ka' => 'ქართული',	# Georgian
 	'kaa' => 'Qaraqalpaqsha',	# Karakalpak
 	'kab' => 'Taqbaylit',	# Kabyle
-	'kg' => 'Kongo',		# Kongo, (FIXME!) should probaly be KiKongo or KiKoongo
+	'kbd' => 'Къэбэрдеибзэ / Qabardjajəbza',	# Kabardian (multiple scripts - defaults to Cyrillic)
+	'kbd-cyrl' => 'къэбэрдеибзэ',	# Kabardian (Cyrillic)
+	'kg' => 'Kongo',	# Kongo, (FIXME!) should probaly be KiKongo or KiKoongo
 	'ki' => 'Gĩkũyũ',	# Gikuyu
 	'kiu' => 'Kırmancki',	# Kirmanjki
-	'kj' => 'Kwanyama',		# Kwanyama
-	'kk' => 'Қазақша',	# Kazakh
+	'kj' => 'Kwanyama',	# Kwanyama
+	'kk' => 'Қазақша',	# Kazakh (multiple scripts - defaults to Cyrillic)
 	'kk-arab' => "\xE2\x80\xABقازاقشا (تٴوتە)\xE2\x80\xAC",	# Kazakh Arabic
 	'kk-cyrl' => "\xE2\x80\xAAҚазақша (кирил)\xE2\x80\xAC",	# Kazakh Cyrillic
 	'kk-latn' => "\xE2\x80\xAAQazaqşa (latın)\xE2\x80\xAC",	# Kazakh Latin
@@ -174,12 +174,12 @@
 	'kri' => 'Krio', # Krio
 	'krj' => 'Kinaray-a', # Kinaray-a
 	'ks' => 'कश्मीरी - (كشميري)',	# Kashmiri
-	'ksh' => 'Ripoarisch',	# Ripuarian 
-	'ku'  => 'Kurdî',	# Kurdish
-	'ku-latn' => "\xE2\x80\xAAKurdî (latînî)\xE2\x80\xAC",	# Northern Kurdish Latin script
-	'ku-arab' => "\xE2\x80\xABكوردي (عەرەبی)\xE2\x80\xAC",	# Northern Kurdish Arabic script
-	'kv' => 'Коми',	# Komi-Zyrian, cyrillic is common script but also written in latin script
-	'kw' => 'Kernewek',		# Cornish
+	'ksh' => 'Ripoarisch',	# Ripuarian
+	'ku'  => 'Kurdî',	# Kurdish (multiple scripts - defaults to Latin)
+	'ku-latn' => "\xE2\x80\xAAKurdî (latînî)\xE2\x80\xAC",	# Northern Kurdish (Latin script)
+	'ku-arab' => "\xE2\x80\xABكوردي (عەرەبی)\xE2\x80\xAC",	# Northern Kurdish (Arabic script) (falls back to ckb)
+	'kv' => 'Коми',	# Komi-Zyrian (Cyrillic is common script but also written in Latin script)
+	'kw' => 'Kernowek',		# Cornish
 	'ky' => 'Кыргызча',	# Kirghiz
 	'la' => 'Latina',		# Latin
 	'lad' => 'Ladino',	# Ladino
@@ -200,12 +200,13 @@
 	'lzh' => '文言',	# Literary Chinese -- (bug 8217) lzh instead of zh-classical, http://www.sil.org/iso639-3/codes.asp?order=639_3&letter=l
 	'lzz' => 'Lazuri',	# Laz
 	'mai' => 'मैथिली', # Maithili
-	'map-bms' => 'Basa Banyumasan', # Banyumasan 
+	'map-bms' => 'Basa Banyumasan', # Banyumasan
 	'mdf' => 'Мокшень',		# Moksha
 	'mg' => 'Malagasy',		# Malagasy
 	'mh' => 'Ebon',			# Marshallese
 	'mhr' => 'Олык Марий',	# Eastern Mari
 	'mi' => 'Māori',	# Maori
+	'min' => 'Baso Minangkabau',	# Minangkabau
 	'mk' => 'Македонски',	# Macedonian
 	'ml' => 'മലയാളം',	# Malayalam
 	'mn' => 'Монгол',	# Halh Mongolian (Cyrillic) (ISO 639-3: khk)
@@ -231,6 +232,7 @@
 	'ng' => 'Oshiwambo',		# Ndonga
 	'niu' => 'Niuē',	# Niuean
 	'nl' => 'Nederlands',	# Dutch
+	'nl-informal' => "\xE2\x80\xAANederlands (informeel)\xE2\x80\xAC",	# Dutch (informal address ("je"))
 	'nn' => "\xE2\x80\xAANorsk (nynorsk)\xE2\x80\xAC",	# Norwegian (Nynorsk)
 	'no' => "\xE2\x80\xAANorsk (bokmål)\xE2\x80\xAC",		# Norwegian
 	'nov' => 'Novial',		# Novial
@@ -241,15 +243,15 @@
 	'oc' => 'Occitan',		# Occitan
 	'om' => 'Oromoo',		# Oromo
 	'or' => 'ଓଡ଼ିଆ',		# Oriya
-	'os' => 'Иронау', # Ossetic
-	'pa' => 'ਪੰਜਾਬੀ', # Eastern Punjabi (pan)
+	'os' => 'Ирон', # Ossetic -- fixed per bug 29091
+	'pa' => 'ਪੰਜਾਬੀ', # Eastern Punjabi (Gurmukhi script) (pan)
 	'pag' => 'Pangasinan',	# Pangasinan
 	'pam' => 'Kapampangan',   # Pampanga
 	'pap' => 'Papiamentu',	# Papiamentu
 	'pcd' => 'Picard',	# Picard
 	'pdc' => 'Deitsch',	# Pennsylvania German
 	'pdt' => 'Plautdietsch',	# Plautdietsch/Mennonite Low German
-	'pfl' => 'Pfälzisch',	# Palatinate German
+	'pfl' => 'Pälzisch',	# Palatinate German
 	'pi' => 'पािऴ',	# Pali
 	'pih' => 'Norfuk / Pitkern', # Norfuk/Pitcairn/Norfolk
 	'pl' => 'Polski',		# Polish
@@ -270,10 +272,10 @@
 	'roa-rup' => 'Armãneashce', # Aromanian
 	'roa-tara' => 'Tarandíne',	# Tarantino
 	'ru' => 'Русский',	# Russian
-	'rue' => 'русиньскый язык',	# Rusyn
-	'ruq' => 'Vlăheşte',	# Megleno-Romanian (falls back to ruq-latn)
+	'rue' => 'Русиньскый',	# Rusyn
+	'ruq' => 'Vlăheşte',	# Megleno-Romanian (multiple scripts - defaults to Latin)
 	'ruq-cyrl' => 'Влахесте',	# Megleno-Romanian (Cyrillic script)
-	#'ruq-grek' => 'Βλαεστε',	# Megleno-Romanian (Greek script)
+	# 'ruq-grek' => 'Βλαεστε',	# Megleno-Romanian (Greek script)
 	'ruq-latn' => 'Vlăheşte',	# Megleno-Romanian (Latin script)
 	'rw' => 'Kinyarwanda',	# Kinyarwanda, should possibly be Kinyarwandi
 	'sa' => 'संस्कृत',	# Sanskrit
@@ -286,6 +288,7 @@
 	'se' => 'Sámegiella',	# Northern Sami
 	'sei' => 'Cmique Itom',	# Seri
 	'sg' => 'Sängö',		# Sango/Sangho
+	'sgs' => 'Žemaitėška', # Samogitian
 	'sh' => 'Srpskohrvatski / Српскохрватски', # Serbocroatian
 	'shi' => 'Tašlḥiyt',    # Tachelhit
 	'si' => 'සිංහල',	# Sinhalese
@@ -298,9 +301,9 @@
 	'sn' => 'chiShona',		# Shona
 	'so' => 'Soomaaliga',	# Somali
 	'sq' => 'Shqip',		# Albanian
-	'sr' => 'Српски / Srpski',	# Serbian
-	'sr-ec' => 'Српски (ћирилица)',	# Serbian Cyrillic ekavian
-	'sr-el' => 'Srpski (latinica)',	# Serbian Latin ekavian
+	'sr' => 'Српски / Srpski',	# Serbian (multiple scripts - defaults to Cyrillic)
+	'sr-ec' => "\xE2\x80\xAAСрпски (ћирилица)\xE2\x80\xAC",	# Serbian Cyrillic ekavian
+	'sr-el' => "\xE2\x80\xAASrpski (latinica)\xE2\x80\xAC",	# Serbian Latin ekavian
 	'srn' => 'Sranantongo',		# Sranan Tongo
 	'ss' => 'SiSwati',		# Swati
 	'st' => 'Sesotho',		# Southern Sotho
@@ -328,16 +331,16 @@
 	'tr' => 'Türkçe',	# Turkish
 	'ts' => 'Xitsonga',		# Tsonga
 	'tt' => 'Татарча/Tatarça',	# Tatar (multiple scripts - defaults to Cyrillic)
-	'tt-cyrl' => 'Татарча',	# Tatar (Cyrillic script)
+	'tt-cyrl' => 'Татарча',	# Tatar (Cyrillic script) (default)
 	'tt-latn' => 'Tatarça',	# Tatar (Latin script)
 	'tum' => 'chiTumbuka',  # Tumbuka
 	'tw' => 'Twi',			# Twi, (FIXME!)
 	'ty' => 'Reo Mā`ohi',	# Tahitian
 	'tyv' => 'Тыва дыл',	# Tyvan
 	'udm' => 'Удмурт',	# Udmurt
-	'ug' => 'Uyghurche‎ / ئۇيغۇرچە',	# Uyghur (multiple scripts - defaults to Latin)
-	'ug-arab' => 'ئۇيغۇرچە', # Uyghur (Arabic script)
-	'ug-latn' => 'Uyghurche‎', # Uyghur (Latin script - default)
+	'ug' => 'ئۇيغۇرچە / Uyghurche‎',	# Uyghur (multiple scripts - defaults to Arabic)
+	'ug-arab' => 'ئۇيغۇرچە', # Uyghur (Arabic script) (default)
+	'ug-latn' => 'Uyghurche‎', # Uyghur (Latin script)
 	'uk' => 'Українська',	# Ukrainian
 	'ur' => 'اردو',	# Urdu
 	'uz' => 'O\'zbek',	# Uzbek
@@ -365,8 +368,8 @@
 	'zh' => '中文',						# (Zhōng Wén) - Chinese
 	'zh-classical' => '文言',			# Classical Chinese/Literary Chinese -- (see bug 8217)
 	'zh-cn' => "\xE2\x80\xAA中文(中国大陆)\xE2\x80\xAC",	# Chinese (PRC)
-	'zh-hans' => "\xE2\x80\xAA中文(简体)\xE2\x80\xAC",	# Chinese written using the Simplified Chinese script
-	'zh-hant' => "\xE2\x80\xAA中文(繁體)\xE2\x80\xAC",	# Chinese written using the Traditional Chinese script
+	'zh-hans' => "\xE2\x80\xAA中文(简体)\xE2\x80\xAC",	# Mandarin Chinese (Simplified Chinese script) (cmn-hans)
+	'zh-hant' => "\xE2\x80\xAA中文(繁體)\xE2\x80\xAC",	# Mandarin Chinese (Traditional Chinese script) (cmn-hant)
 	'zh-hk' => "\xE2\x80\xAA中文(香港)\xE2\x80\xAC",	# Chinese (Hong Kong)
 	'zh-min-nan' => 'Bân-lâm-gú',				# Min-nan -- (see bug 8217)
 	'zh-mo' => "\xE2\x80\xAA中文(澳門)\xE2\x80\xAC",	# Chinese (Macau)
