@@ -1,10 +1,8 @@
 <?php
 /** Kazakh (Қазақша)
-  *
-  *
-  * @addtogroup Language
-  */
-
+ *
+ * @ingroup Language
+ */
 
 class LanguageKk_cyrl extends Language {
 
@@ -29,24 +27,24 @@ class LanguageKk_cyrl extends Language {
 		$allVowels = array( "е", "ө", "ү", "і", "ә", "э", "а", "о", "ұ", "ы", "я", "ё", "и" );
 		// Preceding letters
 		$Nasals = array( "м", "н", "ң" );
-		$Sonants = array( "и", "й", "л", "р", "у", "ю");
+		$Sonants = array( "и", "й", "л", "р", "у", "ю" );
 		$Consonants = array( "п", "ф", "к", "қ", "т", "ш", "с", "х", "ц", "ч", "щ", "б", "в", "г", "д" );
 		$Sibilants = array( "ж", "з" );
-		$Sonorants = array( "и", "й", "л", "р", "у", "ю", "м", "н", "ң", "ж", "з");
+		$Sonorants = array( "и", "й", "л", "р", "у", "ю", "м", "н", "ң", "ж", "з" );
 
 		// Possessives
 		$firstPerson = array( "м", "ң" ); // 1st singular, 2nd unformal
 		$secondPerson = array( "з" ); // 1st plural, 2nd formal
 		$thirdPerson = array( "ы", "і" ); // 3rd
 
-		$lastLetter = self::lastLetter( $word, $allVowels );
+		$lastLetter = $this->lastLetter( $word, $allVowels );
 		$wordEnding =& $lastLetter[0];
 		$wordLastVowel =& $lastLetter[1];
 
 		// Now convert the word
 		switch ( $case ) {
 			case "dc1":
-			case "genitive": #ilik
+			case "genitive": # ilik
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "тің";
@@ -59,7 +57,7 @@ class LanguageKk_cyrl extends Language {
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "ның";
 					}
-				} elseif ( in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants )) {
+				} elseif ( in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "дің";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -68,7 +66,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc2":
-			case "dative": #barıs
+			case "dative": # barıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ке";
@@ -84,7 +82,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc21":
-			case "possessive dative": #täweldık + barıs
+			case "possessive dative": # täweldık + barıs
 				if ( in_array( $wordEnding, $firstPerson ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "е";
@@ -106,7 +104,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc3":
-			case "accusative": #tabıs
+			case "accusative": # tabıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ті";
@@ -114,13 +112,13 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "ты";
 					}
 				} elseif ( in_array( $wordEnding, $allVowels ) ) {
-					if ( in_array($wordLastVowel, $frontVowels ) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ні";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "ны";
 					}
-				} elseif ( in_array( $wordEnding, $Sonorants) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+				} elseif ( in_array( $wordEnding, $Sonorants ) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ді";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "ды";
@@ -128,7 +126,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc31":
-			case "possessive accusative": #täweldık + tabıs
+			case "possessive accusative": # täweldık + tabıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ді";
@@ -140,7 +138,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc4":
-			case "locative": #jatıs
+			case "locative": # jatıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "те";
@@ -148,15 +146,15 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "та";
 					}
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Sonorants ) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "де";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "да";
 					}
-				} 
+				}
 				break;
 			case "dc41":
-			case "possessive locative": #täweldık + jatıs
+			case "possessive locative": # täweldık + jatıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "де";
@@ -164,28 +162,28 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "да";
 					}
 				} elseif ( in_array( $wordEnding, $thirdPerson  ) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "нде";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "нда";
 					}
-				} 
+				}
 				break;
 			case "dc5":
-			case "ablative": #şığıs
+			case "ablative": # şığıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "тен";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "тан";
 					}
-				} elseif ( in_array($wordEnding, $allVowels ) || in_array($wordEnding, $Sonants ) || in_array($wordEnding, $Sibilants ) ) {
+				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ден";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "дан";
 					}
-				}  elseif ( in_array($wordEnding, $Nasals ) ) {
+				}  elseif ( in_array( $wordEnding, $Nasals ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "нен";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -194,14 +192,14 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc51":
-			case "possessive ablative": #täweldık + şığıs
+			case "possessive ablative": # täweldık + şığıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $thirdPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "нен";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "нан";
 					}
-				} elseif ( in_array($wordEnding, $secondPerson  ) ) {
+				} elseif ( in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ден";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -210,7 +208,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc6":
-			case "comitative": #kömektes
+			case "comitative": # kömektes
 				if ( in_array( $wordEnding, $Consonants ) ) {
 						$word = $word . "пен";
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Nasals ) || in_array( $wordEnding, $Sonants ) ) {
@@ -220,7 +218,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc61":
-			case "possessive comitative": #täweldık + kömektes
+			case "possessive comitative": # täweldık + kömektes
 				if ( in_array( $wordEnding, $Consonants ) ) {
 						$word = $word . "пенен";
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Nasals ) || in_array( $wordEnding, $Sonants ) ) {
@@ -229,7 +227,7 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "бенен";
 				}
 				break;
-			default: #dc0 #nominative #ataw
+			default: # dc0 #nominative #ataw
 		}
 		return $word;
 	}
@@ -249,24 +247,24 @@ class LanguageKk_cyrl extends Language {
 		$allVowels = array( "e", "ö", "ü", "i", "ä", "é", "a", "o", "u", "ı" );
 		// Preceding letters
 		$Nasals = array( "m", "n", "ñ" );
-		$Sonants = array( "ï", "y", "ý", "l", "r", "w");
+		$Sonants = array( "ï", "y", "ý", "l", "r", "w" );
 		$Consonants = array( "p", "f", "k", "q", "t", "ş", "s", "x", "c", "ç", "b", "v", "g", "d" );
 		$Sibilants = array( "j", "z" );
-		$Sonorants = array( "ï", "y", "ý", "l", "r", "w", "m", "n", "ñ", "j", "z");
+		$Sonorants = array( "ï", "y", "ý", "l", "r", "w", "m", "n", "ñ", "j", "z" );
 
 		// Possessives
 		$firstPerson = array( "m", "ñ" ); // 1st singular, 2nd unformal
 		$secondPerson = array( "z" ); // 1st plural, 2nd formal
 		$thirdPerson = array( "ı", "i" ); // 3rd
 
-		$lastLetter = self::lastLetter( $word, $allVowels );
+		$lastLetter = $this->lastLetter( $word, $allVowels );
 		$wordEnding =& $lastLetter[0];
 		$wordLastVowel =& $lastLetter[1];
 
 		// Now convert the word
 		switch ( $case ) {
 			case "dc1":
-			case "genitive": #ilik
+			case "genitive": # ilik
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "tiñ";
@@ -279,7 +277,7 @@ class LanguageKk_cyrl extends Language {
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "nıñ";
 					}
-				} elseif ( in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants )) {
+				} elseif ( in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "diñ";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -288,7 +286,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc2":
-			case "dative": #barıs
+			case "dative": # barıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ke";
@@ -304,7 +302,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc21":
-			case "possessive dative": #täweldık + barıs
+			case "possessive dative": # täweldık + barıs
 				if ( in_array( $wordEnding, $firstPerson ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "e";
@@ -326,7 +324,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc3":
-			case "accusative": #tabıs
+			case "accusative": # tabıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ti";
@@ -334,13 +332,13 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "tı";
 					}
 				} elseif ( in_array( $wordEnding, $allVowels ) ) {
-					if ( in_array($wordLastVowel, $frontVowels ) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ni";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "nı";
 					}
-				} elseif ( in_array( $wordEnding, $Sonorants) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+				} elseif ( in_array( $wordEnding, $Sonorants ) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "di";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "dı";
@@ -348,7 +346,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc31":
-			case "possessive accusative": #täweldık + tabıs
+			case "possessive accusative": # täweldık + tabıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "di";
@@ -360,7 +358,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc4":
-			case "locative": #jatıs
+			case "locative": # jatıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "te";
@@ -368,15 +366,15 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "ta";
 					}
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Sonorants ) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "de";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "da";
 					}
-				} 
+				}
 				break;
 			case "dc41":
-			case "possessive locative": #täweldık + jatıs
+			case "possessive locative": # täweldık + jatıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "de";
@@ -384,28 +382,28 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "da";
 					}
 				} elseif ( in_array( $wordEnding, $thirdPerson  ) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "nde";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "nda";
 					}
-				} 
+				}
 				break;
 			case "dc5":
-			case "ablative": #şığıs
+			case "ablative": # şığıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ten";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "tan";
 					}
-				} elseif ( in_array($wordEnding, $allVowels ) || in_array($wordEnding, $Sonants ) || in_array($wordEnding, $Sibilants ) ) {
+				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "den";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "dan";
 					}
-				}  elseif ( in_array($wordEnding, $Nasals ) ) {
+				}  elseif ( in_array( $wordEnding, $Nasals ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "nen";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -414,14 +412,14 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc51":
-			case "possessive ablative": #täweldık + şığıs
+			case "possessive ablative": # täweldık + şığıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $thirdPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "nen";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "nan";
 					}
-				} elseif ( in_array($wordEnding, $secondPerson  ) ) {
+				} elseif ( in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "den";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -430,7 +428,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc6":
-			case "comitative": #kömektes
+			case "comitative": # kömektes
 				if ( in_array( $wordEnding, $Consonants ) ) {
 						$word = $word . "pen";
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Nasals ) || in_array( $wordEnding, $Sonants ) ) {
@@ -440,7 +438,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc61":
-			case "possessive comitative": #täweldık + kömektes
+			case "possessive comitative": # täweldık + kömektes
 				if ( in_array( $wordEnding, $Consonants ) ) {
 						$word = $word . "penen";
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Nasals ) || in_array( $wordEnding, $Sonants ) ) {
@@ -449,7 +447,7 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "benen";
 				}
 				break;
-			default: #dc0 #nominative #ataw
+			default: # dc0 #nominative #ataw
 		}
 		return $word;
 	}
@@ -469,24 +467,24 @@ class LanguageKk_cyrl extends Language {
 		$allVowels = array( "ە", "ٶ", "ٷ", "ٸ", "ٵ", "ە", "ا", "و", "ۇ", "ى" );
 		// Preceding letters
 		$Nasals = array( "م", "ن", "ڭ" );
-		$Sonants = array( "ي", "ي", "ل", "ر", "ۋ");
+		$Sonants = array( "ي", "ي", "ل", "ر", "ۋ" );
 		$Consonants = array( "پ", "ف", "ك", "ق", "ت", "ش", "س", "ح", "تس", "چ", "ب", "ۆ", "گ", "د" );
 		$Sibilants = array( "ج", "ز" );
-		$Sonorants = array( "ي", "ي", "ل", "ر", "ۋ", "م", "ن", "ڭ", "ج", "ز");
+		$Sonorants = array( "ي", "ي", "ل", "ر", "ۋ", "م", "ن", "ڭ", "ج", "ز" );
 
 		// Possessives
 		$firstPerson = array( "م", "ڭ" ); // 1st singular, 2nd unformal
 		$secondPerson = array( "ز" ); // 1st plural, 2nd formal
 		$thirdPerson = array( "ى", "ٸ" ); // 3rd
 
-		$lastLetter = self::lastLetter( $word, $allVowels );
-		$wordEnding =& $lastLetter[0];
-		$wordLastVowel =& $lastLetter[1];
+		$lastLetter = $this->lastLetter( $word, $allVowels );
+		$wordEnding = $lastLetter[0];
+		$wordLastVowel = $lastLetter[1];
 
 		// Now convert the word
 		switch ( $case ) {
 			case "dc1":
-			case "genitive": #ilik
+			case "genitive": # ilik
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "تٸڭ";
@@ -499,7 +497,7 @@ class LanguageKk_cyrl extends Language {
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "نىڭ";
 					}
-				} elseif ( in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants )) {
+				} elseif ( in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دٸڭ";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -508,7 +506,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc2":
-			case "dative": #barıs
+			case "dative": # barıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "كە";
@@ -524,7 +522,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc21":
-			case "possessive dative": #täweldık + barıs
+			case "possessive dative": # täweldık + barıs
 				if ( in_array( $wordEnding, $firstPerson ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ە";
@@ -546,7 +544,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc3":
-			case "accusative": #tabıs
+			case "accusative": # tabıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "تٸ";
@@ -554,13 +552,13 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "تى";
 					}
 				} elseif ( in_array( $wordEnding, $allVowels ) ) {
-					if ( in_array($wordLastVowel, $frontVowels ) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "نٸ";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "نى";
 					}
-				} elseif ( in_array( $wordEnding, $Sonorants) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+				} elseif ( in_array( $wordEnding, $Sonorants ) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دٸ";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "دى";
@@ -568,7 +566,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc31":
-			case "possessive accusative": #täweldık + tabıs
+			case "possessive accusative": # täweldık + tabıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دٸ";
@@ -580,7 +578,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc4":
-			case "locative": #jatıs
+			case "locative": # jatıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "تە";
@@ -588,15 +586,15 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "تا";
 					}
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Sonorants ) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دە";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "دا";
 					}
-				} 
+				}
 				break;
 			case "dc41":
-			case "possessive locative": #täweldık + jatıs
+			case "possessive locative": # täweldık + jatıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دە";
@@ -604,28 +602,28 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "دا";
 					}
 				} elseif ( in_array( $wordEnding, $thirdPerson  ) ) {
-					if ( in_array( $wordLastVowel, $frontVowels) ) {
+					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "ندە";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "ندا";
 					}
-				} 
+				}
 				break;
 			case "dc5":
-			case "ablative": #şığıs
+			case "ablative": # şığıs
 				if ( in_array( $wordEnding, $Consonants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "تەن";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "تان";
 					}
-				} elseif ( in_array($wordEnding, $allVowels ) || in_array($wordEnding, $Sonants ) || in_array($wordEnding, $Sibilants ) ) {
+				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Sonants ) || in_array( $wordEnding, $Sibilants ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دەن";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "دان";
 					}
-				}  elseif ( in_array($wordEnding, $Nasals ) ) {
+				}  elseif ( in_array( $wordEnding, $Nasals ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "نەن";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -634,14 +632,14 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc51":
-			case "possessive ablative": #täweldık + şığıs
+			case "possessive ablative": # täweldık + şığıs
 				if ( in_array( $wordEnding, $firstPerson ) || in_array( $wordEnding, $thirdPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "نەن";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
 						$word = $word . "نان";
 					}
-				} elseif ( in_array($wordEnding, $secondPerson  ) ) {
+				} elseif ( in_array( $wordEnding, $secondPerson  ) ) {
 					if ( in_array( $wordLastVowel, $frontVowels ) ) {
 						$word = $word . "دەن";
 					} elseif ( in_array( $wordLastVowel, $backVowels ) ) {
@@ -650,7 +648,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc6":
-			case "comitative": #kömektes
+			case "comitative": # kömektes
 				if ( in_array( $wordEnding, $Consonants ) ) {
 						$word = $word . "پەن";
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Nasals ) || in_array( $wordEnding, $Sonants ) ) {
@@ -660,7 +658,7 @@ class LanguageKk_cyrl extends Language {
 				}
 				break;
 			case "dc61":
-			case "possessive comitative": #täweldık + kömektes
+			case "possessive comitative": # täweldık + kömektes
 				if ( in_array( $wordEnding, $Consonants ) ) {
 						$word = $word . "پەنەن";
 				} elseif ( in_array( $wordEnding, $allVowels ) || in_array( $wordEnding, $Nasals ) || in_array( $wordEnding, $Sonants ) ) {
@@ -669,19 +667,18 @@ class LanguageKk_cyrl extends Language {
 						$word = $word . "بەنەن";
 				}
 				break;
-			default: #dc0 #nominative #ataw
+			default: # dc0 #nominative #ataw
 		}
 		return $word;
 	}
 
 	function lastLetter( $word, $allVowels ) {
 		$lastLetter = array();
-		$ar = array();
 
 		// Put the word in a form we can play with since we're using UTF-8
-		$ar = preg_split('//u', parent::lc($word), -1, PREG_SPLIT_NO_EMPTY);
+		$ar = preg_split( '//u', parent::lc( $word ), -1, PREG_SPLIT_NO_EMPTY );
 
-		// Here's an array with the order of the letters in the word reversed 
+		// Here's an array with the order of the letters in the word reversed
 		// so we can find a match quicker *shrug*
 		$wordReversed = array_reverse( $ar );
 
@@ -714,7 +711,7 @@ class LanguageKk_cyrl extends Language {
 	 */
 	function commafy( $_ ) {
 		if ( !preg_match( '/^\d{1,4}$/', $_ ) ) {
-			return strrev( (string)preg_replace( '/(\d{3})(?=\d)(?!\d*\.)/', '$1,', strrev($_) ) );
+			return strrev( (string)preg_replace( '/(\d{3})(?=\d)(?!\d*\.)/', '$1,', strrev( $_ ) ) );
 		} else {
 			return $_;
 		}
