@@ -1,12 +1,12 @@
 <?php
+
 /** Polish (polski)
  *
- * @addtogroup Language
+ * @ingroup Language
  */
-
 class LanguagePl extends Language {
 	function convertPlural( $count, $forms ) {
-		if ( !count($forms) ) { return ''; }
+		if ( !count( $forms ) ) { return ''; }
 		$forms = $this->preConvertPlural( $forms, 3 );
 		$count = abs( $count );
 		if ( $count == 1 )
@@ -21,4 +21,12 @@ class LanguagePl extends Language {
 				return $forms[2];   // plural genitive
 		}
 	}
-}
\ No newline at end of file
+
+	function commafy( $_ ) {
+		if ( !preg_match( '/^\-?\d{1,4}(\.\d+)?$/', $_ ) ) {
+			return strrev( (string)preg_replace( '/(\d{3})(?=\d)(?!\d*\.)/', '$1,', strrev( $_ ) ) );
+		} else {
+			return $_;
+		}
+	}
+}
