@@ -1,17 +1,16 @@
 <?php
+
 /**
  * Turkish (Türkçe)
  *
- * @addtogroup Language
+ * @ingroup Language
  */
 class LanguageTr extends Language {
 	function ucfirst ( $string ) {
-		if ( $string[0] == 'i' ) {
+		if ( !empty( $string ) && $string[0] == 'i' ) {
 			return 'İ' . substr( $string, 1 );
 		} else {
 			return parent::ucfirst( $string );
 		}
 	}
-
 }
-?>
