@@ -11,6 +11,7 @@
  * @author JJohnson
  * @author Omnipaedista
  * @author Spacebirdy
+ * @author Tsepelcory
  * @author Wōdenhelm
  */
 
@@ -29,47 +30,64 @@ $namespaceNames = array(
 
 $messages = array(
 # User preference toggles
-'tog-underline'              => 'Hlenċa undermearcian:',
-'tog-hideminor'              => 'Lytla ādihtunga hȳdan in nīƿliċum hƿeorfum',
-'tog-hidepatrolled'          => 'Ƿeardede ādihtas hȳdan ƿiþ nīƿe hƿearfas',
-'tog-newpageshidepatrolled'  => 'Ƿeardede sīdan hȳdan ƿiþ nīƿe hƿearfas',
-'tog-extendwatchlist'        => 'Ƿæccȝetale sprædan to scēaƿenne ealle hƿearfas, ne efne þā nīƿoste',
-'tog-numberheadings'         => 'Selffremmende-rīm hēafodingas',
-'tog-showtoolbar'            => 'Þone tōlstæf scēaƿian (þearf JavaScript)',
-'tog-editondblclick'         => 'Sīdan ādihtan bȳ tƿicnæppende (þearf JavaScript)',
-'tog-editsection'            => 'Dǣla ādihtende þafian bȳ [ādihtan] hlenċum',
-'tog-showtoc'                => 'Innunga tæfle sēon (for sīdum þe mā þonne 3 hēafodingas habbaþ)',
-'tog-rememberpassword'       => 'Mīne inmeldunge ȝemyndan on þissum spearcatelle',
-'tog-editwidth'              => 'Þone ādihtbox sprædan to fyllenne þæt fulānsīenēagþȳrl',
-'tog-watchcreations'         => 'Sīdan þe iċ scieppe ēacian tō mīnre ƿæccȝetale',
-'tog-watchdefault'           => 'Sīdan þe iċ ādihte ēacian tō mīnre ƿæccȝetale',
-'tog-watchmoves'             => 'Sīdan þe iċ hƿeorfe ēacian tō mīnre ƿæccȝetale',
-'tog-watchdeletion'          => 'Sīdan þe iċ forlēose ēacian tō mīnre ƿæccȝetale',
-'tog-minordefault'           => 'Ealle ādihtende mearcian tōlas ȝeƿunelīċe',
-'tog-previewontop'           => 'Forescēaƿe sēon fore ādihtbox',
-'tog-previewonfirst'         => 'Forescēaƿe sēon on formestum ādihte',
-'tog-shownumberswatching'    => 'Hū mæniȝ ƿæccende brūcendas sēon',
-'tog-uselivepreview'         => 'Līfe forescēaƿe brūcan (þearf JavaScript) (oferfundenisc)',
-'tog-watchlisthideown'       => 'Mīna ādihtunga hȳdan ƿiþ þā ƿæccȝetale',
-'tog-watchlisthidebots'      => 'Searuþrala ādihtas hȳdan ƿiþ þā ƿæccȝetale',
-'tog-watchlisthideminor'     => 'Minliċa ādihtunga hȳdan ƿiþ þæt ƿæccbrede',
-'tog-watchlisthideliu'       => 'Ādihtas bȳ inmeldedum brūcendum hȳdan ƿiþ þā ƿæccȝetale',
-'tog-watchlisthideanons'     => 'Ādihtas bȳ uncūðum brūcendum hȳdan ƿiþ þā ƿæccȝetale',
-'tog-watchlisthidepatrolled' => 'Ƿeardede ādihtas hȳdan ƿiþ þā ƿæccȝetale',
-'tog-ccmeonemails'           => 'Mē tƿifealda sendan þāra e-ǣrenda þe iċ ōðrum brūcendum sende',
-'tog-diffonly'               => 'Ne scēaƿian sīdan innunge under scādungum',
-'tog-showhiddencats'         => 'Ȝehȳdede floccas scēaƿian',
+'tog-underline'               => 'Hlenċa undermearcian:',
+'tog-highlightbroken'         => 'Sete unfulfylede hlencan <a href="" class="new">sƿā þis</a> (þīn ōðer cyre is tō habbenne hīe sƿā þis:<a href="" class="internal">?</a>)',
+'tog-justify'                 => 'Macian cwidfloccas riht',
+'tog-hideminor'               => 'Lytla ādihtas hȳdan in nīƿum hƿeorfum',
+'tog-hidepatrolled'           => 'Ƿeardede ādihtas hȳdan in nīƿe hƿearfas',
+'tog-newpageshidepatrolled'   => 'Ƿeardede sīdan hȳdan in nīƿe hƿearfas',
+'tog-extendwatchlist'         => 'Ƿæccȝetale sprædan to scēaƿenne ealle hƿearfas, ne efne þā nīƿoste',
+'tog-usenewrc'                => 'Benota forðod ȝetæl nīƿra hƿeorfunȝa (þis þearf JavaScript)',
+'tog-numberheadings'          => 'Selffremmende-rīm hēafodingas',
+'tog-showtoolbar'             => 'Þone tōlstæf scēaƿian (þearf JavaScript)',
+'tog-editondblclick'          => 'Sīdan ādihtan bȳ tƿicnæppende (þearf JavaScript)',
+'tog-editsection'             => 'Dǣla ādihtende þafian bȳ [ādihtan] hlenċum',
+'tog-editsectiononrightclick' => 'Þafa dǣla ādihtune þurh sƿenȝas þǣre sƿīðran healfe on dǣla titulum (þis þearf JavaScript)',
+'tog-showtoc'                 => 'Innoðes tæfle sēon (for sīdum þe mā þonne 3 hēafodingas habbaþ)',
+'tog-rememberpassword'        => 'Mīne inmeldunge ȝemyndan on þissum spearcatelle (oþ $1 {{PLURAL:$1|dæȝ|dagas}})',
+'tog-watchcreations'          => 'Sīdan þe iċ scieppe ēacian tō mīnre ƿæccȝetale',
+'tog-watchdefault'            => 'Sīdan þe iċ ādihte ēacian tō mīnre ƿæccȝetale',
+'tog-watchmoves'              => 'Sīdan þe iċ hƿeorfe ēacian tō mīnre ƿæccȝetale',
+'tog-watchdeletion'           => 'Sīdan þe iċ forlēose ēacian tō mīnre ƿæccȝetale',
+'tog-minordefault'            => 'Ealle ādihtende mearcian tōlas ȝeƿunelīċe',
+'tog-previewontop'            => 'Forescēaƿe sēon fore ādihtbox',
+'tog-previewonfirst'          => 'Forescēaƿe sēon on formestum ādihte',
+'tog-nocache'                 => 'Ne þafa trameta settunȝe',
+'tog-enotifwatchlistpages'    => 'Send mē spearccræftiȝ ǣrend þǣr tramet on mīnum ƿæccȝetæle ƿierþ andƿended',
+'tog-enotifusertalkpages'     => 'Send mē spearccræftiȝ ǣrend þǣr mīn brūcendtramet is andƿended',
+'tog-enotifminoredits'        => 'Send mē spearccræftiȝ ǣrend þǣr trametas sind efne lytellīce andƿended',
+'tog-enotifrevealaddr'        => 'Ēoƿa mīn spearccræftiȝra ǣrenda stōƿnaman on sprearccræftiȝum ȝecȳðendum ǣrendum',
+'tog-shownumberswatching'     => 'Hū mæniȝ ƿæccende brūcendas sēon',
+'tog-oldsig'                  => 'Foresihþ þæs selftācnes þe is nū ȝenotod:',
+'tog-fancysig'                => 'Dō mid þissum selftācne sƿā mid Ƿikitext (lēas ǣr ȝedōnes hlencan)',
+'tog-externaleditor'          => 'Nota ūtƿeardne ādihttōl tō ȝeƿunelicre ȝesetednesse (synderlīce tō sƿīðe cræftiȝum mannum - þearf ānlica ȝesetednessa on þīnum spearctelle)',
+'tog-externaldiff'            => 'Nota ūtƿearde scādunȝe tō ȝeƿunelicre ȝesetednesse (synderlīce tō sƿīðe cræftiȝum mannum - þearf ānlica ȝesetednesse on þīnum spearctelle)',
+'tog-showjumplinks'           => 'Lǣt "ȝā tō" ȝefēre hlencan',
+'tog-uselivepreview'          => 'Nota andefene foresihþe (þearf JavaScript) (tō costnunȝe)',
+'tog-forceeditsummary'        => 'Scyhte mē þǣr ic inƿrīte nāne ādihtsceortnesse',
+'tog-watchlisthideown'        => 'Mīna ādihtunga hȳdan ƿiþ þā ƿæccȝetale',
+'tog-watchlisthidebots'       => 'Searuþrala ādihtas hȳdan ƿiþ þā ƿæccȝetale',
+'tog-watchlisthideminor'      => 'Lȳtl ādihtas hȳdan ƿiþ þā ƿæccȝetale',
+'tog-watchlisthideliu'        => 'Ādihtas bȳ inmeldedum brūcendum hȳdan ƿiþ þā ƿæccȝetale',
+'tog-watchlisthideanons'      => 'Hȳd ādihtas fram uncūðum brūcendum ƿiþ þæt ƿæccȝetæl',
+'tog-watchlisthidepatrolled'  => 'Hȳd ƿeardode ādihtas ƿiþ þæt ƿæccȝetæl',
+'tog-nolangconversion'        => 'Ne lǣt missenlicnessa æfter āwendungum',
+'tog-ccmeonemails'            => 'Send mē ȝelīcnessa þāra spearcræftiȝena ǣrenda þe ic ōðrum brūcendum sende',
+'tog-diffonly'                => 'Ne ēoƿa sīdan innunȝe under scādunȝum',
+'tog-showhiddencats'          => 'Ēoƿa ȝehȳdede floccas',
+'tog-noconvertlink'           => 'Ne lǣt hlencena titula āwendunge',
+'tog-norollbackdiff'          => 'Forlǣt scādunȝe æfter edƿeorc is ȝedōn',
 
 'underline-always'  => 'Ǣfre',
 'underline-never'   => 'Nǣfre',
-'underline-default' => 'Ƿebbsēċendes ȝeƿuna',
+'underline-default' => 'Ƿebbsēcendes ȝeƿunelic ȝesetedness',
 
 # Font style option in Special:Preferences
-'editfont-style'     => 'Feldes trahtānsīenmōd ādihtan:',
-'editfont-default'   => 'Ƿebbsēċendes ȝeƿuna',
-'editfont-monospace' => 'Ānbrǣdisc trahtānsīen',
-'editfont-sansserif' => 'Būtonscrīfisc trahtānsīen',
-'editfont-serif'     => 'Scrīfisc trahtānsīen',
+'editfont-style'     => 'Stæfcynd for þǣre ƿrītunȝe on þǣm ādihtearce:',
+'editfont-default'   => 'Ƿebbsēcendes ȝeƿunelic ȝesetedness',
+'editfont-monospace' => 'Ānbrǣded stæfcynd',
+'editfont-sansserif' => 'Tæȝellēas stæfcynd',
+'editfont-serif'     => 'Tæȝelbǣr stæfcynd',
 
 # Dates
 'sunday'        => 'Sunnandæȝ',
@@ -78,7 +96,7 @@ $messages = array(
 'wednesday'     => 'Ƿēdnesdæȝ',
 'thursday'      => 'Þunresdæȝ',
 'friday'        => 'Frīȝedæȝ',
-'saturday'      => 'Sæternesdæȝ',
+'saturday'      => 'Sæterndæȝ',
 'sun'           => 'Sun',
 'mon'           => 'Mōn',
 'tue'           => 'Tīƿ',
@@ -86,31 +104,31 @@ $messages = array(
 'thu'           => 'Þun',
 'fri'           => 'Frī',
 'sat'           => 'Sæt',
-'january'       => 'Se Æfterra Ȝēola',
+'january'       => 'Æfterra Ȝēola',
 'february'      => 'Solmōnaþ',
 'march'         => 'Hrēþmōnaþ',
 'april'         => 'Ēostremōnaþ',
 'may_long'      => 'Þrimilcemōnaþ',
-'june'          => 'Sēremōnaþ',
+'june'          => 'Sēarmōnaþ',
 'july'          => 'Mǣdmōnaþ',
 'august'        => 'Ƿēodmōnaþ',
 'september'     => 'Hāliȝmōnaþ',
 'october'       => 'Ƿinterfylleþ',
 'november'      => 'Blōtmōnaþ',
-'december'      => 'Ȝēolmōnaþ',
-'january-gen'   => 'þæs Æfterran Ȝēolan',
+'december'      => 'Ǣrra Ȝēola',
+'january-gen'   => 'Æfterran Ȝēolan',
 'february-gen'  => 'Solmōnþes',
 'march-gen'     => 'Hrēþmōnþes',
 'april-gen'     => 'Ēostremōnþes',
 'may-gen'       => 'Þrimilcemōnþes',
-'june-gen'      => 'Sēremōnþes',
+'june-gen'      => 'Sēarmōnþes',
 'july-gen'      => 'Mǣdmōnþes',
 'august-gen'    => 'Ƿēodmōnþes',
 'september-gen' => 'Hāliȝmōnþes',
 'october-gen'   => 'Ƿinterfylleðes',
 'november-gen'  => 'Blōtmōnþes',
-'december-gen'  => 'Ȝēolmōnþes',
-'jan'           => 'ÆȜē',
+'december-gen'  => 'Ǣrran Ȝēolan',
+'jan'           => 'Ǣr Ȝē',
 'feb'           => 'Sol',
 'mar'           => 'Hrē',
 'apr'           => 'Ēos',
@@ -119,161 +137,162 @@ $messages = array(
 'jul'           => 'Mǣd',
 'aug'           => 'Ƿēo',
 'sep'           => 'Hāl',
-'oct'           => 'Ƿin',
+'oct'           => 'Ƿinfyl',
 'nov'           => 'Blō',
-'dec'           => 'Ȝēo',
+'dec'           => 'Æf Ȝē',
 
 # Categories related messages
-'pagecategories'                => '{{PLURAL:$1|Flocc|Floccas}}',
-'category_header'               => 'Ȝeƿritu in flocce "$1"',
-'subcategories'                 => 'Underfloccas',
-'category-media-header'         => 'Ȝemynda in flocce "$1"',
-'category-empty'                => "''Þes flocc hæfþ nū nān ȝeƿritu oþþe ȝemynda in.''",
-'hidden-categories'             => '{{PLURAL:$1|Ȝehȳded flocc|Ȝehȳdede floccas}}',
-'hidden-category-category'      => 'Ȝehȳdede floccas',
-'category-subcat-count'         => '{{PLURAL:$2|Þes flocc hæfþ efne þone folgende underflocc.|Þes flocc hæfþ þā folgende {{PLURAL:$1|underflocc|$1 underfloccas}}, þāra $2.}}',
-'category-subcat-count-limited' => 'Þes flocc hæfþ {{PLURAL:$1|þisne underflocc|$1 þās underfloccas}}.',
-'category-article-count'        => '{{PLURAL:$2|Þes flocc hæfþ efne þā folgende sīdan.|{{PLURAL:$1|Sēo folgende sīde is|$1 Þā folgendan sīdan sind}} in þissum flocce, þāra $2.}}',
-'category-file-count-limited'   => '{{PLURAL:$1|Þēos fīl is|$1 Þās fīlan sind}} in þissum flocce.',
-'listingcontinuesabbrev'        => 'mā',
+'pagecategories'                 => '{{PLURAL:$1|Flocc|Floccas}}',
+'category_header'                => 'Trametas in flocce "$1"',
+'subcategories'                  => 'Underfloccas',
+'category-media-header'          => 'Missenmiddel in flocce "$1"',
+'category-empty'                 => "''Þes flocc hæfþ nū nǣnȝu ȝeƿritu oþþe missenmiddel.''",
+'hidden-categories'              => '{{PLURAL:$1|Ȝehȳded flocc|$1 Ȝehȳdede floccas}}',
+'hidden-category-category'       => 'Ȝehȳdede floccas',
+'category-subcat-count'          => '{{PLURAL:$2|Þes flocc hæfþ efne þone folȝiendan underflocc.|Þes flocc hæfþ {{PLURAL:$1|þone folȝiendan underflocc|$1 þā folȝiendan underfloccas}}, þāra fullena $2.}}',
+'category-subcat-count-limited'  => 'Þes flocc hæfþ {{PLURAL:$1|þisne underflocc|$1 þās underfloccas}}.',
+'category-article-count'         => '{{PLURAL:$2|Þes flocc hæfþ efne þā folȝiendan āne sīdan.|{{PLURAL:$1|Sēo folȝiende sīde is|$1 Þā folȝiendan sīdan sind}} in þissum flocce, þāra fullena $2.}}',
+'category-article-count-limited' => '{{PLURAL:$1|Se folȝienda tramet is|$1 Þā folȝiendan trametas sind}} on þissum flocce hēr.',
+'category-file-count'            => ' {{PLURAL:$2|Þes flocc hæfþ efne þæt folȝiende ȝeƿithord.|{{PLURAL:$1|Þæt folȝiende ȝeƿithord is|$1 Þā folȝiendan ȝeƿithord sind}} in þissum flocce, þāra fullena $2.}}',
+'category-file-count-limited'    => '{{PLURAL:$1|Þis ȝeƿithord is|$1 Þās ȝeƿithord sind}} in þissum flocce hēr.',
+'listingcontinuesabbrev'         => 'mā',
+'index-category'                 => 'Ȝebēacniende trametas',
+'noindex-category'               => 'Unȝebēacniende trametas',
 
-'mainpagedocfooter' => '[http://meta.wikimedia.org/wiki/Help:Contents Brūcendlǣdend] þeahtian for helpe on bryċe þǣre ƿikihnescƿare.
+'mainpagetext'      => "'''MediaǷiki hafaþ ȝeƿorden spēdiȝe inseted.'''",
+'mainpagedocfooter' => 'Þeahta þone [http://meta.wikimedia.org/wiki/Help:Contents Brūcenda Lǣdend]  on helpe mid þǣre nytte of ƿikisōftƿare.
 
-== Beȝinnende ==
-* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Configuration settings list]
-* [http://www.mediawiki.org/wiki/Manual:FAQ MediaWiki FAQ]
-* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce MediaWiki release mailing list]',
+== Beȝinnunȝ ==
+* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Onfæstnunȝa ȝesetednessa ȝetæl]
+* [http://www.mediawiki.org/wiki/Manual:FAQ Ȝetæl oft ascodra ascunȝa ymb MediaǷiki]
+* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce Ǣrendunȝȝetæl nīƿra MediaǷiki forþsendnessa]',
 
 'about'         => 'Ymbe',
-'article'       => 'Innoþsīde',
-'newwindow'     => '(openaþ in nīƿum ēagþyrele)',
-'cancel'        => 'Undōn',
+'article'       => 'Innunȝsīde',
+'newwindow'     => '(openaþ in nīƿum ēaȝþyrelum)',
+'cancel'        => 'Undō',
 'moredotdotdot' => 'Mā...',
-'mypage'        => 'Mīnu sīde',
-'mytalk'        => 'Mīn ȝespreċ',
-'anontalk'      => 'Ȝespreċ for þissum IP',
+'mypage'        => 'Mīn sīde',
+'mytalk'        => 'Mīnu ȝespreċ',
+'anontalk'      => 'Þisses IP stōƿnaman talu',
 'navigation'    => 'Þurhfōr',
 'and'           => '&#32;and',
 
 # Cologne Blue skin
-'qbfind'         => 'Findan',
-'qbbrowse'       => 'Ofer sēċan',
-'qbedit'         => 'Ādihtan',
+'qbfind'         => 'Find',
+'qbbrowse'       => 'Onbirȝe',
+'qbedit'         => 'Ādihte',
 'qbpageoptions'  => 'Þēos sīde',
 'qbpageinfo'     => 'Ȝeƿef',
 'qbmyoptions'    => 'Mīna sīdan',
 'qbspecialpages' => 'Syndriȝa sīdan',
-'faq'            => 'Oftost ascoda ascunga',
+'faq'            => 'Oftost ascoda ascunȝa',
 'faqpage'        => 'Project:FAQ',
 
 # Vector skin
-'vector-action-addsection'   => 'Mearcunge ēacian',
-'vector-action-move'         => 'Ƿeȝan',
-'vector-action-protect'      => 'Beorgan',
-'vector-action-undelete'     => 'Edƿyrcan',
-'vector-action-unprotect'    => 'Unbeorgan',
-'vector-namespace-category'  => 'Flocc',
-'vector-namespace-help'      => 'Helpsīde',
-'vector-namespace-image'     => 'Fīl',
-'vector-namespace-main'      => 'Sīde',
-'vector-namespace-media'     => 'Ȝemyndesīde',
-'vector-namespace-mediawiki' => 'Ǣrend',
-'vector-namespace-project'   => 'Ƿeorcsīde',
-'vector-namespace-special'   => 'Syndriȝu sīde',
-'vector-namespace-talk'      => 'Ȝespreċ',
-'vector-namespace-template'  => 'Bysen',
-'vector-namespace-user'      => 'Brūcendsīde',
-'vector-view-create'         => 'Scieppan',
-'vector-view-edit'           => 'Ādihtan',
-'vector-view-history'        => 'Stǣr sēon',
-'vector-view-view'           => 'Rǣdan',
-'vector-view-viewsource'     => 'Fruma sēon',
-'actions'                    => 'Fremmendas',
-'namespaces'                 => 'Namastedas',
-'variants'                   => 'Missenliċnessa',
+'vector-action-addsection'       => 'Mearcunge ēacian',
+'vector-action-delete'           => 'Forlēos',
+'vector-action-move'             => 'Ƿeȝ',
+'vector-action-protect'          => 'Beorȝa',
+'vector-action-undelete'         => 'Sciepe tramet eft',
+'vector-action-unprotect'        => 'Unbeorȝa',
+'vector-simplesearch-preference' => 'Lǣt forðoda sēcunge tōtyhtinga (synderlīce for Vector scinne)',
+'vector-view-create'             => 'Sciepe',
+'vector-view-edit'               => 'Ādihte',
+'vector-view-history'            => 'Stǣr',
+'vector-view-view'               => 'Rǣd',
+'vector-view-viewsource'         => 'Sēo fruman',
+'actions'                        => 'Fremmunga',
+'namespaces'                     => 'Namstedas',
+'variants'                       => 'Missenlicnessa',
 
 'errorpagetitle'    => 'Ƿōh',
-'returnto'          => 'To $1 eftgān.',
-'tagline'           => 'Fram {{SITENAME}}n',
+'returnto'          => 'Ȝā eft tō $1',
+'tagline'           => 'Fram {{SITENAME}}',
 'help'              => 'Help',
-'search'            => 'Sēċan',
-'searchbutton'      => 'Sēċan',
-'go'                => 'Gān',
+'search'            => 'Sēc',
+'searchbutton'      => 'Sēc',
+'go'                => 'Gā',
 'searcharticle'     => 'Gān',
 'history'           => 'Sīdan stǣr',
 'history_short'     => 'Stǣr',
-'updatedmarker'     => 'nīƿed siþþan ƿæs iċ ǣror hēr',
+'updatedmarker'     => 'nīƿod æfter ic cōm hider ǣror',
 'info_short'        => 'Cȳþþu',
-'printableversion'  => 'Ȝemǣlendliċu fadung',
-'permalink'         => 'Fæst hlenċ',
-'print'             => 'Ȝemǣlan',
-'edit'              => 'Ādihtan',
-'create'            => 'Scieppan',
-'editthispage'      => 'Þās sīdan ādihtan',
-'create-this-page'  => 'Þās sīdan scieppan',
-'delete'            => 'āfeorsian',
-'deletethispage'    => 'Þās sīdan āfeorsian',
-'protect'           => 'Beorgan',
-'protect_change'    => 'hƿeorfan',
-'protectthispage'   => 'Þās sīdan beorgan',
+'printableversion'  => 'Ūtmǣlendlicu fadunȝ',
+'permalink'         => 'Fæst hlenċe',
+'print'             => 'Ūtmǣl',
+'edit'              => 'Ādiht',
+'create'            => 'Sciepe',
+'editthispage'      => 'Ādiht þās sīdan',
+'create-this-page'  => 'Sciepe þās sīdan',
+'delete'            => 'Forlēos',
+'deletethispage'    => 'Forlēos þās sīdan',
+'undelete_short'    => 'Maca {{PLURAL:$1|ānne ādiht|$1 ādihtas}} eft',
+'protect'           => 'Beorȝa',
+'protect_change'    => 'Hƿeorf',
+'protectthispage'   => 'Beorȝa þās sīdan',
 'unprotect'         => 'Unbeorgan',
-'unprotectthispage' => 'Þās sīdan unbeorgan',
+'unprotectthispage' => 'Unbeorȝa þās sīdan',
 'newpage'           => 'Nīƿu sīde',
-'talkpage'          => 'Þās sīdan ymbspreċan',
+'talkpage'          => 'Sprec ymb þās sīdan',
 'talkpagelinktext'  => 'ȝespreċ',
-'specialpage'       => 'Syndriȝu sīde',
-'personaltools'     => 'Āgen tōl',
+'specialpage'       => 'Syndriȝ sīde',
+'personaltools'     => 'Āgne tōlas',
 'postcomment'       => 'Nīƿe dǣl',
-'articlepage'       => 'Innoþsīdan sēon',
-'talk'              => 'ȝespreċ',
-'views'             => 'Ānsīene',
-'toolbox'           => 'Tōlbox',
-'userpage'          => 'Brūcendsīdan sēon',
-'projectpage'       => 'Ƿeorcsīdan sēon',
-'imagepage'         => 'Fīlsīdan sēon',
+'articlepage'       => 'Seoh innungsīdan',
+'talk'              => 'Ȝespreċ',
+'views'             => 'Ansīena',
+'toolbox'           => 'Tōlearc',
+'userpage'          => 'Seoh brūcendsīdan',
+'projectpage'       => 'Seoh ƿeorcsīdan',
+'imagepage'         => 'Seoh ȝeƿithordsīdan',
 'mediawikipage'     => 'Ȝeƿritsīdan sēon',
-'templatepage'      => 'Bysensīdan sēon',
-'viewhelppage'      => 'Helpsīdan sēon',
-'categorypage'      => 'Floccsīdan sēon',
-'viewtalkpage'      => 'Ȝespreċ sēon',
+'templatepage'      => 'Seoh bysensīdan',
+'viewhelppage'      => 'Seoh helpsīdan',
+'categorypage'      => 'Seoh floccsīdan',
+'viewtalkpage'      => 'Seoh tæle',
 'otherlanguages'    => 'On ōðrum sprǣċum',
 'redirectedfrom'    => '(Edlǣded fram $1)',
 'redirectpagesub'   => 'Edlǣdsīde',
-'lastmodifiedat'    => 'Man læst þās sīdan hƿearf on $1, æt $2.',
-'protectedpage'     => 'Borgenu sīde',
-'jumpto'            => 'Forðgangan on:',
+'lastmodifiedat'    => 'Man nīwanost þās sīdan hƿearf on þǣre $2 stunde þæs $1.',
+'viewcount'         => 'Þēos sīde hæfþ ȝeƿorden ȝeseƿen {{PLURAL:$1|āne|$1 hwīlum}}.',
+'protectedpage'     => 'Borȝod sīde',
+'jumpto'            => 'Gā tō:',
 'jumptonavigation'  => 'þurhfōr',
-'jumptosearch'      => 'sēcan',
-'view-pool-error'   => 'Sāriȝ, þās þeȝntelleras nū ƿyrcaþ tō miċel.
-Tō mæniȝ brūcendas fandiaþ to sēonne þās sīdan.
-Bidde forbyrde scortre tīde fore fandiende to sēonne þās sīdan eft.
+'jumptosearch'      => 'sēċan',
+'view-pool-error'   => 'Ƿē sind sāriȝe for þǣm þe þās þeȝntōlas nū oferlīce ƿyrcaþ.
+Tō mæniȝe brūcendas ȝesēcaþ to sēonne þās sīdan.
+Ƿ̈ē biddaþ þæt þū abīde scortre tīde fore þū ȝesēce to sēonne þās sīdan eft.
 
 $1',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'            => 'Ymbe {{SITENAME}}n',
+'aboutsite'            => 'Ymbe {{SITENAME}}',
 'aboutpage'            => 'Project:Ymbe',
-'copyright'            => 'Man mæȝ innoþ under $1 findan.',
-'copyrightpage'        => '{{ns:project}}:Ȝeƿritesriht',
-'currentevents'        => 'Efenealde belimpas',
-'currentevents-url'    => 'Project:Efenealde belimpas',
-'disclaimers'          => 'Ymbcƿidas',
-'disclaimerpage'       => 'Ƿeorc:Ymbcƿidas',
-'edithelp'             => 'Ādihtan help',
-'edithelppage'         => 'Help:Ādihtan',
+'copyright'            => 'Man mæȝ innunȝe under $1 findan.',
+'copyrightpage'        => '{{ns:project}}:Ȝelīcnessriht',
+'currentevents'        => 'Ȝelimpunȝa þisses tīman',
+'currentevents-url'    => 'Project:Ȝelimpunga þisses tīman',
+'disclaimers'          => 'Ætsacunga',
+'disclaimerpage'       => 'Project:Ætsacunga',
+'edithelp'             => 'Help mid ādihtunge',
+'edithelppage'         => 'Help:Ādihtung',
 'helppage'             => 'Help:Innoþ',
 'mainpage'             => 'Hēafodsīde',
 'mainpage-description' => 'Hēafodsīde',
-'policy-url'           => 'Project:Þēaƿ',
-'portal'               => 'Gemǣnscipe Ingang',
-'portal-url'           => 'Project:Gemǣnscipe Ingang',
-'privacy'              => 'Ānlīepnesse þēaƿ',
-'privacypage'          => 'Project:Ānlīepnesse þēaƿ',
+'policy-url'           => 'Project:Rǣd',
+'portal'               => 'Ȝemǣnscipes ingang',
+'portal-url'           => 'Project:Ȝemǣnscipes inȝanȝ',
+'privacy'              => 'Ānlēpnesse rǣd',
+'privacypage'          => 'Project:Ānlēpnesse rǣd',
 
-'badaccess'        => 'Þafunge ƿōh',
-'badaccess-group0' => 'Þū ne mōst dōn þā dǣde þǣre þe þū hafast abitt.',
+'badaccess'        => 'Þafunȝe ƿōh',
+'badaccess-group0' => 'Þū ne mōst dōn þā dǣde þǣre þe þū hafast abeden.',
+'badaccess-groups' => 'Þēos dǣd þǣre þū hafast abeden is synderlīce alȳfedlic brūcendum on {{PLURAL:$2|þissum þrēate|ānum þāra þrēata}}: $1.',
 
-'versionrequired' => 'Fadunge $1 þæs MediaWicis nēodaþ',
+'versionrequired'     => '$1 fadunȝ of MediaǷiki is ȝeþorften',
+'versionrequiredtext' => 'Fadung $1 MediaǷiki is ȝeþorften tō notiennde þisne tramet.
+Sēoh þone [[Special:Version|fadunge tramet]].',
 
 'ok'                      => 'OK',
 'retrievedfrom'           => 'Fram "$1" beȝieten',
@@ -290,12 +309,12 @@ $1',
 'toc'                     => 'Innoþ',
 'showtoc'                 => 'sēon',
 'hidetoc'                 => 'hȳdan',
-'thisisdeleted'           => 'Wilt þū sēon oþþe nīwian $1?',
+'thisisdeleted'           => '$1 sēon oþþe nīƿian?',
 'viewdeleted'             => '$1 sēon?',
-'restorelink'             => '{{PLURAL:$1|ān ahwītod ādihtung}$1 ahwītoda ādihtunga}}',
+'restorelink'             => '{{PLURAL:$1|ān āfeorsed ādiht|$1 āfeorsed ādihtas}}',
 'feedlinks'               => 'Flōd:',
-'feed-invalid'            => 'Ungenge underwrītunge inlāde gecynd.',
-'feed-unavailable'        => 'Fruman inlāda ne sind gearwa',
+'feed-invalid'            => 'Ungenge underƿrītunge inlāde ȝecynd.',
+'feed-unavailable'        => 'Fruman inlāda ne sind ȝearƿa',
 'site-rss-feed'           => '$1 RSS strēam',
 'site-atom-feed'          => '$1 Atom strēam',
 'page-rss-feed'           => '$1 RSS strēam',
@@ -327,12 +346,12 @@ Getæl gengra ānlicra trameta cann mann findand be [[Special:SpecialPages|{{int
 # General errors
 'error'               => 'Ƿōh',
 'databaseerror'       => 'Cȳþþuhordes ƿōh',
-'dberrortext'         => 'Gewitnesshordes bēnes endebyrdnesse unrihtness hæfþ gelumpen.
-Þis mæg gelimpan unrihtnesse on þǣre sōftware.
-Sēo nīwoste gesōhte sōftware bēn wæs:
+'dberrortext'         => 'Cȳþþuhordes bēnes endebyrdnesse fremmode ƿōh.
+Þis mæȝe mǣnan regolƿōh on þǣre sōftƿare.
+Sēo nīƿoste ȝesōhte sōftƿare bēn ƿæs:
 <blockquote><tt>$1</tt></blockquote>
-fram innan weorce "<tt>$2</tt>".
-Gewitnesshord edwende unrihtnesse "<tt>$3: $4</tt>"',
+fram innan ƿeorce "<tt>$2</tt>".
+Cȳþþuhord edƿende ƿōh "<tt>$3: $4</tt>"',
 'laggedslavemode'     => "'''Ƿarnung:''' Sīde ne mihteliċ ne hæfþ nīƿa nīƿunga.",
 'enterlockreason'     => 'Wrīt race þǣre forwiernunge and apunsunge be þǣm tīman on þǣm bēo sēo forwiernung forlǣten',
 'missingarticle-rev'  => '(nīƿung#: $1)',
@@ -359,7 +378,7 @@ Cnāw þæt sume sīdan cunnon gelǣstende ēowod wesan swā þū wǣre gīet in
 'yourname'                   => 'Þīn brūcendnama',
 'yourpassword'               => 'Þafungƿord:',
 'yourpasswordagain'          => 'Þafungƿord edƿrītan:',
-'remembermypassword'         => 'Mīne inmeldunge ȝemyndan on þissum spearcatelle',
+'remembermypassword'         => 'Mīne inmeldunge ȝemyndan on þissum spearcatelle (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => 'Þīn ȝeƿeald:',
 'login'                      => 'Inmeldian',
 'nav-login-createaccount'    => 'Nīƿne hordcleofan scieppan oþþe inmeldian',
@@ -372,6 +391,7 @@ Cnāw þæt sume sīdan cunnon gelǣstende ēowod wesan swā þū wǣre gīet in
 'createaccount'              => 'Hordcleofan scieppan',
 'gotaccountlink'             => 'Inmeldian',
 'createaccountmail'          => 'Þurh spearcenaǣrend',
+'createaccountreason'        => 'Racu:',
 'badretype'                  => 'Þā þafungƿord þe ƿrite þū, bēoþ unȝemæcca.',
 'userexists'                 => 'Hƿā hæfþ þæt brūcendnama.
 Bidde ōðer brūcendnama ċēosan.',
@@ -379,12 +399,12 @@ Bidde ōðer brūcendnama ċēosan.',
 'createaccounterror'         => 'Ne cūðe macian reccend: $1',
 'nocookiesnew'               => 'Se brūcendreccend wæs gemacod, ac þū neart inmedlod.
 {{SITENAME}} brȳcþ tācninclu tō inmeldienne brūcendas.
-Þū hafast forwierned tācninclu. 
+Þū hafast forwierned tācninclu.
 Bidde þē, lǣt hīe tō twyrcenne, and þǣræfter inmelda þurh þīnne nīwan brūcendnaman and gelēafnessword.',
 'loginsuccesstitle'          => 'Inmeldung gesǣlde',
 'loginsuccess'               => "'''Þu eart nū inmeldod tō {{SITENAME}} swā \"\$1\".'''",
 'nosuchuser'                 => 'Þǣr nis nān brūcere þe hæfþ þone naman "$1".
-Stafena micelnesse sind hefige and ānlica on brūcendnamum. 
+Stafena micelnesse sind hefige and ānlica on brūcendnamum.
 Scēawa þīne wrītunge eft, oþþe brūc þā cartan þe is hērunder tō [[Special:UserLogin/signup|settene nīwne brūcendreccend]].',
 'nosuchusershort'            => 'Þǣr is nān brūcend mid þǣm naman "<nowiki>$1</nowiki>".  Edscēawa on þīne wrītunge.',
 'passwordtooshort'           => 'Gelēafword sculon habban læst {{PLURAL:$1|1 stafan|$1 stafan}}.',
@@ -394,10 +414,12 @@ Scēawa þīne wrītunge eft, oþþe brūc þā cartan þe is hērunder tō [[Sp
 'loginlanguagelabel'         => 'Sprǣċ: $1',
 
 # Password reset dialog
+'resetpass'                 => 'Þafungƿord hƿeorfan',
 'oldpassword'               => 'Eald þafungƿord:',
 'newpassword'               => 'Nīƿu þafungƿord:',
 'retypenew'                 => 'Nīƿe þafungƿord edƿrītan',
 'resetpass-submit-loggedin' => 'Þafungƿord hƿeorfan',
+'resetpass-submit-cancel'   => 'Undōn',
 
 # Edit page toolbar
 'bold_sample'     => 'Þicce traht',
@@ -406,7 +428,7 @@ Scēawa þīne wrītunge eft, oþþe brūc þā cartan þe is hērunder tō [[Sp
 'italic_tip'      => 'Flōƿende traht',
 'link_sample'     => 'Hlenċnama',
 'link_tip'        => 'Innanƿeard hlenċe',
-'extlink_sample'  => 'http://www.bisen.com hlenċnama',
+'extlink_sample'  => 'http://www.example.com hlenċnama',
 'extlink_tip'     => 'Ūtanƿeard hlenċe (ȝemune http:// foredǣl)',
 'headline_sample' => 'Hēafodlīnan traht',
 'headline_tip'    => 'Emnet 2 hēafodlīn',
@@ -467,9 +489,6 @@ Gif þu hider misfōn cōme, cnoca þā þīnne webbscēaweres '''on bæc''' cn
 Þū behǣtst ēac þæt þū selfa þis ƿrite, oþþe efenlǣhtest of sumre
 folcliċum āgnunge oþþe ȝelīċum frēom horde (sēo $1 for āscungum).
 '''Ne forþsend efenlǣhtscielded ƿeorc būtan þafunge!'''",
-'longpagewarning'                  => 'WARNUNG: Þes tramet is $1 kilobyta lang; sume
-webbscēaweras hæbben earfoðu mid þȳ þe hīe ādihtaþ trametas nēa oþþe lengran þonne 32kb.
-Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
 'templatesused'                    => '{{PLURAL:$1|Bysen|Bysena}} brocen on þisre sīdan:',
 'templatesusedpreview'             => '{{PLURAL:$1|Bysen|Bysena}} brocen on þisre forescēaƿe:',
 'template-protected'               => '(borgen)',
@@ -613,6 +632,7 @@ Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
 'yourgender'         => 'Ȝecynd:',
 'gender-male'        => 'Ƿer',
 'gender-female'      => 'Frēo',
+'email'              => 'E-ǣrende',
 
 # User rights
 'userrights-user-editname' => 'Brūcendnama ƿrītan:',
@@ -649,12 +669,8 @@ Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
 'recentchanges'                  => 'Nīƿe hƿearfas',
 'recentchanges-legend'           => 'Nīƿa hƿearfa forebearƿan',
 'recentchanges-feed-description' => 'Þā mǣst nīƿoste hƿearfan huntan to þisse ƿiki in þissum strēame',
-'recentchanges-label-legend'     => 'Cǣȝ: $1.',
-'recentchanges-legend-newpage'   => '$1 - nīƿu sīde',
 'recentchanges-label-newpage'    => 'Þes ādiht macode nīƿa sīdan',
-'recentchanges-legend-minor'     => '$1 - lȳtl ādiht',
 'recentchanges-label-minor'      => 'Þes is lȳtl ādiht',
-'recentchanges-legend-bot'       => '$1 - searuþræles ādiht',
 'recentchanges-label-bot'        => 'Searuþræl fremmode þisne ādiht',
 'rcnote'                         => "Under {{PLURAL:$1|... '''1''' ...|sind þā æftemestan '''$1''' hweorfunga}} in {{PLURAL:$2|...|þǣm æftemestum '''$2''' dagum}}, . . $5, $4.",
 'rcnotefrom'                     => 'Under sind þā hweorfunga siþþan <b>$2</b> (oþ <b>$1</b> geīewed).',
@@ -701,22 +717,22 @@ Bidde behycge þæt þu bricst þone tramet intō smalrum dǣlum.',
 'uploadedimage'     => 'forþsendode "[[$1]]"',
 'sourcefilename'    => 'Fruman þrǣdnama:',
 
-'license'           => 'Gelēaf:',
-'license-header'    => 'Gelēaf',
+'license'           => 'Ȝelēaf:',
+'license-header'    => 'Ȝelēaf:',
 'nolicense'         => 'Nǣnne gecorenne',
-'license-nopreview' => 'Þis gelēaf nis gearu.',
+'license-nopreview' => '(Forescēaƿe nis ȝearu)',
 
 # Special:ListFiles
-'listfiles-summary'     => 'Þes syngriga tramet ēowaþ ealle forþsendede fīlas.
-Æfter gewunelicum wīsum, þā nīwostan fīlas sind ēowod be hēafe þæs getæles.
-Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
+'listfiles-summary'     => 'Þēos syndriȝa sīde ēoƿaþ ealle forþsendede fīlas.
+Æfter ȝeƿuneliċum ƿīsum, þā nīƿostan fīlas sind ēoƿod be hēafde þæs ȝetæles.
+Cnæpp on sƿeorhēafde hƿeorfþ þā endebyrdnessa.',
 'listfiles_search_for'  => 'Sēcan biliþnaman:',
 'imgfile'               => 'fīl',
 'listfiles'             => 'Biliþgetalu',
 'listfiles_date'        => 'Tælmearc',
 'listfiles_name'        => 'Nama',
 'listfiles_user'        => 'Brūcend',
-'listfiles_size'        => 'Micelness',
+'listfiles_size'        => 'Miċelnes',
 'listfiles_description' => 'Tōƿritennes',
 'listfiles_count'       => 'Fadunga',
 
@@ -724,30 +740,30 @@ Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
 'file-anchor-link'          => 'Fīl',
 'filehist'                  => 'Fīlanstǣr',
 'filehist-help'             => 'Cnæpp on dæȝe/tīde to sēonne þā fīlan sƿā ƿæs hēo on þǣre tīde.',
-'filehist-deleteall'        => 'afeorsian eall',
-'filehist-deleteone'        => 'afeorsian',
+'filehist-deleteall'        => 'eall āfeorsian',
+'filehist-deleteone'        => 'āfeorsian',
 'filehist-revert'           => 'undōn',
 'filehist-current'          => 'nū',
 'filehist-datetime'         => 'Dæȝ/Tīd',
 'filehist-thumb'            => 'Lȳtlbiliþ',
 'filehist-thumbtext'        => 'Lȳtlbiliþ for fadunge sƿā $1',
-'filehist-nothumb'          => 'Nān biliþincel',
+'filehist-nothumb'          => 'Nān biliþinċel',
 'filehist-user'             => 'Brūcend',
 'filehist-dimensions'       => 'Miċela',
-'filehist-filesize'         => 'Fīlmicelness',
+'filehist-filesize'         => 'Fīlmiċelnes',
 'filehist-comment'          => 'Ymbsprǣċ',
 'filehist-missing'          => 'Fīl lēas',
 'imagelinks'                => 'Fīlhlenċan',
 'linkstoimage'              => 'Þā folgendan {{PLURAL:$1|sīde hæfþ hlenċe|sīdan habbaþ hlenċan}} for þissum fīle:',
 'nolinkstoimage'            => 'Þǣr sind nāne trametas þe bindaþ tō þissum biliðe.',
-'morelinkstoimage'          => 'Seoh [[Special:WhatLinksHere/$1|mā hlencan]] tō þissum fīle.',
-'redirectstofile'           => '{{PLURAL:$1|Þes fīl edlǣdeþ|$1 Þās fīlas hēr edlǣdaþ}} tō þissum  fīle:',
-'duplicatesoffile'          => '{{PLURAL:$1|Þes fīl hēr is gelīcness|Þās fīlas hēr sind gelīcnessa}} þisses fīles (seoh [[Special:FileDuplicateSearch/$2|mā gewitnesse hērymb]]):',
+'morelinkstoimage'          => '[[Special:WhatLinksHere/$1|Mā hlenċan]] sēon tō þissum fīle.',
+'redirectstofile'           => '{{PLURAL:$1|Þēos fīl edlǣdeþ|$1 Þās fīlan hēr edlǣdaþ}} tō þissum  fīle:',
+'duplicatesoffile'          => '{{PLURAL:$1|Sēo folgende fīl is ȝelīċnes|Þā folgende fīlan sind ȝelīċnessa}} þisses fīles (sēo [[Special:FileDuplicateSearch/$2|mā ȝeƿitnesse hērymb]]):',
 'sharedupload'              => 'Þēos fīl is fram $1 and man mæȝ hīe brūcan on ōðrum ƿeorcum.',
 'uploadnewversion-linktext' => 'Nīƿe fadunge þisse fīlan forþsendan',
 
 # File reversion
-'filerevert-legend' => 'Eftdōn fīl',
+'filerevert-legend' => 'Fīlan eftdōn',
 
 # File deletion
 'filedelete-submit' => 'āfeorsian',
@@ -805,7 +821,7 @@ Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
 'booksources'               => 'Bōcfruman',
 'booksources-search-legend' => 'Sēcan bōcfruman',
 'booksources-go'            => 'Gān',
-'booksources-text'          => 'Under is getalu benda tō ōðrum webstedum þe bebycgaþ nīwa and gebrocena bēc, and hæbben 
+'booksources-text'          => 'Under is getalu benda tō ōðrum webstedum þe bebycgaþ nīwa and gebrocena bēc, and hæbben
 ēac mā āscunga ymbe bēc þe þu sēcst:',
 
 # Special:Log
@@ -828,7 +844,9 @@ Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
 
 # Special:Categories
 'categories'         => 'Floccas',
-'categoriespagetext' => 'Þā folgendan floccas standaþ in þǣm wici.',
+'categoriespagetext' => 'Þā folgendan floccas standaþ in þǣm wici.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # Special:DeletedContributions
 'sp-deletedcontributions-contribs' => 'forðunga',
@@ -869,7 +887,6 @@ Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
 # Watchlist
 'watchlist'         => 'Mīnu ƿæcceȝetalu',
 'mywatchlist'       => 'Mīnu ƿæcceȝetalu',
-'watchlistfor'      => "(for '''$1''')",
 'addedwatch'        => 'To ƿæcceȝetale ēacod',
 'removedwatch'      => 'Fornōm fram ƿæccȝetale',
 'removedwatchtext'  => 'Sēo sīde "[[:$1]]" ƿæs fram [[Special:Watchlist|þīnre ƿæccȝetale]] fornōm.',
@@ -903,7 +920,7 @@ Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
 'historywarning'        => 'Warnung: Se tramet, þone þu āfeorsian teohhast, hæfþ stǣre:',
 'actioncomplete'        => 'Ƿeorcdǣd fuldōn',
 'deletedarticle'        => 'āfeorsode "[[$1]]"',
-'dellogpage'            => 'Āfeorsunge_wisbōc',
+'dellogpage'            => 'Āfeorsunge ƿīsbōc',
 'deletionlog'           => 'āfeorsunge wisbōc',
 'deletecomment'         => 'Racu:',
 'deleteotherreason'     => 'Ōðra/ēaca racu:',
@@ -917,7 +934,7 @@ Swenge wiþ sweorhēafod andwendeþ þā endebyrdnessa.',
 'revertpage'     => 'Ācierde ādihtunga fram [[Special:Contributions/$2|$2]] ([[User talk:$2|Gesprec]]); wendede on bæc tō ǣrran fadunge fram [[User:$1|$1]]',
 
 # Protect
-'protectlogpage'              => 'Beorges ealdhord',
+'protectlogpage'              => 'Beorges ƿīsbōc',
 'protectedarticle'            => 'borgen "[[$1]]"',
 'unprotectedarticle'          => 'unborgen "[[$1]]"',
 'protect-title'               => 'Beorges emnet hƿeorfan for "$1"',
@@ -1104,7 +1121,7 @@ Bidde cēos ōðerne naman.',
 'tooltip-t-upload'                => 'Fīlan forþsendan',
 'tooltip-t-specialpages'          => 'Ȝetalu eallra syndriȝa sīdena',
 'tooltip-t-print'                 => 'Ȝemǣnendliċu fadung þisse sīdan',
-'tooltip-t-permalink'             => 'Fæst hlenċ for þisse fadunge þǣre sīdan',
+'tooltip-t-permalink'             => 'Fæst hlenċe for þisse fadunge þǣre sīdan',
 'tooltip-ca-nstab-main'           => 'Þā innoþsīdan sēon',
 'tooltip-ca-nstab-user'           => 'Þā brūcendsīdan sēon',
 'tooltip-ca-nstab-special'        => 'Þēos is syndriȝu sīde, þū ne meaht þā sīdan hireself ādihtan',
@@ -1145,9 +1162,9 @@ Bidde cēos ōðerne naman.',
 # Media information
 'imagemaxsize'         => 'Settan biliðu on biliþgemearcungtrametum tō:',
 'thumbsize'            => 'Þumannæglmicelnes:',
-'file-info-size'       => '($1 × $2 pixels, fīlmiċelu: $3, MIMEcynn: $4)',
+'file-info-size'       => '$1 × $2 pixels, fīlmiċelu: $3, MIMEcynn: $4',
 'file-nohires'         => '<small>Þǣr nis nǣniȝ mā miċelu.</small>',
-'svg-long-desc'        => '(SVG fīl, rihte $1 × $2 pixels, fīlmiċelu: $3)',
+'svg-long-desc'        => 'SVG fīl, rihte $1 × $2 pixels, fīlmiċelu: $3',
 'show-big-image'       => 'Fulmiċelu',
 'show-big-image-thumb' => '<small>Þēos forescēaƿe miċelu: $1 × $2 pixels</small>',
 
