@@ -8,6 +8,7 @@
  * @file
  *
  * @author Amikeco
+ * @author Amire80
  * @author MF-Warburg
  * @author MONARCH79
  * @author Phoebe
@@ -17,10 +18,10 @@ $fallback = 'ru';
 
 $messages = array(
 # Dates
-'sunday'    => 'ГьатIан',
+'sunday'    => 'ГьатӀан',
 'monday'    => 'Итни',
 'tuesday'   => 'Талат',
-'wednesday' => 'АрбагI',
+'wednesday' => 'АрбагӀ',
 'thursday'  => 'Хамиз',
 'friday'    => 'Рузман',
 'saturday'  => 'Шаммат',
@@ -31,19 +32,19 @@ $messages = array(
 'errorpagetitle'   => 'Гъалатl',
 'help'             => 'Кумек',
 'history'          => 'Хиса-басазул тарих',
-'printableversion' => 'КутIизе версия',
-'permalink'        => 'Кидаго букIунеб рехсей',
+'printableversion' => 'КутӀизе версия',
+'permalink'        => 'Кидаго букӀунеб рехсей',
 'edit'             => 'Хисизабе',
 'talkpage'         => 'Гьумералда тlасан бахlс',
 'talk'             => 'Бахlс',
 'toolbox'          => 'Алатал',
-'userpage'         => 'ГIахьалчиясул гьумер',
-'otherlanguages'   => 'Цойги мацIазда',
+'userpage'         => 'ГӀахьалчиясул гьумер',
+'otherlanguages'   => 'Цойги мацӀазда',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'currentevents'        => 'Жакъасел лъугьа-бахъинал',
-'mainpage'             => 'БетIераб гьумер',
-'mainpage-description' => 'БетIераб гьумер',
+'mainpage'             => 'БетӀераб гьумер',
+'mainpage-description' => 'БетӀераб гьумер',
 'portal'               => 'Майдан',
 'portal-url'           => 'Project:Майдан',
 
@@ -58,39 +59,39 @@ $messages = array(
 'viewsource'    => 'Код бихьи',
 
 # Login and logout pages
-'loginpagetitle' => 'Цlар бице',
-'userlogin'      => 'ЦIар бице',
-'userlogout'     => 'Къватlиве лъугьине',
+'userlogin'  => 'ЦIар бице',
+'userlogout' => 'Къватlиве лъугьине',
 
 # Edit pages
-'savearticle' => 'Хъвай-хъвай цIунизе',
+'savearticle' => 'Хъвай-хъвай цӀунизе',
 
 # Preferences page
-'preferences'        => 'Рекъезаби',
-'math_unknown_error' => 'Лъалареб гъалатl',
-'localtime'          => 'Бакlалъул заман',
+'preferences' => 'Рекъезаби',
+'localtime'   => 'Бакlалъул заман',
 
 # User rights
-'userrights-user-editname' => 'ГIахьалчиясул цIар хъвай:',
+'userrights-user-editname' => 'ГӀахьалчиясул цӀар хъвай:',
 
 # Recent changes
-'recentchanges'   => 'ЦIиял хиса-басал',
-'rcshowhideminor' => '$1 гIиси-микъинал хиса-басал',
+'recentchanges'   => 'ЦӀиял хиса-басал',
+'rcshowhideminor' => '$1 гӀиси-микъинал хиса-басал',
 'rcshowhidebots'  => '$1 бот',
-'rcshowhideliu'   => '$1 цIар рагьарал гIахьалчагIи',
-'rcshowhideanons' => '$1 цIаргьечI',
+'rcshowhideliu'   => '$1 цӀар рагьарал гӀахьалчагӀи',
+'rcshowhideanons' => '$1 цӀаргьечӀ',
 'rcshowhidemine'  => '$1 дир хиса-басал',
-'diff'            => 'батIалъи',
+'diff'            => 'батӀалъи',
 'hide'            => 'Бахчизе',
 'show'            => 'Бихьизабизе',
-'minoreditletter' => 'гI.-м.',
-'newpageletter'   => 'ЦI',
+'minoreditletter' => 'гӀ.-м.',
+'newpageletter'   => 'ЦӀ',
 
 # Recent changes linked
-'recentchangeslinked' => 'Рухьарал хиса-басиял',
+'recentchangeslinked'         => 'Рухьарал хиса-басиял',
+'recentchangeslinked-feed'    => 'Рухьарал хиса-басиял',
+'recentchangeslinked-toolbox' => 'Рухьарал хиса-басиял',
 
 # Upload
-'uploadnologin' => 'Дуца цIар бицун гьечIо',
+'uploadnologin' => 'Дуца цӀар бицун гьечӀо',
 
 # Random page
 'randompage' => 'Цебе ккараб гьумер',
@@ -101,20 +102,20 @@ $messages = array(
 'listusers'  => 'Гlахьалчагlазул сияхl',
 
 # Special:Log
-'specialloguserlabel' => 'ГIахьалчи:',
+'specialloguserlabel' => 'ГӀахьалчи:',
 
 # Special:AllPages
 'allarticles' => 'Киналго макъалаби',
 
 # Special:Log/newusers
-'newuserlog-create-entry' => 'ЦIияв гIахьалчи',
+'newuserlog-create-entry' => 'ЦӀияв гӀахьалчи',
 
 # Watchlist
 'watchlist' => 'Дур халгьабиялъул сияхl',
 'watch'     => 'хал гьабизе',
 
 # Contributions
-'contributions' => 'ГIахьалчиясул хIалтIи',
+'contributions' => 'ГӀахьалчиясул хӀалтӀи',
 'mycontris'     => 'Дур гlахьаллъи',
 
 # What links here
@@ -122,9 +123,12 @@ $messages = array(
 
 # Move page
 'move-page-legend' => 'Гьумералъул цlар хисизе',
-'movearticle'      => 'Гьумералъул цIар хисизе',
+'movearticle'      => 'Гьумералъул цӀар хисизе',
 'movepagebtn'      => 'Гьумералъул цlар хисизе',
 
+# Math errors
+'math_unknown_error' => 'Лъалареб гъалатӀ',
+
 # Special:SpecialPages
 'specialpages' => 'Хассал гьумерал',
 
