@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Iketsi
  * @author Ushanka
  */
 
@@ -60,13 +61,15 @@ $messages = array(
 'oct'           => 'Okt',
 'dec'           => 'Des',
 
+'mypage' => 'Pej blong mi',
+'mytalk' => 'Tingting blong mi',
+'and'    => '&#32;mo',
+
+# Cologne Blue skin
 'qbedit'         => 'Jenisim hem',
 'qbpageoptions'  => 'Pej ia',
 'qbmyoptions'    => 'Ol pej blong mi',
 'qbspecialpages' => 'Ol spesel pej',
-'mypage'         => 'Pej blong mi',
-'mytalk'         => 'Tingting blong mi',
-'and'            => '&#32;mo',
 
 'edit'             => 'Jenisim hem',
 'newpage'          => 'Mekem niu pej',
@@ -110,6 +113,8 @@ $messages = array(
 # Contributions
 'year' => 'Yia:',
 
+'sp-contributions-talk' => 'toktok',
+
 # Block/unblock
 'proxyblocksuccess' => 'Finis.',
 
