@@ -43,6 +43,9 @@ $messages = array(
 
 'help'           => 'Dɛmɛ',
 'search'         => 'Nyini',
+'searchbutton'   => 'Nyini',
+'go'             => 'Taa',
+'searcharticle'  => 'Taa',
 'history'        => 'Nyɛka tariku',
 'history_short'  => 'Tariku',
 'info_short'     => 'Kunnafoni',
@@ -55,6 +58,7 @@ $messages = array(
 'userpage'       => 'Utilisateur ka nyɛ',
 'imagepage'      => 'Janin ka nyɛ',
 'otherlanguages' => 'Kanw wɛrɛ',
+'jumptosearch'   => 'Nyini',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'currentevents'        => 'Kunnafoni',
@@ -111,6 +115,9 @@ $messages = array(
 # Special:Categories
 'categories' => 'Nyɛ ka cogoyaw',
 
+# Special:LinkSearch
+'linksearch-ok' => 'Nyini',
+
 # Watchlist
 'watch'         => 'Tulomajɔ',
 'watchthispage' => 'Nyɛ tulomajɔ',
