@@ -9,6 +9,7 @@
  *
  * @author Behdarvandyani
  * @author GerardM
+ * @author Huji
  * @author Meno25
  */
 
@@ -28,8 +29,7 @@ $messages = array(
 'tog-editsection'             => 'امکان اصلاح یه قسمت زه راه لینکها',
 'tog-editsectiononrightclick' => 'امکان اصلاح یه قسمت زه راه راست کلیک کردن رو عنوان  اوقسمت- جاوااسکریپت',
 'tog-showtoc'                 => 'نشودادن فهرست محتوا سی صفحاتی که بیشتر زه سه سرخط دارن',
-'tog-rememberpassword'        => 'به حافظه کامپیوتر دادن نحوه ورودی خوم',
-'tog-editwidth'               => 'اصلاح جعبه یا کادری که عرضا پر وابیده',
+'tog-rememberpassword'        => 'به حافظه کامپیوتر دادن نحوه ورودی خوم (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'          => 'اضاف کردن اوصفحاتی که خوم درست کردم به فهرست نمایشی',
 'tog-watchdefault'            => 'اضاف کردن اوصفحاتی که خوم اصلاح کردم به فهرست نمایشی',
 'tog-watchmoves'              => 'اضاف کردن صفحاتی که خوم جابجا کردم به فهرست نمایشی',
@@ -258,7 +258,7 @@ $1',
 # Login and logout pages
 'yourname'                => 'نام کاربر:',
 'yourpassword'            => 'رمز:',
-'remembermypassword'      => 'رمز اویدن به سیستم را دراین رایانه به خاطر بسپار',
+'remembermypassword'      => 'رمز اویدن به سیستم را دراین رایانه به خاطر بسپار (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'                   => 'اویدن به سیستم',
 'nav-login-createaccount' => 'اویدن به سیستم',
 'loginprompt'             => 'ایسا وا کوکی ها رافعال کنین سی اویدن به  {{SITENAME}}.',
@@ -360,9 +360,6 @@ $1',
 
 ایر نه خوین نوشته‌هاتو بی‌رحمانه اصلاح بوه و به دلخواه ارسال بوه، ایچو نفرستن.<br />
 درضمن ایسادارین به ایما قول ادین که خودتو یونه نوشتین یا هونه زه یک منبع آزاد با مالکیت عمومی یا مثل هو ورداشتین. '''کارهای دارای کارهای دارای حق کپی رایت را بی‌اجازه نفرستین!'''',",
-'longpagewarning'            => "'''هشدار: ای صفحه $1 کیلوبایت طول داره؛
-بعضی زه مرورگرها ممکنه با اصلاح صفحات نزدیک به ۳۲ کیلوبایت یا طولانی‌تر زه آن مشکلاتی داشته بون.
-لطفاً درمورد خرد کردن ای صفحه به قسمت‌های کوچکتر فکر کنین.'''",
 'templatesused'              => 'قالبهای استفاده شده من ای صفحه:',
 'templatesusedpreview'       => 'قالبها  یا الگوهای استفاده وابیده در ای پیش نمایش:',
 'template-protected'         => '(تحت حمایت)',
@@ -560,7 +557,6 @@ $2',
 # Watchlist
 'watchlist'         => 'لیست پیگیریهای مو',
 'mywatchlist'       => 'لیست پیگیریهای مو',
-'watchlistfor'      => "(سی '''$1''')",
 'addedwatch'        => 'اضاف وابید به لیست پیگیری',
 'addedwatchtext'    => "صفحه «<nowiki>$1</nowiki>» به [[Special:Watchlist|لیست پی‌گیری‌های ]] ایسا
 اضاف وابید.
@@ -618,7 +614,7 @@ $2',
 'protect-expiring'            => 'سپری وابیده $1 (UTC)',
 'protect-cascade'             => 'حمایت صفحات دربرگیرنده در ای صفحه (cascading protection)',
 'protect-cantedit'            => 'ایسا نترین تغییر بدین سطوح حمایتی ای صفحه را, زیرا ایسا اجازه اصلاح آن را ندارین.',
-'protect-expiry-options'      => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌پایان:infinite',
+'protect-expiry-options'      => '۱ ساعت:1 hour,۱ روز:1 day,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌نهایت:infinite',
 'restriction-type'            => 'اجازه:',
 'restriction-level'           => 'سطح محدودیت:',
 
@@ -655,7 +651,7 @@ $2',
 
 # Block/unblock
 'blockip'       => 'بستن کاربر',
-'ipboptions'    => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌پایان:infinite',
+'ipboptions'    => '۲ ساعت:2 hours,۱ روز:1 day,۳ روز:3 days,۱ هفته:1 week,۲ هفته:2 weeks,۱ ماه:1 month,۳ ماه:3 months,۶ ماه:6 months,۱ سال:1 year,بی‌نهایت:infinite',
 'ipblocklist'   => 'آدرسهای  آی پی وکاربران بسته وابیدند',
 'blocklink'     => 'بسته بوه !',
 'unblocklink'   => 'باز بوه',
@@ -776,9 +772,9 @@ $2',
 'nextdiff'     => 'تفاوت بعدی→',
 
 # Media information
-'file-info-size'       => '($1 × $2 پیکسل, اندازه فایل: $3, MIME نوع: $4)',
+'file-info-size'       => '$1 × $2 پیکسل, اندازه فایل: $3, MIME نوع: $4',
 'file-nohires'         => '<small>قابلیت تفکیک بالاتری در دسترس نه.</small>',
-'svg-long-desc'        => '(SVG فایل, تقریبا$1 × $2 پیکسل, اندازه فایل: $3)',
+'svg-long-desc'        => 'SVG فایل, تقریبا$1 × $2 پیکسل, اندازه فایل: $3',
 'show-big-image'       => 'تصویر با قابلیت تفکیک کامل',
 'show-big-image-thumb' => '<کوچیک>اندازه پیش نمایش: $1 × $2 پیکسلها</کوچیک>',
 
