@@ -79,8 +79,7 @@ $messages = array(
 'tog-editsection'             => 'Mausab ang mga seksiyon gamit ang [usba] nga sumpay',
 'tog-editsectiononrightclick' => 'Mahimo ang pag-usab sa seksyon pinaagi sa pag-right click sa titulo sa seksyon (JavaScript kinahanglan)',
 'tog-showtoc'                 => 'Ipakita ang talaan sa sulod (alang sa mga panid nga may daghan pa sa 3 ka heading)',
-'tog-rememberpassword'        => 'Hinumdomi ako sa kining kompyuter',
-'tog-editwidth'               => 'Palapdan ang kahon sa pag-usab aron mapuno sa tibuok screen',
+'tog-rememberpassword'        => 'Hinumdomi ako sa kining kompyuter (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'          => 'Bantayi ang akong gisugdang mga panid',
 'tog-watchdefault'            => 'Bantayi ang akong giusab nga mga panid',
 'tog-watchmoves'              => 'Bantayi ang akong gibalhin nga mga panid',
@@ -222,31 +221,20 @@ $messages = array(
 'faqpage'        => 'Project:FAQ',
 
 # Vector skin
-'vector-action-addsection'   => 'Pagdugang og topiko',
-'vector-action-delete'       => 'Papasa',
-'vector-action-move'         => 'Ibalhin',
-'vector-action-protect'      => 'Protektahi',
-'vector-action-undelete'     => 'Ayaw papasa',
-'vector-action-unprotect'    => 'Ayaw protektahi',
-'vector-namespace-category'  => 'Kategoriya',
-'vector-namespace-help'      => 'Panid sa tabang',
-'vector-namespace-image'     => 'Payl',
-'vector-namespace-main'      => 'Panid',
-'vector-namespace-media'     => 'Panid sa medya',
-'vector-namespace-mediawiki' => 'Mensahe',
-'vector-namespace-project'   => 'Panid sa proyekto',
-'vector-namespace-special'   => 'Espesyal nga panid',
-'vector-namespace-talk'      => 'Panaghisgot-hisgot',
-'vector-namespace-template'  => 'Plantilya',
-'vector-namespace-user'      => 'Panid sa tiggamit',
-'vector-view-create'         => 'Himoa',
-'vector-view-edit'           => 'Usba',
-'vector-view-history'        => 'Tan-awa ang kaagi',
-'vector-view-view'           => 'Basaha',
-'vector-view-viewsource'     => 'Tan-awa ang ginikanan',
-'actions'                    => 'Mga lihok',
-'namespaces'                 => 'Mga ngalang espasyo',
-'variants'                   => 'Mga baryant',
+'vector-action-addsection' => 'Pagdugang og topiko',
+'vector-action-delete'     => 'Papasa',
+'vector-action-move'       => 'Ibalhin',
+'vector-action-protect'    => 'Protektahi',
+'vector-action-undelete'   => 'Ayaw papasa',
+'vector-action-unprotect'  => 'Ayaw protektahi',
+'vector-view-create'       => 'Himoa',
+'vector-view-edit'         => 'Usba',
+'vector-view-history'      => 'Tan-awa ang kaagi',
+'vector-view-view'         => 'Basaha',
+'vector-view-viewsource'   => 'Tan-awa ang ginikanan',
+'actions'                  => 'Mga lihok',
+'namespaces'               => 'Mga ngalang espasyo',
+'variants'                 => 'Mga baryant',
 
 'errorpagetitle'    => 'Sayop',
 'returnto'          => 'Balik sa $1.',
@@ -470,7 +458,7 @@ Ayaw kalimot sa pag-usab sa imong [[Special:Preferences|{{SITENAME}} mga prepere
 'yourname'                => 'Ngalan sa tiggamit:',
 'yourpassword'            => 'Pasword:',
 'yourpasswordagain'       => 'Itayp og usab ang pasword:',
-'remembermypassword'      => 'Hinumdomi ako niini nga kompyuter',
+'remembermypassword'      => 'Hinumdomi ako niining brawser (sa kadugayon nga $1 {{PLURAL:$1|ka adlaw|ka mga adlaw}})',
 'yourdomainname'          => 'Ang imong domain:',
 'externaldberror'         => 'May nahitabong authentication database error o kaha wala ka tugoti nga mag-update sa imong eksternal nga akawnt.',
 'login'                   => 'Sulod',
@@ -1026,7 +1014,6 @@ Also see [[Special:WantedCategories|wanted categories]].',
 # Watchlist
 'watchlist'         => 'Akong gibantayan',
 'mywatchlist'       => 'Akong gibantayan',
-'watchlistfor'      => "(para kang '''$1''')",
 'addedwatch'        => 'Nadugang sa gibantayan',
 'addedwatchtext'    => "Ang panid \"[[:\$1]]\" nadugang na sa imong [[Special:Watchlist|gibantayan]].
 Ang mga pag-usab puhon sa kining panid ug ang kaubang panid sa hisgot dinhi maitala, ug ang panid mopakita nga '''nakalugom''' sa [[Special:RecentChanges|talaan sa mga bag-ong pag-usab]] aron dali kini pilion.",
@@ -1240,9 +1227,9 @@ Puyde dugangan og rason sa mubong sugid.',
 'nextdiff'     => 'Mas bag-ong pag-usab →',
 
 # Media information
-'file-info-size'       => '($1 × $2 pixels, size sa payl: $3, MIME type: $4)',
+'file-info-size'       => '$1 × $2 pixels, size sa payl: $3, MIME type: $4',
 'file-nohires'         => '<small>Walay mas taas nga resolusyon.</small>',
-'svg-long-desc'        => '(SVG nga payl, nominally $1 × $2 pixels, size sa payl: $3)',
+'svg-long-desc'        => 'SVG nga payl, nominally $1 × $2 pixels, size sa payl: $3',
 'show-big-image'       => 'Tibuok resolusyon',
 'show-big-image-thumb' => '<small>Size niining preview: $1 × $2 pixels</small>',
 
