@@ -70,18 +70,25 @@ $messages = array(
 'category_header' => 'Articuli in a categuria "$1"',
 'subcategories'   => 'Sottucategurie',
 
-'about'          => 'À prupositu',
-'article'        => 'Articulu',
-'cancel'         => 'Annullà',
+'about'      => 'À prupositu',
+'article'    => 'Articulu',
+'cancel'     => 'Annullà',
+'mypage'     => 'A mo pagina',
+'mytalk'     => 'E mo discussioni',
+'anontalk'   => 'Discussione per istu indirizzu IP',
+'navigation' => 'Navigazione',
+'and'        => '&#32;è',
+
+# Cologne Blue skin
 'qbpageoptions'  => 'Issa pagina',
 'qbpageinfo'     => 'Cuntestu',
 'qbmyoptions'    => 'E mo pagine',
 'qbspecialpages' => 'Pagine spiciale',
-'mypage'         => 'A mo pagina',
-'mytalk'         => 'E mo discussioni',
-'anontalk'       => 'Discussione per istu indirizzu IP',
-'navigation'     => 'Navigazione',
-'and'            => '&#32;è',
+
+# Vector skin
+'vector-action-delete'  => 'Supprimà',
+'vector-action-protect' => 'Pruteghje',
+'vector-view-edit'      => 'Mudificà',
 
 'errorpagetitle'   => 'Errore',
 'returnto'         => 'Vultà à $1.',
@@ -108,7 +115,7 @@ $messages = array(
 'toolbox'          => 'Stuvigli',
 'userpage'         => 'Vede a pagina di utilizatore',
 'otherlanguages'   => 'In altri lingui',
-'lastmodifiedat'   => 'Ultima mudifica di ista pagina u $1 à e $2.', # $1 date, $2 time
+'lastmodifiedat'   => 'Ultima mudifica di ista pagina u $1 à e $2.',
 'protectedpage'    => 'Pagina prutetta',
 'jumptonavigation' => 'navigazione',
 'jumptosearch'     => 'ricerca',
@@ -132,6 +139,7 @@ $messages = array(
 'newmessagesdifflink' => 'ultima mudifica',
 'editsection'         => 'mudificà',
 'editold'             => 'mudificà',
+'editlink'            => 'mudificà',
 'toc'                 => 'Cuntenutu',
 'showtoc'             => 'mustrà',
 'hidetoc'             => 'piattà',
@@ -163,11 +171,7 @@ $messages = array(
 'nologinlink'                => 'Registramentu',
 'createaccount'              => 'Registramentu',
 'gotaccountlink'             => 'Cunnessione',
-'youremail'                  => 'Indirizzu e-mail:',
-'yourrealname'               => 'U to veru nome:',
-'yourlanguage'               => "Lingua di l'interfaccia:",
-'yourvariant'                => 'Variante',
-'yournick'                   => 'Signatura pè e discussioni:',
+'createaccountreason'        => 'Mutivu:',
 'loginsuccesstitle'          => 'Cunnessione fatta',
 'acct_creation_throttle_hit' => "Desulatu, ai digià fattu $1 registramenti. Ùn ne poi micca fà d'altri.",
 'accountcreated'             => 'Registramentu fattu',
@@ -205,7 +209,6 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 # History pages
 'currentrev'  => 'Ultima revisione',
 'page_first'  => 'prima',
-'deletedrev'  => '[supprimatu]',
 'histfirst'   => 'Prima',
 'histlast'    => 'Ultima',
 'historysize' => '({{PLURAL:$1|1 ottettu|$1 ottetti}})',
@@ -214,7 +217,11 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'history-feed-title' => 'Cronolugia di e revisione',
 
 # Revision deletion
-'rev-delundel' => 'mustrà/piattà',
+'rev-delundel'  => 'mustrà/piattà',
+'revdelete-log' => 'Mutivu:',
+
+# History merging
+'mergehistory-reason' => 'Mutivu:',
 
 # Search results
 'searchresults' => 'Risultati di a ricerca',
@@ -223,19 +230,24 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 # Preferences page
 'preferences'       => 'Preferenze',
 'mypreferences'     => 'Preferenze',
-'math'              => 'Matematica',
-'math_syntax_error' => 'errore di sintassa',
+'prefs-math'        => 'Matematica',
 'prefs-rc'          => 'Ultimi cambiamenti',
 'prefs-watchlist'   => 'Articuli seguitati',
 'columns'           => 'Culonne:',
 'searchresultshead' => 'Ricerca',
 'localtime'         => 'Ora lucale',
 'allowemail'        => 'Abilità a ricezzione di e-mail da altri utilizatori',
-'files'             => 'Schedarii',
+'prefs-files'       => 'Schedarii',
+'youremail'         => 'Indirizzu e-mail:',
+'yourrealname'      => 'U to veru nome:',
+'yourlanguage'      => "Lingua di l'interfaccia:",
+'yourvariant'       => 'Variante',
+'yournick'          => 'Signatura pè e discussioni:',
 
 # User rights
 'editinguser'             => "Mudifica di '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]]{{int:pipe-separator}}[[Special:Contributions/$1|{{int:contribslink}}]])",
 'userrights-groupsmember' => 'Membru di:',
+'userrights-reason'       => 'Mutivu:',
 
 # Groups
 'group'            => 'Gruppu:',
@@ -267,7 +279,9 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'show'            => 'mustrà',
 
 # Recent changes linked
-'recentchangeslinked' => 'Cambiamenti assuciati',
+'recentchangeslinked'         => 'Cambiamenti assuciati',
+'recentchangeslinked-feed'    => 'Cambiamenti assuciati',
+'recentchangeslinked-toolbox' => 'Cambiamenti assuciati',
 
 # Upload
 'upload'     => 'Incaricà un schedariu',
@@ -284,10 +298,18 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'listfiles_user' => 'Utilizatore',
 
 # File description page
-'filehist'         => "Cronolugia di l'imagine",
-'filehist-user'    => 'Utilizatore',
-'imagelinks'       => 'Ligami',
-'noimage-linktext' => 'incaricà lu',
+'file-anchor-link'   => 'Schedariu',
+'filehist'           => "Cronolugia di l'imagine",
+'filehist-deleteone' => 'supprimà',
+'filehist-user'      => 'Utilizatore',
+'imagelinks'         => 'Ligami',
+
+# File reversion
+'filerevert-comment' => 'Mutivu:',
+
+# File deletion
+'filedelete-comment' => 'Mutivu:',
+'filedelete-submit'  => 'Supprimà',
 
 # Unused templates
 'unusedtemplateswlh' => 'altri ligami',
@@ -299,7 +321,7 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'statistics'              => 'Statistiche',
 'statistics-header-users' => "Statistiche nant'à l'utilizatori",
 
-'brokenredirects-edit' => '(mudificà)',
+'brokenredirects-edit' => 'mudificà',
 
 # Miscellaneous special pages
 'ncategories'       => '$1 {{PLURAL:$1|categuria|categurie}}',
@@ -341,17 +363,16 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'listusers-submit' => 'Mustrà',
 
 # E-mail user
-'emailto'      => 'À',
-'emailsubject' => 'Sughjettu',
-'emailmessage' => 'Messaghju',
+'emailto'      => 'À:',
+'emailsubject' => 'Sughjettu:',
+'emailmessage' => 'Messaghju:',
 'emailsend'    => 'Invià',
 
 # Watchlist
-'watchlist'    => 'Articuli seguitati',
-'mywatchlist'  => 'Articuli seguitati',
-'watchlistfor' => "(di l'ultizatore '''$1''')",
-'addedwatch'   => "Aghjuntu à u listinu di l'articuli seguitati",
-'watch'        => 'Seguità',
+'watchlist'   => 'Articuli seguitati',
+'mywatchlist' => 'Articuli seguitati',
+'addedwatch'  => "Aghjuntu à u listinu di l'articuli seguitati",
+'watch'       => 'Seguità',
 
 'enotif_reset'       => 'Marcà tutte e pagine visitate',
 'enotif_newpagetext' => 'Ista hè una pagina nova.',
@@ -363,15 +384,19 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'excontent'       => "u cuntenutu era: '$1'",
 'excontentauthor' => "u cuntenutu era: '$1' (è u solu cuntributore era '[[Special:Contributions/$2|$2]]')",
 'exblank'         => 'a pagina era biota',
+'delete-legend'   => 'Supprimà',
 'actioncomplete'  => 'Azzione compia',
+'deletecomment'   => 'Mutivu:',
 
 # Protect
 'protectedarticle'            => 'prutettu "[[$1]]"',
 'prot_1movedto2'              => 'hà mossu [[$1]] à [[$2]]',
 'protect-legend'              => 'Cunfirmà a prutezzione',
+'protectcomment'              => 'Mutivu:',
 'protect-level-autoconfirmed' => 'Bluccà i cuntributori micca arrighjistrati',
 
 # Restrictions (nouns)
+'restriction-edit'   => 'Mudificà',
 'restriction-create' => 'Creà',
 
 # Restriction levels
@@ -379,7 +404,7 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 
 # Undelete
 'viewdeletedpage'        => 'Fighjulà e p agine supprimate',
-'undeletecomment'        => 'Cummentu:',
+'undeletecomment'        => 'Mutivu:',
 'undelete-search-box'    => 'Circà e pagine supprimate',
 'undelete-search-submit' => 'Ricerca',
 
@@ -393,12 +418,15 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'contribsub2'   => 'Per $1 ($2)',
 'month'         => 'Da u mese (è nanzu):',
 
+'sp-contributions-talk' => 'discussione',
+
 # What links here
 'istemplate' => 'inclusione',
 
 # Block/unblock
 'ipaddress'                => 'Adrizzu IP',
 'ipadressorusername'       => 'Adrizzu IP o nome di cuntributore',
+'ipbreason'                => 'Mutivu:',
 'ipblocklist-submit'       => 'Ricerca',
 'blocklistline'            => '$1, $2 bluccati $3 ($4)',
 'anononlyblock'            => 'solu i cuntributori anonimi',
@@ -418,7 +446,7 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 '1movedto2'               => 'hà mossu [[$1]] à [[$2]]',
 '1movedto2_redir'         => 'hà reindirizzatu [[$1]] à [[$2]]',
 'movelogpagetext'         => 'Elencu di e pagine mosse.',
-'movereason'              => 'Mutivu',
+'movereason'              => 'Mutivu:',
 'delete_and_move_confirm' => 'Iè, supprimà issa pagina',
 
 # Export
@@ -433,8 +461,6 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'allmessagescurrent'        => 'Testu attuale',
 'allmessagestext'           => 'Istu hè u listinu di tutti i messaghji dispunibili in u spaziu MediaWiki.',
 'allmessagesnotsupportedDB' => "'''{{ns:special}}:Allmessages''' ùn hè dispunibile perchè '''\$wgUseDatabaseMessages''' ùn hè micca attivu.",
-'allmessagesfilter'         => "Filtru nant'à i messaghji:",
-'allmessagesmodified'       => 'Mustrà solu i mudificati',
 
 # Special:Import
 'import-interwiki-submit' => 'Impurtà',
@@ -461,9 +487,12 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'tooltip-ca-nstab-user'  => 'Vede a pagina di utilizatore',
 
 # Attribution
-'anonymous' => 'Utilizatore(/i) anonimu(/i) di {{SITENAME}}',
+'anonymous' => '{{PLURAL:$1|Utilizatore anonimu|Utilizatori anonimi}} di {{SITENAME}}',
 'others'    => 'altri',
 
+# Math errors
+'math_syntax_error' => 'errore di sintassa',
+
 # Media information
 'show-big-image' => 'Imagine in alta resoluzione',
 
@@ -479,7 +508,7 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'exif-artist'           => 'Autore',
 'exif-usercomment'      => "Cummenti di l'utilizatore",
 
-'exif-orientation-1' => 'Nurmale', # 0th row: top; 0th column: left
+'exif-orientation-1' => 'Nurmale',
 
 'exif-componentsconfiguration-0' => 'ùn esiste micca',
 
@@ -513,7 +542,7 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 'watchlistedit-raw-titles' => 'Pagine:',
 
 # Special:Version
-'version' => 'Versione', # Not used as normal message but as header for the special page itself
+'version' => 'Versione',
 
 # Special:FilePath
 'filepath-page' => 'Schedariu:',
@@ -521,4 +550,7 @@ U to indirizzu IP serà registratu indu a cronolugia di ista pagina.",
 # Special:SpecialPages
 'specialpages' => 'Pagine spiciale',
 
+# Special:Tags
+'tags-edit' => 'mudificà',
+
 );
