@@ -53,8 +53,7 @@ $messages = array(
 'tog-editsection'             => '«Тӳрлет» ссылкăна кашни пайра кăтартмалла',
 'tog-editsectiononrightclick' => 'Шăшин сылтăм пускăчне пуссан статья пайне тӳрлетмелле (JavaScript)',
 'tog-showtoc'                 => 'Тупмаллине кăтартмалла (3, е ытларах заголовок пулсан)',
-'tog-rememberpassword'        => 'Мана ку компьютер çинче астуса хăвармалла',
-'tog-editwidth'               => 'Тӳрлетмелли чӳречене браузерăн пĕтĕм сарлакăшĕпе кăтартмалла',
+'tog-rememberpassword'        => 'Мана ку компьютер çинче астуса хăвармалла (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'          => 'Эпĕ тунă страницăсене сăнав списокне кĕртмелле',
 'tog-watchdefault'            => 'Тӳрлетнĕ страницăсене сăнав списокне кĕртмелле',
 'tog-watchmoves'              => 'Страница ятне эпĕ улаштарсан вĕсене сăнав списокне кĕртмелле',
@@ -185,24 +184,14 @@ $messages = array(
 'faqpage'        => 'Project:ЫйХу',
 
 # Vector skin
-'vector-action-addsection'   => 'Тема хуш',
-'vector-action-delete'       => 'Кăларса пăрах',
-'vector-action-move'         => 'Ятне улăштар',
-'vector-action-protect'      => 'Хӳтĕле',
-'vector-namespace-category'  => 'Категори',
-'vector-namespace-help'      => 'Пулăшу страници',
-'vector-namespace-image'     => 'Файл',
-'vector-namespace-main'      => 'Страница',
-'vector-namespace-mediawiki' => 'Пĕлтерӳ',
-'vector-namespace-project'   => 'Проект çинчен',
-'vector-namespace-special'   => 'Ятарлă страницă',
-'vector-namespace-talk'      => 'Сӳтсе яв',
-'vector-namespace-template'  => 'Шаблон',
-'vector-namespace-user'      => 'Хутшăнакан страници',
-'vector-view-create'         => 'Çĕннине ту',
-'vector-view-edit'           => 'Тӳрлет',
-'vector-view-history'        => 'Кун-çул',
-'vector-view-view'           => 'Вула',
+'vector-action-addsection' => 'Тема хуш',
+'vector-action-delete'     => 'Кăларса пăрах',
+'vector-action-move'       => 'Ятне улăштар',
+'vector-action-protect'    => 'Хӳтĕле',
+'vector-view-create'       => 'Çĕннине ту',
+'vector-view-edit'         => 'Тӳрлет',
+'vector-view-history'      => 'Кун-çул',
+'vector-view-view'         => 'Вула',
 
 'errorpagetitle'    => 'Йăнăш',
 'returnto'          => '$1 страницăна таврăн.',
@@ -407,7 +396,7 @@ $1',
 'yourname'                   => 'Сирĕн ят',
 'yourpassword'               => 'Вăрттăн сăмах:',
 'yourpasswordagain'          => 'Вăрттăн сăмах тепре çырăр:',
-'remembermypassword'         => 'Ку компьютер çинче мана астуса хăвармалла',
+'remembermypassword'         => 'Ку компьютер çинче мана астуса хăвармалла (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => 'Сирĕн домен',
 'login'                      => 'Сайта кĕр',
 'nav-login-createaccount'    => 'Сайта кĕр / регистрацилен',
@@ -694,30 +683,26 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'rightsnone'    => '(çук)',
 
 # Recent changes
-'recentchanges'                    => 'Улшăнусем',
-'recentchanges-legend'             => 'Çĕнĕ улшăнусен ĕнерлевĕ',
-'recentchanges-legend-newpage'     => '$1 — çĕнĕ страница',
-'recentchanges-legend-minor'       => '$1 — пĕчĕк улшăну',
-'recentchanges-legend-bot'         => '$1 — бот улăштарни',
-'recentchanges-label-bot'          => 'Ку улшăнăва бот тунă',
-'recentchanges-legend-unpatrolled' => '$1 — тĕрĕслемен улшăну',
-'rcnote'                           => 'Юлашки <strong>$2</strong> кун хушшинчи <strong>$1</strong> улшăнусем. Халě пěтěмпе  <strong>{{NUMBEROFARTICLES}}</strong> статья.',
-'rclistfrom'                       => 'Юлашки улшăнусене $1 вăхăтран пуçласа кăтартнă',
-'rcshowhideminor'                  => 'пĕчĕк тӳрлетӳсене $1',
-'rcshowhidebots'                   => 'ботсене $1',
-'rcshowhideliu'                    => 'сайта кĕнĕскерсене $1',
-'rcshowhideanons'                  => 'ячĕсене палăртманскерсене $1',
-'rcshowhidepatr'                   => 'тĕрĕсленĕ тӳрлетӳсене $1',
-'rcshowhidemine'                   => 'хăвăн тӳрлетӳсене $1',
-'rclinks'                          => 'Юлашки $2 кун хушшинче тунă $1 улшăнусене кăтартмалла<br />$3',
-'diff'                             => 'танл.',
-'hist'                             => 'истори',
-'hide'                             => 'кăтартмалла мар',
-'show'                             => 'кăтартмалла',
-'minoreditletter'                  => 'п',
-'newpageletter'                    => 'Ç',
-'rc_categories_any'                => 'Кашни',
-'newsectionsummary'                => '/* $1 */ Çĕнĕ тема',
+'recentchanges'           => 'Улшăнусем',
+'recentchanges-legend'    => 'Çĕнĕ улшăнусен ĕнерлевĕ',
+'recentchanges-label-bot' => 'Ку улшăнăва бот тунă',
+'rcnote'                  => 'Юлашки <strong>$2</strong> кун хушшинчи <strong>$1</strong> улшăнусем. Халě пěтěмпе  <strong>{{NUMBEROFARTICLES}}</strong> статья.',
+'rclistfrom'              => 'Юлашки улшăнусене $1 вăхăтран пуçласа кăтартнă',
+'rcshowhideminor'         => 'пĕчĕк тӳрлетӳсене $1',
+'rcshowhidebots'          => 'ботсене $1',
+'rcshowhideliu'           => 'сайта кĕнĕскерсене $1',
+'rcshowhideanons'         => 'ячĕсене палăртманскерсене $1',
+'rcshowhidepatr'          => 'тĕрĕсленĕ тӳрлетӳсене $1',
+'rcshowhidemine'          => 'хăвăн тӳрлетӳсене $1',
+'rclinks'                 => 'Юлашки $2 кун хушшинче тунă $1 улшăнусене кăтартмалла<br />$3',
+'diff'                    => 'танл.',
+'hist'                    => 'истори',
+'hide'                    => 'кăтартмалла мар',
+'show'                    => 'кăтартмалла',
+'minoreditletter'         => 'п',
+'newpageletter'           => 'Ç',
+'rc_categories_any'       => 'Кашни',
+'newsectionsummary'       => '/* $1 */ Çĕнĕ тема',
 
 # Recent changes linked
 'recentchangeslinked'         => 'Çыхăннă улшăнусем',
@@ -726,36 +711,36 @@ $1 хутшăнакан патне, е ытти [[{{MediaWiki:Grouppage-sysop}}|
 'recentchangeslinked-page'    => 'Страница ячĕ:',
 
 # Upload
-'upload'             => 'Файла кĕртесси',
-'uploadbtn'          => 'Файла кĕрт',
-'uploadnologin'      => 'Эсир сайта кĕмен.',
-'uploadnologintext'  => 'Файла кĕртес умĕн сирĕн малтан [[Special:UserLogin|сайта кĕмелле]].',
-'uploaderror'        => 'Файла кĕртне чухне йăнăш пулчĕ',
-'uploadlog'          => 'Файлсене кĕртнин логĕ',
-'uploadlogpage'      => 'Файлсене кĕртнине кăтартакан журнал',
-'uploadlogpagetext'  => 'Аяларах эсир юлашкинчен кĕртнĕ файлсене куратăр.
+'upload'              => 'Файла кĕртесси',
+'uploadbtn'           => 'Файла кĕрт',
+'uploadnologin'       => 'Эсир сайта кĕмен.',
+'uploadnologintext'   => 'Файла кĕртес умĕн сирĕн малтан [[Special:UserLogin|сайта кĕмелле]].',
+'uploaderror'         => 'Файла кĕртне чухне йăнăш пулчĕ',
+'uploadlog'           => 'Файлсене кĕртнин логĕ',
+'uploadlogpage'       => 'Файлсене кĕртнине кăтартакан журнал',
+'uploadlogpagetext'   => 'Аяларах эсир юлашкинчен кĕртнĕ файлсене куратăр.
 Пур çĕрте те сервер вăхăтне (Гринвич тăрăх, UTC) кăтартнă.',
-'filedesc'           => 'Кĕскен ăнлантарни',
-'fileuploadsummary'  => 'Кĕске ăнлантару:',
-'filestatus'         => 'Усă курмалли майсем',
-'filesource'         => 'Çăлкуç',
-'uploadedfiles'      => 'Кĕртнĕ файлсем',
-'ignorewarning'      => 'Асăрхаттарусене пăхмасăр файла çав-çавах çырса хумалла.',
-'ignorewarnings'     => 'Асăрхаттарусене шута илмелле мар',
-'badfilename'        => 'Файл ятне $1 çине улăштарнă',
-'filetype-badmime'   => '"$1" MIME-тĕслĕ файлсене кĕртейместпĕр.',
-'filetype-missing'   => 'Файлăн хушма ячĕ тупăнмарĕ (тĕслĕхрен, «.jpg»).',
-'largefileserver'    => 'Файл пысăкăшĕ юрăхлинчен пысăкрах (пĕчĕклетĕр).',
-'successfulupload'   => 'Файла ăнăçлă тултартăмăр',
-'uploadwarning'      => 'Асăрхаттару',
-'savefile'           => 'Файла çырса хур',
-'uploadedimage'      => '«[[$1]]» кĕртрĕмĕр',
-'uploaddisabled'     => 'Каçарăр та сайта халĕ нимĕн те кĕртме юрамаст.',
-'uploaddisabledtext' => 'Ку вики-сайтра файлсене кĕртме чарнă.',
-'uploadvirus'        => 'Файл ăшĕнче вирус пур! $1 пăхăр.',
-'sourcefilename'     => 'Файлăн чăн ячĕ',
-'watchthisupload'    => 'Ку файла сăнав списокне кĕртмелле',
-'filewasdeleted'     => 'Ку ятла файл малтан пулнă, анчах та ăна кăларса пăрахнă. Тархасшăн, $1 кĕртес умĕн тĕрĕслĕр.',
+'filedesc'            => 'Кĕскен ăнлантарни',
+'fileuploadsummary'   => 'Кĕске ăнлантару:',
+'filestatus'          => 'Усă курмалли майсем',
+'filesource'          => 'Çăлкуç',
+'uploadedfiles'       => 'Кĕртнĕ файлсем',
+'ignorewarning'       => 'Асăрхаттарусене пăхмасăр файла çав-çавах çырса хумалла.',
+'ignorewarnings'      => 'Асăрхаттарусене шута илмелле мар',
+'badfilename'         => 'Файл ятне $1 çине улăштарнă',
+'filetype-badmime'    => '"$1" MIME-тĕслĕ файлсене кĕртейместпĕр.',
+'filetype-missing'    => 'Файлăн хушма ячĕ тупăнмарĕ (тĕслĕхрен, «.jpg»).',
+'largefileserver'     => 'Файл пысăкăшĕ юрăхлинчен пысăкрах (пĕчĕклетĕр).',
+'uploadwarning'       => 'Асăрхаттару',
+'savefile'            => 'Файла çырса хур',
+'uploadedimage'       => '«[[$1]]» кĕртрĕмĕр',
+'uploaddisabled'      => 'Каçарăр та сайта халĕ нимĕн те кĕртме юрамаст.',
+'uploaddisabledtext'  => 'Ку вики-сайтра файлсене кĕртме чарнă.',
+'uploadvirus'         => 'Файл ăшĕнче вирус пур! $1 пăхăр.',
+'sourcefilename'      => 'Файлăн чăн ячĕ',
+'watchthisupload'     => 'Ку файла сăнав списокне кĕртмелле',
+'filewasdeleted'      => 'Ку ятла файл малтан пулнă, анчах та ăна кăларса пăрахнă. Тархасшăн, $1 кĕртес умĕн тĕрĕслĕр.',
+'upload-success-subj' => 'Файла ăнăçлă тултартăмăр',
 
 'upload-proto-error' => 'Йăнăш протокол',
 'upload-file-error'  => 'Шалти йăнăш',
@@ -1162,8 +1147,8 @@ Also see [[Special:WantedCategories|wanted categories]].',
 'nextdiff' => 'Малаллахи тӳрлетӳ →',
 
 # Media information
-'file-info'      => '(файл пысăкăшĕ: $1, MIME-тĕсĕ: $2)',
-'file-info-size' => '($1 × $2 пиксел, файл пысăкăше: $3, MIME-тĕсĕ: $4)',
+'file-info'      => 'файл пысăкăшĕ: $1, MIME-тĕсĕ: $2',
+'file-info-size' => '$1 × $2 пиксел, файл пысăкăше: $3, MIME-тĕсĕ: $4',
 'file-nohires'   => '<small>Пысăкрах калăпăшли çук.</small>',
 
 # Special:NewFiles
