@@ -29,8 +29,7 @@ $messages = array(
 'tog-editsection'             => 'Bölümleri [diiştir] baalantılarılan diiştirmää hakkı ver',
 'tog-editsectiononrightclick' => 'Bölüm başlıına saa tuşla basarak bölümü düzmää izin ver.(JavaScript)',
 'tog-showtoc'                 => 'İçindäkiler tablițasını düz<br />(3-tän çok başlıı olan sayfalar için)',
-'tog-rememberpassword'        => 'Parolu hatırla',
-'tog-editwidth'               => 'Diiştirmää eri brauzer penceräsi büüklüktä olsun',
+'tog-rememberpassword'        => 'Parolu hatırla (en fazla $1 {{PLURAL:$1|gün|gün}})',
 'tog-watchcreations'          => 'Yarattıım sayfaları bakmaa listama ekle',
 'tog-watchdefault'            => 'Diişmäk yapılan sayfayı bakmaa listasına ekle',
 'tog-watchmoves'              => 'Bakmaa listama ekle o sayfaları angılarını taşıdım',
@@ -75,18 +74,18 @@ $messages = array(
 'thu'           => 'Per',
 'fri'           => 'Cumaa',
 'sat'           => 'Cts',
-'january'       => 'Yanvar',
-'february'      => 'Fevral',
-'march'         => 'Marta',
-'april'         => 'Aprel',
-'may_long'      => 'May',
-'june'          => 'İyün',
-'july'          => 'İyül',
-'august'        => 'Avgust',
-'september'     => 'Sentäbri',
-'october'       => 'Oktäbri',
-'november'      => 'Noyabri',
-'december'      => 'Dekabri',
+'january'       => 'Büük ay',
+'february'      => 'Küçük ay',
+'march'         => 'Baba Marta',
+'april'         => 'Çiçek ay',
+'may_long'      => 'Hederlez',
+'june'          => 'Kirez ay',
+'july'          => 'Orak ay',
+'august'        => 'Harman ay',
+'september'     => 'Ceviz ay',
+'october'       => 'Canavar ay',
+'november'      => 'Kasım',
+'december'      => 'Kırım ay',
 'january-gen'   => 'Büük ay',
 'february-gen'  => 'Küçük ay',
 'march-gen'     => 'Baba Marta',
@@ -156,6 +155,7 @@ $messages = array(
 
 # Vector skin
 'vector-view-edit' => 'Diiştir',
+'vector-view-view' => 'Oku',
 
 'errorpagetitle'    => 'Yannış',
 'returnto'          => '$1 dön.',
@@ -314,7 +314,7 @@ Esapınız açıldı. Unutmayın [[Special:Preferences|{{SITENAME}} preferences]
 'yourname'                   => 'Kullanıcı adınız',
 'yourpassword'               => 'Parol',
 'yourpasswordagain'          => 'Parolu enidän yaz',
-'remembermypassword'         => 'Parolu hatırla.',
+'remembermypassword'         => 'Parolu hatırla (en fazla $1 {{PLURAL:$1|gün|gün}} için)',
 'yourdomainname'             => 'Domen adınız',
 'login'                      => 'Gir',
 'nav-login-createaccount'    => 'Gir / esap yarat',
@@ -438,7 +438,6 @@ lițenziyası şartları içindä (detallar için $1'a bakınız).
 Herliim istemeersiniz ani sizin tekstlär serbest yayılsın hem diiştirilsin übür kullanıcılar tarafınnan, onnarı erleştirmeyniz buraya.<br />
 Hem siz garantiyada bulunêrsiniz ani eklemäklerin avtorusunuz, yaki onnarı kopiya ettiniz kaynaktan angısı izin verer teksti serbest yaymaa hem diiştirmää.<br />
 '''<center>AVTORLUK KORUNMAK HAKKILAN KORUNMAYAN MATERİALLAR EKLEMEYNİZ!</center>'''",
-'longpagewarning'                  => "'''BAK: Bu sayfanın ölçüsü $1 kilobayt; ölçüsü 32 kb-a yakın yaki onnan çok sayfalar bir takım brauzerlärdä var nicä yannış görünsün. Savaşênız onu bölümnerä ayırmaa.'''",
 'templatesused'                    => 'Bu sayfada kullanılan {{PLURAL:$1|şablon|şablonlar}}:',
 'templatesusedpreview'             => '{{PLURAL:$1|Şablon|Şablonnar}} ani bu ön siirdä kullanıldı:',
 'templatesusedsection'             => 'Bu bölümde kullanılan {{PLURAL:$1|şablon|şablonlar}}:',
@@ -657,6 +656,7 @@ Sizin bakmaa [[Special:Watchlist|listasındaki]] sayfalar verildi '''kalın''' b
 'statistics-edits'             => '{{SITENAME}} kurulmaa beeri yapmaa sayfa diişmäkleri',
 'statistics-edits-average'     => 'Her yapraktaki diişmäklerin sayısı',
 'statistics-views-total'       => 'Hepsi resimlär',
+'statistics-views-total-desc'  => 'Var nica olmadı hem maasus yapraklarından resim eklenmee',
 'statistics-views-peredit'     => 'Diişmäk başına resimlär',
 'statistics-users'             => 'Registratlı [[Special:ListUsers|kullanıcılar]]',
 'statistics-users-active'      => 'Aktivli kullanıcılar',
@@ -746,7 +746,6 @@ Sizin bakmaa [[Special:Watchlist|listasındaki]] sayfalar verildi '''kalın''' b
 # Watchlist
 'watchlist'         => 'Bakmaa listam',
 'mywatchlist'       => 'Bakmaa listam',
-'watchlistfor'      => "('''$1''' için)",
 'addedwatch'        => 'Bakmaa listasına registrat edildi.',
 'addedwatchtext'    => '"<nowiki>$1</nowiki>" adlı sayfa [[Special:Watchlist|bakmaa listanıza]] registrat olundu.
 
@@ -939,6 +938,8 @@ Yalvarêrêz başka bir ad seçmää.',
 'tooltip-search'                  => '{{SITENAME}} içindä ara',
 'tooltip-search-go'               => 'Herliim varsa, git salt bu adlı bir sayfaa',
 'tooltip-search-fulltext'         => 'Bu tekst için sayfaları aara',
+'tooltip-p-logo'                  => '
+Dönün baş yapraa',
 'tooltip-n-mainpage'              => 'Dönün baş yapraa',
 'tooltip-n-mainpage-description'  => 'Dönün baş yapraa',
 'tooltip-n-portal'                => 'Proyekt uurunda, ne nändä, nelär var nicä yapmaa',
@@ -979,9 +980,9 @@ Yalvarêrêz başka bir ad seçmää.',
 'nextdiff'     => 'Geerki versiyalan aradaki fark →',
 
 # Media information
-'file-info-size'       => '($1 × $2 piksel, fayl ölçüsü: $3, MIME tipi: $4)',
+'file-info-size'       => '$1 × $2 piksel, fayl ölçüsü: $3, MIME tipi: $4',
 'file-nohires'         => '<small>Taa üüksek aydınnıklı versiya bulunmêêr.</small>',
-'svg-long-desc'        => '(SVG faylı, nominal $1 × $2 piksel, fayl ölçüsü: $3)',
+'svg-long-desc'        => 'SVG faylı, nominal $1 × $2 piksel, fayl ölçüsü: $3',
 'show-big-image'       => 'Taman aydınnık',
 'show-big-image-thumb' => '<small>Ön siir ölçüsü: $1 × $2 piksel</small>',
 
