@@ -9,6 +9,7 @@
  *
  * @author Albonio
  * @author Artomo
+ * @author Kaganer
  * @author Lakaoso
  * @author Malafaya
  * @author Reedy
@@ -122,8 +123,7 @@ $messages = array(
 'tog-editsection'             => 'Kapabligez redakto di secioni per [redaktar]-ligamini',
 'tog-editsectiononrightclick' => 'Kapabligez redakto di secioni kande on dextra-klikus tituli di secioni (JavaScript bezonesas)',
 'tog-showtoc'                 => 'Montrez indexo (por pagini havanta plu multa kam 3 tituli)',
-'tog-rememberpassword'        => 'Memorez mea pasovorto en ica komputoro',
-'tog-editwidth'               => 'Larjigez la redakto-buxo por ke ol okupas la tota skreno',
+'tog-rememberpassword'        => "Memorez mea pasovorto en ca ''browser'' (maxime $1 {{PLURAL:$1|dio|dii}})",
 'tog-watchcreations'          => 'Adjuntez pagini kreota da me ad mea surveyaji',
 'tog-watchdefault'            => 'Adjuntez pagini redaktota da me ad mea surveyaji',
 'tog-watchmoves'              => 'Adjuntez pagini movota da me ad mea surveyaji',
@@ -138,7 +138,7 @@ $messages = array(
 'tog-enotifrevealaddr'        => 'Montrez mea e-posto adreso en notifiko e-posti',
 'tog-shownumberswatching'     => 'Montrez nombro di surveyanta uzanti',
 'tog-fancysig'                => 'Traktez signaturo kom wikikodo (sen automata ligilo)',
-'tog-externaleditor'          => 'Uzez extera redaktanto nespecigite (nur por experti, bezonas specala moderi ye vua komputoro)',
+'tog-externaleditor'          => 'Uzez extera redaktanto nespecigite (nur por experti, bezonas specala moderi ye vua komputoro .[http://www.mediawiki.org/wiki/Manual:External_editors Plusa informo.])',
 'tog-forceeditsummary'        => 'Notifikez me kande skribanta vakua redakto-rezumo',
 'tog-watchlisthideown'        => 'Celez mea redaktaji de la surveyaji',
 'tog-watchlisthidebots'       => 'Celez redaktaji da roboti de la surveyaji',
@@ -208,6 +208,7 @@ $messages = array(
 'pagecategories'                 => '{{PLURAL:$1|Kategorio|Kategorii}}',
 'category_header'                => 'Artikli en kategorio "$1"',
 'subcategories'                  => 'Subkategorii',
+'category-media-header'          => '"Media" en kategorio "$1"',
 'category-empty'                 => "''Nuntempe existas nula pagini en ita kategorio.''",
 'hidden-categories'              => '{{PLURAL:$1|Celita kategorio|Celita kategorii}}',
 'hidden-category-category'       => 'Celita kategorii',
@@ -247,27 +248,20 @@ $messages = array(
 'qbspecialpages' => 'Specala pagini',
 
 # Vector skin
-'vector-action-addsection'   => 'Adjuntar topiko',
-'vector-action-delete'       => 'Efacar',
-'vector-action-move'         => 'Movar',
-'vector-action-protect'      => 'Protektar',
-'vector-action-undelete'     => 'Rekuperar',
-'vector-action-unprotect'    => 'Desprotektar',
-'vector-namespace-category'  => 'Kategorio',
-'vector-namespace-help'      => 'Helpo-pagino',
-'vector-namespace-image'     => 'Failo',
-'vector-namespace-main'      => 'Pagino',
-'vector-namespace-mediawiki' => 'Mesajo',
-'vector-namespace-special'   => 'Specala pagino',
-'vector-namespace-talk'      => 'Diskuto',
-'vector-namespace-template'  => 'Shablono',
-'vector-namespace-user'      => 'Uzanto-pagino',
-'vector-view-create'         => 'Krear',
-'vector-view-edit'           => 'Redaktar',
-'vector-view-history'        => 'Vidar versionaro',
-'vector-view-view'           => 'Lektar',
-'vector-view-viewsource'     => 'Vidar fonto',
-'namespaces'                 => 'Nomari',
+'vector-action-addsection' => 'Adjuntar topiko',
+'vector-action-delete'     => 'Efacar',
+'vector-action-move'       => 'Movar',
+'vector-action-protect'    => 'Protektar',
+'vector-action-undelete'   => 'Rekuperar',
+'vector-action-unprotect'  => 'Desprotektar',
+'vector-view-create'       => 'Krear',
+'vector-view-edit'         => 'Redaktar',
+'vector-view-history'      => 'Vidar versionaro',
+'vector-view-view'         => 'Lektar',
+'vector-view-viewsource'   => 'Vidar fonto',
+'actions'                  => 'Agi',
+'namespaces'               => 'Nomari',
+'variants'                 => 'Varianti',
 
 'errorpagetitle'    => 'Eroro',
 'returnto'          => 'Retrovenar a $1.',
@@ -434,7 +428,7 @@ Voluntez, ne obliviez chanjor vua [[Special:Preferences|preferaji en {{SITENAME}
 'yourname'                   => 'Vua uzantonomo:',
 'yourpassword'               => 'Pasovorto:',
 'yourpasswordagain'          => 'Riskribez la pasovorto:',
-'remembermypassword'         => 'Memorez mea pasovorto inter sesioni en ca komputoro',
+'remembermypassword'         => 'Memorez mea pasovorto en ca komputoro (maximo: $1 {{PLURAL:$1|dio|dii}})',
 'yourdomainname'             => 'Vua domano:',
 'login'                      => 'Enirar',
 'nav-login-createaccount'    => 'Enirar',
@@ -450,6 +444,7 @@ Voluntez, ne obliviez chanjor vua [[Special:Preferences|preferaji en {{SITENAME}
 'gotaccount'                 => "Ka vu ja havas konto? '''$1'''.",
 'gotaccountlink'             => 'Enirar',
 'createaccountmail'          => 'per e-posto',
+'createaccountreason'        => 'Motivo:',
 'badretype'                  => 'La pasovorti vu donis ne esas sama.',
 'userexists'                 => 'La uzantonomo, quan vu skribis, ja selektesis antee.
 Voluntez, elektez ula diferanta uzantonomo.',
@@ -550,8 +545,11 @@ Se vu esas hike erore, kliktez sur la butono por retrovenar en vua navigilo.',
 Vu povas [[Special:Search/{{PAGENAME}}|serchar ica titulo]] en altra pagini,
 <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} serchar en la relata registri],
 o [{{fullurl:{{FULLPAGENAME}}|action=edit}} redaktar ica pagino]</span>.',
+'userpage-userdoesnotexist'        => 'Uzanto-nomo "$1" no registragesis.
+Voluntez konfirmez se vu volas krear/redaktar ica pagino.',
+'userpage-userdoesnotexist-view'   => 'Uzanto-nomo "$1" no registragesis.',
 'clearyourcache'                   => "'''Atencez: Pos registragar, vu probable mustas renovigar la tempala-magazino di vua navigilo por vidar la chanji.'''
-'''Mozilla / Firefox / Safari:''' tenez ''Shift'' kliktante ''Reload'', o presez sive  ''Ctrl-F5'' sive ''Ctrl-R'' (''Command-R'' ye Macintosh);
+'''Mozilla / Firefox / Safari:''' tenez ''Shift'' kliktante ''Reload'', o presez sive  ''Ctrl-F5'' sive ''Ctrl-R'' (''Command-R'' ye Mac);
 '''Konqueror''': kliktez ''Reload'' o presez ''F5'';
 '''Opera:''' vakuigez la tempala-magazino en ''Tools → Preferences'';
 '''Internet Explorer:''' tenez ''Ctrl'' kliktante ''Refresh,'' o presez ''Ctrl-F5''.",
@@ -584,9 +582,6 @@ Se vu gardus ol, la chanji facita pos ita revizo perdesos.'''",
 Se vu ne deziras ke altri modifikez vua artikli od oli distributesez libere, lore voluntez ne skribar oli hike.<br />
 Publikigante vua skribajo hike, vu asertas ke olu skribesis da vu ipsa o kopiesis de libera fonto.
 '''NE SENDEZ ARTIKLI KUN ''COPYRIGHT'' SEN PERMISO!'''",
-'longpagewarning'                  => "'''EGARDEZ''': Ica pagino esas $1 kilobicoki longa;
-Ula navigili posible havas problemi redaktante pagini proximeskanta o plu longa kam 32kb.
-Voluntez konsideras separar la pagino aden plu mikra secioni.",
 'protectedpagewarning'             => "'''AVERTO: Ica pagino esas blokusita, do nur ''sysop''-i povas redaktar olu.'''",
 'templatesused'                    => '{{PLURAL:$1|Shablono|Shabloni}} uzata en ica pagino:',
 'templatesusedpreview'             => '{{PLURAL:$1|Shablono|Shabloni}} uzata en ica prevido:',
@@ -638,7 +633,10 @@ Surskriburo: '''({{int:cur}})''' = diferi kun l'aktuala versiono,
 'revdelete-hide-user'        => 'Celar uzantonomo od IP di redaktanto',
 'revdelete-radio-set'        => 'Yes',
 'revdelete-radio-unset'      => 'No',
+'revdelete-log'              => 'Motivo:',
 'revdel-restore'             => 'chanjar videbleso',
+'revdel-restore-deleted'     => 'efacita revizadi',
+'revdel-restore-visible'     => 'videbla revizadi',
 'pagehist'                   => 'Pagino-versionaro',
 'deletedhist'                => 'Efacita versionaro',
 'revdelete-content'          => 'kontenajo',
@@ -664,48 +662,51 @@ Surskriburo: '''({{int:cur}})''' = diferi kun l'aktuala versiono,
 'editundo'                => 'des-facez',
 
 # Search results
-'searchresults'             => 'Rezultaji dil sercho',
-'searchresults-title'       => 'Sercho-rezultaji por "$1"',
-'searchresulttext'          => 'Por plusa informo pri quale serchar en {{SITENAME}}, videz [[{{MediaWiki:Helppage}}|help]].',
-'searchsubtitle'            => 'Vu serchis \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|omna pagini komencanta kun "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|omna pagini liganta ad "$1"]])',
-'searchsubtitleinvalid'     => "Vu serchis '''$1'''",
-'titlematches'              => 'Koincidi de titulo di artiklo',
-'notitlematches'            => 'No esas koincidi en la tituli dil artikli',
-'textmatches'               => 'Koincidi de texto di artiklo',
-'notextmatches'             => 'Nula paginala texto fitas',
-'prevn'                     => 'antea {{PLURAL:$1|$1}}',
-'nextn'                     => 'sequanta {{PLURAL:$1|$1}}',
-'viewprevnext'              => 'Vidar ($1 {{int:pipe-separator}} $2) ($3).',
-'searchmenu-new'            => "'''Kreez la pagino \"[[:\$1]]\" in ca wiki!'''",
-'searchhelp-url'            => 'Help:Helpo',
-'searchprofile-articles'    => 'Artikli',
-'searchprofile-project'     => 'Helpo',
-'searchprofile-images'      => "''Media''",
-'searchprofile-everything'  => 'Omno',
-'search-result-size'        => '$1 ({{PLURAL:$2|1 vorto|$2 vorti}})',
-'search-result-score'       => 'Importo: $1%',
-'search-redirect'           => '(ridirektilo $1)',
-'search-section'            => '(seciono $1)',
-'search-suggest'            => 'Ka vu volis dicar: $1',
-'search-interwiki-caption'  => 'Altra projekti',
-'search-interwiki-default'  => 'Rezultaji di $1:',
-'search-interwiki-more'     => '(plusa)',
-'search-mwsuggest-enabled'  => 'kun sugestaji',
-'search-mwsuggest-disabled' => 'sen sugestaji',
-'searchall'                 => 'omna',
-'showingresults'            => "Montrante infre {{PLURAL:$1|'''1''' rezulto|'''$1''' rezulti}}, qui komencas kun numero #'''$2'''.",
-'showingresultsnum'         => "Montrante infre {{PLURAL:$3|'''1''' rezulto|'''$3''' rezulti}}, qui komencas kun numero #'''$2'''.",
-'nonefound'                 => "'''Atencez''': Nespecigite, nur ula nomari esas serchata.
+'searchresults'                  => 'Rezultaji dil sercho',
+'searchresults-title'            => 'Sercho-rezultaji por "$1"',
+'searchresulttext'               => 'Por plusa informo pri quale serchar en {{SITENAME}}, videz [[{{MediaWiki:Helppage}}|help]].',
+'searchsubtitle'                 => 'Vu serchis \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|omna pagini komencanta kun "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|omna pagini liganta ad "$1"]])',
+'searchsubtitleinvalid'          => "Vu serchis '''$1'''",
+'titlematches'                   => 'Koincidi de titulo di artiklo',
+'notitlematches'                 => 'No esas koincidi en la tituli dil artikli',
+'textmatches'                    => 'Koincidi de texto di artiklo',
+'notextmatches'                  => 'Nula paginala texto fitas',
+'prevn'                          => 'antea {{PLURAL:$1|$1}}',
+'nextn'                          => 'sequanta {{PLURAL:$1|$1}}',
+'viewprevnext'                   => 'Vidar ($1 {{int:pipe-separator}} $2) ($3).',
+'searchmenu-new'                 => "'''Kreez la pagino \"[[:\$1]]\" in ca wiki!'''",
+'searchhelp-url'                 => 'Help:Helpo',
+'searchprofile-articles'         => 'Temala pagini',
+'searchprofile-project'          => 'Helpo',
+'searchprofile-images'           => "''Media''",
+'searchprofile-everything'       => 'Omno',
+'searchprofile-articles-tooltip' => 'Serchez en $1',
+'searchprofile-project-tooltip'  => 'Serchez en $1',
+'searchprofile-images-tooltip'   => 'Serchez arkivi',
+'search-result-size'             => '$1 ({{PLURAL:$2|1 vorto|$2 vorti}})',
+'search-result-score'            => 'Importo: $1%',
+'search-redirect'                => '(ridirektilo $1)',
+'search-section'                 => '(seciono $1)',
+'search-suggest'                 => 'Ka vu volis dicar: $1',
+'search-interwiki-caption'       => 'Altra projekti',
+'search-interwiki-default'       => 'Rezultaji di $1:',
+'search-interwiki-more'          => '(plusa)',
+'search-mwsuggest-enabled'       => 'kun sugestaji',
+'search-mwsuggest-disabled'      => 'sen sugestaji',
+'searchall'                      => 'omna',
+'showingresults'                 => "Montrante infre {{PLURAL:$1|'''1''' rezulto|'''$1''' rezulti}}, qui komencas kun numero #'''$2'''.",
+'showingresultsnum'              => "Montrante infre {{PLURAL:$3|'''1''' rezulto|'''$3''' rezulti}}, qui komencas kun numero #'''$2'''.",
+'nonefound'                      => "'''Atencez''': Nespecigite, nur ula nomari esas serchata.
 Probez prefixizar vua demando kun ''all:'' por serchar omna kontenajo (inkluzanta debato-pagini, shabloni, edc.), od uzar la dezirata nomaro kom prefixo.",
-'powersearch'               => 'Avancita sercho',
-'powersearch-legend'        => 'Avancita sercho',
-'powersearch-ns'            => 'Serchez en nomari:',
-'powersearch-redir'         => 'Listar ridirekti',
-'powersearch-field'         => 'Serchar',
-'powersearch-toggleall'     => 'Omna',
-'powersearch-togglenone'    => 'Nula',
-'search-external'           => 'Extera sercho',
-'searchdisabled'            => 'La sercho en la kompleta texto desaktivigesis temporale pro superkargo dil servanto. Ni esperas riaktivigar ol pos facar ula proxima aktualigi. Dum ica tempo, vu povas serchar per Google.',
+'powersearch'                    => 'Avancita sercho',
+'powersearch-legend'             => 'Avancita sercho',
+'powersearch-ns'                 => 'Serchez en nomari:',
+'powersearch-redir'              => 'Listar ridirekti',
+'powersearch-field'              => 'Serchar',
+'powersearch-toggleall'          => 'Omna',
+'powersearch-togglenone'         => 'Nula',
+'search-external'                => 'Extera sercho',
+'searchdisabled'                 => 'La sercho en la kompleta texto desaktivigesis temporale pro superkargo dil servanto. Ni esperas riaktivigar ol pos facar ula proxima aktualigi. Dum ica tempo, vu povas serchar per Google.',
 
 # Quickbar
 'qbsettings'      => 'Preferaji pri "Quickbar"',
@@ -727,8 +728,8 @@ Probez prefixizar vua demando kun ''all:'' por serchar omna kontenajo (inkluzant
 'prefs-rc'                      => 'Recenta chanji',
 'prefs-watchlist'               => 'Surveyo-listo',
 'prefs-watchlist-days'          => 'Dii montrata en surveyaji:',
-'prefs-watchlist-days-max'      => '(maximo 7 dii)',
-'prefs-watchlist-edits-max'     => '(maxima nombro: 1000)',
+'prefs-watchlist-days-max'      => 'Maximo 7 dii',
+'prefs-watchlist-edits-max'     => 'Maxima nombro: 1000',
 'prefs-misc'                    => 'Mixaji',
 'prefs-resetpass'               => 'Chanjar pasovorto',
 'prefs-rendering'               => 'Aspekto',
@@ -829,35 +830,33 @@ Ol mustas ne havar plu kam $1 {{PLURAL:$1|litero|literi}}.',
 'action-browsearchive' => 'serchar pagini efacita',
 
 # Recent changes
-'nchanges'                     => '$1 {{PLURAL:$1|chanjo|chanji}}',
-'recentchanges'                => 'Recenta chanji',
-'recentchanges-legend'         => 'Recenta chanji preferaji',
-'recentchangestext'            => 'Regardez la maxim recenta chanji en Wiki per ica pagino.',
-'recentchanges-legend-newpage' => '$1 - nova pagino',
-'recentchanges-label-newpage'  => 'Ca redaktajo kreis nova pagino',
-'recentchanges-legend-minor'   => '$1 - mikra redaktajo',
-'recentchanges-label-minor'    => 'Ica es mikra redaktajo',
-'recentchanges-legend-bot'     => '$1 - redakto da roboto',
-'rcnote'                       => "Infre esas la lasta {{PLURAL:$1|'''1''' chanjo|'''$1''' chanji}} dum la lasta {{PLURAL:$2|dio|'''$2''' dii}} ye $5, $4.",
-'rcnotefrom'                   => "Infre esas la lasta chanji depos '''$2''' (montrita til '''$1''').",
-'rclistfrom'                   => 'Montrar nova chanji startante de $1',
-'rcshowhideminor'              => '$1 mikra redakti',
-'rcshowhidebots'               => '$1 roboti',
-'rcshowhideliu'                => '$1 enirinta uzanti',
-'rcshowhideanons'              => '$1 anonima uzanti',
-'rcshowhidemine'               => '$1 mea redakti',
-'rclinks'                      => 'Montrar la lasta $1 chanji dum la lasta $2 dii<br />$3',
-'diff'                         => 'dif',
-'hist'                         => 'vers',
-'hide'                         => 'Celar',
-'show'                         => 'Montrar',
-'minoreditletter'              => 'm',
-'newpageletter'                => 'N',
-'boteditletter'                => 'r',
-'rc_categories_any'            => 'Ula',
-'newsectionsummary'            => '/* $1 */ nova seciono',
-'rc-enhanced-expand'           => 'Montrar detali (JavaScript bezonesas)',
-'rc-enhanced-hide'             => 'Celar detali',
+'nchanges'                    => '$1 {{PLURAL:$1|chanjo|chanji}}',
+'recentchanges'               => 'Recenta chanji',
+'recentchanges-legend'        => 'Recenta chanji preferaji',
+'recentchangestext'           => 'Regardez la maxim recenta chanji en Wiki per ica pagino.',
+'recentchanges-label-newpage' => 'Ca redaktajo kreis nova pagino',
+'recentchanges-label-minor'   => 'Ica es mikra redaktajo',
+'recentchanges-label-bot'     => 'Ta chanjo facita da bot',
+'rcnote'                      => "Infre esas la lasta {{PLURAL:$1|'''1''' chanjo|'''$1''' chanji}} dum la lasta {{PLURAL:$2|dio|'''$2''' dii}} ye $5, $4.",
+'rcnotefrom'                  => "Infre esas la lasta chanji depos '''$2''' (montrita til '''$1''').",
+'rclistfrom'                  => 'Montrar nova chanji startante de $1',
+'rcshowhideminor'             => '$1 mikra redakti',
+'rcshowhidebots'              => '$1 roboti',
+'rcshowhideliu'               => '$1 enirinta uzanti',
+'rcshowhideanons'             => '$1 anonima uzanti',
+'rcshowhidemine'              => '$1 mea redakti',
+'rclinks'                     => 'Montrar la lasta $1 chanji dum la lasta $2 dii<br />$3',
+'diff'                        => 'dif',
+'hist'                        => 'vers',
+'hide'                        => 'Celar',
+'show'                        => 'Montrar',
+'minoreditletter'             => 'm',
+'newpageletter'               => 'N',
+'boteditletter'               => 'r',
+'rc_categories_any'           => 'Ula',
+'newsectionsummary'           => '/* $1 */ nova seciono',
+'rc-enhanced-expand'          => 'Montrar detali (JavaScript bezonesas)',
+'rc-enhanced-hide'            => 'Celar detali',
 
 # Recent changes linked
 'recentchangeslinked'         => 'Relatanta chanji',
@@ -870,33 +869,35 @@ Pagini en [[Special:Watchlist|vua surveryo-listo]] esas '''dika'''.",
 'recentchangeslinked-to'      => 'Montrez chanji a pagini ligita a la specigita pagino vice',
 
 # Upload
-'upload'            => 'Adkargar arkivo',
-'uploadbtn'         => 'Adkargar arkivo',
-'reuploaddesc'      => 'Retrovenar al adkargo-formularo.',
-'uploadnologin'     => 'Vu ne eniris',
-'uploadnologintext' => 'Vu mustas [[Special:UserLogin|enirir]] por adkargar arkivi.',
-'uploaderror'       => 'Eroro dum adkargo',
-'uploadlog'         => 'adkargo-registraro',
-'uploadlogpage'     => 'Adkargo-registraro',
-'uploadlogpagetext' => 'Infre esas listo di la plu recenta adkargaji.
+'upload'              => 'Adkargar arkivo',
+'uploadbtn'           => 'Adkargar arkivo',
+'reuploaddesc'        => 'Retrovenar al adkargo-formularo.',
+'uploadnologin'       => 'Vu ne eniris',
+'uploadnologintext'   => 'Vu mustas [[Special:UserLogin|enirir]] por adkargar arkivi.',
+'uploaderror'         => 'Eroro dum adkargo',
+'uploadlog'           => 'adkargo-registraro',
+'uploadlogpage'       => 'Adkargo-registraro',
+'uploadlogpagetext'   => 'Infre esas listo di la plu recenta adkargaji.
 Videz rezumo plu vidala en la [[Special:NewFiles|galerio di nova arkivi]].',
-'filename'          => 'Arkivo-nomo',
-'filedesc'          => 'Titulo',
-'fileuploadsummary' => 'Rezumo:',
-'filestatus'        => 'Stando di kopiyuro:',
-'filesource'        => 'Fonto:',
-'uploadedfiles'     => 'Adkargita arkivi',
-'ignorewarning'     => 'Ignorar la averto e gardar la arkivo irgakaze.',
-'badfilename'       => 'La imajo-nomo chanjesis a "$1".',
-'fileexists'        => "Arkivo kun ica nomo ja existas.
+'filename'            => 'Arkivo-nomo',
+'filedesc'            => 'Titulo',
+'fileuploadsummary'   => 'Rezumo:',
+'filestatus'          => 'Stando di kopiyuro:',
+'filesource'          => 'Fonto:',
+'uploadedfiles'       => 'Adkargita arkivi',
+'ignorewarning'       => 'Ignorar la averto e gardar la arkivo irgakaze.',
+'badfilename'         => 'La imajo-nomo chanjesis a "$1".',
+'fileexists'          => "Arkivo kun ica nomo ja existas.
 Volutez kontrolar '''<tt>[[:$1]]</tt>''' se vu ne esas certa pri chanjar olu.
 [[$1|thumb]]",
-'successfulupload'  => 'Adcharjo sucesoza',
-'uploadwarning'     => 'Averto pri la adkargo di arkivo',
-'savefile'          => 'Registragar arkivo',
-'uploadedimage'     => 'adkargita "[[$1]]"',
-'uploaddisabled'    => 'Pardonez, la adkargo esas desaktiva.',
-'watchthisupload'   => 'Surveyar ica arkivo',
+'uploadwarning'       => 'Averto pri la adkargo di arkivo',
+'savefile'            => 'Registragar arkivo',
+'uploadedimage'       => 'adkargita "[[$1]]"',
+'uploaddisabled'      => 'Pardonez, la adkargo esas desaktiva.',
+'watchthisupload'     => 'Surveyar ica arkivo',
+'upload-success-subj' => 'Adcharjo sucesoza',
+
+'license-header' => 'Licencizo',
 
 # Special:ListFiles
 'imgfile'         => 'arkivo',
@@ -1083,7 +1084,6 @@ Volutez kontrolar '''<tt>[[:$1]]</tt>''' se vu ne esas certa pri chanjar olu.
 # Watchlist
 'watchlist'          => 'Mea surveyaji',
 'mywatchlist'        => 'Mea surveyaji',
-'watchlistfor'       => "(por '''$1''')",
 'nowatchlist'        => 'Vu ne havas objekti en vua listo di surveyaji.',
 'watchnologin'       => 'Vu ne startis sesiono',
 'watchnologintext'   => 'Vu mustas [[Special:UserLogin|enirir]] por modifikar vua surveyaji.',
@@ -1193,6 +1193,7 @@ restauris ad lasta versiono da $2.',
 'undeleterevisions'         => '$1 {{PLURAL:$1|revizo|revizi}} konservita',
 'undeletebtn'               => 'Restaurar',
 'undeletelink'              => 'vidar/restaurar',
+'undeleteviewlink'          => 'videz',
 'undeletecomment'           => 'Komento:',
 'undeletedarticle'          => 'restaurita "[[$1]]"',
 'undelete-search-box'       => 'Serchez efacita pagini',
@@ -1420,6 +1421,7 @@ Voluntez vizitar [http://www.mediawiki.org/wiki/Localisation MediaWiki Lokizado]
 'tooltip-rollback'                => '"Retrorular" desfacas omna chanji ad ca pagino da la lasta kontributanto per un kliko',
 'tooltip-undo'                    => '"Desfacez" nuligas ca versiono e apertas la redakto-pagino en prevido-modo.
 Vu darfos adjuntar kauso en la rezumo.',
+'tooltip-summary'                 => 'Skribez kurta rezumo',
 
 # Metadata
 'notacceptable' => 'La servanto di {{SITENAME}} ne povas provizar datumi en formato quan vua kliento povas komprenar.',
@@ -1447,13 +1449,14 @@ Vu darfos adjuntar kauso en la rezumo.',
 
 # Patrol log
 'patrol-log-auto' => '(automata)',
+'patrol-log-diff' => 'revizado $1',
 
 # Browsing diffs
 'previousdiff' => '← Plu anciena versiono',
 'nextdiff'     => 'Plu recenta versiono →',
 
 # Media information
-'widthheightpage'      => '$1×$2, $3 {{PLURAL:$3|pagino|pagini}}',
+'widthheightpage'      => '$1 × $2, $3 {{PLURAL:$3|pagino|pagini}}',
 'file-nohires'         => '<small>Ne existas grandeso plu granda.</small>',
 'show-big-image'       => 'Grandeso kompleta',
 'show-big-image-thumb' => '<small>Dimensioni di ca previdajo: $1 × $2 pixel-i</small>',
@@ -1504,6 +1507,9 @@ Vu darfos adjuntar kauso en la rezumo.',
 'exif-gpsspeed-k' => 'Kilometri per horo',
 'exif-gpsspeed-m' => 'Milii per horo',
 
+# External editor support
+'edit-externally' => 'Chanjez ta arkivo per externa programo',
+
 # 'all' in various places, this might be different for inflected languages
 'recentchangesall' => 'omna',
 'imagelistall'     => 'omna',
