@@ -7,9 +7,11 @@
  * @ingroup Language
  * @file
  *
+ * @author (vinny)
  * @author Homo logos
  * @author Malafaya
  * @author OldakQuill
+ * @author PierreAbbat
  */
 
 $messages = array(
@@ -24,17 +26,18 @@ $messages = array(
 'thursday'      => 'la vodjed.',
 'friday'        => 'la mudjed.',
 'saturday'      => 'la xadjed.',
-'january'       => 'la pamast.',
-'february'      => 'la remast.',
-'march'         => 'la cimast.',
-'april'         => 'la vomast.',
-'june'          => 'la xamast.',
-'july'          => 'la zemast.',
-'august'        => 'la bimast.',
-'september'     => 'la somast.',
-'october'       => 'la daumast.',
-'november'      => 'la feimast.',
-'december'      => 'la gaimast.',
+'january'       => 'ianvari',
+'february'      => 'frebruari',
+'march'         => 'martio',
+'april'         => 'prilio',
+'may_long'      => 'madjio',
+'june'          => 'djunio',
+'july'          => 'djulio',
+'august'        => 'avgusto',
+'september'     => 'septembero',
+'october'       => 'oktobero',
+'november'      => 'novmbero',
+'december'      => 'decmbero',
 'january-gen'   => 'la pamast.',
 'february-gen'  => 'la remast.',
 'march-gen'     => 'la cimast.',
@@ -47,18 +50,37 @@ $messages = array(
 'october-gen'   => 'la daumast.',
 'november-gen'  => 'la feimast.',
 'december-gen'  => 'la gaimast.',
-'may'           => 'la mumast.',
+'jan'           => 'ian',
+'feb'           => 'fre',
+'mar'           => 'mar',
+'apr'           => 'pri',
+'may'           => 'mad',
+'jun'           => 'jun',
+'jul'           => 'jul',
+'aug'           => 'avg',
+'sep'           => 'sep',
+'oct'           => 'okt',
+'nov'           => 'nov',
+'dec'           => 'dec',
 
 # Categories related messages
-'pagecategories'  => '{{PLURAL:$1|klesi|klesi}}',
-'category_header' => 'fe le kibypapri cu klesi "$1"',
-'subcategories'   => "le'a ti",
+'pagecategories'         => '{{PLURAL:$1|klesi|klesi}}',
+'category_header'        => 'fe le kibypapri cu klesi "$1"',
+'subcategories'          => "le'a ti",
+'category-subcat-count'  => "$2 klesi cu vipsi le vi klesi .i $1 vipkle cu ni'a se jarco",
+'category-article-count' => "$2 kibypapri cu cmima le vi klesi .i $1 kibypapri cu ni'a se jarco",
 
+'mytalk'     => 'casnu mi',
+'navigation' => 'ckupau',
+
+# Cologne Blue skin
 'qbedit'        => 'stika',
 'qbpageoptions' => 'ti ckupau',
-'mytalk'        => 'casnu mi',
+'faq'           => 'FAQ',
+'faqpage'       => 'Project:FAQ',
 
 'errorpagetitle'   => 'fliba',
+'tagline'          => "ra'i {{SITENAME}}",
 'help'             => 'sidju ckupau',
 'search'           => 'sisku',
 'searchbutton'     => 'sisku',
@@ -67,21 +89,26 @@ $messages = array(
 'printableversion' => 'plepri simsa',
 'permalink'        => "vitno terjo'e",
 'edit'             => 'stika',
+'create'           => 'ninzba',
 'delete'           => 'daspo',
 'protect'          => 'bandu',
+'protect_change'   => 'binxo',
 'talkpagelinktext' => 'casnu',
 'specialpage'      => 'steci ckupau',
+'personaltools'    => 'Sivni tyobuobulysy',
 'talk'             => 'casnu',
+'views'            => 'Catlu',
 'toolbox'          => 'tutci',
 'otherlanguages'   => 'drata bangu',
-'lastmodifiedat'   => "le vi ckupau rore'u se galfi de'i li $2 $1", # $1 date, $2 time
+'lastmodifiedat'   => "le vi ckupau rore'u se galfi de'i li $2 $1",
+'jumpto'           => 'plipe tyobu:',
+'jumptonavigation' => 'ckupau',
 'jumptosearch'     => 'sisku',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'About {{SITENAME}}',
-'aboutpage'            => 'Project:About',
+'aboutpage'            => "Project:sera'a",
 'copyright'            => "lo selvau cu gubni ja'i la'o gy. $1 .gy.",
-'copyrightpagename'    => "{{SITENAME}} fukyzifpo'e",
 'copyrightpage'        => "{{ns:project}}:fukyzifpo'e",
 'currentevents'        => "caca'a fasnu",
 'currentevents-url'    => "Project:caca'a fasnu",
@@ -89,22 +116,22 @@ $messages = array(
 'disclaimerpage'       => "Project:kampu nunxusra be lo za'i na fuzme",
 'edithelp'             => 'stika nunsidju',
 'edithelppage'         => 'Help:Editing',
-'faq'                  => 'FAQ',
-'faqpage'              => 'Project:FAQ',
-'mainpage'             => 'ralju ckupau',
+'mainpage'             => 'Ralju Ckupau',
 'mainpage-description' => 'ralju ckupau',
 'portal'               => 'bende ckupau',
 'portal-url'           => 'Project:bende ckupau',
 'privacy'              => "javni be sera'a lo sivni",
+'privacypage'          => "Project:i'inai zukselpla",
 
+'retrievedfrom'        => 'cpacu fi la\'o .url. "$1" .url.',
 'editsection'          => 'stika ti',
 'editsection-brackets' => '[$1]',
-'editold'              => 'edit',
+'editold'              => 'stika',
 'viewsourceold'        => 'catlu le mifra',
 'editlink'             => 'stika ti',
 'viewsourcelink'       => 'casnu le mifra',
 'editsectionhint'      => 'stika ti: $1',
-'toc'                  => 'ckupau pakbu',
+'toc'                  => 'ckupau pagbu',
 'showtoc'              => 'jarco',
 'hidetoc'              => 'toljarco',
 'thisisdeleted'        => 'View or restore $1?',
@@ -113,6 +140,8 @@ $messages = array(
 'feedlinks'            => 'Feed:',
 'feed-invalid'         => 'Invalid subscription feed type.',
 'feed-unavailable'     => 'Syndication feeds are not available',
+'site-rss-feed'        => '$1 RSS cidja',
+'site-atom-feed'       => '$1 Atom cidja',
 'red-link-title'       => '$1 (le vi kibypapri cu na zasti)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
@@ -123,11 +152,18 @@ $messages = array(
 'nstab-mediawiki' => 'notci',
 'nstab-category'  => 'klesi',
 
+# General errors
+'viewsource' => 'catlu le mifra',
+
 # Login and logout pages
-'login'          => "co'a se jaspu",
-'logout'         => "co'u se jaspu",
-'userlogout'     => "co'u se jaspu",
-'gotaccountlink' => "co'a se jaspu",
+'login'                   => "co'a se jaspu",
+'nav-login-createaccount' => 'jaspu nerkla / vreji lo cnino pilno',
+'logout'                  => "co'u se jaspu",
+'userlogout'              => "co'u se jaspu",
+'gotaccountlink'          => "co'a se jaspu",
+
+# Edit page toolbar
+'extlink_sample' => 'http://www.example.com link title',
 
 # Edit pages
 'minoredit'      => "ti nu na'evajni galfi",
@@ -143,25 +179,46 @@ $messages = array(
 'editingcomment' => 'ca galfi le selcmene be zoi $1 (comment)',
 
 # History pages
-'last'       => "prula'i",
-'page_first' => 'pamoi',
-'page_last'  => 'fanmo',
+'revisionasof' => "velfarvi de'i $1",
+'cur'          => 'cab',
+'last'         => "prula'i",
+'page_first'   => 'pamoi',
+'page_last'    => 'fanmo',
+
+# Revision deletion
+'rev-delundel' => 'jarco/mipri',
+
+# Diffs
+'lineno'   => 'Linji $1',
+'editundo' => 'fatstika',
 
 # Search results
-'searchresults' => "tu'a le se sisku",
+'searchresults'             => "tu'a le se sisku",
+'searchresults-title'       => 'Sisku pruce for "$1"',
+'search-result-size'        => '$1 .i $2 valsi',
+'search-suggest'            => "xu do sisydji lu $1 li'u",
+'search-mwsuggest-enabled'  => 'kansa stidiiyobunysy',
+'search-mwsuggest-disabled' => 'no stidiiyobunysy',
 
 # Preferences page
 'preferences'       => 'zmaselnei',
 'mypreferences'     => 'zmaselnei liste',
-'textboxsize'       => 'ca galfi',
+'prefs-editing'     => 'ca galfi',
 'searchresultshead' => "tu'a le se sisku",
 'savedprefs'        => 'le do zmaselnei pu vreji',
 
 # Recent changes
 'recentchanges'     => 'puzi nunstika',
 'recentchangestext' => 'liste loi nu puzi galfi la .uikis.',
+'rcshowhidebots'    => '$1 lo zmiku',
+'rcshowhideliu'     => '$1 lo samyzva',
 'diff'              => 'te frica',
 'hist'              => 'galfi plivei',
+'hide'              => 'Toljarco',
+'show'              => 'Jarco',
+'minoreditletter'   => 'm',
+'newpageletter'     => 'n',
+'boteditletter'     => 'z',
 
 # Recent changes linked
 'recentchangeslinked' => "srana nunga'i",
@@ -170,6 +227,10 @@ $messages = array(
 'upload'    => 'benji lo datnyvei',
 'uploadbtn' => 'benji lo datnyvei',
 
+# File description page
+'filehist-current'  => 'cabna',
+'filehist-datetime' => 'detytcika',
+
 # Random page
 'randompage' => 'cunso ckupau',
 
@@ -177,7 +238,8 @@ $messages = array(
 'move' => 'stika lo cmene',
 
 # Special:AllPages
-'allarticles' => 'ro notci',
+'allarticles'    => 'ro notci',
+'allpagessubmit' => 'jarco',
 
 # Special:Categories
 'categories' => 'klesi',
@@ -185,44 +247,61 @@ $messages = array(
 # Watchlist
 'watchlist'     => 'selzgaste',
 'mywatchlist'   => 'selzgaste',
-'watch'         => 'zgana',
+'watch'         => 'jundi',
 'watchthispage' => 'zgana ti',
 
+# Displayed when you click the "watch" button and it is in the process of watching
+'watching'   => "co'a jundi",
+'unwatching' => "co'u jundi",
+
 # Delete
 'deletedarticle' => "pu daspo la'e lu [[$1]] li'u",
 'dellogpage'     => 'plivei fi loi nu daspo',
 'deletionlog'    => 'plivei fi loi nu daspo',
 
+# Rollback
+'rollbacklink' => 'lamxru',
+
 # Restrictions (nouns)
 'restriction-edit' => 'stika',
 
+# Namespace form on various pages
+'blanknamespace' => '(ralju)',
+
 # Contributions
 'contributions' => 'selstika le pilno',
 'mycontris'     => 'pu selstika mi',
 
+'sp-contributions-talk'   => 'casnu',
 'sp-contributions-submit' => 'sisku',
 
 # What links here
 'whatlinkshere' => 'ma jorne ti',
 
 # Block/unblock
-'blocklink'    => 'zunti',
-'contribslink' => 'selstika',
+'blocklink'        => 'zunti',
+'change-blocklink' => 'stika bliku',
+'contribslink'     => 'selstika',
 
 # Move page
-'movedto'   => 'te muvdu',
-'1movedto2' => "le pu se cmene lu [[$1]] li'u cu ca se cmene lu [[$2]] li'u",
+'movedto'    => 'te muvdu',
+'1movedto2'  => "le pu se cmene lu [[$1]] li'u cu ca se cmene lu [[$2]] li'u",
+'revertmove' => 'xruti',
 
 # Tooltip help for the actions
 'tooltip-pt-watchlist'          => 'le liste be lo kibypapri poi do zgana',
 'tooltip-pt-mycontris'          => 'le liste be le do selstika',
 'tooltip-pt-logout'             => "co'u se jaspu",
 'tooltip-ca-watch'              => 'jmive le vi kibypapri le do selzgaste',
+'tooltip-search'                => 'Sisku {{SITENAME}}',
+'tooltip-search-go'             => "Litru tyobu abu kibypapri kansa tyy'y.buibusy satci cmene ibufy zasti",
+'tooltip-search-fulltext'       => "sisku do'i lei ckupau",
 'tooltip-n-mainpage'            => 'vitke le ralju ckupau',
 'tooltip-n-randompage'          => 'jarco lo cunso ckupau',
 'tooltip-n-help'                => 'sidju kibypapri',
 'tooltip-t-whatlinkshere'       => "nu liste lo zifyga'ikibjudri poi ke'a kibjorne le vi ckupau",
 'tooltip-t-recentchangeslinked' => "lo puzi nunga'i pe lo kibypapri poi kibjorne le vi ckupau",
+'tooltip-undo'                  => "fatygau le nunstika gi'e jarco le stika tampapri tai lo nu troci jarco .i kakne jmina lo krinu le torvelski",
 
 # Special:FilePath
 'filepath-page' => 'se datnyvei zoi',
