@@ -10,6 +10,7 @@
  * @author Harvzsf
  * @author Joebertj
  * @author Jose77
+ * @author Oxyzen
  * @author RonaldPanaligan
  */
 
@@ -22,7 +23,7 @@ $messages = array(
 'tog-extendwatchlist'      => "Palapadun ang ''watchlist'' agud nga mapakita ang tanan nga ginasogtan nga pag-ilis",
 'tog-numberheadings'       => "Automatiko nga togroan kang nomero ang manga ''heading''",
 'tog-showtoolbar'          => 'Ipakita ang pangbolig sa pag-ilis (JavaScript)',
-'tog-rememberpassword'     => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer''",
+'tog-rememberpassword'     => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer'' (for a maximum of $1 {{PLURAL:$1|day|days}})",
 'tog-watchcreations'       => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpanghimo ko",
 'tog-watchdefault'         => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpang-''edit'' ko",
 'tog-watchmoves'           => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpanghalin ko",
@@ -100,19 +101,23 @@ $messages = array(
 'category-media-header' => 'Manga midya sa "$1"',
 'category-empty'        => "''Wara it manga artikolo okon medya ang katergorya nga dya.''",
 
-'about'          => 'Angut sa Iwan',
-'article'        => 'Pahina kasudlan',
-'newwindow'      => "(gabokas sa bag-o nga ''window'')",
-'cancel'         => 'Kanselar',
+'about'         => 'Angut sa Iwan',
+'article'       => 'Pahina kasudlan',
+'newwindow'     => "(gabokas sa bag-o nga ''window'')",
+'cancel'        => 'Kanselar',
+'moredotdotdot' => 'Raku pa...',
+'mypage'        => 'Akun nga pahina',
+'anontalk'      => "Istoryahun ang dya nga ''IP''",
+
+# Cologne Blue skin
 'qbfind'         => 'Sagap',
 'qbbrowse'       => 'Bilid',
 'qbedit'         => 'Iislan',
 'qbpageoptions'  => 'Dya nga Pahina',
 'qbpageinfo'     => 'Konteksto',
 'qbspecialpages' => 'Manga espesyal nga pahina',
-'moredotdotdot'  => 'Raku pa...',
-'mypage'         => 'Akun nga pahina',
-'anontalk'       => "Istoryahun ang dya nga ''IP''",
+'faq'            => 'FAQ',
+'faqpage'        => 'Project:FAQ',
 
 'errorpagetitle'    => 'Sayup',
 'returnto'          => 'Balik sa $1.',
@@ -143,7 +148,7 @@ $messages = array(
 'specialpage'       => 'Espesyal nga Pahina',
 'postcomment'       => 'Togro Komento',
 'articlepage'       => 'Turukun ang pahina kasudlan',
-'talk'              => 'Sogdanunay',
+'talk'              => 'Sugilanon',
 'views'             => 'Manga paglantaw',
 'toolbox'           => 'Pangbolig',
 'otherlanguages'    => 'Sa iban nga lingwahe',
@@ -159,8 +164,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:Panginwala nga Pangtanan',
 'edithelp'             => 'Panoytoy sa Pag-ilis',
 'edithelppage'         => 'Help:Pag-ilis',
-'faq'                  => 'FAQ',
-'faqpage'              => 'Project:FAQ',
 'mainpage'             => 'Pono nga Pahina',
 'mainpage-description' => 'Pono nga Pahina',
 'privacy'              => 'Surundun sa Privacy',
@@ -199,7 +202,6 @@ Lantawa sa [[Special:Version|version kang page]].',
 # General errors
 'error'                => 'Sayup',
 'databaseerror'        => 'Sayup sa database',
-'nodb'                 => "Indi mapili ang ''database'' nga $1",
 'readonly'             => "Napintalan ang ''database''",
 'internalerror'        => 'Sayup internal',
 'internalerror_info'   => 'Sayup internal: $1',
@@ -212,11 +214,9 @@ Lantawa sa [[Special:Version|version kang page]].',
 'viewsource'           => 'Turukun ang ginhalinan',
 
 # Login and logout pages
-'remembermypassword' => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer''",
+'remembermypassword' => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer'' (for a maximum of $1 {{PLURAL:$1|day|days}})",
 'nologinlink'        => "Himo ka sangka ''account''",
 'createaccount'      => "Himo ka ''account''",
-'youremail'          => 'E-mail:',
-'email'              => 'E-mail',
 
 # Edit pages
 'preview' => 'Bilid',
@@ -224,6 +224,8 @@ Lantawa sa [[Special:Version|version kang page]].',
 # Preferences page
 'skin-preview'      => 'Bilid',
 'searchresultshead' => 'Sagap',
+'youremail'         => 'E-mail:',
+'email'             => 'E-mail',
 
 # Recent changes
 'hide' => 'Itago',
@@ -234,11 +236,14 @@ Lantawa sa [[Special:Version|version kang page]].',
 # Special:ListFiles
 'imgfile' => 'inayap',
 
+# File description page
+'file-anchor-link' => 'Inayap',
+
 # File deletion
 'filedelete-submit' => 'Para',
 
-'brokenredirects-edit'   => '(Iislan)',
-'brokenredirects-delete' => '(para)',
+'brokenredirects-edit'   => 'Iislan',
+'brokenredirects-delete' => 'para',
 
 'withoutinterwiki-submit' => 'Ipakita',
 
@@ -266,6 +271,7 @@ Lantawa sa [[Special:Version|version kang page]].',
 # Undelete
 'undelete-search-submit' => 'Sagap',
 
+'sp-contributions-talk'   => 'Wakal',
 'sp-contributions-submit' => 'Sagap',
 
 # What links here
