@@ -26,7 +26,7 @@ $messages = array(
 'tog-editsection'             => "Emiko ku mpapula gibengako enyunzi eza '[kyusa]' ezikuggusa w'osobolera okugikyusiza.",
 'tog-editsectiononrightclick' => "Okunyiga ku omutwe gw'omuko ku lupapula n'eppeesa erya ddyo kubikkulenga w'ogukyusiza (kyetaagisa 'JavaScript')",
 'tog-showtoc'                 => 'Teekawo endagiriro (singa ku lupapula kubaako emitwe gisukka mu esatu)',
-'tog-rememberpassword'        => 'Ekigambo kyange ekikuumi kitereke ku kompyuta eno',
+'tog-rememberpassword'        => 'Tereka ekigambo kyange ekikuumi ku kompyuta eno (okumala {{PLURAL:$1|olunaku|ennaku ezitasukka mu}} $1)',
 'tog-watchcreations'          => "Empapula zenkolawo ziteekebwenga ku lukalala lw'ezo zengoberera",
 'tog-watchdefault'            => "Empapula zenkyusamu ziteekebwenga ku lukalala lw'ezo zengoberera",
 'tog-watchmoves'              => "Empapula zenkyusa erinnya ziteekebwenga ku lukalala lw'ezo zengoberera",
@@ -42,8 +42,8 @@ $messages = array(
 'tog-shownumberswatching'     => "Ndaganga obungi bw'abagoberera olupapula",
 'tog-oldsig'                  => 'Omukono gwo kakano:',
 'tog-fancysig'                => 'Omukono gubemu obubonero bwa ki-wiki (naye nga tegufuuka nyunzi)',
-'tog-externaleditor'          => 'Wandikisanga puloguramu eri ku kompyuta yo (kyetaagisa bumanyirivu bungi, wetaaga ntegeka ezitali za bulijjo ku kompyuta yo)',
-'tog-externaldiff'            => "Kozesanga puloguramu ey'oku kompyuta yo okukebera njawulo wakati w'ebiwandike (kyetaagisa bumanyirivu bungi, wetaaga ntegeka ezitali za bulijjo ku kompyuta yo)",
+'tog-externaleditor'          => 'Wandikisanga puloguramu eri ku kompyuta yo (kyetaagisa bumanyirivu bungi, kubanga wetaaga okutegeka kompyuta yo mu ngeri ezitali za bulijjo. [http://www.mediawiki.org/wiki/Manual:External_editors Okutangaaza okusingawo.])',
+'tog-externaldiff'            => "Kozesanga puloguramu ey'oku kompyuta yo okukebera njawulo wakati w'ebiwandike (kyetaagisa bumanyirivu bungi, wetaaga ntegeka ezitali za bulijjo ku kompyuta yo. [http://www.mediawiki.org/wiki/Manual:External_editors Okutangaaza okusingawo.])",
 'tog-showjumplinks'           => 'Wabeerewo enyunzi eza "Genda ku"',
 'tog-uselivepreview'          => 'Enkyukakyuka ze nkoze zirabikirewo nga tekyetaagisiza kumala kunyiga ppeesa (kyetaagisa JavaScript)(Kikyagezesebwa)',
 'tog-forceeditsummary'        => 'Ŋambaako bwe mba ŋenda okuleka nga sinnyonyodde bye nkyusizza',
@@ -168,20 +168,20 @@ $messages = array(
 'faqpage'        => 'Project:Ebitera okubuuzibwa ku',
 
 # Vector skin
-'vector-action-addsection' => 'Tandikawo emboozi endala',
-'vector-action-delete'     => 'Gyawo olupapula luno',
-'vector-action-move'       => 'Simbuliza',
-'vector-action-protect'    => 'Ssiba',
-'vector-action-undelete'   => 'Zawo',
-'vector-action-unprotect'  => 'Gyako ebikugizo',
-'vector-namespace-main'    => 'Lupapula',
-'vector-view-create'       => 'Lukolewo',
-'vector-view-edit'         => 'Kyusa',
-'vector-view-history'      => 'Ennanda ya fayiro eno',
-'vector-view-view'         => 'Soma',
-'vector-view-viewsource'   => "Kebera obulambike obw'ennono obw'olupapula luno",
-'actions'                  => "By'oyinza okukola",
-'namespaces'               => 'Makuŋaanyizo',
+'vector-action-addsection'       => 'Tandikawo emboozi endala',
+'vector-action-delete'           => 'Gyawo olupapula luno',
+'vector-action-move'             => 'Simbuliza',
+'vector-action-protect'          => 'Ssiba',
+'vector-action-undelete'         => 'Zawo',
+'vector-action-unprotect'        => 'Kyusa ebikugizo',
+'vector-simplesearch-preference' => "Wiki esobole okukuwa amagezi ku by'onoonya (kino kikolera mu ndabika ya Vector yokka)",
+'vector-view-create'             => 'Lukolewo',
+'vector-view-edit'               => 'Kyusa',
+'vector-view-history'            => 'Ennanda ya fayiro eno',
+'vector-view-view'               => 'Soma',
+'vector-view-viewsource'         => "Kebera obulambike obw'ennono obw'olupapula luno",
+'actions'                        => "By'oyinza okukola",
+'namespaces'                     => 'Makuŋaanyizo',
 
 'errorpagetitle'    => 'Kiremya',
 'returnto'          => 'Dda ku $1.',
@@ -208,8 +208,8 @@ $messages = array(
 'protect'           => 'Ssiba',
 'protect_change'    => 'lusibe/lusumulule',
 'protectthispage'   => 'Siba olupapula luno',
-'unprotect'         => 'Gyako ebikugizo',
-'unprotectthispage' => 'Sumulula olupapula luno',
+'unprotect'         => 'Kyusa ebikugizo',
+'unprotectthispage' => 'Kyusa ebikugizo ebiri ku lupapula luno',
 'newpage'           => 'Lupapula lupya',
 'talkpage'          => "W'ebirowozo ku lupapula luno",
 'talkpagelinktext'  => 'Yogera nange',
@@ -242,6 +242,9 @@ Olw'obungi bw'abakebera olupapula olwo, kompyuta zaffe tezisobola kwongerako mul
 Lindako akaseera oddemu ogezeeko okulukebera.
 
 $1",
+'pool-timeout'      => "Obudde obugere obw'okulinda okufuna obuyinza obw'okulukozesa buweddeko",
+'pool-queuefull'    => "Olukalala lw'emirimu egirinda okukolebwako lujjudde",
+'pool-errorunknown' => 'Ekireesewo kiremya tekitegeerese',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Okutangaaza ku {{SITENAME}}',
@@ -387,6 +390,7 @@ Lindako eddakiika entonotono oly'oke oddemu okugezako ekikolwa.",
 Luliko ebikugizo ebirugaana okwonooebwa.",
 'editinginterface'     => "'''Kulabula:''' Okyusa olupapula sofutiweya kw'egya ebigambo byayo.
 Enkyukakyuka z'okola wano zigyakubaako kye zikola ku ngeri abantu gye bakozesaamu enfo eno.",
+'sqlhidden'            => '(Waliwo wo ebya SQL ebibikkidwa)',
 'cascadeprotected'     => 'Olupapula luno lulandideko ekikugizo ekirugaana okukyusibwako ekisibuka ku {{PLURAL:$1|lunnaalwo luno olulukozesa|zinnalwo zino ezirukozesa}}:<br />
 $2',
 'namespaceprotected'   => "Tolina buyinza bwa kukyusa ku mpapula ez'omu kkuŋaanizo erya '''$1'''.",
@@ -411,7 +415,8 @@ Tewerabira kwetereereza [[Special:Preferences|enteekateeka yo ey'oku {{SITENAME}
 'yourname'                   => "Ery'obwa memba",
 'yourpassword'               => 'Ekigambo ekikuumi',
 'yourpasswordagain'          => 'Ddamu ekigambo ekikuumi',
-'remembermypassword'         => 'Tereka ekigambo kyange ekikuumi ku kompyuta eno',
+'remembermypassword'         => 'Tereka ekigambo kyange ekikuumi ku kompyuta eno (okumala {{PLURAL:$1|olunaku|ennaku ezitasukka mu}} $1)',
+'securelogin-stick-https'    => "Sigala ku mukutu gwa kika kya HTTPS ng'omaze okuyingira",
 'yourdomainname'             => 'Linnya lya twale lya kayungirizi lyo:',
 'externaldberror'            => "Waliwo kiremya mu ggwanika lya data ekozesebwa okukakasa bamemba oba tokkirizibwa okukyusa ku akawunti yo ey'awalala.",
 'login'                      => 'Yingira',
@@ -428,6 +433,7 @@ Tewerabira kwetereereza [[Special:Preferences|enteekateeka yo ey'oku {{SITENAME}
 'gotaccount'                 => "Akawunti wafuna? '''$1'''.",
 'gotaccountlink'             => 'Yingira',
 'createaccountmail'          => 'Akawunti gikole ne E-mail',
+'createaccountreason'        => 'Ekikukozesezawo akawunti:',
 'badretype'                  => "Ebigambo ebikuumi by'owandise tebifaanagana.",
 'userexists'                 => "Ery'obwa memba ly'owandise wali omulala alirina.<br />
 Londa eddala.",
@@ -456,6 +462,7 @@ Ddamu ogezeeko.",
 Ddamu ogezeeko.',
 'passwordtooshort'           => 'Ekigambo ekikuumi kiteekwa okubaamu {{PLURAL:$1|akabonero wakiri kamu|obubonero obutakka wansi wa $1}}.',
 'password-name-match'        => "Tokkirizibwa kukozesa linnya lyo ery'obwa memba ng'ekigambo ekikuumi.",
+'password-login-forbidden'   => "Ebigambo bino tebikkirizibwa kukozesebwa ng'amannya g'obwa memba oba bigambo bikuumi.",
 'mailmypassword'             => 'Nsindikira ekigambo ekikuumi ekipya',
 'passwordremindertitle'      => "Ekigambo ekikuumi eky'oku {{SITENAME}} ekipya. Kya kiseerabuseera.",
 'passwordremindertext'       => 'Waliwo eyayimidde ku ndagiriro eya IP $1 (tusuubiri nti ye ggwe) n\'asaba ekigambo ekikuumi eky\'oku {{SITENAME}} ($4) ekipya.<br />
@@ -498,6 +505,9 @@ Sooka olindeko akaseera okuddamu n'ate.",
 'suspicious-userlogout'      => "Sisitemu ezize ekiragiro kyo eky'okugivaamu kubanga kirabise nga ekivudde mu kalambulanetti enfu<br />
 oba mu puloguramu etereka n'eddamu okuyisa ebiragiro ebivudde awalala.",
 
+# E-mail sending
+'php-mail-error-unknown' => "Wazzewo kiremya atategeerese mu mukolo mail() ogw'omu PHP",
+
 # Password reset dialog
 'resetpass'                 => 'Kyusa ekigambo ekikuumi',
 'resetpass_announce'        => "Weyambisa ekyama eky'ekiseerabuseera okuyingira.<br />
@@ -549,9 +559,12 @@ Oyinz'okuba nga wamaze okutegeka ekya ddala ekipya oba nga wakasabayo eky'ekisee
 'showdiff'                         => 'Ndaga bwe bikyuse',
 'anoneditwarning'                  => "'''Kulabula:''' Owandika toyingidde mu sisitemu. Tujjakuwandika endagiriro eya kompyuta kwosinzidde
 mu lukalala lw'enkuykakyuka ez'omu lupapula luno.",
+'anonpreviewwarning'               => "''Okola toyingidde sisitemu. Bw'on'okaza by'okola nga sisitemu ewandika n'endagiriro yo eya IP mu lukalala lw'enkyukakyuka lw'olupapula luno.''",
 'missingsummary'                   => "'''Okujjukiza:''' Towandise ebinnyonyola enkyukakyuka z'okoze.<br />
 Bw'oddamu okunyiga \"{{int:savearticle}}\", by'okoze tebijjakubaako okunnyonyola.",
 'missingcommenttext'               => 'Wandika ebigambo byo wano awaddako.',
+'missingcommentheader'             => "'''Okujjukiza:''' Ebigambo byo tobiwadde omutwe.<br />
+Bw'oddamu okunyiga \"{{int:savearticle}}\", by'okoze tebijjakubaako omutwe ogubyanjula.",
 'summary-preview'                  => 'Kuno kwe kunnyonyola kwo:',
 'subject-preview'                  => 'Omutwe bwe gunaafaanana:',
 'blockedtitle'                     => 'Ono agaanidwa',
@@ -617,11 +630,72 @@ oyinza <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE
 'userpage-userdoesnotexist'        => 'Akawunti y\'obwamemba "$1" teri mu nkalala za wiki eno.<br />
 Sooka okakase oba ddala oyagala okukolawo olupapula olupya luno.',
 'userpage-userdoesnotexist-view'   => 'Tewali akawunti ey\'obwamemba "$1".',
+'blocked-notice-logextract'        => "Memba ono mu kaakano agaanidwa.<br />
+Bino ebiddako bye ebikwata ku nsonga eyo mu lukalala lw'ebifuddeyo mu by'okugaana:",
+'clearyourcache'                   => "'''Genderera:''' Bw'omala okubaako by'okaza, kiyinza okukwetaagisa okumala<br />
+okukunkumula eggwanika ezzibizi erya kalambulanetti yo olyoke osobole okulaba enkyukakyuka z'okoze.<br />
+<br />
+*Okukola kino mu ez'ekika kya '''Mozilla, Firefox''' ne '''Safari:''' Nyweza eppeesa erya ''Shift'' onyige ne ku kabonero aka ''Reload'', oba nyigira okumu amapeesa aga ''Ctrl'' ne ''F5'' oba aga ''Ctrl'' ne ''R'' (''Command'' ne ''R'' ku kompyuta ey'ekika kya Mac/Apple);<br />
+<br />
+*Okukikolera mu ey'ekika kya '''Google Chrome:''' Nyigira okumu amapeesa aga ''Ctrl, Shift'' ne ''R'' (''Command, Shift'' ne ''R'' ku kompyuta ey'ekika kya Mac/Apple);<br />
+<br />
+*Okukikolera mu ey'ekika kya '''Konqueror:''' Nyiga ku kabonero aka ''Reload'' oba nyiga eppeesa erya ''F5'';<br />
+<br />
+*Mu ey'ekika kya '''Opera:''' Genda mu ''Tools → Preferences'' gy'onosangira ebikola omulimu ogwo;<br />
+<br />
+*Ate mu '''Internet Explorer:''' Nyewza erya ''Ctrl'' nga bw'onyiga akabonero aka ''Refresh'', oba nyigira okumu aga ''Ctrl'' ne ''F5''.",
+'usercssyoucanpreview'             => "'''Amagezi:''' Bw'onyiga akabonero aka \"{{int:showpreview}}\" osobola okulozako enfaanana ya CSS gw'otegese nga tosoose okugikaza.",
+'userjsyoucanpreview'              => "'''Amagezi:''' Nyiga ku kabonero aka \"{{int:showpreview}}\" osobole okulozako enkola ya JavaScript gw'otegese nga tosoose okumukaza.",
+'usercsspreview'                   => "'''Jukira nti CSS gw'otegese omulozakobulozi.'''<br />
+'''Tannakazibwa.'''",
+'userjspreview'                    => "'''Jukira nti JavaScript gw'otegese omugezesamubugezesa oba omulozakobulozi.'''<br />
+'''Tannakazibwa.'''",
+'sitecsspreview'                   => "'''Jukira nti CSS ono omulozakobulozi.'''<br />
+'''Tannakazibwa.'''",
+'sitejspreview'                    => "'''Jukira nti JavaScript ono omulozakobulozi.'''<br />
+'''Tannakazibwa.'''",
+'userinvalidcssjstitle'            => "'''Kulabula:''' Tewali endabika eyitibwa \"\$1\".<br />
+Empapula eza .css ne .js bamemba ze b'ekoledde, amannya ga zo ennukuta za mu<br />
+zonna ziteekwa okuba ntono, okugeza ''{{ns:user}}:Foo/vector.css'' so ssi ''{{ns:user}}:Foo/Vector.css''.",
+'updated'                          => '(Ebituukanisidwa)',
+'note'                             => "'''Okunnyonyola:'''",
 'previewnote'                      => "'''Kuno kugezaamubugeza; by'okoze tebinnakazibwa!'''",
+'previewconflict'                  => "Okulagako kuno y'engeri ebiri w'owandikira gye binaafaananamu singa oba obikazizza.",
+'session_fail_preview'             => "'''Tetusobodde okukola ku by'okyusizza olw'okubanga olutuula'''<br />
+'''lwa wiki luno luzzemu okugootaana olwa data okubula.'''<br /> 
+Kikwetaagisa okuddamu by'okoze. <br />
+Ekyo bwe kitagonjoola ebizibu sooka [[Special:UserLogout|oveemu]] mu wiki oddemu ate okugiyingira.",
+'session_fail_preview_html'        => "'''Tukwetondera! Tekisobose okukola ku nkyukakyuka z'okozewo kubanga data ekwata ku lutuula lwo evuddewo.'''<br />
+<br />
+''{{SITENAME}} esobozesa abantu okukola ku buwandike bwa yo obw'ennono obwa HTML.''<br />
+''Olw'ensonga eyo tukisizza okulagako kw'ebigikyusidwako nga tugeza okwetaasa''<br />
+''abakola enkyukakyuka ez'ekiyaaye nga bayitira mu JavaScript.''<br />
+<br />
+'''Bw'oba nga ddala ogenderera okukola enkyukakyuka wano mu bwesimbu, ddamu ogezeko.'''<br />
+Ekyo bwe kitakola, sooka [[Special:UserLogout|oveemu]] mu wiki oryoke oddemu<br />
+okugiyingira ogezeeko n'ate okukola enkyukakyuka zo.",
+'token_suffix_mismatch'            => "'''Enkyukakyuka zo zigaanidwa olw'okuba nti puloguramu gy'okozesa etabuddetabudde'''<br />
+'''obubonero obumenya mu bubaka obukakasa obugenderevu bw'omulimu ogwo.'''<br />
+Okukyusakyusa kugaanidwa ebigambo ebiri ku lupapula lw'obadde okyusamu bireme nabyo okujjamu entabukatabuka.<br />
+Kino kijjawo oluusi bw'obanga okozesa sisitemu ekusobozesa okulambula yintaneti ebikufaako ne bitayolesebwa<br /> abalala abagiriko, sisitemu eyo nga erimu ebitaatereera.",
 'editing'                          => 'Kati okyusa $1',
 'editingsection'                   => 'Okyusa $1 (kitundu)',
 'editingcomment'                   => 'Okyusa $1 (kitundu kipya)',
+'editconflict'                     => 'Ebikyusidwamu bireesewo okusobagana: $1',
+'explainconflict'                  => "Waliwo omulala akyusizza mu lupapula luno nga okyalukolako.<br />
+Ekitundu eky'ebiwandike ekisooka wano kikulaga ebigambo ebiruliko kakano.<br />
+By'owandise byo biri mu kitundu eky'ebiwandike ekiddako.<br />
+Ebigambo ebibyo on'obigatta mu ebyo ebiriwo ku lupapula kakano.<br />
+Ebinaaba birabika mu kitundu eky'ebiwandike ekisooka w'on'onyigira ku<br />
+\"{{int:savearticle}}\" '''bye byokka''' ebij'okukazibwa.",
 'yourtext'                         => 'Ebigambo ebibyo',
+'storedversion'                    => 'Ebiriwo kakano',
+'nonunicodebrowser'                => "'''Kulabula: Kalambulaneti yo tekwatagana bulungi n'enkola ya unicode.'''<br />
+Okuvvuunuka obuzibu buno osobole okukyusa mu mpapula, buli lw'on'owandikawo<br />
+akabonero akatali ka ASCII kajjanga okuteekebwawo mu mpandika eya nengakkuminabbiri.",
+'editingold'                       => "'''Kulabula: Olupapula lw'okyusamu luliko oluwandika lwa lwo olusinga luno obugya.'''<br />
+By'okoze wano bw'on'obikaza enkyukakyuka endala zonna ezaakakolebwa abalala zijjakusaanawo.",
+'yourdiff'                         => 'Ebikyuse',
 'copyrightwarning'                 => "Genderera nti buli kyowandika muno mu {{SITENAME}} kibalibwa ng'ekifugibwa $2 (okuyiga ebisingawo, laba $1).
 Obanga tewetegese okulaba by'owandise nga babikyusakyusa n'okubisaasaanya nga bwe balaba, tobiwandika muno.<br />
 Tukwesiga nti by'owandika muno bibyo oba wabigya mu kya bonna oba awalala gye batalina bikugizo eby'obwa nannyini.
@@ -629,18 +703,64 @@ Tukwesiga nti by'owandika muno bibyo oba wabigya mu kya bonna oba awalala gye ba
 'copyrightwarning2'                => "Genderera nti buli kyowandika muno mu {{SITENAME}} abalala bayinza okubikyusa oba n'okubigiramu ddala. Obanga tewetegese okulaba by'owandise nga babikyusakyusa n'okubisaasaanya nga bwe balaba, tobiwandika muno.<br />
 Tukwesiga nti by'owandika muno bibyo oba wabigya mu kya bonna oba awalala gye batalina bikugizo eby'obwa nannyini. (okuyiga ebisingawo, laba $1).
 '''TOTEEKAMU EBIRIKO EBIKUGIZO EBY'OBWA NANNYINI NGA BA NYINI BYO TEBAKUWADDE LUKUSA!'''",
+'longpageerror'                    => "'''Kulabula: By'owandise birimu kilobayiti $1.'''<br />
+'''Ebisukka mu kilobayiti $2 tebikkirizibwa.'''<br />
+Tekisobose kukaza by'owandise.",
+'readonlywarning'                  => "'''Kulabula: Eggwanika lya data ku ssaawa eno terikkirizamu ebipya, kubanga balilongoosa.'''<br />
+'''Tojjakusobola okukaza by'okola.'''<br />
+Oyinza okukoppa by'owandise n'obitereka mu fayiro ku kompyuta yo osobole okubiteeka wano edda.<br />
+<br />
+Omuteesiteesi eyalisibye annyonyodde bwatyi: $1",
+'protectedpagewarning'             => "'''Kulabula: Olupapula luno luliko ekikugizo ekikkiriza abalina endukusa z'obuteesiteesi bokka okulukyusamu.'''<br />
+Ekyasemba okuyingizibwa mu lukalala olw'ebifuddeyo lwa lwo bibino okwongera okukutangaaza ku nsonga eno:",
+'semiprotectedpagewarning'         => "'''Genderera: Olupapula luno luliko ekikugizo ekikkirizako ab'ewandisa ku wiki eno bokka okulukyusamu.'''<br />
+Ekyasemba okuyingizibwa mu lukalala olw'ebifuddeyo lwa lwo bibino okwongera okukutangaaza ku nsonga eno:",
+'cascadeprotectedwarning'          => "'''Kulabula:''' Olupapula luno luliko ekikugizo ekikkiriza abalina olukusa lw'obuteesiteesi bokka okulukyusamu.<br />
+Kino kikoledwa olw'okuba nti lukozesebwa {{PLURAL:$1|olupapula oluliko ekikugizo ekiranda luna|empapula eziriko ebikugizo ebiranda zino}}:",
+'titleprotectedwarning'            => "'''Kulabula: Olupapula luno luliko ekikugizo ekikwetaagisa [[Special:ListGroupRights|obuyinza obw'enjawulo]] okulukyusamu.'''<br />
+Ekyasemba okuyingizibwa mu lukalala olw'ebifuddeyo lwa lwo bibino okwongera okukutangaaza ku nsonga eno:",
 'templatesused'                    => 'Olupapula luno lukozesa {{PLURAL:$1|olutiba luno|ntiba zino}} :',
 'templatesusedpreview'             => 'Okulagako kuno kweyambisa {{PLURAL:$1|olutiba luno|ntiba zino}}:',
 'templatesusedsection'             => 'Ekitundu kino kyeyambisa {{PLURAL:$1|olutiba luno|ntiba zino}}:',
 'template-protected'               => '(luno lusibidwa)',
 'template-semiprotected'           => '(ebimu ku lupapula luno bisibidwa)',
 'hiddencategories'                 => 'Olupapula luno lusangibwa mu {{PLURAL:$1|ttuluba erikise limu|matuluba amakise $1}}:',
+'nocreatetitle'                    => 'Okukolawo empapula kuliko obukwakkulizo',
 'nocreatetext'                     => "Ku {{SITENAME}} tosobola okukolawo empapula mpya nga tokozesa buyinza obw'obwamemba. Kati oyinza kugenda n'okyusamu olupapula olulala olwakolebwa dda, oba oyinza [[Special:UserLogin|okufuna obuyinza obw'obwamemba]].",
+'nocreate-loggedin'                => 'Tolina buyinza bwa kukolawo empapula mpya.',
+'sectioneditnotsupported-title'    => 'Okukyusa mu bitundu tekukkirizibwa',
+'sectioneditnotsupported-text'     => 'Olupapula luno terukkiriza okukyusa mu bitundu.',
+'permissionserrors'                => 'Wazzewo kiremya mu ndukusa zo',
+'permissionserrorstext'            => "Kyoyagala okukola tekikukkirizibwa, olw'ensonga {{PLURAL:$1|eno|zino}}:",
 'permissionserrorstext-withaction' => "Tokkirizibwa $2, olw'ensonga {{PLURAL:eno|zino|$1}}:",
 'recreate-moveddeleted-warn'       => "'''Kulabula: Ogenda okuzzaawo olupapuka olwagyibwawo.'''
 
 Okakasa nti kisaanira okuluzzaawo?
 Ebifa ku kugyibwawo kw'olupapula luno bye bino:",
+'moveddeleted-notice'              => "Olupapula luno lwagyibwawo.<br />
+Ebiri mu lukalala olw'ebifa ku kulugyawo n'okulujjulula bibino okukutangaaza ku nsonga eno:",
+'log-fulllog'                      => "Ndaga olukalala olw'ebifuddeyo mu bujjuvu",
+'edit-hook-aborted'                => "Omulimu gwo gutegude emmanduso n'egukomya.<br />
+Tewali kunnyonyola okusingawo.",
+'edit-gone-missing'                => 'Olupapula tekisobose okulutuukanisa.<br />
+Kirabika lwagyibwawo.',
+'edit-conflict'                    => 'Ebikyusidwamu bireesewo okusobagana.',
+'edit-no-change'                   => "Sisitemu ekubaze nga atalina ky'agikozeko, olw'okubanga ebiri ku lupapula obirese nga bwe wabisanze.",
+'edit-already-exists'              => "Olupapula lw'ogeza okukolawo weruli, lwakolebwawo dda.<br />
+Tekisobose kuddamu n'ate oulukolawo.",
+
+# Parser/template warnings
+'expensive-parserfunction-warning'        => "'''Kulabula:''' Olupapula luno luliko ebiragiro eby'ekikebera engoberera y'amateeka g'empandika ebizito ebiyitiridde obungi.<br />
+<br />
+Terukkirizibwa kubaako {{PLURAL:$2|kiragiro ky'ekibekebera ngoberera y'amateeka g'empandika ekisukka|biragiro by'ekikebera mpandika y'amateeka g'empandika ebisukka}} mu $2. Kakano ebiragiro ebyo luliko {{PLURAL:$1|kimu|$1}}.",
+'expensive-parserfunction-category'       => "Empapula eziriko ebiragiro eby'ekikebera engoberera y'amateeka g'empandika ebizito ebiyitiridde obungi",
+'post-expand-template-inclusion-warning'  => "'''Kulabula:''' Entiba ez'okunonebwa ziyitiridde obungi.<br />
+Ezimu zijjakulebwayo.",
+'post-expand-template-inclusion-category' => "Empapula eziriko entiba eziyitiridde obunene olw'ebinone bye zikozesa",
+'post-expand-template-argument-warning'   => "'''Kulabula''' Olupapula luno luliko agumenti ey'omu lutiba nga amakulu gaamu bwe<br />
+gawandikibwa mu bujjuvu ekivaamu kiyitirira obunene. Muyinz'okubaamu n'endala ez'engeri eno.<br />
+Agumenti ezo sistemu tezikozesezza.",
+'post-expand-template-argument-category'  => "Empapula eziriko agumenti ez'omu ntiba sisitemu z'etakozesezza",
 
 # History pages
 'viewpagelogs'           => "Kebera likooda ez'olupapula luno",
@@ -652,6 +772,8 @@ Ebifa ku kugyibwawo kw'olupapula luno bye bino:",
 'currentrevisionlink'    => 'Oluwandika oluliwo kakati',
 'cur'                    => 'ebiriwo',
 'last'                   => 'ebyasookawo bino',
+'page_first'             => 'Olusooka',
+'page_last'              => 'Olusembayo',
 'histlegend'             => "'''Ebyokugerageranizibwa:''' nyiga obutonnyeze ku likooda zoyagala okugerageranya olyoke onyige eppeesa erya 'Enter'<br />
 oba ku gano agali ku lupapula luno.<br />
 '''Ebigambo:''' (erw) = enjawulo ku ebiriwo, (eku) = enjawulo ku egikulembera, N = enkyukakyuka entono.",
@@ -660,9 +782,17 @@ oba ku gano agali ku lupapula luno.<br />
 'histlast'               => 'Tandikira ku bisinga obupya',
 'historysize'            => '({{PLURAL:$1|bayiti 1|bayiti $1}})',
 
+# Revision feed
+'history-feed-item-nocomment' => 'Bya $1, nga $2',
+
 # Revision deletion
-'rev-delundel'   => 'laga/kisa',
-'revdel-restore' => "tegeka ebiba biragibwa n'ebikisibwa",
+'rev-delundel'      => 'laga/kisa',
+'rev-showdeleted'   => 'laga',
+'revdelete-log'     => 'Nsonga:',
+'revdel-restore'    => "tegeka ebiba biragibwa n'ebikisibwa",
+'pagehist'          => "Ennanda y'olupapula luno",
+'revdelete-content' => 'ebirimu',
+'revdelete-uname'   => "ery'obwa memba",
 
 # Merge log
 'revertmerge' => 'Yawula ebigattidwa',
@@ -675,49 +805,93 @@ oba ku gano agali ku lupapula luno.<br />
 'editundo'                => 'julula enkyukakyuka',
 
 # Search results
-'searchresults'             => 'Noonyeza mu bizuulidwa',
-'searchresults-title'       => 'Ebizuulidwa ku "$1"',
-'searchresulttext'          => "Okumanya ebisingawo ku konoonya bintu ku {{SITENAME}}, kebera ku '[[{{MediaWiki:Helppage}}|{{int:help}}]]'.",
-'searchsubtitle'            => 'Onoonyezza \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|empapula zonna ezitandika ne "$1"]]{{int:pipe-separator}}
+'searchresults'                  => 'Noonyeza mu bizuulidwa',
+'searchresults-title'            => 'Ebizuulidwa ku "$1"',
+'searchresulttext'               => "Okumanya ebisingawo ku konoonya bintu ku {{SITENAME}}, kebera ku '[[{{MediaWiki:Helppage}}|{{int:help}}]]'.",
+'searchsubtitle'                 => 'Onoonyezza \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|empapula zonna ezitandika ne "$1"]]{{int:pipe-separator}}
 [[Special:WhatLinksHere/$1|empapula zonna ezikuggusa ku "$1"]])',
-'searchsubtitleinvalid'     => "Onoonyezza '''$1'''",
-'notitlematches'            => 'Tewali mpapula zirina mutwe guno',
-'notextmatches'             => 'Tewali mpapula ziriko bigambo bino',
-'prevn'                     => '{{PLURAL:$1|$1}} ezikulembedde zino',
-'nextn'                     => '{{PLURAL:$1|$1}} eziddako',
-'viewprevnext'              => 'Laga ($1 {{int:pipe-separator}} $2) ($3).',
-'searchhelp-url'            => 'Help:Endagiriro',
-'search-result-size'        => '$1 ({{PLURAL:$2|kigambo 1 | bigambo $2}})',
-'search-redirect'           => "(olupapula '$1' lukuggusiza wano)",
-'search-section'            => '(ekitundu ekya $1)',
-'search-suggest'            => 'Obadde onoonya $1 ?',
-'search-interwiki-caption'  => "Pulojekiti ezikolagana n'eno",
-'search-interwiki-default'  => 'ebizuulidwa ku $1:',
-'search-interwiki-more'     => '(ebikyaliyo)',
-'search-mwsuggest-enabled'  => 'mpeeraako amagezi',
-'search-mwsuggest-disabled' => "sisitemu ereme okuteebereza ky'onoonya",
-'nonefound'                 => "'''Wekkaanye''': Okunoonya kuno kukoma mu makuŋaanyizo amalondemu okugyako nga okulagidde okweyonera awalala.
+'searchsubtitleinvalid'          => "Onoonyezza '''$1'''",
+'toomanymatches'                 => "Ebikwataganya by'onoonyezesazza biyitiridde obungi. Ky'onoonyezesa kikyusemu",
+'titlematches'                   => 'Empapula ezirina emitwe egyefaananyiriza guno',
+'notitlematches'                 => 'Tewali mpapula zirina mutwe guno',
+'textmatches'                    => "Empapula eziriko ebigambo by'onoonyezesezza",
+'notextmatches'                  => 'Tewali mpapula ziriko bigambo bino',
+'prevn'                          => '{{PLURAL:$1|$1}} ezikulembedde zino',
+'nextn'                          => '{{PLURAL:$1|$1}} eziddako',
+'prevn-title'                    => '{{PLURAL:$1|Ekizuulidwa $1 ekikulembera|Ebizuulidwa $1 ebikulembera}}',
+'nextn-title'                    => '{{PLURAL:$1|Ekizuulidwa $1 ekiddako|Ebizuulidwa $1 ebiddako}}',
+'shown-title'                    => 'Ndaga {{PLURAL:$1|ekizuulidwa|ebizuulidwa}} $1 ku buli lupapula',
+'viewprevnext'                   => 'Laga ($1 {{int:pipe-separator}} $2) ($3).',
+'searchmenu-legend'              => 'Kyusamu ennoonya',
+'searchmenu-exists'              => "'''Olupapula \"[[:\$1]]\" gyeruli ku wiki eno.'''",
+'searchmenu-new'                 => "'''Oba oyagala, olupapula \"[[:\$1]]\" gwe osobola okulukolawo ku wiki eno.'''",
+'searchhelp-url'                 => 'Help:Endagiriro',
+'searchmenu-prefix'              => '[[Special:PrefixIndex/$1|Kebera mu mpapula eziriko akatandikwa kano]]',
+'searchprofile-articles'         => "Empapula ez'ensonga",
+'searchprofile-project'          => "Empapula eziriko obuyambi n'eza Kawefube",
+'searchprofile-images'           => "Mediya ey'ekintabuli - Bifaananyi, Vidiyo n'ebiWulirizibwa",
+'searchprofile-everything'       => 'Wonna',
+'searchprofile-articles-tooltip' => 'Noonyeza mu $1',
+'searchprofile-project-tooltip'  => 'Noonyeza mu $1',
+'searchprofile-images-tooltip'   => 'Noonya fayiro',
+'search-result-size'             => '$1 ({{PLURAL:$2|kigambo 1 | bigambo $2}})',
+'search-redirect'                => "(olupapula '$1' lukuggusiza wano)",
+'search-section'                 => '(ekitundu ekya $1)',
+'search-suggest'                 => 'Obadde onoonya $1 ?',
+'search-interwiki-caption'       => "Pulojekiti ezikolagana n'eno",
+'search-interwiki-default'       => 'ebizuulidwa ku $1:',
+'search-interwiki-more'          => '(ebikyaliyo)',
+'search-mwsuggest-enabled'       => 'mpeeraako amagezi',
+'search-mwsuggest-disabled'      => "sisitemu ereme okuteebereza ky'onoonya",
+'searchall'                      => '',
+'nonefound'                      => "'''Wekkaanye''': Okunoonya kuno kukoma mu makuŋaanyizo amalondemu okugyako nga okulagidde okweyonera awalala.
 W'owandikira by'onoonya bw'osoosawo akagambo ''all:'', okunoonya kubuna Wikipediya yonna. Bw'obanga olina ekkuŋaanyizo limu lyokka lyoyagala okunoonyezamu, soosawo erinnya lyalyo w'owandikira by'onoonya.",
-'powersearch'               => 'Noonya mu ngeri esunsula',
-'powersearch-legend'        => 'Noonya mu ngeri esunsula',
-'powersearch-ns'            => 'Noonyeza mu makuŋaaniro gano:',
-'powersearch-redir'         => "Laga n'empapula ezikutwalabutwazi ku zinnaazo",
-'powersearch-field'         => 'Nnoonyeza',
+'powersearch'                    => 'Noonya mu ngeri esunsula',
+'powersearch-legend'             => 'Noonya mu ngeri esunsula',
+'powersearch-ns'                 => 'Noonyeza mu makuŋaaniro gano:',
+'powersearch-redir'              => "Laga n'empapula ezikutwalabutwazi ku zinnaazo",
+'powersearch-field'              => 'Nnoonyeza',
+'powersearch-togglelabel'        => 'Londa:',
+'powersearch-toggleall'          => 'Gonna',
 
 # Preferences page
-'preferences'       => 'Enteekateeka yange',
-'mypreferences'     => 'Enteekateeka yange',
-'skin-preview'      => 'Kulozzako',
-'prefs-personal'    => 'Ebikufaako',
-'saveprefs'         => 'Bino bikaze',
-'resetprefs'        => 'Gyawo enkyukakyuka ze sinnakaza',
-'searchresultshead' => 'Noonya',
-'savedprefs'        => 'Enteekateeka yo ekazidwa.',
-'allowemail'        => 'Kkiriza bamemba abalala okukusindikira e-mail',
-'username'          => "Ery'obwa memba:",
-'yourlanguage'      => 'Lulimi lwo:',
-'yournick'          => 'Empaako yo (ssi ya tteeka):',
-'prefs-help-email'  => "Okuwayo E-mail yo ssi kya tteeka, naye yetaagisibwa bw'obanga werabide ekigambo kyo ekikuumi - basobole okukusindikira ekipya.
+'preferences'               => 'Enteekateeka yange',
+'mypreferences'             => 'Enteekateeka yange',
+'skin-preview'              => 'Kulozzako',
+'prefs-personal'            => 'Ebikufaako',
+'prefs-resetpass'           => 'Kyusa ekigambo ekikuumi',
+'prefs-email'               => 'Enteekateeka eza E-mail',
+'prefs-rendering'           => 'Endabika',
+'saveprefs'                 => 'Bino bikaze',
+'resetprefs'                => 'Gyawo enkyukakyuka ze sinnakaza',
+'restoreprefs'              => 'Zawo enteekateeka zi nansangwawo',
+'prefs-editing'             => 'Kukyusa',
+'searchresultshead'         => 'Noonya',
+'savedprefs'                => 'Enteekateeka yo ekazidwa.',
+'timezonelegend'            => 'Ssaawa za mu:',
+'localtime'                 => "Ssaawa za w'oli:",
+'timezoneuseserverdefault'  => 'Kozesa ssaawa sistemu ze yerondera',
+'timezoneuseoffset'         => 'Ndala (tegeka enjawulo mu budde)',
+'timezoneoffset'            => 'Njawulo mu budde¹:',
+'servertime'                => 'Ssaawa ya sisitemu:',
+'guesstimezone'             => 'Kalambulanetti etegeke obudde',
+'timezoneregion-africa'     => 'Afirika',
+'timezoneregion-america'    => 'Amerika',
+'timezoneregion-antarctica' => 'Antakitika',
+'timezoneregion-arctic'     => 'Akitiki',
+'timezoneregion-asia'       => 'Ezya',
+'timezoneregion-atlantic'   => 'Liyanja Atalantika',
+'timezoneregion-australia'  => 'Awusitureliya',
+'timezoneregion-europe'     => 'Bulaaya',
+'timezoneregion-indian'     => 'Liyanja ya Buyindi',
+'timezoneregion-pacific'    => 'Liyanja Kirimulaala',
+'allowemail'                => 'Kkiriza bamemba abalala okukusindikira e-mail',
+'prefs-searchoptions'       => 'Enteekateeka ezifuga okunoonya',
+'prefs-namespaces'          => 'Makuŋaanyizo',
+'username'                  => "Ery'obwa memba:",
+'yourlanguage'              => 'Lulimi lwo:',
+'yournick'                  => 'Empaako yo (ssi ya tteeka):',
+'prefs-help-email'          => "Okuwayo E-mail yo ssi kya tteeka, naye yetaagisibwa bw'obanga werabide ekigambo kyo ekikuumi - basobole okukusindikira ekipya.
 
 Osobola okusalawo okuba nga ab'etaaga okukutuukirira bayitira ku nfo yo ey'obwa memba oba olupapula lwo olwa 'yogera nange' nga ggwe tewetaaze kulaga bikufaako.",
 
@@ -796,6 +970,9 @@ Osobola okusalawo okuba nga ab'etaaga okukutuukirira bayitira ku nfo yo ey'obwa
 'sharedupload'              => "Fayiro eno, ey'omu $1, y'emu esobola okuba nga empapula ez'omu pulojekiti endala zigikozesa",
 'uploadnewversion-linktext' => 'Teekayo oluwandika lwa fayiro eno olupya',
 
+# File deletion
+'filedelete-comment' => 'Ekigyisizzawo fayiro:',
+
 # Random page
 'randompage' => 'Nondera olupapula muwawa',
 
@@ -842,6 +1019,7 @@ Osobola okusalawo okuba nga ab'etaaga okukutuukirira bayitira ku nfo yo ey'obwa
 # Special:LinkSearch
 'linksearch'    => 'Ennyunzi eziggukira wabweru wa Wikipediya',
 'linksearch-ns' => 'Kuŋaanyizo:',
+'linksearch-ok' => 'Noonya',
 
 # Special:Log/newusers
 'newuserlogpage'          => "Olukalala olw'ebifudeyo mu kukolawo akawunti empya",
@@ -930,10 +1108,11 @@ Oyinz'okukyusa okusibibwa kw'olupapula luno, naye tekijjakukyusa ebikugizo ebivu
 'restriction-move' => 'Simbuliza',
 
 # Undelete
-'undeletebtn'      => 'Luzzewo',
-'undeletelink'     => 'lukebere/luzzewo',
-'undeletecomment'  => 'Nsonga:',
-'undeletedarticle' => '"[[$1]]" luzzidwawo',
+'undeletebtn'            => 'Luzzewo',
+'undeletelink'           => 'lukebere/luzzewo',
+'undeletecomment'        => 'Nsonga:',
+'undeletedarticle'       => '"[[$1]]" luzzidwawo',
+'undelete-search-submit' => 'Noonya',
 
 # Namespace form on various pages
 'namespace'      => 'Kuŋaanyizo:',
@@ -977,7 +1156,8 @@ Oyinz'okukyusa okusibibwa kw'olupapula luno, naye tekijjakukyusa ebikugizo ebivu
 'blockip'                  => 'Gaana memba okuwandika',
 'ipboptions'               => 'saawa 2:2 hours,lunaku 1:1 day,nnaku 3:3 days,sande 1:1 week,sande 2:2 weeks,mwezi 1:1 month,myezi 3:3 months,myezi 6:6 months,mwaka 1:1 year,okutali kkomo:infinite',
 'blockipsuccesssub'        => 'Memba agaaniddwa okuwandika',
-'ipblocklist'              => "Endagiriro n'amanya ag'abagaanidwa",
+'ipblocklist'              => 'Abagaanidwa',
+'ipblocklist-submit'       => 'Noonya',
 'blocklink'                => 'Ono agaanibwe okuwandika',
 'unblocklink'              => 'kkiriza memba okuwandika',
 'change-blocklink'         => 'kyusa okugaanibwa',
@@ -1085,7 +1265,7 @@ Ob'oyagala okuyamba ku kuvvuunula eby'omu MediaWiki yonna, kebera ku [http://www
 'tooltip-t-whatlinkshere'         => "Nyiga wano okulaba empapula ez'oku wiki zonna eziriko enyunzi ezikuggusa ku luno",
 'tooltip-t-recentchangeslinked'   => "Enkyukakyuka mpya ku mpapula z'osobola okuggukako okuva ku luno",
 'tooltip-feed-rss'                => "Nyiga wano okulaba omukutu gw'amawulire agafa ku lupapula luno ogw'ekika kya RSS",
-'tooltip-feed-atom'               => "↓ Nyiga wano okulaba omukutu gw'amawulire agafa ku lupapula luno ogw'ekika kya Atom",
+'tooltip-feed-atom'               => "Nyiga wano okulaba omukutu gw'amawulire agafa ku lupapula luno ogw'ekika kya Atom",
 'tooltip-t-contributions'         => "Nyiga wano ob'oyagala okumanya memba ono by'akozeyo ku wiki eno",
 'tooltip-t-emailuser'             => "Nyiga wano ob'oyagala memba ono okumusindikira e-mail",
 'tooltip-t-upload'                => "Nyiga wano ob'oyagala okuteekayo fayiro ku wiki eno",
@@ -1121,12 +1301,15 @@ Ob'oyagala okuyamba ku kuvvuunula eby'omu MediaWiki yonna, kebera ku [http://www
 'nextdiff'     => 'Enkyukakyuka ezaddako okukolebwa→',
 
 # Media information
-'file-info-size'       => '(pikseli $1 ku $2 , bunene bwa fayiro: $3, kika kya MIME: $4)',
+'file-info-size'       => 'pikseli $1 ku $2 , bunene bwa fayiro: $3, kika kya MIME: $4',
 'file-nohires'         => '<small>Tewali kisingako wano.</small>',
-'svg-long-desc'        => '(Fayiro ya kika  kya SVG, ya pikselo $1 ku $2 awamu, ya obunene bwa: $3)',
+'svg-long-desc'        => 'Fayiro ya kika  kya SVG, ya pikselo $1 ku $2 awamu, ya obunene bwa: $3',
 'show-big-image'       => 'Laga ekifaananyi ekijjuvu',
 'show-big-image-thumb' => '<small>Okulagako kuno kwa pikiseli: $1 ku $2</small>',
 
+# Special:NewFiles
+'ilsubmit' => 'Noonya',
+
 # Bad image list
 'bad_image_list' => 'Empandika entuufu:
 
@@ -1186,6 +1369,9 @@ Ebirala biyinza butalabika okujjako ng'okiragidde.
 # Special:Version
 'version-specialpages' => 'Empapula enjawule',
 
+# Special:FileDuplicateSearch
+'fileduplicatesearch-submit' => 'Noonya',
+
 # Special:SpecialPages
 'specialpages' => 'Empapula enjawule',
 
