@@ -12,6 +12,25 @@
  * @author Jureits
  */
 
+$namespaceNames = array(
+	NS_MEDIA            => 'Medeja',
+	NS_SPECIAL          => 'Seviškuo',
+	NS_TALK             => 'Sprīža',
+	NS_USER             => 'Lītuotuojs',
+	NS_USER_TALK        => 'Sprīža_ap_lītuotuoju',
+	NS_PROJECT_TALK     => 'Sprīža_ap_{{GRAMMAR:accusative|$1}}',
+	NS_FILE             => 'Fails',
+	NS_FILE_TALK        => 'Sprīža_ap_failu',
+	NS_MEDIAWIKI        => 'MediaWiki',
+	NS_MEDIAWIKI_TALK   => 'Sprīža_ap_MediaWiki',
+	NS_TEMPLATE         => 'Taiss',
+	NS_TEMPLATE_TALK    => 'Sprīža_ap_taisu',
+	NS_HELP             => 'Paleigs',
+	NS_HELP_TALK        => 'Sprīža_ap_paleigu',
+	NS_CATEGORY         => 'Kategoreja',
+	NS_CATEGORY_TALK    => 'Sprīža_ap_kategoreju',
+);
+
 $fallback = 'lv';
 
 $messages = array(
@@ -107,27 +126,21 @@ $messages = array(
 'faqpage'        => 'Project:BUV',
 
 # Vector skin
-'vector-action-addsection'   => 'Dalikt padaļu',
-'vector-action-delete'       => 'Iztreit',
-'vector-action-move'         => 'Puorceļt',
-'vector-action-protect'      => 'Apsorguot',
-'vector-action-unprotect'    => 'Nūjimt apsardzeibu',
-'vector-namespace-category'  => 'Kategoreja',
-'vector-namespace-image'     => 'Fails',
-'vector-namespace-mediawiki' => 'Viestejums',
-'vector-namespace-project'   => 'Projekta puslopa',
-'vector-namespace-special'   => 'Specialuo puslopa',
-'vector-namespace-talk'      => 'Sprīža',
-'vector-namespace-template'  => 'Taiss',
-'vector-view-edit'           => 'Pataiseit',
-'vector-view-history'        => 'Viesture',
-'vector-view-view'           => 'Vērtīs',
-'namespaces'                 => 'Vuordu pluoti',
-'variants'                   => 'Varianti',
+'vector-action-addsection' => 'Dalikt padaļu',
+'vector-action-delete'     => 'Iztreit',
+'vector-action-move'       => 'Puorceļt',
+'vector-action-protect'    => 'Apsorguot',
+'vector-action-unprotect'  => 'Puormeit apsardzeibu',
+'vector-view-edit'         => 'Pataiseit',
+'vector-view-history'      => 'Viesture',
+'vector-view-view'         => 'Vērtīs',
+'actions'                  => 'Darbeibys',
+'namespaces'               => 'Vuordu pluoti',
+'variants'                 => 'Varianti',
 
 'errorpagetitle'   => 'Klaida',
 'returnto'         => 'Grīztīs da puslopys $1.',
-'tagline'          => 'Nu {{SITENAME}}',
+'tagline'          => 'Materials nu {{grammar:genitive|{{SITENAME}}}}',
 'help'             => 'Paleigs',
 'search'           => 'Maklātivs',
 'searchbutton'     => 'Meklēt',
@@ -148,7 +161,7 @@ $messages = array(
 'protect'          => 'Apsorguot',
 'protect_change'   => 'puormeit',
 'protectthispage'  => 'Apsorguot itū puslopu',
-'unprotect'        => 'Nūjimt apsardzeibu',
+'unprotect'        => 'Puormeit apsardzeibu',
 'newpage'          => 'Jauna puslopa',
 'talkpage'         => 'Apmīgt itū puslopu',
 'talkpagelinktext' => 'sprīža',
@@ -238,7 +251,7 @@ Par to var ziņuot [[Special:ListUsers/sysop|kaidam administratoram]], nūruodū
 # Login and logout pages
 'yourname'                => 'Slāgvuords:',
 'yourpassword'            => 'Paroļs:',
-'remembermypassword'      => 'Atguoduot munu paroli iz ituo datora',
+'remembermypassword'      => 'Atguoduot muni  iz ituo datora (na vaira kai $1 {{PLURAL:$1|dīnu|dīnom|dīnom}})',
 'login'                   => 'Dasaslāgt',
 'nav-login-createaccount' => 'Dasaslāgt / sataiseit jaunu lītuotuoju',
 'userlogin'               => 'Dasaslāgt / sataiseit jaunu lītuotuoju',
@@ -248,12 +261,14 @@ Par to var ziņuot [[Special:ListUsers/sysop|kaidam administratoram]], nūruodū
 'nologinlink'             => 'Registrētīs',
 'createaccount'           => 'Sataiseit jaunu lītuotuoju',
 'gotaccountlink'          => 'Dasaslāgt',
+'createaccountreason'     => 'Īmesle:',
 'mailmypassword'          => 'Atsyuteit maņ jaunu paroli',
 'loginlanguagelabel'      => 'Volūda: $1',
 
 # Password reset dialog
-'resetpass_text'          => '<!-- Dalikt tekstu ite -->',
-'resetpass-submit-cancel' => 'Atsaukt',
+'resetpass_text'            => '<!-- Dalikt tekstu ite -->',
+'resetpass-submit-loggedin' => 'Puormeit paroļu',
+'resetpass-submit-cancel'   => 'Atsaukt',
 
 # Edit page toolbar
 'bold_sample'     => 'Pamalnais roksts',
@@ -389,30 +404,43 @@ n = nasvareigs lobuojums.',
 'powersearch-togglenone'    => 'Nikas',
 
 # Preferences page
-'preferences'      => 'Īstatejumi',
-'mypreferences'    => 'Muni īstatejumi',
-'datedefault'      => 'Piec nūklusiejuma',
-'prefs-datetime'   => 'Data i laiks',
-'saveprefs'        => 'Izglobuot',
-'timezonelegend'   => 'Laika zona:',
-'prefs-namespaces' => 'Vuordu pluoti',
-'username'         => 'Slāgvuords:',
-'uid'              => 'Lītuotuoja ID:',
-'yourlanguage'     => 'Volūda:',
-'yourgender'       => 'Kuorta:',
-'gender-unknown'   => 'Nava nūruodeits',
-'gender-male'      => 'Veirīts',
-'gender-female'    => 'Sīvīts',
-'prefs-info'       => 'Pamatinformaceja',
+'preferences'           => 'Īstatejumi',
+'mypreferences'         => 'Muni īstatejumi',
+'changepassword'        => 'Puormeit paroļu',
+'datedefault'           => 'Piec nūklusiejuma',
+'prefs-datetime'        => 'Data i laiks',
+'saveprefs'             => 'Izglobuot',
+'timezonelegend'        => 'Laika zona:',
+'localtime'             => 'Vītejais laiks:',
+'timezoneregion-africa' => 'Afrika',
+'timezoneregion-asia'   => 'Azeja',
+'timezoneregion-europe' => 'Europa',
+'prefs-namespaces'      => 'Vuordu pluoti',
+'prefs-files'           => 'Faili',
+'youremail'             => 'Tovs e-posta adress:',
+'username'              => 'Slāgvuords:',
+'uid'                   => 'Lītuotuoja ID:',
+'yourrealname'          => 'Jiusu eistyns vuords:',
+'yourlanguage'          => 'Volūda:',
+'yourgender'            => 'Kuorta:',
+'gender-unknown'        => 'Nava nūruodeits',
+'gender-male'           => 'Veirīts',
+'gender-female'         => 'Sīvīts',
+'email'                 => 'E-posts',
+'prefs-info'            => 'Pamatinformaceja',
+'prefs-signature'       => 'Paroksts',
 
 # Groups
 'group'       => 'Grupa:',
 'group-user'  => 'Lītuotuoji',
 'group-bot'   => 'Boti',
 'group-sysop' => 'Administratori',
+'group-all'   => '(vysi)',
 
-'group-user-member'  => 'lītuotuojs',
-'group-sysop-member' => 'Administrators',
+'group-user-member'       => 'lītuotuojs',
+'group-bot-member'        => 'robots',
+'group-sysop-member'      => 'administrators',
+'group-bureaucrat-member' => 'birokrats',
 
 'grouppage-user'  => '{{ns:project}}:Lītuotuoji',
 'grouppage-bot'   => '{{ns:project}}:Boti',
@@ -421,6 +449,7 @@ n = nasvareigs lobuojums.',
 # Rights
 'right-upload'        => 'Īsyuteit failus',
 'right-upload_by_url' => 'Īsyuteit failu nu URL adresa',
+'right-delete'        => 'Iztreit puslopys',
 
 # User rights log
 'rightslog'  => 'Lītuotuoju tīseibu registrs',
@@ -573,7 +602,6 @@ Lopys, kas ir tovā [[Special:Watchlist|puorraugamūs rokstu sarokstā]] ir '''r
 # Watchlist
 'watchlist'         => 'Muns davēris saroksts',
 'mywatchlist'       => 'Muns davēris saroksts',
-'watchlistfor'      => "(deļ '''$1''')",
 'addedwatch'        => 'Davīnuots puorraugamū sarokstam.',
 'addedwatchtext'    => "Lopa \"[[:\$1]]\" ir davīnuota [[Special:Watchlist|tevis puorraugamajom lopom]], kur tiks paruodeitys izmainis, kas izdareitys itymā lopā voi ituos lopys sarunu lopā, kai ari itei lopa tiks īzeimāta '''pusrasna''' [[Special:RecentChanges|pādejūs izmaiņu lopā]], lai itū byutu vīgluok pamaneit.
 
@@ -666,7 +694,7 @@ Pašreizejī lopys '''$1''' īstatejumi ir:",
 'linkshere'                => "Itamuos lopuos ir nūruodis iz lopu '''[[:$1]]''':",
 'isredirect'               => 'puoradresiešonys puslopa',
 'istemplate'               => 'izsaukts',
-'isimage'                  => 'atvaiga saita',
+'isimage'                  => 'Faila saita',
 'whatlinkshere-prev'       => '{{PLURAL:$1|īprīškejū|īprīškejūs $1}}',
 'whatlinkshere-next'       => '{{PLURAL:$1|nuokamū|nuokamūs $1}}',
 'whatlinkshere-links'      => '← saitys',
@@ -813,9 +841,9 @@ Tys ļaun davīnuot pamatuojumu kūpsavylkumā.',
 'nextdiff'     => 'Jaunuokuo verseja →',
 
 # Media information
-'file-info-size'       => '($1 × $2 pikseli, faila izmārs: $3, MIME tips: $4)',
+'file-info-size'       => '$1 × $2 pikseli, faila izmārs: $3, MIME tips: $4',
 'file-nohires'         => '<small>Augstuoka izškirtspieja nav pīejama.</small>',
-'svg-long-desc'        => '(SVG fails, definātais lelums $1 × $2 pikseli, faila lelums: $3)',
+'svg-long-desc'        => 'SVG fails, definātais lelums $1 × $2 pikseli, faila lelums: $3',
 'show-big-image'       => 'Pylnā lelumā',
 'show-big-image-thumb' => '<small>Ituo pyrmsskota lelums: $1 × $2 pikseli</small>',
 
@@ -863,6 +891,7 @@ Puorejī lauki, piec nūklusiejuma, byus nūglobuoti.
 'version-specialpages'     => 'Specialuos puslopys',
 'version-version'          => '(Verseja $1)',
 'version-license'          => 'Liceņceja',
+'version-poweredby-others' => 'cyti',
 'version-software-product' => 'Produkts',
 'version-software-version' => 'Verseja',
 
