@@ -66,8 +66,7 @@ $messages = array(
 'tog-editsection'             => "Permette 'e cagnà 'e sezzione cu a jonta [cagna]",
 'tog-editsectiononrightclick' => "Permette 'e cangne 'e sezzione cliccanno p''o tasto destro ncopp 'e titule 'e sezzione (JavaScript)",
 'tog-showtoc'                 => "Mosta ll'innece pe 'e paggene cu cchiù 'e 3 sezzione",
-'tog-rememberpassword'        => "Ricurda 'a registrazzione pe' cchiu sessione",
-'tog-editwidth'               => "Larghezza massima d''a casella pe scrivere",
+'tog-rememberpassword'        => "Ricurda 'a registrazzione pe' cchiu sessione (for a maximum of $1 {{PLURAL:$1|day|days}})",
 
 'underline-always' => 'Sèmpe',
 'underline-never'  => 'Màje',
@@ -128,22 +127,21 @@ $messages = array(
 'category_header' => 'Paggene rìnt\'a categurìa "$1"',
 'subcategories'   => 'Categurìe secunnarie',
 
-'about'          => 'Nfromma',
-'article'        => 'Articulo',
-'newwindow'      => "(s'arape n'ata fenèsta)",
-'cancel'         => 'Scancèlla',
+'about'     => 'Nfromma',
+'article'   => 'Articulo',
+'newwindow' => "(s'arape n'ata fenèsta)",
+'cancel'    => 'Scancèlla',
+'mypage'    => "'A paggena mia",
+'mytalk'    => "'E mmie chiacchieriàte",
+'anontalk'  => 'Chiacchierate pe chisto IP',
+
+# Cologne Blue skin
 'qbfind'         => 'Truòva',
 'qbedit'         => 'Càgna',
 'qbpageoptions'  => 'Chesta paggena',
 'qbpageinfo'     => "Nfrummazzione ncopp'â paggena",
 'qbmyoptions'    => "'E ppaggene mie",
 'qbspecialpages' => 'Pàggene speciàle',
-'mypage'         => "'A paggena mia",
-'mytalk'         => "'E mmie chiacchieriàte",
-'anontalk'       => 'Chiacchierate pe chisto IP',
-
-# Metadata in edit box
-'metadata_help' => 'Metadate:',
 
 'errorpagetitle'    => 'Sbaglio',
 'returnto'          => 'Torna a $1.',
@@ -173,7 +171,7 @@ $messages = array(
 'imagepage'         => 'Paggena fiùra',
 'otherlanguages'    => 'Ate léngue',
 'redirectedfrom'    => "(Redirect 'a $1)",
-'lastmodifiedat'    => "Urdema cagnamiénto pe' a paggena: $2, $1.", # $1 date, $2 time
+'lastmodifiedat'    => "Urdema cagnamiénto pe' a paggena: $2, $1.",
 'viewcount'         => 'Chesta paggena è stata lètta {{PLURAL:$1|una vòta|$1 vòte}}.',
 'jumpto'            => 'Vaje a:',
 'jumptonavigation'  => 'navigazione',
@@ -224,7 +222,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'welcomecreation'            => "== Bemmenuto, $1! ==
 
 'O cunto è stato criato currettamente.  Nun scurdà 'e perzonalizzà 'e ppreferenze 'e {{SITENAME}}.",
-'remembermypassword'         => 'Allicuordate d"a password',
+'remembermypassword'         => 'Allicuordate d"a password (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => "Spiecà 'o dumminio",
 'login'                      => 'Tràse',
 'userlogin'                  => "Tràse o cria n'acciesso nuovo",
@@ -236,8 +234,6 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'createaccount'              => 'Cria nu cunto nuovo',
 'gotaccount'                 => "Tiene già nu cunto? '''$1'''.",
 'gotaccountlink'             => 'Tràse',
-'username'                   => 'Nomme utente',
-'yourlanguage'               => 'Lengua:',
 'loginerror'                 => "Probblema 'e accièsso",
 'loginsuccesstitle'          => 'Acciesso affettuato',
 'nosuchusershort'            => 'Nun ce stanno utente cu o nòmme "<nowiki>$1</nowiki>". Cuntrolla si scrivìste buòno.',
@@ -272,7 +268,6 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 
 # History pages
 'currentrev' => "Verzione 'e mmo",
-'deletedrev' => '[scancellata]',
 
 # Revision deletion
 'rev-delundel' => 'faje vedé/annascunne',
@@ -280,7 +275,6 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 # Search results
 'searchresults'    => "Risultato d''a recerca",
 'searchresulttext' => "Pe sapé de cchiù ncopp'â comme ascia 'a {{SITENAME}}, vere [[{{MediaWiki:Helppage}}|Ricerca in {{SITENAME}}]].",
-'noexactmatch'     => "''''A paggena \"\$1\" nun asiste.''' Se pô [[:\$1|criala mmo]].",
 'notitlematches'   => "Voce addemannata nun truvata dint' 'e titule 'e articulo",
 'notextmatches'    => "Voce addemannata nun truvata dint' 'e teste 'e articulo",
 'searchhelp-url'   => 'Help:Ajùto',
@@ -293,6 +287,8 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'prefs-watchlist'       => 'Asservate speciale',
 'columns'               => 'Culonne:',
 'timezoneregion-africa' => 'Afreca',
+'username'              => 'Nomme utente',
+'yourlanguage'          => 'Lengua:',
 
 # User rights log
 'rightsnone' => '(nisciuno)',
@@ -313,20 +309,21 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'rc_categories_any' => 'Qualònca',
 
 # Recent changes linked
-'recentchangeslinked' => 'Cagnamiénte cullegate',
+'recentchangeslinked'         => 'Cagnamiénte cullegate',
+'recentchangeslinked-feed'    => 'Cagnamiénte cullegate',
+'recentchangeslinked-toolbox' => 'Cagnamiénte cullegate',
 
 # Upload
-'upload'           => 'Careca file',
-'fileexists-thumb' => "<center>'''Immagine esistente'''</center>",
-'uploadedimage'    => 'ha carecato "[[$1]]"',
+'upload'        => 'Careca file',
+'uploadedimage' => 'ha carecato "[[$1]]"',
 
 # Special:ListFiles
 'listfiles_name' => 'Nomme',
 
 # File description page
+'file-anchor-link' => 'Fiura',
 'filehist-user'    => 'Utente',
 'imagelinks'       => 'Jonte ê ffiure',
-'noimage-linktext' => 'carrecarlo mmo',
 
 # Random page
 'randompage'         => 'Na paggena qualsiase',
@@ -355,7 +352,9 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 
 # Special:Categories
 'categories'         => 'Categurìe',
-'categoriespagetext' => "Lista cumpleta d\"e categurie presente ncopp' 'o sito.",
+'categoriespagetext' => "Lista cumpleta d\"e categurie presente ncopp' 'o sito.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].",
 
 # Special:LinkSearch
 'linksearch-ok' => 'Truova',
@@ -379,15 +378,15 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'deletedarticle'  => 'ha scancellato "[[$1]]"',
 'dellogpage'      => 'Scancellazione',
 'deletionlog'     => 'Log d"e scancellazione',
-'deletecomment'   => 'Mutivo d"a scancellazione',
+'deletecomment'   => 'Raggióne',
 
 # Rollback
 'rollback'   => "Ausa na revizione 'e primma",
-'revertpage' => "Cangiaje 'e cagnamiénte 'e [[Special:Contributions/$2|$2]] ([[User talk:$2|discussione]]), cu â verzione 'e pprimma 'e  [[User:$1|$1]]", # Additionally available: $3: revid of the revision reverted to, $4: timestamp of the revision reverted to, $5: revid of the revision reverted from, $6: timestamp of the revision reverted from
+'revertpage' => "Cangiaje 'e cagnamiénte 'e [[Special:Contributions/$2|$2]] ([[User talk:$2|discussione]]), cu â verzione 'e pprimma 'e  [[User:$1|$1]]",
 
 # Protect
 'prot_1movedto2'         => 'ha spustato [[$1]] a [[$2]]',
-'protect-expiry-options' => '2 ore:2 hours,1 juorno:1 day,3 juorne:3 days,1 semmana:1 week,2 semmane:2 weeks,1 mise:1 month,3 mese:3 months,6 mese:6 months,1 anno:1 year,infinito:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options' => '2 ore:2 hours,1 juorno:1 day,3 juorne:3 days,1 semmana:1 week,2 semmane:2 weeks,1 mise:1 month,3 mese:3 months,6 mese:6 months,1 anno:1 year,infinito:infinite',
 
 # Undelete
 'viewdeletedpage' => "Vìre 'e ppàggine scancellate",
@@ -399,6 +398,8 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'contributions' => 'Contribbute utente',
 'mycontris'     => 'Mie contribbute',
 
+'sp-contributions-talk' => 'Chiàcchiera',
+
 # What links here
 'whatlinkshere'       => 'Paggene ca cullegano a chesta',
 'whatlinkshere-title' => 'Paggene ca cullegano a $1',
@@ -407,7 +408,7 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 # Block/unblock
 'blockip'            => 'Ferma utelizzatóre',
 'ipadressorusername' => 'Nnerizzo IP o nomme utente',
-'ipboptions'         => '2 ore:2 hours,1 juorno:1 day,3 juorne:3 days,1 semmana:1 week,2 semmane:2 weeks,1 mise:1 month,3 mese:3 months,6 mese:6 months,1 anno:1 year,infinito:infinite', # display1:time1,display2:time2,...
+'ipboptions'         => '2 ore:2 hours,1 juorno:1 day,3 juorne:3 days,1 semmana:1 week,2 semmane:2 weeks,1 mise:1 month,3 mese:3 months,6 mese:6 months,1 anno:1 year,infinito:infinite',
 'blockipsuccesssub'  => 'Blocco aseguito',
 'blocklistline'      => '$1, $2 ha fermato $3 ($4)',
 'blocklink'          => 'ferma',
@@ -431,11 +432,9 @@ Putite cuntinuà a ausà {{SITENAME}} comme n'utente senza nomme, o si nò putit
 'export' => "Spurta 'e ppaggene",
 
 # Namespace 8 related
-'allmessages'         => "'Mmasciate d''o sistema",
-'allmessagesname'     => 'Nomme',
-'allmessagescurrent'  => "Testo 'e mo",
-'allmessagesfilter'   => "Lammecca ncopp' 'e mmasciate:",
-'allmessagesmodified' => 'Faje vedé solo chille cagnate',
+'allmessages'        => "'Mmasciate d''o sistema",
+'allmessagesname'    => 'Nomme',
+'allmessagescurrent' => "Testo 'e mo",
 
 # Special:Import
 'import'                  => 'Mpurta paggene',
