@@ -7,6 +7,7 @@
  * @ingroup Language
  * @file
  *
+ * @author Reedy
  * @author Seb az86556
  * @author לערי ריינהארט
  */
@@ -163,7 +164,7 @@ $messages = array(
 # Login and logout pages
 'yourname'                => 'Choyoołʼįįhí bizhiʼ:',
 'yourpassword'            => 'Passwordígíí:',
-'remembermypassword'      => 'shipassword béédíínih',
+'remembermypassword'      => 'shipassword béédíínih (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'nav-login-createaccount' => 'Log in / accountígíí ádíílííł',
 'nologinlink'             => 'Accountígíí ádíílííł',
 'mailmypassword'          => 'passwordígíí ániidí shichʼįʼ ádíílííł (e-mail)',
@@ -287,14 +288,13 @@ $3',
 # Watchlist
 'watchlist'         => 'bikʼi déshʼį́į́ʼígíí',
 'mywatchlist'       => 'bikʼi déshʼį́į́ʼígíí',
-'watchlistfor'      => "('''$1''')",
 'addedwatchtext'    => "[[Special:Watchlist|Naaltsoos bikʼi díníʼį́į́ʼígíí]] bíhiniidééh. \"[[:\$1]]\" kʼad bikʼi díníʼį́į́ʼ.<br />Nááná [[Special:RecentChanges|\"áníídí łahgo ályaaígíí\"]] bikáaʼgi díí naaltsoos kʼad kodóó '''ditą́ą''' dooleeł.",
 'removedwatchtext'  => '"[[:$1]]" kʼad doo [[Special:Watchlist|bikʼi díníʼį́į]] da.',
 'watch'             => 'bikʼi déshʼį́į́ʼ nisin',
 'watchthispage'     => 'díí naaltsoos bikʼi déshʼį́į́ʼ nisin',
 'unwatch'           => 'doo bikʼi déshʼį́įʼ nisin da',
 'watchlist-details' => '{{PLURAL:$1|$1 naaltsoos|$1 naaltsoos}} bikʼi díníʼį́į́ʼ',
-'wlshowlast'        => '<div style="text-size:14px; padding:10px; background:#bbeeff;"><small>
+'wlshowlast'        => '<small>
 * ( $1 ) ahééʼílkidę́ędą́ą́ʼ kojįʼ
 * ( $2 ) yiskánídą́ą́ʼ kojįʼ
 * ( $3 )</small>',
