@@ -63,6 +63,10 @@ $messages = array(
 'navigation'    => 'Nabegashon',
 'and'           => '&#32;i',
 
+# Cologne Blue skin
+'faq'     => 'Preguntanan mas Puntrá',
+'faqpage' => 'Project:Preguntanan mas Puntrá',
+
 'errorpagetitle'    => 'Eror',
 'returnto'          => 'Bai bèk $1.',
 'tagline'           => 'Di {{SITENAME}}',
@@ -96,7 +100,7 @@ $messages = array(
 'otherlanguages'    => 'Na otro idioma',
 'redirectedfrom'    => '(Bo a yega akinan pa via di e página $1)',
 'redirectpagesub'   => 'Página ku ta sirbi komo portal',
-'lastmodifiedat'    => 'E páginá aki a wòrdu kambiá ultimo biaha riba $1, ora $2.', # $1 date, $2 time
+'lastmodifiedat'    => 'E páginá aki a wòrdu kambiá ultimo biaha riba $1, ora $2.',
 'viewcount'         => 'E paginá aki a wòrdu mirá {{PLURAL:$1|biaha|$1 biaha}}.',
 'protectedpage'     => 'Página Protehá',
 'jumpto'            => 'Bai na:',
@@ -107,7 +111,6 @@ $messages = array(
 'aboutsite'            => 'Tokante {{SITENAME}}',
 'aboutpage'            => 'Project:Info',
 'copyright'            => 'E kontenido ta disponibel bou di $1.',
-'copyrightpagename'    => '{{SITENAME}} derecho di outor',
 'copyrightpage'        => '{{ns:project}}:Derechinan di outor',
 'currentevents'        => 'Eventonan aktual',
 'currentevents-url'    => 'Project:Eventonan aktual',
@@ -115,8 +118,6 @@ $messages = array(
 'disclaimerpage'       => 'Project:Deklarashon di Liberashon for di Responsabilidat General',
 'edithelp'             => 'Ayudo ku editamentu',
 'edithelppage'         => 'Help:Kon pa editá artíkulo',
-'faq'                  => 'Preguntanan mas Puntrá',
-'faqpage'              => 'Project:Preguntanan mas Puntrá',
 'helppage'             => 'Help:Kontenido',
 'mainpage'             => 'Página Prinsipal',
 'mainpage-description' => 'Página Prinsipal',
@@ -170,18 +171,10 @@ No lubidá di kambia bo [[Special:Preferences|{{SITENAME}} preferensianan]].',
 'yourname'                   => 'Nòmber di uzadó',
 'yourpassword'               => 'Kontraseña',
 'yourpasswordagain'          => 'Hinka kontraseña atrobe',
-'remembermypassword'         => 'Kordá mi',
+'remembermypassword'         => 'Kordá mi (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'userlogin'                  => 'Traha un kuenta nobo òf outentiká',
 'userlogout'                 => 'Terminá sesion',
 'badretype'                  => 'E kontraseñanan hinká no ta kuadra.',
-'youremail'                  => 'E-mail:',
-'username'                   => 'Nòmber di uzadó:',
-'uid'                        => 'ID di uzadó:',
-'yourrealname'               => 'Nòmber berdadero:',
-'yourlanguage'               => 'Idioma:',
-'yourvariant'                => 'Variante:',
-'yournick'                   => 'Nòmber di kariño:',
-'badsig'                     => 'Firma inválido; kontrolá e HTML uzá.',
 'wrongpassword'              => 'Kontraseña no ta korekto. Por fabor purba atrobe.',
 'wrongpasswordempty'         => 'Kontraseña tabata bashí. Por fabor purba atrobe.',
 'acct_creation_throttle_hit' => 'Bishitantenan na uzando bo IP adrès a traha $1 kuenta den e último 24 ora, lokual ta e máksimo permití den e periodo aki. Esaki ta nifiká ku hendenan uzando e IP adrès aki no por traha mas kuenta na e momentu aki.',
@@ -197,7 +190,6 @@ No lubidá di kambia bo [[Special:Preferences|{{SITENAME}} preferensianan]].',
 Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e historia di kambionan hasí na e página aki.',
 'blockedtitle'       => 'Uzadó ta blokiá',
 'whitelistedittitle' => 'Mester outentiká promé pa editá',
-'confirmedittitle'   => 'Konfirmashon di e-mail eksigí pa editá',
 'confirmedittext'    => 'Bo mester konfirmá bo e-mail adrès promé ku bo editá página. Por fabor duna i validá bo e-mail adrès via bo [[Special:Preferences|preferensianan]].',
 'accmailtitle'       => 'Kontraseña mandá.',
 'accmailtext'        => "E kontraseña pa '$1' tabata mandá pa $2.",
@@ -218,7 +210,7 @@ Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e
 'histlast'            => 'Último',
 
 # Search results
-'nextn'          => 'siguiente $1',
+'nextn'          => 'siguiente {{PLURAL:$1|$1}}',
 'searchhelp-url' => 'Help:Kontenido',
 
 # Preferences page
@@ -227,6 +219,14 @@ Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e
 'changepassword' => 'Kambia kontraseña',
 'timezonelegend' => 'Zona di tempu',
 'allowemail'     => 'Akseptá e-mail di otro uzadó',
+'youremail'      => 'E-mail:',
+'username'       => 'Nòmber di uzadó:',
+'uid'            => 'ID di uzadó:',
+'yourrealname'   => 'Nòmber berdadero:',
+'yourlanguage'   => 'Idioma:',
+'yourvariant'    => 'Variante:',
+'yournick'       => 'Nòmber di kariño:',
+'badsig'         => 'Firma inválido; kontrolá e HTML uzá.',
 
 # Recent changes
 'recentchanges'     => 'Kambionan resien',
@@ -239,6 +239,9 @@ Bo por kambia página libremente, pero tene kuenta ku lo nota bo IP adrès den e
 'hide'              => 'Skonde',
 'show'              => 'Mustra',
 
+# File description page
+'file-anchor-link' => 'Imagen',
+
 # Unwatched pages
 'unwatchedpages' => 'Páginanan no observá',
 
@@ -273,7 +276,9 @@ Bo por skohe un tipo di registro tambe, òf filtrá e bista ku un nòmber di uza
 
 # Special:Categories
 'categories'         => 'Kategorianan',
-'categoriespagetext' => 'Esaki ta e kategorianan ku ta eksistí den {{SITENAME}}.',
+'categoriespagetext' => 'Esaki ta e kategorianan ku ta eksistí den {{SITENAME}}.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # E-mail user
 'emailuser'       => 'Manda e-mail pa e uzadó aki',
@@ -354,13 +359,11 @@ Por fabor skohe un otro título.',
 '1movedto2_redir' => '[[$1]] mové pa [[$2]] riba redirect',
 
 # Namespace 8 related
-'allmessages'         => 'Mensahenan di sistema',
-'allmessagesname'     => 'Nòmber',
-'allmessagesdefault'  => 'Teksto predeterminá',
-'allmessagescurrent'  => 'Teksto aktual',
-'allmessagestext'     => 'Esaki ta un lista di mensahe di sistema disponibel den e dominio di MediaWiki.',
-'allmessagesfilter'   => 'Filter pa nòmber di mensahe:',
-'allmessagesmodified' => 'Mustra solamente esnan modifiká',
+'allmessages'        => 'Mensahenan di sistema',
+'allmessagesname'    => 'Nòmber',
+'allmessagesdefault' => 'Teksto predeterminá',
+'allmessagescurrent' => 'Teksto aktual',
+'allmessagestext'    => 'Esaki ta un lista di mensahe di sistema disponibel den e dominio di MediaWiki.',
 
 # Attribution
 'anonymous' => 'Uzadó(nan) anonimo di {{SITENAME}}',
