@@ -18,7 +18,7 @@ $messages = array(
 'tog-underline'               => 'Loïens soulinés:',
 'tog-justify'                 => 'Aligner ches paragrafes',
 'tog-hideminor'               => 'Muche ches tiots edits din ches nouvieus cangemints',
-'tog-hidepatrolled'           => 'Mucher chés wardés canjemints din chés nouvieus canjemints',
+'tog-hidepatrolled'           => 'Mucher chés wardés édichons din chés nouvieus canjemints',
 'tog-newpageshidepatrolled'   => 'Muche ches paches pormenées del lisse ed ches nouvèles paches',
 'tog-extendwatchlist'         => "Étènne l'lisse pou vir tortous ches cangemints, poin seulemint ches nouvieus",
 'tog-numberheadings'          => 'liméro automatique ed ches intétes',
@@ -27,19 +27,18 @@ $messages = array(
 'tog-editsection'             => "Pérmet l'édichion del sekchion via [edit] loïens",
 'tog-editsectiononrightclick' => "Pérmet l'édichion del sekchion par un droé buke su ch'tite del sekchion (i feut JavaScript)",
 'tog-showtoc'                 => "Aficher l'tabe ed ches étnus (pou ches paches aveuc plu ed 3 intétes)",
-'tog-rememberpassword'        => "Warder min lodjine su chl'ordinateu-lo.",
-'tog-editwidth'               => "Alatcher l'boéte d'édichon pou rimplir tout ch'cassi",
-'tog-watchcreations'          => "Ajouter ches paches qu'éj crée su em lisse",
-'tog-watchdefault'            => "Ajouter ches paches qu'éj édite su em lisse.",
-'tog-watchmoves'              => "Ajouter ches paches qu'éj déplache su m'lisse.",
-'tog-watchdeletion'           => "Ajouter ches paches qu'éj déface su m'lisse.",
+'tog-rememberpassword'        => "Warder min lodjine su chl'ordinateu-lo (pour un maximum éd $1 {{PLURAL:$1|jour|jours}})",
+'tog-watchcreations'          => "Ajouter chés paches qu'éj crée dseu em lisse",
+'tog-watchdefault'            => "Ajouter chés paches qu'éj édite dseu em lisse.",
+'tog-watchmoves'              => "Ajouter chés paches qu'éj déplache dseu m'lisse.",
+'tog-watchdeletion'           => "Ajouter chés paches qu'éj déface dseur m'lisse.",
 'tog-previewontop'            => "Aficher l'prévue édvint el bouéte édite",
 'tog-previewonfirst'          => "Aficher l'prévue au preumié édite.",
 'tog-enotifwatchlistpages'    => "Éspédier din m'boéte un imèle quante eune pache su m'lisse est candgée",
 'tog-enotifusertalkpages'     => 'Éspédier un imèle su em bouéte quante m\'pache "Dvise Uzeu" est candgée.',
 'tog-enotifminoredits'        => 'Éspédier à mi étous un imèle pou ches tiots édites éd ches paches',
 'tog-shownumberswatching'     => "Aficher ch'nombe ed gins qu'ont vu.",
-'tog-watchlisthideown'        => 'Muche mes édites su el lisse',
+'tog-watchlisthideown'        => 'Muche mes édites dseur el lisse',
 'tog-watchlisthidebots'       => 'Muche ches robots édites su el lisse',
 'tog-watchlisthideminor'      => 'Muche ches tiots édites su el lisse.',
 'tog-watchlisthideliu'        => 'Muche ches édites ed ches lodjés gins su el lisse.',
@@ -52,6 +51,9 @@ $messages = array(
 'underline-always' => 'Toudis',
 'underline-never'  => 'Janmoais',
 
+# Font style option in Special:Preferences
+'editfont-serif' => 'Police Serif',
+
 # Dates
 'sunday'        => 'Diminche',
 'monday'        => 'Lindi',
@@ -105,16 +107,20 @@ $messages = array(
 'dec'           => 'Déc',
 
 # Categories related messages
-'pagecategories'           => '{{PLURAL:$1|Catégorie|Catégories}}',
-'category_header'          => 'Paches in catégorie "$1"',
-'subcategories'            => 'Dsoucatégories',
-'category-media-header'    => 'Média in catégorie "$1"',
-'category-empty'           => "''Din l'catégorie-lo, i n'y o poin d'paches ou d'média.''",
-'hidden-categories'        => '{{PLURAL:$1|Catégorie muchée|Catégories muchées}}',
-'hidden-category-category' => 'Catégouries muchées',
-'category-subcat-count'    => "{{PLURAL:$2|Chol catégorie o seulemint el sou-catégorie-lo.|Chol catégorie o  {{PLURAL:$1|l'sou-catégorie-lo|$1 sou-catégories}}, pou un total éd $2.}}",
-'category-article-count'   => "{{PLURAL:$2|Chol catégorie o seulemint chol pache-lo.|{{PLURAL:$1|El pache-lo est|$1 Chés paches-lo sont}} din l'catégorie-lo, pou un total éd $2 .}}",
-'listingcontinuesabbrev'   => 'cont.',
+'pagecategories'                 => '{{PLURAL:$1|Catégorie|Catégories}}',
+'category_header'                => 'Paches in catégorie "$1"',
+'subcategories'                  => 'Dsoucatégories',
+'category-media-header'          => 'Média in catégorie "$1"',
+'category-empty'                 => "''Din l'catégorie-lo, i n'y o poin d'paches ou d'média.''",
+'hidden-categories'              => '{{PLURAL:$1|Catégorie muchée|Catégories muchées}}',
+'hidden-category-category'       => 'Catégouries muchées',
+'category-subcat-count'          => "{{PLURAL:$2|Chol catégorie o seulemint el sou-catégorie-lo.|Chol catégorie o  {{PLURAL:$1|l'sou-catégorie-lo|$1 sou-catégories}}, pou un total éd $2.}}",
+'category-subcat-count-limited'  => "L'catégorie-lo ale o {{PLURAL:$1|el dsous-catégorie|chés $1 dsous-catégories}} -lo:",
+'category-article-count'         => "{{PLURAL:$2|Chol catégorie o seulemint chol pache-lo.|{{PLURAL:$1|El pache-lo est|$1 Chés paches-lo sont}} din l'catégorie-lo, pou un total éd $2 .}}",
+'category-article-count-limited' => "{{PLURAL:$1|L' pache d'apré ale est|Chés $1 paches d'apré sont}} dins l'catégorie-lo.",
+'category-file-count'            => "{{PLURAL:$2|Chol catégorie o seulemint chol fichié-lo.|{{PLURAL:$1|Ech fichier-lo est|$1 Chés fichiés-lo sont}} din l'catégorie-lo, pou un total éd $2 fichiés.}}",
+'category-file-count-limited'    => "{{PLURAL:$1|Ech fichié d'apré est|Chés $1 fichiés d'apré sont}} dins l'catégorie-lo.",
+'listingcontinuesabbrev'         => 'cont.',
 
 'mainpagetext' => "'''MediaWiki o té instalé aveuc victoère.'''",
 
@@ -141,28 +147,21 @@ $messages = array(
 'faqpage'        => 'Project:FAQ',
 
 # Vector skin
-'vector-action-addsection'   => 'Rajouter un sujeut',
-'vector-action-delete'       => 'Défacer',
-'vector-action-move'         => "Canger ch'nom",
-'vector-action-protect'      => 'Garantir',
-'vector-action-undelete'     => "N'poin défacher",
-'vector-action-unprotect'    => "N'poin garantir",
-'vector-namespace-help'      => "Pache d'aïude",
-'vector-namespace-image'     => 'Fichié',
-'vector-namespace-main'      => 'Pache',
-'vector-namespace-mediawiki' => 'Message',
-'vector-namespace-special'   => 'Pache éspéchiale',
-'vector-namespace-talk'      => 'Pérlache',
-'vector-namespace-template'  => 'Modéle',
-'vector-namespace-user'      => 'Pache dechl uzeu',
-'vector-view-create'         => 'Créer',
-'vector-view-edit'           => 'Éditer',
-'vector-view-history'        => "Vir l'histoère",
-'vector-view-view'           => 'Lire',
-'vector-view-viewsource'     => "Vir l'source",
-'actions'                    => 'Acchons',
-'namespaces'                 => "Éspaces d'chés noms",
-'variants'                   => 'Ércanjantes',
+'vector-action-addsection'       => 'Rajouter un sujeut',
+'vector-action-delete'           => 'Défacer',
+'vector-action-move'             => "Canger ch'nom",
+'vector-action-protect'          => 'Garantir',
+'vector-action-undelete'         => "N'poin défacher",
+'vector-action-unprotect'        => "Canger l'garantie",
+'vector-simplesearch-preference' => "Déhousser chés avanches d'ércherche améliorées (seulemint pour Vector)",
+'vector-view-create'             => 'Créer',
+'vector-view-edit'               => 'Éditer',
+'vector-view-history'            => "Vir l'histoère",
+'vector-view-view'               => 'Lire',
+'vector-view-viewsource'         => "Vir l'source",
+'actions'                        => 'Acchons',
+'namespaces'                     => "Éspaces d'chés noms",
+'variants'                       => 'Ércanjantes',
 
 'errorpagetitle'    => 'Bérlure',
 'returnto'          => 'Értrouve $1.',
@@ -172,7 +171,7 @@ $messages = array(
 'searchbutton'      => 'Tracher',
 'go'                => 'Aller',
 'searcharticle'     => 'Aller',
-'history'           => 'Pache historique',
+'history'           => 'Historique deul pache',
 'history_short'     => 'Histoère',
 'updatedmarker'     => 'Cangé édpui em darinne visite',
 'info_short'        => 'Informachion',
@@ -189,8 +188,8 @@ $messages = array(
 'protect'           => 'Garantir',
 'protect_change'    => 'canger',
 'protectthispage'   => "Défènner l'pache",
-'unprotect'         => 'Mie défènné',
-'unprotectthispage' => "N'poin garantir chol pache",
+'unprotect'         => "Canger l'garantie",
+'unprotectthispage' => 'Canger la garantie ed chol pache',
 'newpage'           => 'Nouvèle pache',
 'talkpage'          => "Alédjer l'pache-lo",
 'talkpagelinktext'  => 'Dviser',
@@ -213,6 +212,7 @@ $messages = array(
 'redirectedfrom'    => '(Érdirection édpis $1)',
 'redirectpagesub'   => 'Pache érdérivée',
 'lastmodifiedat'    => "L'pache-lo ale o té modifiée l'fouos darin l' $1, à $2.",
+'viewcount'         => "L' page-lo ale o té vue {{PLURAL:$1|1 foués|$1 foués}}.",
 'protectedpage'     => 'Pache défènnée',
 'jumpto'            => 'Aler à:',
 'jumptonavigation'  => 'navigachon',
@@ -237,7 +237,8 @@ $messages = array(
 'privacy'              => "Politique d'éscrè",
 'privacypage'          => "Project:Politique d'éscrè",
 
-'badaccess' => 'Bérlure éd pérmission',
+'badaccess'        => 'Bérlure éd pérmission',
+'badaccess-group0' => 'Vos n’avez poin chés droéts pour foaire l’action dmindée.',
 
 'ok'                      => 'OK',
 'retrievedfrom'           => 'Érprind din  "$1"',
@@ -316,7 +317,7 @@ Si s'n'est poin ch'cas-lo, pététe éq ch'est un bogue din ch'businkillache. <b
 'yourname'                => "nom d'uzeu:",
 'yourpassword'            => "Mot d'passe:",
 'yourpasswordagain'       => "Intrer à nouvieu ch'mot d'passe:",
-'remembermypassword'      => "Inrégistrer m'loguine su echl ordinateu-lo",
+'remembermypassword'      => "Intrer oùtonmatiquemint l'prochaine fouos (pour un maximum éd $1 {{PLURAL:$1|jour|jours}})",
 'yourdomainname'          => 'Vote donmène:',
 'login'                   => 'Intrer',
 'nav-login-createaccount' => 'Intrer / créer vote conpte',
@@ -332,8 +333,9 @@ Si s'n'est poin ch'cas-lo, pététe éq ch'est un bogue din ch'businkillache. <b
 'gotaccountlink'          => 'Intrer',
 'createaccountmail'       => 'par imèle',
 'badretype'               => "Chés mots d'passe intrés, is sont poin bon.",
-'userexists'              => "ch'nom d'uzeu intré, il est piécha donné.
-
+'userexists'              => "Nom d’utilisateur entré déjà utilisé.
+Nom d’uzeu intré déjo donné.
+i feut prinde un eute nom.
 j'm'escuse mais i feut prinde un aute nom.",
 'loginerror'              => 'Bérlurache del intrée',
 'noname'                  => "Os n'avez poin donné un nom d'uzeu valabe.",
@@ -599,7 +601,7 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 'linksearch' => 'Loïens éstérieurs',
 
 # Special:Log/newusers
-'newuserlogpage'          => 'Jornal del créachon pou echl uzeu',
+'newuserlogpage'          => "Jornal éd chés créachons d'comptes d'uzeu",
 'newuserlog-create-entry' => "Nouvieu conpte d'uzeu",
 
 # Special:ListGroupRights
@@ -612,7 +614,6 @@ Ale doét mie éte pu longue éq $1 {{PLURAL:$1|caracter|caractéres}}.',
 # Watchlist
 'watchlist'         => 'Em lisse à suire',
 'mywatchlist'       => "M'lisse à suire",
-'watchlistfor'      => "(pou '''$1''')",
 'addedwatch'        => "Rajouté su l'lisse à suire",
 'addedwatchtext'    => "L' pache « [[:$1]] » o té rajoutée à vote [[Special:Watchlist|lisse à suire]].<br /> Chés  canjemints à vnir del pache-lo pi del page éd pérlache sront mis din l'lisse. L'pache sro '''in cros''' din el [[Special:RecentChanges|lisse d'chés darins canjemints]] pou les értreuver fachilmint. Pou értirer chol pache del ''lisse à suire'', bukez su « {{MediaWiki:Unwatch}} ».",
 'removedwatch'      => 'Értiré del lisse à suire',
@@ -695,6 +696,7 @@ Vlo chés réglages del pache '''$1''' à ch'momint-chi:",
 'sp-contributions-blocklog' => 'jornal éd chés blotcåjhes',
 'sp-contributions-search'   => 'Tracher pou chés contérbuchons',
 'sp-contributions-username' => "Adérche IP ou nom d'uzeu",
+'sp-contributions-toponly'  => "n'montrer qu'chés darins canjemints",
 'sp-contributions-submit'   => 'Tracher',
 
 # What links here
@@ -725,7 +727,7 @@ I feut l'foaire seleumint pour inréyer ech vindalime et pi i feut ète acordant
 Donner apré ch'motif  (pèr egzimpe chiter chés paches qu'ont té vindalisées).",
 'ipboptions'               => '2 heures:2 hours,1 jour:1 day,3 jours:3 days,1 ésminne:1 week,2 ésminnes:2 weeks,1 moés:1 month,3 moés:3 months,6 moés:6 months,1 an:1 year,infini:infinite',
 'ipbotheroption'           => 'eute',
-'ipblocklist'              => "Adréches IP pi noms d'uzeu blotchés",
+'ipblocklist'              => 'Uzeus blotchés',
 'blocklink'                => 'blotcher',
 'unblocklink'              => 'déblotcher',
 'change-blocklink'         => 'cange ech block',
@@ -826,6 +828,7 @@ Os pouvez vir l'source",
 'tooltip-watch'                   => 'Ajouter chol pache-lo à vo lisse à suire',
 'tooltip-rollback'                => '« Racacher » cancéle aveuc un clic el (ou chés) modificachon(s) del pache-lo pèr sin darin contérbucheu.',
 'tooltip-undo'                    => "« Undo » ( ''démangler'' ) értire ch'canjemint-lo pi ouvre l' fénéte d'édichon din ch'mode ''prévir''. <br /> In put mette un motif din ch'résumé.",
+'tooltip-preferences-save'        => 'Warder chés préférinches.',
 
 # Info page
 'numedits' => 'Nombe ed canjemints (pache) : $1',
@@ -835,9 +838,9 @@ Os pouvez vir l'source",
 'nextdiff'     => 'Nouvèle édichon →',
 
 # Media information
-'file-info-size'       => '($1 × $2 picséls, diminchon dech fichié: $3, MIME tipe: $4)',
+'file-info-size'       => '$1 × $2 picséls, diminchon dech fichié: $3, MIME tipe: $4',
 'file-nohires'         => '<small>Poin éd pu grande résoluchon possibe.</small>',
-'svg-long-desc'        => '(Fichié SVG, résoluchon éd $1 × $2 picsels, diminchon: $3)',
+'svg-long-desc'        => 'Fichié SVG, résoluchon éd $1 × $2 picsels, diminchon: $3',
 'show-big-image'       => 'Plinne résoluchon',
 'show-big-image-thumb' => '<small>Diminchon del intérvue-lo : $1 × $2 picséls</small>',
 
@@ -897,6 +900,13 @@ Chés eutes cans is s'ront muchés pèr défeut.
 # Special:BlankPage
 'blankpage' => 'Blanke pache',
 
+# Special:ComparePages
+'compare-page1'  => 'Pache 1',
+'compare-page2'  => 'Pache 2',
+'compare-rev1'   => 'Canjemint 1',
+'compare-rev2'   => 'Canjemint 2',
+'compare-submit' => 'Aconparer',
+
 # Database error messages
 'dberr-header' => 'Ech wiki-lo il o dés problémes',
 
