@@ -7,10 +7,13 @@
  * @ingroup Language
  * @file
  *
+ * @author Purodha
  * @author Slomox
  * @author Wikipeeta
  */
 
+$fallback = 'de';
+
 $messages = array(
 # User preference toggles
 'tog-underline'               => 'Links unjastritje:',
@@ -89,22 +92,24 @@ $messages = array(
 'category_header'          => 'Siede in Kategorie "$1"',
 'category-media-header'    => 'Bilda in Kategorie "$1"',
 'hidden-categories'        => "{{PLURAL:$1|Fe'stoakne Kategorie|Fe'stoakne Kategorien}}",
-'hidden-category-category' => "Fe'stoakne Kategorien", # Name of the category where hidden categories will be listed
+'hidden-category-category' => "Fe'stoakne Kategorien",
 
-'about'          => 'Äwa',
-'newwindow'      => '(got in en nie Fensta op)',
-'cancel'         => 'Aufbräakje',
+'about'         => 'Äwa',
+'newwindow'     => '(got in en nie Fensta op)',
+'cancel'        => 'Aufbräakje',
+'moredotdotdot' => 'Mea...',
+'mypage'        => 'Miene Sied',
+'mytalk'        => 'Miene Beredsied',
+'anontalk'      => 'Beredsied fe dise IP',
+'navigation'    => 'Navigatioon',
+'and'           => '&#32;onn',
+
+# Cologne Blue skin
 'qbfind'         => 'finje',
 'qbedit'         => 'Endre',
 'qbpageoptions'  => 'Dise Sied',
 'qbmyoptions'    => 'Miene Siede',
 'qbspecialpages' => "Opp'poate Siede",
-'moredotdotdot'  => 'Mea...',
-'mypage'         => 'Miene Sied',
-'mytalk'         => 'Miene Beredsied',
-'anontalk'       => 'Beredsied fe dise IP',
-'navigation'     => 'Navigatioon',
-'and'            => '&#32;onn',
 
 'errorpagetitle'   => 'Fäla',
 'returnto'         => 'Trigj no $1.',
@@ -148,7 +153,7 @@ $messages = array(
 'otherlanguages'   => 'In aundre Sproake',
 'redirectedfrom'   => '(wieda jeleidt von $1)',
 'redirectpagesub'  => 'Sied tom Wiedaleide',
-'lastmodifiedat'   => "Dise Sied word aum $1, klock $2 daut latzte Mol je'endat.", # $1 date, $2 time
+'lastmodifiedat'   => "Dise Sied word aum $1, klock $2 daut latzte Mol je'endat.",
 'protectedpage'    => 'Sied mett besondrem Schutz',
 'jumpto'           => 'Sprinj no:',
 'jumptonavigation' => 'Navigatioon',
@@ -229,10 +234,6 @@ Daut latzte Opproope vonne Dotebank we:
 <blockquote><tt>$1</tt></blockquote>
 ute Funktioon "<tt>$2</tt>".
 MySQL mald dem Fehla "<tt>$3: $4</tt>".',
-'noconnect'       => 'Sorry! Daut jefft technische Schwierichtjeite, tjeen Kontakt es meajlich mette Dotebank opp <br />
-$1',
-'nodb'            => 'Kunn Dotebank $1 nich utwehle',
-'cachederror'     => 'Waut hia tjemmt es eene Kopie utem Cache en es vleicht nich meea aktuell.',
 'laggedslavemode' => 'Oppjepausst: Dee jewesne Sied es nich onbedinjt dee latzte Versioon.',
 'readonly'        => 'Dotebank es jeschlote',
 'enterlockreason' => 'Nan bitte een Grunt doafea, wurom dee Dotebank jeschlote saul en saj, woolang daut onjefea diere saul',
@@ -263,12 +264,6 @@ Bitte schriew eene Notiz aun [[Special:ListUsers/sysop|administrator]], en lot d
 'badretype'               => 'Dee beid Pauswed stemme nich ewaeen.',
 'userexists'              => 'Dem Bruckanome haft aul wea.
 Bitte nemm eenen aundren.',
-'youremail'               => 'Email:',
-'username'                => 'Bruckanome:',
-'uid'                     => 'Brucka-ID:',
-'prefs-memberingroups'    => 'Mettjliet von {{PLURAL:$1|group|groups}}:',
-'yourrealname'            => 'Ajchta Nome:',
-'yourlanguage'            => 'Sproak:',
 'loginlanguagelabel'      => 'Sproak: $1',
 
 # Edit page toolbar
@@ -295,13 +290,15 @@ Bitte nemm eenen aundren.',
 'template-protected'   => "(be'schutst)",
 
 # History pages
-'cur'        => 'dise',
-'last'       => 'latste',
-'page_first' => 'easchte',
-'page_last'  => 'latste',
+'revisionasof'  => 'Versioon von $1',
+'revision-info' => 'Versioon von $1 von $2',
+'cur'           => 'dise',
+'last'          => 'latste',
+'page_first'    => 'easchte',
+'page_last'     => 'latste',
 
 # Revision feed
-'history-feed-item-nocomment' => '$1 omm $2', # user at time
+'history-feed-item-nocomment' => '$1 omm $2',
 
 # Revision deletion
 'rev-delundel' => 'wies/vestopp',
@@ -314,9 +311,9 @@ Bitte nemm eenen aundren.',
 'searchresults'             => 'Setj Resultaute',
 'searchresults-title'       => 'Setj Resultaute fe "$1"',
 'searchsubtitle'            => 'Du sochst \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|all pages starting with "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|all pages that link to "$1"]])',
-'prevn'                     => '$1 ferhäa',
-'nextn'                     => 'näakjste $1',
-'viewprevnext'              => 'Tjitj ($1) ($2) ($3)',
+'prevn'                     => '{{PLURAL:$1|$1}} ferhäa',
+'nextn'                     => 'näakjste {{PLURAL:$1|$1}}',
+'viewprevnext'              => 'Tjitj ($1 {{int:pipe-separator}} $2) ($3)',
 'searchhelp-url'            => 'Help:Enhault',
 'search-result-size'        => '$1 ({{PLURAL:$2|1 Wot|$2 Wed}})',
 'search-mwsuggest-enabled'  => 'mett Veaschlag',
@@ -326,8 +323,14 @@ Bitte nemm eenen aundren.',
 'powersearch-field'         => 'Setj no',
 
 # Preferences page
-'preferences'   => 'Ennstalinje',
-'mypreferences' => 'Miene Ennstalinje',
+'preferences'          => 'Ennstalinje',
+'mypreferences'        => 'Miene Ennstalinje',
+'youremail'            => 'Email:',
+'username'             => 'Bruckanome:',
+'uid'                  => 'Brucka-ID:',
+'prefs-memberingroups' => 'Mettjliet von {{PLURAL:$1|group|groups}}:',
+'yourrealname'         => 'Ajchta Nome:',
+'yourlanguage'         => 'Sproak:',
 
 # Recent changes
 'nchanges'        => '$1 {{PLURAL:$1|Endaniss|Endanisse}}',
@@ -346,6 +349,8 @@ Bitte nemm eenen aundren.',
 
 # Recent changes linked
 'recentchangeslinked'          => 'Endarunge aun velinkte Siede',
+'recentchangeslinked-feed'     => 'Endarunge aun velinkte Siede',
+'recentchangeslinked-toolbox'  => 'Endarunge aun velinkte Siede',
 'recentchangeslinked-title'    => 'Endarunge aun Siede, woone von "$1" velinkt send',
 'recentchangeslinked-backlink' => '← $1',
 'recentchangeslinked-noresult' => 'Em utjesochten Tietrum es aun dee velinkte Siede nuscht aundasch jemoakt worde.',
@@ -367,6 +372,7 @@ Bitte nemm eenen aundren.',
 'listfiles_user' => 'Brucker',
 
 # File description page
+'file-anchor-link'    => 'Datei',
 'filehist'            => 'Dokument-Jeschicht',
 'filehist-datetime'   => 'Tiet',
 'filehist-user'       => 'Brucker',
@@ -413,7 +419,6 @@ Bitte nemm eenen aundren.',
 
 # Watchlist
 'mywatchlist'   => 'Miene Oppaussied',
-'watchlistfor'  => "(fer '''$1''')",
 'addedwatch'    => "No Oppausssied bieje'done",
 'watch'         => 'Oppausse',
 'watchthispage' => 'Op dise Sied oppausse',
@@ -432,7 +437,7 @@ Bitte nemm eenen aundren.',
 
 # Protect
 'protectexpiry'          => 'Ütgontiet:',
-'protect-expiry-options' => '2 Stunde:2 hours,1 Dach:1 day,1 Wäakj:1 week,2 Wäakje:2 weeks,1 Moonat:1 month,3 Moonate:3 months,6 Moonate:6 months,1 Joa:1 year,one Enj:infinite', # display1:time1,display2:time2,...
+'protect-expiry-options' => '2 Stunde:2 hours,1 Dach:1 day,1 Wäakj:1 week,2 Wäakje:2 weeks,1 Moonat:1 month,3 Moonate:3 months,6 Moonate:6 months,1 Joa:1 year,one Enj:infinite',
 'restriction-type'       => "Er'laubniss:",
 
 # Namespace form on various pages
@@ -445,6 +450,8 @@ Bitte nemm eenen aundren.',
 'month'     => 'Fonn Moonat (onn ferdäm):',
 'year'      => 'Fonn Joa (onn ferdäm):',
 
+'sp-contributions-talk' => 'Beredsied',
+
 # What links here
 'whatlinkshere'          => 'Links opp dise Sied',
 'whatlinkshere-title'    => 'Siede, woone opp "$1" eenen Link habe',
@@ -459,7 +466,7 @@ Bitte nemm eenen aundren.',
 'whatlinkshere-links'    => '← Links',
 
 # Block/unblock
-'ipboptions'       => '2 Stunde:2 hours,1 Dach:1 day,3 Doag:3 days,1 Wäakj:1 week,2 Wäakje:2 weeks,1 Moonat:1 month,3 Moonate:3 months,6 Moonate:6 months,1 Joa:1 year,one Enj:infinite', # display1:time1,display2:time2,...
+'ipboptions'       => '2 Stunde:2 hours,1 Dach:1 day,3 Doag:3 days,1 Wäakj:1 week,2 Wäakje:2 weeks,1 Moonat:1 month,3 Moonate:3 months,6 Moonate:6 months,1 Joa:1 year,one Enj:infinite',
 'blocklink'        => 'blocke',
 'unblocklink'      => 'frie jewe',
 'change-blocklink' => 'Daut Blocke endre',
@@ -467,7 +474,6 @@ Bitte nemm eenen aundren.',
 'autoblocker'      => 'Automatisch jeblockt, wiels diene IP-Adras soo es aus bie "[[User:$1|$1]]".
 Dee Grunt es: "$2"',
 'blocklogpage'     => 'Block-Logbok',
-'blocklog-fulllog' => 'Vollstendjet Block-Logbok',
 'blocklogentry'    => 'haft [[$1]] jeblockt fe dee Tiet $2 $3',
 'reblock-logentry' => "haft dee Block-Enstalinj fe [[$1]] je'endat fe dee Tiet $2 $3",
 
@@ -507,6 +513,7 @@ Dee Grunt es: "$2"',
 'tooltip-search-go'               => 'Go opp dee Sied, woone jenau disem Nome haft',
 'tooltip-search-fulltext'         => 'Setj no Siede mett soonem Tatjst',
 'tooltip-n-mainpage'              => 'Besäkj de Hauptsied',
+'tooltip-n-mainpage-description'  => 'Besetj dee Hauptsied',
 'tooltip-n-portal'                => 'Ewa daut Portal, waut du doone kaunst, woo waut to finje es',
 'tooltip-n-currentevents'         => 'Hinjagruntinformatioone ewa aktuelle Sache finje',
 'tooltip-n-recentchanges'         => 'List mette latste Endanisse em Wiki.',
@@ -561,7 +568,7 @@ Dee Grunt es: "$2"',
 'nostalgia.js'   => '/* Daut neachste JavaScript woat fe Brucka mett Nostalgie-Skin jelode. */',
 'cologneblue.js' => '/* Daut neachste JavaScript woat fe Brucka mett Keloonsch-Blau-Skin jelode */',
 'monobook.js'    => '/* Daut neachste JavaScript woat fe Brucka mett Monobook-Skin jelode */',
-'myskin.js'      => '/* Daut neachste JavaScript woat fe Brucka mett Myskin-Skin jelode */',
+'myskin.js'      => '/* Daut neachste JavaScript woat fe Brucka mett MySkin-Skin jelode */',
 'chick.js'       => '/* Daut neachste JavaScript woat fe Brucka mett Chick-Skin jelode */',
 'simple.js'      => '/* Daut neachste JavaScript woat fe Brucka mett Eenfach-Skin jelode */',
 'modern.js'      => '/* Daut neachste JavaScript woat fe Brucka mett Modern-Skin jelode. */',
@@ -574,7 +581,7 @@ Dee Grunt es: "$2"',
 # Attribution
 'anonymous'        => 'Onbekaunda Brucka {{PLURAL:$1|user|users}} von {{SITENAME}}',
 'siteuser'         => '{{SITENAME}}-Brucka $1',
-'lastmodifiedatby' => "Dise Sied word daut latste Mol aum $1, Klock $2 von $3 je'endat.", # $1 date, $2 time, $3 user
+'lastmodifiedatby' => "Dise Sied word daut latste Mol aum $1, Klock $2 von $3 je'endat.",
 'othercontribs'    => 'Oppe Gruntloag vonne Oabeit von $1.',
 'others'           => 'aundre',
 'siteusers'        => '{{SITENAME}}-{{PLURAL:$2|user|users}} $1',
