@@ -7,6 +7,8 @@
  * @ingroup Language
  * @file
  *
+ * @author Kaganer
+ * @author Laila
  * @author Skuolfi
  * @author Teak
  * @author The Evil IP address
@@ -16,38 +18,37 @@
 
 $messages = array(
 # User preference toggles
-'tog-underline'               => 'Liŋkkaid vuollaisárgun',
-'tog-highlightbroken'         => 'Čájet liŋkkaid siidduide mat váilojit <a href="#" class="new">ná</a> (molssaeaktun ná: <a href="#" class="internal">?</a>).',
+'tog-underline'               => 'Liŋkkaid vuolláisárgun',
+'tog-highlightbroken'         => 'Čájet liŋkkaid siidduide mat váilot <a href="#" class="new">ná</a> (molssaeaktun ná: <a href="#" class="internal">?</a>).',
 'tog-hideminor'               => 'Čiega unna rievdadusaid varas rievdadusat -listtus',
-'tog-extendwatchlist'         => 'Viidit čuovvunlisttu čájehit buot dahkon rievdadusaid',
-'tog-usenewrc'                => 'Viididuvvon varas rievdadusat -listu (JavaScript)',
-'tog-numberheadings'          => 'Nummaraste bájilčállagiid',
+'tog-extendwatchlist'         => 'Viiddit čuovvunlisttu, nu ahte čájeha buot dahkon rievdadusaid, iige dušše ođđaseamos',
+'tog-usenewrc'                => 'Viiddiduvvon varas rievdadusat -listu (gáibida JavaScript)',
+'tog-numberheadings'          => 'Nummaraste bajilčállagiid',
 'tog-showtoolbar'             => 'Čájet rievdadangaskaomiid',
-'tog-editondblclick'          => 'Rievdat siidduid dubbaldeaddilemiin (JavaScript)',
-'tog-editsection'             => 'Čájet rievdadanliŋkkaid juohke oasáža bájabealde',
-'tog-editsectiononrightclick' => 'Rievdat osiid nu ahte deaddilat bájilčállaga sáhpána olggeš boaluin (JavaScript)',
-'tog-showtoc'                 => 'Čájet sisdoallologahallama siidduin, main lea eanet go golbma bájilčállaga',
-'tog-rememberpassword'        => 'Muite mu dieđuid dán dihtoris',
-'tog-editwidth'               => 'Ođasmahttinlođa lea olles siiddu viidosaš',
-'tog-watchcreations'          => 'Lasit čuovvunlistui siidduid maid lean álggahan',
+'tog-editondblclick'          => 'Rievdat siidduid duppaldeaddilemiin (JavaScript)',
+'tog-editsection'             => 'Čájet rievdadanliŋkkaid juohke oasáža bajábealde',
+'tog-editsectiononrightclick' => 'Rievdat osiid nu ahte deaddilat bajilčállaga sáhpána olgeš boaluin (JavaScript)',
+'tog-showtoc'                 => 'Čájet sisdoallologahallama siidduin, main lea eanet go golbma bajilčállaga',
+'tog-rememberpassword'        => 'Muite mu dieđuid dán dihtoris (for a maximum of $1 {{PLURAL:$1|day|days}})',
+'tog-watchcreations'          => 'Lasit siidduid maid lean álggahan mu čuovvunlistui',
 'tog-watchdefault'            => 'Lasit čuovvunlistui siidduid maid lean ođasmahttán',
 'tog-watchmoves'              => 'Lasit čuovvunlistui siidduid maid lean sirdán',
 'tog-watchdeletion'           => 'Lasit čuovvunlistui siidduid maid lean sihkkon',
 'tog-minordefault'            => 'Rievdadusat leat unnit, jus ii eará álmmuhuvvo',
-'tog-previewontop'            => 'Čájet siidduid rievdadusaid ovdalgihtii geahččama ođasmahttin lođá bajábealde',
-'tog-previewonfirst'          => 'Čájehisgoađe siidduid rievdadusaid ovdalgihtii, go siiddu rievdadeapmi álggahuvvo',
-'tog-nocache'                 => 'Ále vurke siidduid gaskabottasašmuitui',
+'tog-previewontop'            => 'Čájet siidduid rievdadusaid ovddalgihtii geahččama ođasmahttin lođá bajábealde',
+'tog-previewonfirst'          => 'Čájehišgoađe siidduid rievdadusaid ovddalgihtii, go siiddu rievdadeapmi álggahuvvo',
+'tog-nocache'                 => 'Ále vurke siidduid gaskaboddasašmuitui',
 'tog-enotifwatchlistpages'    => 'Sádde dieđu e-poasttain go mu čuovvunlistui gullevaš siidu rievdaduvvo',
 'tog-enotifusertalkpages'     => 'Sádde e-poasta, go geavaheaddjisiiddu ságastallansiidu rievdaduvvo',
-'tog-enotifminoredits'        => 'Sádde dieđu e-poasttain maid unna rievdadusain',
-'tog-enotifrevealaddr'        => 'Čájet e-poastačujuhusain almmuhusain, maid sádden earáide',
+'tog-enotifminoredits'        => 'Sádde dieđu e-poasttain maid unna rievdadusaid birra',
+'tog-enotifrevealaddr'        => 'Čájet mu e-poastačujuhusa go sádden maila earáide',
 'tog-shownumberswatching'     => 'Čájet galle geavaheaddji čuvvot siiddu',
-'tog-fancysig'                => 'Oktageardán vuolláidčálus liŋkka haga',
-'tog-forceeditsummary'        => 'Fuomašuhte, jus čoahkkáigeassu ii leat čállojuvvon',
-'tog-watchlisthideown'        => 'Čiega iežas rievdadusaid',
-'tog-watchlisthidebots'       => 'Čiega bohtaid rievdadusaid',
+'tog-fancysig'                => 'Oktageardán vuolláičálus liŋkka haga',
+'tog-forceeditsummary'        => 'Fuomášuhte, jos in leat čállán čoahkkáigeasu',
+'tog-watchlisthideown'        => 'Čiega mu iežan rievdadusaid',
+'tog-watchlisthidebots'       => 'Čiega bot-prográmmaid rievdadusaid',
 'tog-watchlisthideminor'      => 'Čiega unna rievdadusaid',
-'tog-nolangconversion'        => 'Ále daga rievdadusaid giellavarianttaid gaskal',
+'tog-nolangconversion'        => 'Ále daga rievdadusaid giellavariánttaid gaskal',
 'tog-ccmeonemails'            => 'Sádde munnje kopiija e-poasttain, maid sádden eará geavaheddjiide',
 
 'underline-always' => 'Álo',
@@ -134,7 +135,7 @@ $messages = array(
 'qbspecialpages' => 'Doaibmasiiddut',
 
 # Vector skin
-'vector-namespace-image' => 'Fiila',
+'vector-view-view' => 'Loga',
 
 'errorpagetitle'    => 'Feaila',
 'returnto'          => 'Máhcat siidui $1.',
@@ -148,7 +149,7 @@ $messages = array(
 'history_short'     => 'Historjá',
 'updatedmarker'     => 'beaiváduvvon du ovddit fitnama maŋŋá',
 'info_short'        => 'Diđoštus',
-'printableversion'  => 'Prenten veršuvdna',
+'printableversion'  => 'Prentenveršuvdna',
 'permalink'         => 'Bissovaš liŋka',
 'print'             => 'Prente',
 'edit'              => 'Rievdat',
@@ -163,26 +164,26 @@ $messages = array(
 'unprotectthispage' => 'Sihko dán siiddu suodjalusa',
 'newpage'           => 'Ođđa siidu',
 'talkpage'          => 'Ságastala dán siiddu birra',
-'talkpagelinktext'  => 'ságastallan',
-'specialpage'       => 'Doaibmasiidu',
-'personaltools'     => 'Persovnnalaš gaskaoamit',
+'talkpagelinktext'  => 'Ságastallan',
+'specialpage'       => 'Sierrasiidu',
+'personaltools'     => 'Persovnnalaš bargoneavvu',
 'postcomment'       => 'Ođđa sekšuvdna',
-'articlepage'       => 'Čájet fástasiiddu',
+'articlepage'       => 'Čájet sisdoallusiiddu',
 'talk'              => 'Ságastallan',
-'views'             => 'Oaidnámusat',
+'views'             => 'Čájáhusat',
 'toolbox'           => 'Neavvobumbá',
 'userpage'          => 'Čájet geavaheaddjisiiddu',
 'projectpage'       => 'Čájet prošeaktasiiddu',
-'imagepage'         => 'Čájet govvádussiiddu',
-'mediawikipage'     => 'Čájet sátnesiiddu',
-'templatepage'      => 'Čájet mállevuođđusiiddu',
-'viewhelppage'      => 'Čájet neavvosiiddu',
-'categorypage'      => 'Čájet luohkásiiddu',
+'imagepage'         => 'Čájet fiilasiiddu',
+'mediawikipage'     => 'Čájet diehtosiiddu',
+'templatepage'      => 'Čájet mállevuođđosiiddu',
+'viewhelppage'      => 'Čájet veahkkesiiddu',
+'categorypage'      => 'Čájet kategoriijasiiddu',
 'viewtalkpage'      => 'Čájet ságastallansiiddu',
 'otherlanguages'    => 'Eará gielaide',
-'redirectedfrom'    => 'Ođđasitstivrejuvvon siiddus $1',
-'redirectpagesub'   => 'Ođđasitstivrensiidu',
-'lastmodifiedat'    => 'Siidu lea maŋimustá rievdaduvvon $1 diimu $2.',
+'redirectedfrom'    => 'Stivrejuvvon ođđasit siiddus $1',
+'redirectpagesub'   => 'Ođđasit-stivrensiidu',
+'lastmodifiedat'    => 'Siidu lea maŋimustá rievdaduvvon $1 diibmu $2.',
 'viewcount'         => 'Dát siidu lea čájehuvvon {{PLURAL:$1|oktii|$1 geardde}}.',
 'protectedpage'     => 'Suodjáluvvon siidu',
 'jumpto'            => 'Njuike:',
@@ -204,11 +205,12 @@ $messages = array(
 'mainpage-description' => 'Váldosiidu',
 'portal'               => 'Gáffestohpu',
 'portal-url'           => 'Project:Gáffestohpu',
+'privacypage'          => 'Project:Personsuodjalus',
 
-'versionrequired'     => 'MediaWikis gáibiduvvo unnimusta veršuvdna $1',
-'versionrequiredtext' => 'MediaWikis gáibiduvvo unnimusta veršuvdna $1 dán siiddu geavaheapmái. Geahča [[Special:Version|veršuvdna]]',
+'versionrequired'     => 'MediaWikis gáibiduvvo unnimustá veršuvdna $1',
+'versionrequiredtext' => 'MediaWikis gáibiduvvo unnimustá veršuvdna $1 dán siiddu geavaheapmái. Geahča [[Special:Version|veršuvdna]]',
 
-'retrievedfrom'           => 'Viččojuvvon čujuhusas $1',
+'retrievedfrom'           => 'Vižžojuvvon čujuhusas $1',
 'youhavenewmessages'      => 'Dutnje leat $1 ($2).',
 'newmessageslink'         => 'ođđa dieđut',
 'newmessagesdifflink'     => 'maŋimus rievdadus',
@@ -222,7 +224,7 @@ $messages = array(
 'hidetoc'                 => 'čiega',
 'thisisdeleted'           => 'Čájet dahje máhcat $1.',
 'viewdeleted'             => 'Čájet $1?',
-'restorelink'             => '{{PLURAL:$1|okta sihkojuvvon rievdadus|$1 sihkojuvvon rievdadusa}}',
+'restorelink'             => '{{PLURAL:$1|okta sihkkojuvvon rievdadus|$1 sihkkojuvvon rievdadusa}}',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Siidu',
@@ -237,18 +239,18 @@ $messages = array(
 'nstab-category'  => 'Luohkká',
 
 # Main script and global functions
-'nosuchaction'      => 'Dovdameahtun dahkku',
+'nosuchaction'      => 'Dovdameahttun dahkku',
 'nosuchspecialpage' => 'Diekkár doaibmasiidu ii dihtto',
 'nospecialpagetext' => 'Wikiprográmma ii dovdda diekkár doaibmasiiddu.',
 
 # General errors
 'error'                => 'Feaila',
-'databaseerror'        => 'Diehtovuođđufeaila',
+'databaseerror'        => 'Diehtovuođđofeaila',
 'readonly'             => 'Diehtuvuođđu lea giddejuvvon',
-'internalerror'        => 'Siskaldas feaila',
-'internalerror_info'   => 'Siskaldas feaila: $1',
+'internalerror'        => 'Siskkaldas feaila',
+'internalerror_info'   => 'Siskkaldas feaila: $1',
 'filecopyerror'        => 'Fiilla <b>$1</b> kopieren fiilan <b>$2</b> ii lihkosmuvvan.',
-'filerenameerror'      => 'Fiilla <b>$1</b> ođđasitnamadeapmi namain <b>$2</b> ii lihkosmuvvan.',
+'filerenameerror'      => 'Fiilla <b>$1</b> ođđasitnammadeapmi namain <b>$2</b> ii lihkosmuvvan.',
 'filedeleteerror'      => 'Fiilla <b>$1</b> sihkkun ii lihkosmuvvan.',
 'directorycreateerror' => 'Logahallama ”$1” ráhkadeapmi ii lihkosmuvvan.',
 'filenotfound'         => 'Fiila <b>$1</b> ii dihtton.',
@@ -258,38 +260,38 @@ $messages = array(
 'cannotdelete'         => 'Siiddu dahje fiilla sihkkon ii lihkosmuvvan. Muhtun eará lea sáhttán sihkkut dan.',
 'badtitle'             => 'Feaila bájilčállagis',
 'badtitletext'         => 'Siiddu bájilčállagis lei feaila, dahje dat lei guoros dahje boastut ráhkaduvvon wikiid- dahje gielaidgaskasaš liŋka.',
-'perfcached'           => 'Dieđut leat gaskabottosašmuittus eaige sihkarit vástit dálá hámi.',
-'perfcachedts'         => 'Čuovvovaš data lea buktojuvvon gaskabottosašmuittus ja dat lea maŋimusta beaividuvvon $1.',
-'querypage-no-updates' => 'Dán siiddu dieđut eai beaividuvvo.',
-'viewsource'           => 'Geahča gálddu',
+'perfcached'           => 'Dieđut leat gaskabottosašmuittus eaige sihkkarit vástit dálá hámi.',
+'perfcachedts'         => 'Čuovvovaš data lea buktojuvvon gaskabottosašmuittus ja dat lea maŋimusta beaiváduvvon $1.',
+'querypage-no-updates' => 'Dán siiddu dieđut eai beaiváduvvo.',
+'viewsource'           => 'Geahča gáldu',
 'viewsourcefor'        => 'siidui $1',
 'protectedpagetext'    => 'Dát siidu lea suodjaluvvon rievdadusain.',
-'viewsourcetext'       => 'Sáhtat geahčat ja kopieret dán siiddu gáldokoda:',
-'sqlhidden'            => '(SQL-jierahallan lea čihkojuvvon)',
+'viewsourcetext'       => 'Sáhtát geahčat ja kopieret dán siiddu gáldokoda:',
+'sqlhidden'            => '(SQL-jearahallan lea čihkojuvvon)',
 
 # Login and logout pages
 'logouttext'                 => "'''Leat dál čálligoahtán olggos {{GRAMMAR:elative|{{SITENAME}}}}.'''
 
-Sáhtat joatkit {{GRAMMAR:genitive|{{SITENAME}}}} geavaheami anonyman, dahje čálligoahtit ođđasit sisa.",
+Sáhtát joatkit {{GRAMMAR:genitive|{{SITENAME}}}} geavaheami anonyman, dahje čálligoahtit ođđasit sisa.",
 'welcomecreation'            => '== Bures boahtin, $1! ==
 Du geavaheaddjidovddaldat lea dál anus.
 Ále vajáldahte rievdadit {{GRAMMAR:genitive|{{SITENAME}}}} iežat ásahusaid.',
 'yourname'                   => 'Geavaheaddjidovddaldat',
 'yourpassword'               => 'Suollemassátni:',
 'yourpasswordagain'          => 'Čále suollemassáni ođđasit:',
-'remembermypassword'         => 'Muite mu',
+'remembermypassword'         => 'Muite mu (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => 'Fierbmenamma',
 'login'                      => 'Čálligoađe sisa',
 'nav-login-createaccount'    => 'Daga ođđa geavaheaddjidovddaldaga dahje čálligoađe sisa',
-'loginprompt'                => 'Sisačállimii darbbašuvvo geavssat (cookies).',
+'loginprompt'                => 'Sisačállimii dárbbašuvvojit geavssat (cookies).',
 'userlogin'                  => 'Daga ođđa geavaheaddjidovddaldaga dahje čálligoađe sisa',
 'logout'                     => 'Čálligoađe olggos',
 'userlogout'                 => 'Čálligoađe olggos',
 'notloggedin'                => 'It leat čálligoahttan sisa',
-'nologin'                    => "Jus dus ii vel leat geavaheaddjidovddaldat, sáhtat '''$1''' dakkára.",
+'nologin'                    => "Jus dus ii vel leat geavaheaddjidovddaldat, sáhtát '''$1''' dakkára.",
 'nologinlink'                => 'ráhkadit',
 'createaccount'              => 'Ráhkat ođđa geavaheaddjidovddaldaga',
-'gotaccount'                 => "Jus dus lea jo geavaheaddjidovddaldat, sáhtat '''$1'''.",
+'gotaccount'                 => "Jus dus lea jo geavaheaddjidovddaldat, sáhtát '''$1'''.",
 'gotaccountlink'             => 'čálligoahtit sisa',
 'createaccountmail'          => 'e-poasttain',
 'badretype'                  => 'Suollemassánit, maid čállet, eai leat seammalaganat.',
@@ -304,11 +306,13 @@ Du geavaheaddjidovddaldat lea dál anus.
 'nouserspecified'            => 'Geavaheaddjidovddaldat ii leat meroštallojuvvon.',
 'wrongpassword'              => 'Suollemassátni, man čállet, ii leat riekta. Leage buorre ja iska ođđasit.',
 'wrongpasswordempty'         => 'It čállán suollemassáni. Iska ođđasit.',
-'passwordtooshort'           => 'Suollemassátni, man evttohit, ii dohke. Suollemassátni ferte leat unnimusta $1 mearka guhkki ja eará go geavaheaddjidovddaldagat.',
-'mailmypassword'             => 'Sádde ođđa suollemassáni e-poasttain',
+'passwordtooshort'           => 'Suollemassátni, man evttohit, ii heive. Suollemassátni ferte leat unnimustá $1 mearka guhkki ja eará go geavaheaddjidovddaldagat.',
+'password-name-match'        => 'Suollemassátni ferte leat eará go geavaheaddjidovddaldat.',
+'mailmypassword'             => 'Sádde ođđa suollemassáni e-poasta bokte',
 'passwordremindertitle'      => 'Suollemassátnimuituhus {{GRAMMAR:elative|{{SITENAME}}}}',
 'passwordremindertext'       => 'Muhtun IP-čujuhusas $1 bivddii {{GRAMMAR:partitive|{{SITENAME}}}} ($4) sáddet ođđa suollemassáni. Suollemassátni geavaheaddjái $2 lea dál $3. Čálligoađe sisa ja molsso suollemassáni.',
 'noemail'                    => "Geavaheaddjái '''$1''' ii leat lasihuvvon e-poastačujuhus.",
+'noemailcreate'              => 'Fertet čállit e-poastačujuhusa, mii lea geavahusas',
 'passwordsent'               => 'Ođđa suollemassátni lea sáddejuvvon geavaheaddji <b>$1</b> e-poastačujuhussii.',
 'throttled-mailpassword'     => 'Suollemassátnimuituhus lea sáddejuvvon maŋimus $1 diimma siste. Suollemassátnimuituhus sáddejuvvo eanemusta oktii $1 diimmas.',
 'mailerror'                  => 'Feaila e-poastta sáddedettiin: $1',
@@ -341,7 +345,7 @@ Du geavaheaddjidovddaldat lea dál anus.
 'italic_sample'   => 'Vitnju teaksta',
 'italic_tip'      => 'Vitnju teaksta',
 'link_sample'     => 'liŋka',
-'link_tip'        => 'Siskaldas liŋka',
+'link_tip'        => 'Siskkaldas liŋka',
 'extlink_sample'  => 'http://www.example.com liŋkka bájilčála',
 'extlink_tip'     => 'Wiki olggobeal liŋka (muite http:// ovddas)',
 'headline_sample' => 'Bájilčálateaksta',
@@ -371,23 +375,23 @@ Du geavaheaddjidovddaldat lea dál anus.
 'missingcommenttext'       => 'Čále čoahkkáigeasu vuollái.',
 'missingcommentheader'     => 'It leat čállán bajilčállaga du oaivilii. Vállje <em>Vurke</em>, jus it hálit čállit bajilčállaga.',
 'summary-preview'          => 'Čoahkkáigeasu ovdalgihtiigeahččan:',
-'subject-preview'          => 'Bájilčállaga ovdalgihtiigeahččan:',
+'subject-preview'          => 'Bajilčállaga ovdalgihtiigeahččan:',
 'blockedtitle'             => 'Geavaheaddji lea cakkastallojuvvon',
 'blockedoriginalsource'    => 'Siiddu ”$1” prográmmagálvu:',
 'blockededitsource'        => 'Du rievdadusat siidui ”$1”:',
-'whitelistedittitle'       => 'Fertet čálligoahtit sisa ovdalgo sáhtat rievdadit siiddu',
-'whitelistedittext'        => 'Don fertet $1, ovdalgo sáhtat rievdadit siidduid.',
+'whitelistedittitle'       => 'Don fertet čálligoahtit sisa ovdalgo sáhtát rievdadit siiddu',
+'whitelistedittext'        => 'Don fertet $1, ovdalgo sáhtát rievdadit siidduid.',
 'confirmedittext'          => 'It sáhte rievdadit siiddu ovdalgo leat sihkarastan iežat e-poastačujuhusa. Sáhtat sihkarastit [[Special:Preferences|ásahussiidduin]].',
-'nosuchsectiontitle'       => 'Diekkár oassi ii dihtto',
-'nosuchsectiontext'        => 'Isket rievdadit oasi, mii ii dihtto.',
+'nosuchsectiontitle'       => 'Diekkár oassi ii gávdno',
+'nosuchsectiontext'        => 'Isket rievdadit oasi, mii ii gávdno.',
 'loginreqtitle'            => 'Sisačállin gáibiduvvo',
-'loginreqlink'             => 'čálligoahtit sisa',
+'loginreqlink'             => 'čálligoađe sisa',
 'loginreqpagetext'         => 'Don fertet $1, ovdalgo oainnat eará siidduid.',
 'accmailtitle'             => 'Suollemassátni lea sáddejuvvon.',
 'accmailtext'              => "geavaheaddji '''$1''' suollemassátni lea sáddejuvvon čujuhussii '''$2'''.",
 'newarticle'               => '(ođđa)',
-'newarticletext'           => 'Leat boahtán muhtin liŋkka mielde siidui, mii ii vel dihtto. Sáhtat álggahit siiddu vuollái. Jus it hálit álggahit siiddu, geavat neahttabláđejeaddji máhccandoaimma.',
-'updated'                  => '(Beaividuvvon)',
+'newarticletext'           => 'Leat boahtán muhtin liŋkka mielde siidui, mii ii vel lea čállejuvvon. Sáhtát álggahit siiddu vuollái. Jus it háliit álggahit siiddu, geavat fierbmilohkki máhccandoaimma.',
+'updated'                  => '(Beaiváduvvon)',
 'note'                     => "'''Cuigehus:'''",
 'previewnote'              => "'''Dát lea siiddu ovdalgihtiigeahččan. Siidu ii leat vel vurkejuvvon!'''",
 'editing'                  => 'Rievdadit siiddu $1',
@@ -433,9 +437,9 @@ Du geavaheaddjidovddaldat lea dál anus.
 'history-feed-item-nocomment' => '$1 ($2)',
 
 # Revision deletion
-'rev-deleted-comment'     => '(kommeanta sihkojuvvon)',
-'rev-deleted-user'        => '(geavaheaddjinamma sihkojuvvon)',
-'rev-deleted-event'       => '(dáhpáhus sihkojuvvon)',
+'rev-deleted-comment'     => '(kommentára lea sihkkojuvvon)',
+'rev-deleted-user'        => '(geavaheaddjinamma lea sihkkojuvvon)',
+'rev-deleted-event'       => '(dáhpáhus lea sihkojuvvon)',
 'rev-delundel'            => 'čájet dahje čiega',
 'revisiondelete'          => 'Sihko dahje máhcat veršuvnnaid',
 'revdelete-nooldid-title' => 'Ii veršuvdna',
@@ -450,12 +454,16 @@ Eará bajasdoallit sáhtet lohkat čihkojuvvon sisdoalu ja máhcahit dan.",
 'revdelete-hide-name'     => 'Čiega doaibma ja mearri',
 'revdelete-hide-comment'  => 'Čiega čoahkkáigeasu',
 'revdelete-hide-user'     => 'Čiega dahkki dovddaldaga dahje IP-čujuhusa',
+'revdelete-radio-set'     => 'Jua',
+'revdelete-radio-unset'   => 'Ii',
 'revdelete-suppress'      => 'Čiega maid bajasdolliin',
 'revdelete-unsuppress'    => 'Sihko máhcahuvvon veršuvnnaid rádjehusaid',
 'revdelete-log'           => 'Sivva',
 'revdelete-submit'        => 'Daga',
 'revdelete-logentry'      => 'rievdadii siiddu [[$1]] veršuvnna oidnonásahusaid',
 'logdelete-logentry'      => 'rievdadii siiddu [[$1]] oaidninásahusaid',
+'pagehist'                => 'Siiddu rievdanhistorjá',
+'deletedhist'             => 'Šluhtejuvvon veršuvnnaid historjá',
 
 # Diffs
 'difference'              => 'Veršuvnnaid erohusat',
@@ -482,7 +490,7 @@ $1 {{int:pipe-separator}} $2',
 # Quickbar
 'qbsettings-none'          => 'Ii maidige',
 'qbsettings-fixedleft'     => 'Teaksta mielde, gurut',
-'qbsettings-fixedright'    => 'Teaksta mielde, olggeš',
+'qbsettings-fixedright'    => 'Teaksta mielde, olgeš',
 'qbsettings-floatingleft'  => 'Biso gurutbealde',
 'qbsettings-floatingright' => 'Biso olgesbealde',
 
@@ -491,7 +499,7 @@ $1 {{int:pipe-separator}} $2',
 'mypreferences'         => 'Ásahusat',
 'prefs-edits'           => 'Rievdadusaid mearri:',
 'prefsnologin'          => 'It leat čálligoahtán sisa.',
-'prefsnologintext'      => 'Don fertet [[Special:UserLogin|čálligoahtit sisa]], ovdalgo sáhtat rievdadit du ásahusaid.',
+'prefsnologintext'      => 'Don fertet [[Special:UserLogin|čálligoahtit sisa]], ovdalgo sáhtát rievdadit du ásahusaid.',
 'changepassword'        => 'Suollemassáni molson',
 'prefs-skin'            => 'Olggosoaidnu',
 'skin-preview'          => 'ovdalgihtii geahččan...',
@@ -534,6 +542,8 @@ $1 {{int:pipe-separator}} $2',
 'email'                 => 'E-poastadoaimmat',
 'prefs-help-realname'   => 'Eaktodahtolaš. Du namma čájehuvvo geavaheaddjidovddaldaga sajis siiddu dahkkilogahallamis.',
 'prefs-help-email'      => 'Eaktodahtolaš. Eará geavaheaddjit sáhttet váldit dunnje oktavuođa e-poasttain nu ahte du e-poastačujuhus ii dihtto.',
+'prefs-signature'       => 'Vuolláičálus',
+'prefs-dateformat'      => 'Beaivemeari hábmi',
 
 # User rights
 'userrights'               => 'Geavaheaddjirivttiid stivren',
@@ -541,19 +551,20 @@ $1 {{int:pipe-separator}} $2',
 'userrights-user-editname' => 'Geavaheaddjidovddaldat',
 'editusergroup'            => 'Rievdat geavaheaddjijoavkkuid',
 'editinguser'              => "Rievdadit siiddu '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] | [[Special:Contributions/$1|{{int:contribslink}}]])",
-'userrights-editusergroup' => 'Geavaheaddji joavkkut',
+'userrights-editusergroup' => 'Redigere geavaheaddjijoavkkuid',
 'saveusergroups'           => 'Vurke',
 'userrights-groupsmember'  => 'Lahttun čuovvovaš joavkkuin:',
 'userrights-reason'        => 'Sivva',
 
 # Groups
 'group'            => 'Joavku',
-'group-bot'        => 'bohtat',
+'group-user'       => 'geavaheaddjit',
+'group-bot'        => 'Robohtat',
 'group-sysop'      => 'bájasdoallit',
 'group-bureaucrat' => 'byrokráhtat',
 'group-all'        => '(buot)',
 
-'group-bot-member'        => 'bohtta',
+'group-bot-member'        => 'robohtta',
 'group-sysop-member'      => 'bájasdoalli',
 'group-bureaucrat-member' => 'byrokráhta',
 
@@ -599,37 +610,37 @@ $1 {{int:pipe-separator}} $2',
 'recentchangeslinked-title'   => '"$1" laktaseaddji rievdadusat',
 
 # Upload
-'upload'             => 'Lasit fiilla',
-'uploadbtn'          => 'Lasit fiilla',
-'reuploaddesc'       => 'Máhca sáddenskovvái.',
-'uploadnologin'      => 'It leat čálligoahtán sisa',
-'uploadnologintext'  => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]], ovdalgo sáhtát vurket fiillaid.',
-'uploaderror'        => 'Vurkenfeaila',
-'uploadlog'          => 'Fiilalogga',
-'uploadlogpage'      => 'Fiilalogga',
-'filename'           => 'Fiilla namma:',
-'filedesc'           => 'Čoahkkáigeassu',
-'fileuploadsummary'  => 'Čoahkkáigeassu',
-'filesource'         => 'Gáldu:',
-'uploadedfiles'      => 'Lasihuvvon fiillat',
-'ignorewarning'      => 'Vurke fuolatkeahttá varuhusas',
-'minlength1'         => 'Fiilla namas ferte leat unnimustá okta mearka.',
-'badfilename'        => 'Fiilla nama rievdaduvvui: $1.',
-'filetype-missing'   => 'Fiillas vailui fiilageažus – ovdamearkkan <tt>.jpg</tt>.',
-'large-file'         => 'Fiilla max. sturrodat lea $1. Fiila man lasihit lea $2.',
-'largefileserver'    => 'Dát fiila lea menddo stuoris.',
-'successfulupload'   => 'Lasiheapmi lihkosmuvai',
-'uploadwarning'      => 'Lasihanvaruhus',
-'savefile'           => 'Vurke',
-'uploadedimage'      => 'vurkii fiilla [[$1]]',
-'uploaddisabled'     => '{{GRAMMAR:genitive|{{SITENAME}}}} ii sáhte lasihit fiillaid.',
-'uploaddisabledtext' => 'Fiillaid vurken lea váldojuvvon eret anus.',
-'uploadscripted'     => 'Dát fiila sisdisdoalla HTML-koda dahje skriptaid, maid neahttabláđejeaddji sáhttá vahagis dahkat.',
-'uploadvirus'        => 'Fiila sisdoalla virusa. Dárkilut dieđut: $1',
-'sourcefilename'     => 'Gáldonamma',
-'destfilename'       => 'Mearrenamma',
-'watchthisupload'    => 'Čuovo dán siiddu',
-'filewasdeleted'     => 'Dán nammasaš fiila lea lasihuvvon ja sihkojuvvon jo ovda. Dárkis $1 ovdalgo joatkat.',
+'upload'              => 'Lasit fiilla',
+'uploadbtn'           => 'Lasit fiilla',
+'reuploaddesc'        => 'Máhca sáddenskovvái.',
+'uploadnologin'       => 'It leat čálligoahtán sisa',
+'uploadnologintext'   => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]], ovdalgo sáhtát vurket fiillaid.',
+'uploaderror'         => 'Vurkenfeaila',
+'uploadlog'           => 'Fiilalogga',
+'uploadlogpage'       => 'Fiilalogga',
+'filename'            => 'Fiilla namma:',
+'filedesc'            => 'Čoahkkáigeassu',
+'fileuploadsummary'   => 'Čoahkkáigeassu',
+'filesource'          => 'Gáldu:',
+'uploadedfiles'       => 'Lasihuvvon fiillat',
+'ignorewarning'       => 'Vurke fuolatkeahttá varuhusas',
+'minlength1'          => 'Fiilla namas ferte leat unnimustá okta mearka.',
+'badfilename'         => 'Fiilla nama rievdaduvvui: $1.',
+'filetype-missing'    => 'Fiillas vailui fiilageažus – ovdamearkkan <tt>.jpg</tt>.',
+'large-file'          => 'Fiilla max. sturrodat lea $1. Fiila man lasihit lea $2.',
+'largefileserver'     => 'Dát fiila lea menddo stuoris.',
+'uploadwarning'       => 'Lasihanvaruhus',
+'savefile'            => 'Vurke',
+'uploadedimage'       => 'vurkii fiilla [[$1]]',
+'uploaddisabled'      => '{{GRAMMAR:genitive|{{SITENAME}}}} ii sáhte lasihit fiillaid.',
+'uploaddisabledtext'  => 'Fiillaid vurken lea váldojuvvon eret anus.',
+'uploadscripted'      => 'Dát fiila sisdisdoalla HTML-koda dahje skriptaid, maid neahttabláđejeaddji sáhttá vahagis dahkat.',
+'uploadvirus'         => 'Fiila sisdoalla virusa. Dárkilut dieđut: $1',
+'sourcefilename'      => 'Gáldonamma',
+'destfilename'        => 'Mearrenamma',
+'watchthisupload'     => 'Čuovo dán siiddu',
+'filewasdeleted'      => 'Dán nammasaš fiila lea lasihuvvon ja sihkojuvvon jo ovda. Dárkis $1 ovdalgo joatkat.',
+'upload-success-subj' => 'Lasiheapmi lihkosmuvai',
 
 'upload-proto-error' => 'Feaila protokollas',
 'upload-file-error'  => 'Stuorra feaila',
@@ -661,7 +672,7 @@ $1 {{int:pipe-separator}} $2',
 'filehist-help'             => 'Go deaddilat beaivemeari, oainnat makká fiila lei dalle.',
 'filehist-deleteall'        => 'sihko buot',
 'filehist-deleteone'        => 'sihko dán',
-'filehist-revert'           => 'máhcat',
+'filehist-revert'           => 'ovddit veršuvdnii',
 'filehist-current'          => 'dálá',
 'filehist-datetime'         => 'Beaivemearri/Áigi',
 'filehist-user'             => 'Geavaheaddji',
@@ -677,17 +688,17 @@ $1 {{int:pipe-separator}} $2',
 # File reversion
 'filerevert'                => 'Fiilla $1 máhcaheapmi',
 'filerevert-legend'         => 'Fiilla máhcaheapmi',
-'filerevert-intro'          => "Leat máhcaheami fiilla '''[[Media:$1|$1]]''' [$4 veršuvdnii, mii ráhdaduvvui $2 diibmu $3].",
+'filerevert-intro'          => "Leat máhcaheami fiilla '''[[Media:$1|$1]]''' [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].",
 'filerevert-comment'        => 'Sivva',
 'filerevert-defaultcomment' => 'Máhcahuvvui veršuvdnii, mii ráhkaduvvui $1 diibmu $2',
-'filerevert-submit'         => 'Máhcat',
-'filerevert-success'        => "'''[[Media:$1|$1]]''' lea máhcahvvon [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].",
+'filerevert-submit'         => 'Ovddit veršuvdnii',
+'filerevert-success'        => "'''[[Media:$1|$1]]''' lea máhcahuvvon [$4 veršuvdnii, mii ráhkaduvvui $2 diibmu $3].",
 'filerevert-badversion'     => 'Fiillas ii leat ráhkaduvvon veršuvdna dalle.',
 
 # File deletion
 'filedelete'           => 'Sihko $1',
 'filedelete-legend'    => 'Sihko fiilla',
-'filedelete-intro'     => "Don leat sihkomin '''[[Media:$1|$1]]'''.",
+'filedelete-intro'     => "Don leat sihkomin fiilla '''[[Media:$1|$1]]''' ja fiilla historjjá",
 'filedelete-intro-old' => "Don leat sihkomin veršuvdna '''[[Media:$1|$1]]'''  [$4 $3, $2].",
 'filedelete-comment'   => 'Sivva',
 'filedelete-submit'    => 'Sihko',
@@ -725,9 +736,9 @@ $1 {{int:pipe-separator}} $2',
 
 'disambiguations' => 'Liŋkkat dárkonsiidduide',
 
-'doubleredirects' => 'Guoktegeardán ođđasitstivremat',
+'doubleredirects' => 'Guovttegeardán ođđasitstivremat',
 
-'brokenredirects'        => 'Beđganan ođđasitstivremat',
+'brokenredirects'        => 'Bieđganan ođđasitstivremat',
 'brokenredirectstext'    => 'Čuovvovaš ođđasitstivremat leat artihkkaliidda, mat eai dihtto.',
 'brokenredirects-edit'   => 'rievdat',
 'brokenredirects-delete' => 'sihko',
@@ -756,11 +767,11 @@ $1 {{int:pipe-separator}} $2',
 'popularpages'            => 'Bivnnuhis siiddut',
 'wantedcategories'        => 'Luohkkásávaldagat',
 'wantedpages'             => 'Siidusávaldagat',
-'mostlinked'              => 'Siiddut maidda čujuhuvvo dávjemustá',
-'mostlinkedcategories'    => 'Luohkát, maidda čujuhuvvo dávjemustá',
-'mostlinkedtemplates'     => 'Mállevuođut, maidda čujuhuvvo dávjemustá',
+'mostlinked'              => 'Siiddut maidda čujuhuvvo dávjjimustá',
+'mostlinkedcategories'    => 'Luohkát, maidda čujuhuvvo dávjjimustá',
+'mostlinkedtemplates'     => 'Mállevuođut, maidda čujuhuvvo dávjjimustá',
 'mostcategories'          => 'Siiddut, mat gullet eanemus luohkáide',
-'mostimages'              => 'Govat, maidda lea čujuhuvvon dávjemus',
+'mostimages'              => 'Govat, maidda lea čujuhuvvon dávjjimus',
 'mostrevisions'           => 'Siiddut, mat leat rievdáduvvon eanemustá',
 'shortpages'              => 'Oanehis siiddut',
 'longpages'               => 'Guhkes siiddut',
@@ -780,8 +791,8 @@ $1 {{int:pipe-separator}} $2',
 'notargettext'            => 'It leat meroštallan mearresiiddu dahje -geavaheaddji, masa dahku laktása.',
 
 # Book sources
-'booksources'               => 'Girjegálddut',
-'booksources-search-legend' => 'Oza girjegáldduid',
+'booksources'               => 'Girjegáldut',
+'booksources-search-legend' => 'Oza girjegálduid',
 'booksources-go'            => 'Oza',
 'booksources-text'          => 'Vuolábealde leat liŋkkat olggobeal siidduide, main vuvdojuvvot ođđa ja boares girjjid. Siiddui sáhttá maid leat lassedieđut girjjiin.',
 
@@ -809,7 +820,9 @@ $1 {{int:pipe-separator}} $2',
 
 # Special:Categories
 'categories'         => 'Luohkát',
-'categoriespagetext' => '{{GRAMMAR:inessive|{{SITENAME}}}} lea čuovvovaš luohkát:',
+'categoriespagetext' => '{{GRAMMAR:inessive|{{SITENAME}}}} lea čuovvovaš luohkát.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # Special:ListUsers
 'listusers-submit'   => 'Oza',
@@ -820,7 +833,7 @@ $1 {{int:pipe-separator}} $2',
 'mailnologintext' => 'Don fertet leat [[Special:UserLogin|čálligoahtán sisa]] ja du [[Special:Preferences|ásahusain]] ferte leat gelbbolaš ja <strong>sihkarastojuvvon</strong> e-poastačujuhus, ovdalgo sáhtat sáddet e-poasta eará geavaheddjiide.',
 'emailuser'       => 'Čále e-poastta geavaheaddjái',
 'emailpage'       => 'Sádde e-poastta geavaheaddjái',
-'emailpagetext'   => 'Jus dát geavaheaddji lea lasihin iežaset ásahusaide gelbbolaš e-poastačujuhusa, vuolábeale skoviin sáhtat sáddet sunnje ovtta sáni. Iežat ásahusaide lasihuvvon e-poastačujuhus oidno sáddejeaddji dieđuin, vai vuostáiváldi sáhttá vástidit.',
+'emailpagetext'   => 'Jus dát geavaheaddji lea lasihin iežaset ásahusaide gelbbolaš e-poastačujuhusa, vuolábeale skoviin sáhtat sáddet sudnje ovtta sáni. Iežat ásahusaide lasihuvvon e-poastačujuhus oidno sáddejeaddji dieđuin, vai vuostáiváldi sáhttá vástidit.',
 'usermailererror' => 'Feaila e-poastta sáddedettiin:',
 'defemailsubject' => '{{SITENAME}}-e-poasta',
 'noemailtitle'    => 'Ii e-poastačujuhus',
@@ -838,7 +851,6 @@ $1 {{int:pipe-separator}} $2',
 # Watchlist
 'watchlist'            => 'Čuovvunlistu',
 'mywatchlist'          => 'Čuovvunlistu',
-'watchlistfor'         => '$1',
 'nowatchlist'          => 'Du čuovvunlisttus eai leat siiddut.',
 'watchlistanontext'    => 'Don fertet $1, jus hálidat geavahit čuovvunlisttu.',
 'watchnologin'         => 'It leat čálligoahtán sisa',
@@ -856,7 +868,7 @@ $1 {{int:pipe-separator}} $2',
 'watchlist-details'    => 'Du čuovvunlisttus {{PLURAL:$1|lea $1 siidu|leat $1 siiddu}}. Lohkui eai leat váldojuvvon ságastallansiidduid.',
 'wlheader-enotif'      => '* E-poastaalmmuhusat leat anus.',
 'wlheader-showupdated' => "* Siiddut, mat leat rievdaduvvon du maŋimus geavahangearddi maŋŋá leat merkojuvvon '''buoiddes teavsttain'''",
-'watchmethod-recent'   => 'dárksituvvo varas rievdadusat čuovvunlisttu siidduide',
+'watchmethod-recent'   => 'dárkistuvvo varas rievdadusat čuovvunlisttu siidduide',
 'watchmethod-list'     => 'dárkistuvvo čuovvunlisttu siidduid varas rievdadusat',
 'watchlistcontains'    => 'Du čuovvunlisttus {{PLURAL:$1|lea okta siidu|leat $1 siiddu}}.',
 'iteminvalidname'      => 'Siidduin $1 ledje váttisvuođat! Siiddu namas lea feaila.',
@@ -889,7 +901,7 @@ $1 {{int:pipe-separator}} $2',
 'actioncomplete'    => 'Doaibma lea dahkkon',
 'deletedtext'       => '"<nowiki>$1</nowiki>" lea sihkojuvvon.
 Siiddus $2 lea listu maŋimus sihkomiin.',
-'deletedarticle'    => 'sihkoi siiddu $1',
+'deletedarticle'    => 'sihkoi siiddu [[$1]]',
 'dellogpage'        => 'Sihkkunlogga',
 'dellogpagetext'    => 'Vuolábealde lea logga maŋimus sihkkumiin.',
 'deletionlog'       => 'sihkkunlogga',
@@ -917,14 +929,14 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'protect-legend'              => 'Nanne suodjáleami',
 'protectcomment'              => 'Sivva',
 'protectexpiry'               => 'Boarásnuvvá',
-'protect_expiry_invalid'      => 'Buorášnuvvánáigi ii dohket.',
+'protect_expiry_invalid'      => 'Boarášnuvvánáigi ii dohket.',
 'protect_expiry_old'          => 'Boarásnuvvánáigi lea vássán.',
 'protect-default'             => '(eai rádjehusat)',
 'protect-level-autoconfirmed' => 'Cakkastala ođđa ja anonyma geavaheddjiid',
 'protect-level-sysop'         => 'Dušše bájasdoallit',
-'protect-summary-cascade'     => 'viididuvvon',
+'protect-summary-cascade'     => 'viiddiduvvon',
 'protect-expiring'            => 'boarásnuvvá $1',
-'protect-cascade'             => 'Viidit suodjálusa guoskat buot siidduit, mat gullet dán siidui',
+'protect-cascade'             => 'Viididt suodjálusa guoskat buot siidduit, mat gullet dán siidui',
 'protect-expiry-options'      => '2 diimma:2 hours,1 beaivi:1 day,3 beaivve:3 days,1 vahkku:1 week,2 vahkku:2 weeks,1 mánotbádji:1 month,3 mánotbaji:3 months,6 mánotbaji:6 months,1 jahki:1 year,bissovaš:infinite',
 'restriction-type'            => 'Rádjehus',
 'restriction-level'           => 'Suodjálus',
@@ -978,7 +990,7 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'sp-contributions-submit'      => 'Oza',
 
 # What links here
-'whatlinkshere'       => 'Siiddut mat čujuhit deikke',
+'whatlinkshere'       => 'Siiddut mat čujuhit deike',
 'whatlinkshere-title' => 'Siiddut mat čujuhit $1',
 'linkshere'           => 'Čuovvovaš siidduin lea liŋka siidui <strong>[[:$1]]</strong>:',
 'nolinkshere'         => 'Siidui <strong>[[:$1]]</strong> eai leat liŋkkat.',
@@ -1016,7 +1028,7 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'badipaddress'         => 'IP-čujuhus lea boastut.',
 'blockipsuccesssub'    => 'Easttan lihkosmuvai',
 'blockipsuccesstext'   => "Geavaheaddji dahje IP-čujuhus '''$1''' lea eston.<br />Dálá easttut gávdnot [[Special:IPBlockList|easttolisttus]].",
-'ipb-edit-dropdown'    => 'Rievdat siivaid',
+'ipb-edit-dropdown'    => 'Rievdat sivaid',
 'ipb-unblock-addr'     => 'Sihko geavaheaddji $1 estema',
 'ipb-unblock'          => 'Sihko geavaheaddji dahje IP-čujuhusa rievdadaneasttu',
 'ipblocklist-username' => 'Geavaheaddjidovddaldat dahje IP-čujuhus:',
@@ -1029,8 +1041,8 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 # Developer tools
 'lockdb'             => 'Gidde diehtovuođu',
 'unlockdb'           => 'Raba diehtovuođu',
-'lockconfirm'        => 'Jua, hálidan sihkarit giddet diehtovuođu.',
-'unlockconfirm'      => 'Jua, hálidan sihkarit rahpat diehtovuođu.',
+'lockconfirm'        => 'Jua, háliidan sihkkarit giddet diehtovuođu.',
+'unlockconfirm'      => 'Jua, háliidan sihkkarit rahpat diehtovuođu.',
 'lockbtn'            => 'Gidde diehtovuođu',
 'unlockbtn'          => 'Raba diehtovuođu',
 'lockdbsuccesssub'   => 'Diehtovuođu gidden lihkosmuvai',
@@ -1087,7 +1099,7 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'tooltip-ca-talk'                 => 'Ságastala sisdoalus',
 'tooltip-ca-edit'                 => 'Rievdat dán siiddu',
 'tooltip-ca-addsection'           => 'Lasit kommeantta dán siidui',
-'tooltip-ca-viewsource'           => 'Čájet siiddu galdokoda',
+'tooltip-ca-viewsource'           => 'Čájet siiddu gáldokoda',
 'tooltip-ca-history'              => 'Siiddu ovddit veršuvnnat',
 'tooltip-ca-protect'              => 'Suodjal dán siiddu',
 'tooltip-ca-delete'               => 'Sihko dán siiddu',
@@ -1102,8 +1114,8 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'tooltip-n-currentevents'         => 'Áigeguovdilis áššiin ságastallan',
 'tooltip-n-recentchanges'         => 'Listu varas rievdadusain',
 'tooltip-n-randompage'            => 'Raba summal siidu',
-'tooltip-n-help'                  => 'Ravvagat',
-'tooltip-t-whatlinkshere'         => 'Listu siiddui, mat čujuhit deikke',
+'tooltip-n-help'                  => 'Rávvagat',
+'tooltip-t-whatlinkshere'         => 'Listu siiddui, mat čujuhit deike',
 'tooltip-t-recentchangeslinked'   => 'Varas rievdadusat siiddui, maidda čujuhuvvo dán siiddus',
 'tooltip-t-contributions'         => 'Čájet listtu dán geavaheaddji rievdadusain',
 'tooltip-t-emailuser'             => 'Sádde e-poastta dán geavaheaddjái',
@@ -1162,7 +1174,7 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'nextdiff'     => 'Čuovvovaš rievdadus →',
 
 # Media information
-'widthheightpage' => '$1×$2, $3 siiddut',
+'widthheightpage' => '$1 × $2, $3 siiddut',
 
 # Special:NewFiles
 'newimages'             => 'Ođđa govat',
@@ -1281,7 +1293,7 @@ Siiddus $2 lea listu maŋimus sihkomiin.',
 'watchlistedit-normal-title' => 'Čuovvunlisttu ođasmahttin',
 'watchlistedit-raw-titles'   => 'Siiddut',
 'watchlistedit-raw-submit'   => 'Beaivit čuovvunlisttu',
-'watchlistedit-raw-done'     => 'Du čuovvunlistu lea beaividuvvon.',
+'watchlistedit-raw-done'     => 'Du čuovvunlistu lea beaiváduvvon.',
 'watchlistedit-raw-added'    => '{{PLURAL:$1|Okta siidu|$1 siiddu}} lasihuvvui:',
 'watchlistedit-raw-removed'  => '{{PLURAL:$1|Okta siidu|$1 siiddu}} sihkkojuvvui:',
 
