@@ -94,7 +94,7 @@ O ipuletse akhaonte. O seka wa lebala go fetola tse o di dikgatlhegelo tsa gago
 'yourname'           => 'Leina la modirisi:',
 'yourpassword'       => 'Selotlolo sa sephiri:',
 'yourpasswordagain'  => 'Kwala selotlolo sa gago sa sephiri gape:',
-'remembermypassword' => 'Gakologelwa ikwadiso yame mo khompiutareng e',
+'remembermypassword' => 'Gakologelwa ikwadiso yame mo khompiutareng e (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'login'              => 'Ikwadise',
 'userlogin'          => 'Ikwadise / ipulela tsebe',
 'logout'             => 'Tswala',
