@@ -1,5 +1,5 @@
 <?php
-/** Tonga (lea faka-Tonga)
+/** Tongan (lea faka-Tonga)
  *
  * See MessagesQqq.php for message documentation incl. usage of parameters
  * To improve a translation please visit http://translatewiki.net
@@ -16,7 +16,7 @@ $messages = array(
 # User preference toggles
 'tog-underline'            => 'Ngaahi fehokotaki ʻoku laineʻi ʻi lalo:',
 'tog-highlightbroken'      => 'Ngaohi ʻa e ngaahi fehokotaki maumau ʻoku <a href="" class="new">pehē</a> (meʻa kehe ʻoku pehē <a href="" class="internal">?</a>).',
-'tog-rememberpassword'     => 'Manatuʻi ʻeku kau-ki-ai ʻi he komipiuta ʻeni',
+'tog-rememberpassword'     => 'Manatuʻi ʻeku kau-ki-ai ʻi he komipiuta ʻeni (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'tog-watchcreations'       => 'Tānaki ngaahi peesi ʻoku fakatupu ʻe au ki he hokohoko leʻo',
 'tog-watchdefault'         => 'Tānaki ngaahi peesi ʻoku fatu ʻe au ki he hokohoko leʻo',
 'tog-watchmoves'           => 'Tānaki ki heʻeku hokohoko leʻo ʻa e ngaahi peesi kuo ʻunu ʻe au',
@@ -96,25 +96,29 @@ $messages = array(
 'subcategories'            => 'Ngaahi faʻahinga siʻi',
 'category-empty'           => "''Ko e faʻahinga ʻeni ʻoku ʻikai ʻi ai haʻane kupu pe ʻata.''",
 'hidden-categories'        => 'Faʻahinga toi',
-'hidden-category-category' => 'Ngaahi faʻahinga toi', # Name of the category where hidden categories will be listed
+'hidden-category-category' => 'Ngaahi faʻahinga toi',
 'listingcontinuesabbrev'   => ' hoko',
 
-'about'          => 'Kau ki',
-'article'        => 'Peesi kakano',
-'newwindow'      => '(fakaava ʻi he matapā foʻou)',
-'cancel'         => 'Kaniseli',
+'about'         => 'Kau ki',
+'article'       => 'Peesi kakano',
+'newwindow'     => '(fakaava ʻi he matapā foʻou)',
+'cancel'        => 'Kaniseli',
+'moredotdotdot' => 'Hoko...',
+'mypage'        => 'Peesi ʻaʻaku',
+'mytalk'        => 'Alea ʻaʻaku',
+'anontalk'      => 'Alea maʻa e IP´ ni',
+'navigation'    => 'ʻai taumuʻa ki he…',
+'and'           => '&#32;mo e',
+
+# Cologne Blue skin
 'qbfind'         => 'Kumi',
 'qbbrowse'       => 'Palausa',
 'qbedit'         => 'Fatu',
 'qbpageoptions'  => 'Peesi koʻeni',
 'qbmyoptions'    => 'Peesi ʻaʻaku',
 'qbspecialpages' => 'Ngaahi peesi makehe',
-'moredotdotdot'  => 'Hoko...',
-'mypage'         => 'Peesi ʻaʻaku',
-'mytalk'         => 'Alea ʻaʻaku',
-'anontalk'       => 'Alea maʻa e IP´ ni',
-'navigation'     => 'ʻai taumuʻa ki he…',
-'and'            => '&#32;mo e',
+'faq'            => 'Fehuʻi faʻa eke',
+'faqpage'        => 'Project:Fehuʻi faʻa eke',
 
 'errorpagetitle'    => 'Halaʻi',
 'returnto'          => 'Foki ki he $1',
@@ -170,14 +174,11 @@ $messages = array(
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
 'aboutsite'            => 'Kau ki: {{SITENAME}}',
 'aboutpage'            => 'Project:ʻo kau ki',
-'copyrightpagename'    => 'Foʻi mafai ke pulusi maʻa e {{SITENAME}}',
 'currentevents'        => 'Ngaahi ongoongo',
 'currentevents-url'    => 'Project:Ongoongo taka',
 'disclaimers'          => 'Ngaahi fakaʻataʻatā',
 'disclaimerpage'       => 'Project:Fakaʻataʻatā lūkufua',
 'edithelp'             => 'Tokoni ki he fatu',
-'faq'                  => 'Fehuʻi faʻa eke',
-'faqpage'              => 'Project:Fehuʻi faʻa eke',
 'mainpage'             => 'Peesi tali fiefia',
 'mainpage-description' => 'Peesi tali fiefia',
 'portal'               => 'Fale fakataha',
@@ -229,8 +230,6 @@ $messages = array(
 # General errors
 'error'                => 'Halaʻi',
 'databaseerror'        => 'Halaʻi tānekingaʻilo',
-'nodb'                 => 'Naʻe ʻikai lava fili ʻa e tānekingaʻilo $1',
-'cachederror'          => 'ʻOku ʻasi ʻi lalo ʻa e fafaʻo ʻo e peesi naʻa ke kole, pea mahalo pē ʻoku ʻikai fakaonopooni.',
 'laggedslavemode'      => 'Tokanga: Mahalo pē ʻoku ʻikai ha toki fakafoʻou ʻi loto peesi.',
 'readonly'             => 'ʻOku lokaʻi ʻa e tānekingaʻilo',
 'readonlytext'         => 'ʻOku lokaʻi ʻa e tānekingaʻilo he taimí ni (ʻoku ikai te ke lava fatu) maʻa e monomono fakatānekingaʻilo tuʻumaʻu. ʻOsi ia ʻe foki ia ki hono faʻafai.
@@ -260,7 +259,6 @@ Eke: $2",
 'namespaceprotected'   => "ʻOku ʻikai ngofua ke ke fatu ʻa e ngaahi kupu ʻi he vā hingoa '''$1'''.",
 
 # Login and logout pages
-'logouttitle'                => 'ʻAlu mamaʻo ʻo e ʻetita',
 'logouttext'                 => "'''Kuo ʻalu mamaʻo koe he taimí ni.'''
 
 E lava te ke hoko atu ʻo ngāueʻaki he {{SITENAME}} tatau mo e ʻetita taʻehingoa, pe te ke kau-ki-ai mo e hingoa tatau pe hingoa kehe.
@@ -268,11 +266,10 @@ Tokanga, mahalo pē ʻe ʻi ai ha ngaahi peesi ʻoku ʻasi ko koe kei kau-ki-ai
 'welcomecreation'            => '== Tali fiefia, $1! ==
 
 Kuo fakatupu hoʻo tohi kau-ki-ai. ʻOua ʻe ngalo ke liliu hoʻo faʻiteliha {{SITENAME}}.',
-'loginpagetitle'             => 'Kau-ki-ai ʻo e ʻetita',
 'yourname'                   => 'Hingoa ʻetita',
 'yourpassword'               => 'Leatapu',
 'yourpasswordagain'          => 'Toe ʻai leatapu',
-'remembermypassword'         => 'Manatuʻi au',
+'remembermypassword'         => 'Manatuʻi au (for a maximum of $1 {{PLURAL:$1|day|days}})',
 'yourdomainname'             => 'ho ngāueʻanga',
 'login'                      => 'Kau ki ai',
 'nav-login-createaccount'    => 'Kau ki ai',
@@ -288,17 +285,7 @@ Kuo fakatupu hoʻo tohi kau-ki-ai. ʻOua ʻe ngalo ke liliu hoʻo faʻiteliha {{
 'gotaccountlink'             => 'Kau ki ai',
 'createaccountmail'          => 'ʻi he tohila',
 'badretype'                  => 'ʻOku kehe hoʻo ongo leatapu.',
-'youremail'                  => 'Tohila:',
-'username'                   => 'Ko e ʻetita hono hingoa:',
-'uid'                        => 'hono fika:',
-'yourrealname'               => 'Hingoa moʻoni:',
-'yourlanguage'               => 'Lea:',
-'yourvariant'                => 'Faikeheʻi',
-'yournick'                   => 'Hingoa tenetene:',
-'badsig'                     => 'Ko e fakamoʻoni ʻota ʻoku taʻeʻaonga; siviʻi ngaahi tikite HTML.',
-'email'                      => 'Tohila',
 'loginerror'                 => 'Halaʻi kau-ki-ai',
-'prefs-help-email'           => 'Tohila (tohi-ʻuhila, e-mail) fakafaʻiteliha: ʻE fakamafeiaʻi ʻa e kau ʻetita ʻo lave kia te koe, ngāueʻaki hoʻo peesi pe peesi-alea, taʻe ʻi ai haʻanau ʻilo pe ko hai koe.',
 'nocookiesnew'               => 'Kuo fakatupu hoʻo tohi-kau-ki-ai, kae teʻeki ke kau-ki-ai. ʻOku ngāueʻaki mo e foʻi keke ʻe he {{SITENAME}} ʻi he kau-ki-ai ʻo e kau ʻetita. Naʻa ke fakataʻeʻaongaki ʻa e ngaahi foʻi keke. ʻE fakamafeia kinautolu pea te ke kau-ki-ai mo ho hingoa tenetene foʻou mo hono tapulea.',
 'nocookieslogin'             => 'ʻOku ngāueʻaki mo e foʻi keke ʻe he {{SITENAME}} ʻi he kau-ki-ai ʻo e kau ʻetita. Naʻa ke fakataʻeʻaongaki ʻa e ngaahi foʻi keke. ʻE fakamafeia kinautolu pea te ke toe feinga.',
 'noname'                     => 'Naʻe ʻikai te ke ʻoatu hao hingoa ʻetita ʻoku totonu.',
@@ -368,7 +355,6 @@ Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatap
 'blockededitsource'       => "ʻOku ʻasi ʻi lalo ʻa e tohi ʻo '''hoʻo ngaahi fatu''' ki he '''$1''':",
 'whitelistedittitle'      => 'ʻOku pau ke kau ki ai ke fatuʻi',
 'whitelistedittext'       => 'ʻOku pau te ke $1 kapau te ke fiefatu ʻa e ngaahi kupu.',
-'confirmedittitle'        => 'ʻOku pau ʻe fakaʻmoʻoniʻi hoʻo tohila kapau te ke fieʻetita',
 'confirmedittext'         => 'ʻOku pau te ke fakamoʻoniʻi ho tuʻasila tohila ʻi muʻa hoʻo fatu kupu. Kātaki ʻe fakamoʻoniʻi ia ngāueʻaki hoʻo [[Special:Preferences|faʻiteliha]] fakaʻetita.',
 'loginreqtitle'           => 'ʻOku pau te ke kau ki ai',
 'loginreqlink'            => 'kau ki ai',
@@ -392,7 +378,7 @@ Kapau naʻe kole ia ʻe he tokotaha kehe, pea ʻosi hoʻo manatuʻi ʻo e leatap
 Ko e konga ʻi olunga, ko e kupu ia he onopooni.
 Ko e konga ʻi lalo, ko hoʻo ngaahi liliu ia.
 ʻE pau te ke fakataha hoʻo liliu ʻi loto ʻo e kupu ʻoku tuʻu.
-Ko e konga ʻi olunga, ko e '''konga pē ʻe taha''' ʻe haofaki ʻi he lomiʻi ʻo e meʻalolomi \"haofaki e pēsí\".",
+Ko e konga ʻi olunga, ko e '''konga pē ʻe taha''' ʻe haofaki ʻi he lomiʻi ʻo e meʻalolomi \"{{int:savearticle}}\".",
 'yourtext'                => 'tohi ʻaʻau',
 'storedversion'           => 'Ko e paaki kuo tuku',
 'editingold'              => "'''FAKATOKANGA: ʻOku ke fatu ʻi he paaki fakaonoʻaho ʻo e pēsi. Kapau te ke haofaki ia, ʻe mole ʻa e ngaahi liliu kotoa talu mei ai.'''",
@@ -418,7 +404,7 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'nohistory'           => 'ʻOku ʻikai ʻi ai ha hisitōlia fatu maʻa e kupú ni.',
 'currentrev'          => 'Paaki taka',
 'revisionasof'        => 'Paaki he ko $1',
-'revision-info'       => 'Paaki he ko $1 fai ʻe $2', # Additionally available: $3: revision id
+'revision-info'       => 'Paaki he ko $1 fai ʻe $2',
 'previousrevision'    => '←Paaki motuʻa ange',
 'nextrevision'        => 'Paaki foʻou ange→',
 'currentrevisionlink' => 'Paaki taka',
@@ -427,7 +413,6 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'last'                => 'fakamuimui',
 'histlegend'          => 'Konga faikehekehe: fakaʻilongaʻi ʻa e ngaahi puha fakaletio ʻo e ngaahi paaki ʻo fakatatau pea lomiʻi.<br />
 ʻAtungatala: (taka) = ngaahi lilu mo e paaki taka, (mui) = ngaahi liliu mo paaki naʻe fetongi, s = fatu siʻi.',
-'deletedrev'          => '[kuo tāmateʻi]',
 'histfirst'           => 'Fakamuʻa taha',
 'histlast'            => 'Fakamuimui taha',
 
@@ -439,7 +424,7 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'rev-delundel'              => 'ʻasi/toi',
 'revdelete-hide-comment'    => 'Toi he fakamatala maʻa e tohinoa',
 'revdelete-hide-restricted' => 'ʻAi ʻa e ngaahi fakangatangatá ni maʻa e kau pule fakafounga mo e kau kotoa',
-'revdelete-log'             => 'Fakamatala maʻa e tohinoa:',
+'revdelete-log'             => 'ʻUhinga',
 
 # Merge log
 'revertmerge' => 'Vete ʻa e fakataha',
@@ -454,10 +439,9 @@ Ko e ʻuhinga loka ko e $1 ia.",
 # Search results
 'searchresults'             => 'kumi hono ʻātunga',
 'searchresults-title'       => 'kumi "$1" hono ʻātunga',
-'noexactmatch'              => "'''ʻOku ʻikai ʻi ai ha kupu mo hono ʻuluʻitohi \"\$1\".''' ʻOku lava ke ke [[:\$1|fakatupu he kupú ni]].",
-'prevn'                     => '$1 ki muʻa',
-'nextn'                     => '$1 hoko',
-'viewprevnext'              => 'Vakai ki he ($1) ($2) ($3).',
+'prevn'                     => '{{PLURAL:$1|$1}} ki muʻa',
+'nextn'                     => '{{PLURAL:$1|$1}} hoko',
+'viewprevnext'              => 'Vakai ki he ($1 {{int:pipe-separator}} $2) ($3).',
 'search-suggest'            => 'Mahalo pē naʻa ke fiemaʻu: $1',
 'search-interwiki-more'     => '(lahi ange)',
 'search-mwsuggest-enabled'  => 'mo e fokotuʻu atu',
@@ -474,15 +458,11 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'mypreferences'         => 'faʻiteliha ʻaʻaku',
 'prefsnologin'          => 'ʻOku ʻikai kau ki ai',
 'changepassword'        => 'Liliu hoʻo leatapu',
-'skin'                  => 'Kili',
+'prefs-skin'            => 'Kili',
 'skin-preview'          => 'Vakai pē',
-'math'                  => 'Matematika',
-'dateformat'            => 'Ngaohi ʻo e ʻaho',
+'prefs-math'            => 'Matematika',
 'datedefault'           => 'ʻIkai ha faʻiteliha',
-'datetime'              => 'ʻAho mo e taimi',
-'math_unknown_error'    => 'hala taʻeʻiloa',
-'math_unknown_function' => 'lakanga taʻeʻiloa',
-'math_bad_output'       => 'ʻOku ʻikai lava ʻo tohi pe fakatupu ʻa e takafi maʻa e fua matematika',
+'prefs-datetime'        => 'ʻAho mo e taimi',
 'prefs-personal'        => 'Fōtunga fakatafaʻaki',
 'prefs-rc'              => 'Ngaahi toki liliu',
 'prefs-watchlist'       => 'Hokohoko leʻo',
@@ -491,14 +471,13 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'prefs-misc'            => 'Kehekehe',
 'saveprefs'             => 'Haofaki',
 'resetprefs'            => 'Fakafoki',
-'textboxsize'           => 'ʻOku fatu',
+'prefs-editing'         => 'ʻOku fatu',
 'rows'                  => 'Ngaahi ʻotu:',
 'columns'               => 'Vahaʻa laini:',
 'searchresultshead'     => 'Kumi',
 'recentchangescount'    => 'Ngaahi ʻuluʻitohi ʻoku ʻasi ʻi he toki liliu, hisitōlia peesi, mo e hokohoko:',
 'savedprefs'            => 'Kuo haofaki hoʻo faʻiteliha.',
 'timezonelegend'        => 'Feituʻu taimi',
-'timezonetext'          => 'Ko e lahi ʻo e ngaahi houa ʻoku faikehekehe hoʻo taimi fakakolo mei he taimi māmani.',
 'localtime'             => 'Taimi fakafeituʻu:',
 'timezoneoffset'        => 'Ngaahi houa ʻo e faikehekehe:',
 'servertime'            => 'Taimi ʻo e tauhia:',
@@ -506,7 +485,17 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'allowemail'            => 'Fakamafeiaʻi ʻa e tohila mei he kau ʻetita ʻe taha',
 'defaultns'             => 'Kumi ʻi he vā hingoa fakatuʻunga:',
 'default'               => 'tuʻunga',
-'files'                 => 'Ngaahi faile',
+'prefs-files'           => 'Ngaahi faile',
+'youremail'             => 'Tohila:',
+'username'              => 'Ko e ʻetita hono hingoa:',
+'uid'                   => 'hono fika:',
+'yourrealname'          => 'Hingoa moʻoni:',
+'yourlanguage'          => 'Lea:',
+'yourvariant'           => 'Faikeheʻi',
+'yournick'              => 'Hingoa tenetene:',
+'badsig'                => 'Ko e fakamoʻoni ʻota ʻoku taʻeʻaonga; siviʻi ngaahi tikite HTML.',
+'email'                 => 'Tohila',
+'prefs-help-email'      => 'Tohila (tohi-ʻuhila, e-mail) fakafaʻiteliha: ʻE fakamafeiaʻi ʻa e kau ʻetita ʻo lave kia te koe, ngāueʻaki hoʻo peesi pe peesi-alea, taʻe ʻi ai haʻanau ʻilo pe ko hai koe.',
 
 # Groups
 'group'            => 'Pupunga:',
@@ -549,12 +538,13 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'rc-enhanced-hide'   => 'Toi ngaahi ʻeu',
 
 # Recent changes linked
-'recentchangeslinked' => 'Ngaahi liliu fekauʻaki',
+'recentchangeslinked'         => 'Ngaahi liliu fekauʻaki',
+'recentchangeslinked-feed'    => 'Ngaahi liliu fekauʻaki',
+'recentchangeslinked-toolbox' => 'Ngaahi liliu fekauʻaki',
 
 # Upload
 'upload'                      => 'Hiki hake ʻa e faile',
 'uploadbtn'                   => 'Hiki hake',
-'reupload'                    => 'Toe hiki hake',
 'reuploaddesc'                => 'Foki ki he foomu hiki',
 'uploadnologin'               => 'Teʻeki kau ki ai',
 'uploadnologintext'           => 'ʻOku pau ke [[Special:UserLogin|kau-ki-ai]] kapau te ke fiehiki hake ha faile.',
@@ -577,21 +567,21 @@ Ko e ʻuhinga loka ko e $1 ia.",
 [[$1|thumb]]",
 'fileexists-forbidden'        => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē, pea ʻe ʻikai lava liliu; fakamolemole ʻe foki pea hiki hake ʻa e failé ni mo e ha hingoa foʻou. [[File:$1|thumb|center|$1]]',
 'fileexists-shared-forbidden' => 'ʻOku toka ʻi ai ha peesi mo e hingoa ē ʻi he kalasi vahevahe; fakamolemole ʻe foki pea hiki hake ʻa e failé ni mo e ha hingoa foʻou. [[File:$1|thumb|center|$1]]',
-'successfulupload'            => 'Kuo ola ʻa e hiki hake',
 'uploadwarning'               => 'Tokanga hiki hake',
 'savefile'                    => 'Haofaki faitaá ni',
 'uploadedimage'               => '"[[$1]]" ʻosi hiki hake',
 'uploaddisabled'              => 'ʻOku fakataʻeʻaongaʻi ʻa e ngaahi hiki hake',
 'uploaddisabledtext'          => 'ʻOku fakataʻeʻaongaʻi ha ngaahi hiki hake ʻi heni.',
-'uploadcorrupt'               => 'ʻOku kovi ʻa e failé ni pe ʻoku halaʻi hono fakalōloa. Kātaki, sivi ia pea foki hiki hake ia.',
 'uploadvirus'                 => 'ʻOku ʻi ai ha vailasi ʻi he failé ni! ʻŪ kiʻi meʻa: $1',
 'sourcefilename'              => 'Hingoa ʻo e faile tupunga:',
 'destfilename'                => 'Hingoa ʻo e faile ʻe ʻalu ki ai:',
 'watchthisupload'             => 'Leʻo he pēsí ni',
 'filewasdeleted'              => 'Kuo hiki hake ʻa e faile mo e hingoa ʻeni pea naʻe tāmateʻi ia. Kuo pau te ke vakai ki he $1 ʻi muʻa haʻo feinga ʻo toe hiki hake ia.',
+'upload-success-subj'         => 'Kuo ola ʻa e hiki hake',
 
-'license'   => 'Laiseni:',
-'nolicense' => 'ʻIkai fili ha taha',
+'license'        => 'Laiseni:',
+'license-header' => 'Laiseni:',
+'nolicense'      => 'ʻIkai fili ha taha',
 
 # Special:ListFiles
 'listfiles_search_for'  => 'Kumi ki he hingoa ʻo e faitā:',
@@ -604,15 +594,12 @@ Ko e ʻuhinga loka ko e $1 ia.",
 'listfiles_description' => 'Fakamahino',
 
 # File description page
+'file-anchor-link'          => 'Faitā',
 'filehist-datetime'         => 'ʻAho/Taimi',
 'filehist-user'             => 'Ko e ʻetita',
 'imagelinks'                => 'Ngaahi fehokotaki',
 'linkstoimage'              => 'ʻOku fehokotaki ʻa e peesi ʻe $1 ki he failé ni:',
 'nolinkstoimage'            => 'ʻOku ʻikai ha ngaahi peesi fehokotaki ki he faitaá ni.',
-'shareduploadwiki'          => 'Kātaki, vakai ki he $1 mo hano ongoongo lahi ange.',
-'shareduploadwiki-linktext' => 'Peesi ʻo e faile hono fakamahino',
-'noimage'                   => 'ʻOku ʻikai ʻi ai ha faile mo e hingoa koʻeni, ʻe fakatupu koe $1.',
-'noimage-linktext'          => 'hiki hake ʻe taha',
 'uploadnewversion-linktext' => 'Hiki hake ʻa e paaki foʻou ʻo e failé ni.',
 
 # File reversion
@@ -736,7 +723,9 @@ Ko e ʻuhinga loka ko e $1 ia.",
 
 # Special:Categories
 'categories'         => 'Faʻahinga',
-'categoriespagetext' => 'ʻOku ʻi ai ha ngaahi faʻahinga pehē.',
+'categoriespagetext' => 'ʻOku ʻi ai ha ngaahi faʻahinga pehē.
+[[Special:UnusedCategories|Unused categories]] are not shown here.
+Also see [[Special:WantedCategories|wanted categories]].',
 
 # Special:DeletedContributions
 'deletedcontributions'       => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',
@@ -776,7 +765,6 @@ Ko e ʻuhinga loka ko e $1 ia.",
 # Watchlist
 'watchlist'            => 'Hokohoko leʻo ʻaʻaku',
 'mywatchlist'          => 'Hokohoko leʻo ʻaʻaku',
-'watchlistfor'         => "(maʻa e '''$1''')",
 'nowatchlist'          => 'ʻOku ʻikai ha meʻa ʻi hoʻo hokohoko leʻo.',
 'watchlistanontext'    => 'Kātaki, ʻe $1 kapau te ke fievakai pe fiefatu ha ngaahi meʻa ʻi hoʻo hokohoko leʻo.',
 'watchnologin'         => 'Teʻeki kau ki ai',
@@ -827,7 +815,7 @@ Vakai ki he $2 maʻa e fakamatala ʻo e ngaahi toki tāmateʻi.',
 'dellogpagetext'    => 'ʻOku ʻasi ʻi lalo ha hokohoko ʻo e ngaahi tāmateʻi fakamuimui taha.',
 'deletionlog'       => 'tohinoa ʻo e tāmateʻi',
 'reverted'          => 'Kuo foki ki he paaki mui',
-'deletecomment'     => 'Ko e ʻuhinga ʻo e tāmateʻi',
+'deletecomment'     => 'ʻUhinga',
 
 # Rollback
 'rollback'       => 'Ngaahi fatu he teka hifo',
@@ -838,7 +826,7 @@ Vakai ki he $2 maʻa e fakamatala ʻo e ngaahi toki tāmateʻi.',
 'alreadyrolled'  => 'ʻOku ʻikai lava teka hifo ʻa e fatu fakamuimui ʻo e [[:$1]] ʻe [[User:$2|$2]] ([[User talk:$2|Alea]]); ko e tokotaha ʻe taha naʻe fatu pe fatu teka hifo ʻa e peesi.
 
 Ko e fatu fakamuimui naʻe fatu ʻe [[User:$3|$3]] ([[User talk:$3|Alea]]).',
-'editcomment'    => "Ko e fakamatala fatu naʻe \"''\$1''\" ia.", # only shown if there is an edit comment
+'editcomment'    => "Ko e fakamatala fatu naʻe \"''\$1''\" ia.",
 
 # Protect
 'protectlogpage'      => 'Tohinoa ʻo e maluʻi',
@@ -848,7 +836,7 @@ Ko e fatu fakamuimui naʻe fatu ʻe [[User:$3|$3]] ([[User talk:$3|Alea]]).',
 'protect-title'       => 'ʻOku maluʻi "$1"',
 'prot_1movedto2'      => 'Kuo ʻunu ʻa e [[$1]] ki he [[$2]]',
 'protect-legend'      => 'Fakamoʻoniʻi e maluʻi',
-'protectcomment'      => 'ʻUhingha maʻa e maluʻi',
+'protectcomment'      => 'ʻUhinga',
 'protect-level-sysop' => 'Kau pule fakafounga pē',
 
 # Restrictions (nouns)
@@ -882,6 +870,9 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'mycontris'     => 'Foaki ʻaʻaku',
 'uctop'         => ' (ʻi ʻolunga)',
 
+'sp-contributions-deleted' => 'Ngaahi foaki ʻo ha ʻetita kuo tāmateʻi',
+'sp-contributions-talk'    => 'Alea',
+
 # What links here
 'whatlinkshere'       => 'Ngaahi fehokotaki ki heni',
 'linkshere'           => 'ʻOku fehokotaki ki heni ʻa e ngaahi peesi:',
@@ -913,7 +904,7 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'ipblocklist'          => 'Hokohoko ʻo e ngaahi tuʻasila IP mo e hingoa ʻo e ʻetita kuo taʻofi',
 'blocklistline'        => '$1, $2 taʻofi $3 ($4)',
 'infiniteblock'        => 'taʻengata',
-'expiringblock'        => 'ʻE mate ia $1',
+'expiringblock'        => 'ʻE mate ia $1 $2',
 'anononlyblock'        => 'taʻehingoa pē',
 'createaccountblock'   => 'ʻOku taʻofia ʻa e fakatupu ʻa e tohi-kau-ki-ai',
 'blocklink'            => 'taʻofi',
@@ -997,8 +988,6 @@ Vakai ki he [[Special:Log/delete|hokohoko tāmateʻi]] ki he lekooti ʻo e ngaah
 'allmessagescurrent'        => 'Tohi lolotonga',
 'allmessagestext'           => "Ko e hokohoko ʻeni ʻo e ngaahi tala fakafounga kātoa ʻi he vā hingoa ''MediaWiki''.",
 'allmessagesnotsupportedDB' => "ʻOku ʻikai ngāueʻaki mo e '''{{ns:special}}:Allmessages''' koeʻuhi ʻoku kamosiʻi mate ʻa e '''\$wgUseDatabaseMessages'''.",
-'allmessagesfilter'         => 'Meʻasivi ki he hingoa ʻo e tala:',
-'allmessagesmodified'       => 'ʻAsi mai meʻa kuo liliu pē',
 
 # Thumbnails
 'filemissing' => 'ʻOku pulia ʻa e faile',
@@ -1062,6 +1051,11 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 'mw_math_modern' => 'ʻOku fakahinohino maʻa e palausa fakaonopooni.',
 'mw_math_mathml' => 'Fai MathML kapau malava (fakatotolo)',
 
+# Math errors
+'math_unknown_error'    => 'hala taʻeʻiloa',
+'math_unknown_function' => 'lakanga taʻeʻiloa',
+'math_bad_output'       => 'ʻOku ʻikai lava ʻo tohi pe fakatupu ʻa e takafi maʻa e fua matematika',
+
 # Patrolling
 'rcpatroldisabled' => 'ʻOku fakataʻeʻaʻongaʻi ʻa e leʻo ʻo e ngaahi toki liliu',
 
@@ -1192,7 +1186,7 @@ Pea hoko ai pē hoʻo lava tānaki ha ʻuhinga ʻi he fakanounou',
 'exif-gpslongitude-e' => 'Longitute hahake',
 'exif-gpslongitude-w' => 'Longitute hihifo',
 
-# Pseudotags used for GPSSpeedRef and GPSDestDistanceRef
+# Pseudotags used for GPSSpeedRef
 'exif-gpsspeed-k' => 'Kilomita ki he houa',
 'exif-gpsspeed-m' => 'Maile he houa',
 
@@ -1272,7 +1266,7 @@ Kātaki fakapapauʻi te ke fie toe fatu ʻa e kupu ni.",
 'watchlisttools-raw'  => 'Fatu ʻa e hokohoko leʻo taʻengaohi',
 
 # Special:Version
-'version' => 'Paaki', # Not used as normal message but as header for the special page itself
+'version' => 'Paaki',
 
 # Special:FilePath
 'filepath'        => 'Hala ki he faile',
