@@ -37,11 +37,31 @@ $namespaceNames = array(
 
 $linkTrail = '/^([a-zа-яёӝӟӥӧӵ“»]+)(.*)$/sDu';
 $fallback8bitEncoding = 'windows-1251';
-$separatorTransformTable = array(',' => ' ', '.' => ',' );
+$separatorTransformTable = array( ',' => ' ', '.' => ',' );
 
 $messages = array(
 # User preference toggles
-'tog-underline' => 'Линкъёс ултӥз гожен сызоно',
+'tog-underline'               => 'Линкъёс ултӥз гожен сызоно',
+'tog-highlightbroken'         => 'Кушкам чӧлсконъёсты <a href="" class="new">та кадь</a> возматыны (озьытэк: <a href="" class="internal">?</a>)',
+'tog-hideminor'               => 'Берпуметӥ тупатонъёслэн списоксэс ичи воштонъёстэк возьматыны',
+'tog-hidepatrolled'           => 'Берпуметӥ тупатонъёслэн списоксэс партрулировать каремын воштонъёстэк возьматыны',
+'tog-newpageshidepatrolled'   => 'Выль бамъёслэн списоксэс партрулировать каремын бамъёстэк возьматыны',
+'tog-extendwatchlist'         => 'Чаклан списокын вань тупатонъёсты возьматыны (озьытэк берпуметӥоссэс гинэ)',
+'tog-usenewrc'                => 'Выль тупатонъёслэн списоксэс умояллям сямен возьматыны (JavsScript кулэ)',
+'tog-numberheadings'          => 'Заголовокъёсты автоматически нумеровать карыны',
+'tog-showtoolbar'             => 'Тупатон тӥрлыкъёслэн панельзэс возьматыны (JavaScript кулэ)',
+'tog-editondblclick'          => 'Бамъёсты шырлэн валтӥсь зӥбонэз кык пол ӝог зӥбиськыкуз тупатыны (JavaScript кулэ)',
+'tog-editsection'             => 'Котькуд секциез [тапатоно] чӧлсконэн возьматыны',
+'tog-editsectiononrightclick' => 'Cекциосты шырлэн бур кнопкаез заголовок вылын зӥбиськыкуз тупатыны (JavaScript кулэ)',
+'tog-showtoc'                 => 'Пуштросэз возьматоно (2-лэсь трос заголовокъем бамъёс понна)',
+'tog-rememberpassword'        => 'Мынам пыроннимме та браузерлэн тодаз возьыны ($1 яке $1-лэсь ӧжытгес нунал ӵоже гинэ)',
+'tog-watchcreations'          => 'Бамъёсты, кудъёстэс мон кылдытӥсько, мынам чаклкан списокам пыртыны',
+'tog-watchdefault'            => 'Бамъёсты, кудъёстэс мон тупатӥсько, мынам чаклкан списокам пыртыны',
+'tog-watchmoves'              => 'Бамъёсты, кудъёстэс мон мукет интые выжтӥсько, мынам чаклкан списокам пыртыны',
+'tog-watchdeletion'           => 'Бамъёсты, кудъёстэс мон ӵушисько, мынам чаклкан списоке пыртыны',
+'tog-minordefault'            => 'Вань воштонъёсты «ичи воштон» пусэн пусйыны',
+'tog-previewontop'            => 'Утён азьвыл учконлэсь укнозэ тупатон укнолэсь азьвылгес возьматыны',
+'tog-previewonfirst'          => 'Бам нырысьсэ утиськыкуз уётн азьвыл учконэз возьматыны',
 
 'underline-always'  => 'Котьку',
 'underline-never'   => 'Ноку',
@@ -218,7 +238,7 @@ $messages = array(
 'searchresults'      => 'Шедьтэмын',
 'searchresulttext'   => 'Проектлэн бамъёстӥз утчан сярысь тыро-быдогес тодэмды потӥз ке, учке [[{{MediaWiki:Helppage}}|«Юан-веран» люкетэз]].',
 'searchhelp-url'     => 'Help:Валэктон',
-'search-result-size' => '$1 кыл',
+'search-result-size' => '$1 кыл({{PLURAL:$2|1 word|$2 words}})',
 
 # Preferences page
 'preferences'     => 'настройкаос',
