@@ -31,7 +31,7 @@ $messages = array(
 'tog-editsection'             => '允许通过点击【编辑】链接来编辑段落',
 'tog-editsectiononrightclick' => '允许右击标题编辑段落（JavaScript）',
 'tog-showtoc'                 => '显示目录（针对超过三只标题个页面）',
-'tog-rememberpassword'        => '登该台电脑浪记牢我个登录',
+'tog-rememberpassword'        => '来许箇台电脑上记牢我个密码（可维持$1{{PLURAL:$1|日|日}}）',
 'tog-watchcreations'          => '拿我创建个页面添加到我个监控列表里向',
 'tog-watchdefault'            => '拿我编辑个页面添加到我个监控列表里向',
 'tog-watchmoves'              => '拿我移动个页面添加到我个监控列表里向',
@@ -175,31 +175,21 @@ $messages = array(
 'faqpage'        => 'Project:FAQ',
 
 # Vector skin
-'vector-action-addsection'   => '加入话题',
-'vector-action-delete'       => '删除',
-'vector-action-move'         => '移动',
-'vector-action-protect'      => '保护',
-'vector-action-undelete'     => '反删除',
-'vector-action-unprotect'    => '反保护',
-'vector-namespace-category'  => '分类',
-'vector-namespace-help'      => '帮助页',
-'vector-namespace-image'     => '文件',
-'vector-namespace-main'      => '页面',
-'vector-namespace-media'     => '媒体页面',
-'vector-namespace-mediawiki' => '讯息',
-'vector-namespace-project'   => '项目页面',
-'vector-namespace-special'   => '特殊页面',
-'vector-namespace-talk'      => '讨论',
-'vector-namespace-template'  => '模板',
-'vector-namespace-user'      => '用户页面',
-'vector-view-create'         => '创建',
-'vector-view-edit'           => '编辑',
-'vector-view-history'        => '望历史',
-'vector-view-view'           => '阅读',
-'vector-view-viewsource'     => '查看源码',
-'actions'                    => '动作',
-'namespaces'                 => '名字空间',
-'variants'                   => '变量',
+'vector-action-addsection'       => '加入话题',
+'vector-action-delete'           => '删除',
+'vector-action-move'             => '移动',
+'vector-action-protect'          => '保护',
+'vector-action-undelete'         => '反删除',
+'vector-action-unprotect'        => '反保护',
+'vector-simplesearch-preference' => '打开高级搜索建议（仅适用于Vector皮肤）',
+'vector-view-create'             => '创建',
+'vector-view-edit'               => '编辑',
+'vector-view-history'            => '望历史',
+'vector-view-view'               => '阅读',
+'vector-view-viewsource'         => '查看源码',
+'actions'                        => '动作',
+'namespaces'                     => '名字空间',
+'variants'                       => '变量',
 
 'errorpagetitle'    => '错误',
 'returnto'          => '回转到$1。',
@@ -412,7 +402,7 @@ $2',
 'yourname'                   => '用户名:',
 'yourpassword'               => '密码:',
 'yourpasswordagain'          => '再拍一遍密码:',
-'remembermypassword'         => '登该台电脑浪记牢我个登录',
+'remembermypassword'         => '垃拉箇部电脑上记牢我个密码（可维持$1{{PLURAL:$1|日|日}}）',
 'yourdomainname'             => '侬个域名：',
 'externaldberror'            => '迭个作兴是由于验证数据库错误或者侬拨禁止更新侬个外部账号。',
 'login'                      => '登录',
@@ -429,6 +419,7 @@ $2',
 'gotaccount'                 => "已经有仔帐号哉？ '''$1'''。",
 'gotaccountlink'             => '登录',
 'createaccountmail'          => '通过 e-mail',
+'createaccountreason'        => '理由：',
 'badretype'                  => '倷输入个密码搭倪个档案弗配。',
 'userexists'                 => '箇只ID已经拨注册脱哉。请重新再拣个用户名。',
 'loginerror'                 => '登录错误',
@@ -530,8 +521,10 @@ $2',
 'showlivepreview'                  => '实时预览',
 'showdiff'                         => '显示改动',
 'anoneditwarning'                  => "'''警告：''' 侬弗曾登录。侬个IP地址会得记录拉页面个编辑历史里向。",
+'anonpreviewwarning'               => "''侬弗曾登录。侬个IP位址会得记录拉此页个编辑历史里向。''",
 'missingsummary'                   => "'''提示：''' 侬弗曾提供编辑摘要。假使侬再次单击保存，侬个编辑将弗带编辑摘要保存。",
 'missingcommenttext'               => '请垃下头输入备注。',
+'missingcommentheader'             => "'''提示：''' 侬弗曾为此评论提供只标题。如果侬再次单击“{{int:savearticle}}”，侬个编辑将弗带标题保存。",
 'summary-preview'                  => '摘要预览：',
 'subject-preview'                  => '主题 / 标题 预览：',
 'blockedtitle'                     => '用户拨查封',
@@ -589,7 +582,7 @@ $2',
 'blocked-notice-logextract'        => '箇位用户箇歇畀封锁垃许。
 下头有最近个封锁纪录以供参考：',
 'clearyourcache'                   => "'''注意：垃拉保存之后，侬必须清除浏览器个缓存再好看见所作出个改变。'''
-'''Mozilla / Firefox / Safari'''：揿牢''Shift''再点击''刷新''，或揿''Ctrl-F5''或''Ctrl-R''（垃拉Macintosh上揿 ''Command-R''）；
+'''Mozilla / Firefox / Safari'''：揿牢''Shift''再点击''刷新''，或揿''Ctrl-F5''或''Ctrl-R''（垃拉Mac上揿 ''Command-R''）；
 '''Konqueror'''：只需点击''刷新''或揿''F5''；
 '''Opera'''：垃拉 ''工具→首选项''里向完整清除渠拉个缓存，或揿''Alt-F5''；
 '''Internet Explorer'''：揿牢''Ctrl''再点击''刷新''，或揿''Ctrl-F5''。",
@@ -599,7 +592,7 @@ $2',
 '''还弗曾保存！'''",
 'userjspreview'                    => "'''注意侬只是垃许测试／预览侬个 JavaScript。'''
 '''还弗曾保存！'''",
-'userinvalidcssjstitle'            => "'''警告：''' 弗存在皮肤\"\$1\"。注意自定义个 .css 搭 .js 页要使用小写标题，譬如，{{ns:user}}:Foo/monobook.css 弗同于 {{ns:user}}:Foo/Monobook.css。",
+'userinvalidcssjstitle'            => "'''警告：''' 弗存在皮肤\"\$1\"。注意自定义个 .css 搭 .js 页要使用小写标题，譬如，{{ns:user}}:Foo/vector.css 弗同于 {{ns:user}}:Foo/Vector.css。",
 'updated'                          => '（已更新）',
 'note'                             => "'''注意：'''",
 'previewnote'                      => "'''该个还只是预览；改动还朆保存！'''",
@@ -635,8 +628,6 @@ $2',
 假使侬弗希望侬个文字畀任意修改搭仔再发布，请弗要提交。<br />
 侬同时也要向我伲保证侬提交个内容是侬自家所作，或得自一个弗受版权保护或相似自由个来源（参阅$1个细节）。
 ''' 弗要垃拉弗曾获得授权个情况下头发表！'''",
-'longpagewarning'                  => "'''警告'''：箇页面个长度是$1KB；一些浏览器垃拉编辑长度接近或大于32KB个页面作兴存在问题。
-侬应该考虑拿箇只页面分成功更加小个章节。",
 'longpageerror'                    => "'''错误：侬提交个文本长度有$1KB，大于$2KB个顶大值。'''该文本弗能保存。",
 'readonlywarning'                  => "'''警告：数据库锁定垃许维护，侬箇歇弗好保存侬个修改。'''侬作兴希望先拿本段文字复制并保存到文本文件，等歇再修改。
 
@@ -810,6 +801,8 @@ $1",
 'logdelete-failure'           => "'''事件个可见性无法设置：'''
 $1",
 'revdel-restore'              => '更改可见性',
+'revdel-restore-deleted'      => '已删除个修订版本',
+'revdel-restore-visible'      => '可见个修订版本',
 'pagehist'                    => '页面历史',
 'deletedhist'                 => '已删除之历史',
 'revdelete-content'           => '内容',
@@ -912,6 +905,7 @@ $1",
 'searchprofile-everything-tooltip' => '搜索全部（包括讨论页面）',
 'searchprofile-advanced-tooltip'   => '垃拉自定义名字空间里向搜索',
 'search-result-size'               => '$1（$2字）',
+'search-result-category-size'      => '$1位成员（$2个子分类，$3个文件）',
 'search-result-score'              => '相关度：$1%',
 'search-redirect'                  => '（重定向 $1）',
 'search-section'                   => '（段落 $1）',
@@ -1083,34 +1077,34 @@ $1",
 'recentchangeslinked-to'      => '显示链接到指定页面个页面个改动',
 
 # Upload
-'upload'            => '上载文物',
-'uploadbtn'         => '上载文件',
-'uploadnologin'     => '朆登录',
-'uploadnologintext' => '倷板定要[[Special:UserLogin|登录]]仔再好上载文件。',
-'uploaderror'       => '上载出错',
-'uploadtext'        => "拿下头只表格来上载文件。要查看或者搜寻之前上载个图片个说法，请到[[Special:FileList|已上载文件列表]]，上载搭仔删脱也记录勒拉[[Special:Log/upload|上载日志]]里向。
+'upload'              => '上载文物',
+'uploadbtn'           => '上载文件',
+'uploadnologin'       => '朆登录',
+'uploadnologintext'   => '倷板定要[[Special:UserLogin|登录]]仔再好上载文件。',
+'uploaderror'         => '上载出错',
+'uploadtext'          => "拿下头只表格来上载文件。要查看或者搜寻之前上载个图片个说法，请到[[Special:FileList|已上载文件列表]]，上载搭仔删脱也记录勒拉[[Special:Log/upload|上载日志]]里向。
 
 要勒拉页面里向摆进图片个说法，用下头该种形式个链接
 '''<nowiki>[[{{ns:file}}:文件.jpg]]</nowiki>'''，
 '''<nowiki>[[{{ns:file}}:文件.png|替代文本]]</nowiki>''' 或者用
 '''<nowiki>[[{{ns:media}}:文件.ogg]]</nowiki>''' 直接链到文件。",
-'uploadlog'         => '文件上载日志',
-'uploadlogpage'     => '文件上载日志',
-'uploadlogpagetext' => '下底是最近上载文件列表。',
-'filename'          => '文件名',
-'filedesc'          => '小结',
-'fileuploadsummary' => '小结:',
-'filestatus'        => '版权状态:',
-'filesource'        => '来源:',
-'uploadedfiles'     => '已经上载个文件',
-'ignorewarning'     => '弗管警告，随便哪亨要保存文件。',
-'successfulupload'  => '上载成功哉',
-'uploadwarning'     => '上载警告',
-'savefile'          => '保存文件',
-'uploadedimage'     => '上载 "[[$1]]"',
-'sourcefilename'    => '源文件:',
-'destfilename'      => '目标文件名:',
-'watchthisupload'   => '监控该只页面',
+'uploadlog'           => '文件上载日志',
+'uploadlogpage'       => '文件上载日志',
+'uploadlogpagetext'   => '下底是最近上载文件列表。',
+'filename'            => '文件名',
+'filedesc'            => '小结',
+'fileuploadsummary'   => '小结:',
+'filestatus'          => '版权状态:',
+'filesource'          => '来源:',
+'uploadedfiles'       => '已经上载个文件',
+'ignorewarning'       => '弗管警告，随便哪亨要保存文件。',
+'uploadwarning'       => '上载警告',
+'savefile'            => '保存文件',
+'uploadedimage'       => '上载 "[[$1]]"',
+'sourcefilename'      => '源文件:',
+'destfilename'        => '目标文件名:',
+'watchthisupload'     => '监控该只页面',
+'upload-success-subj' => '上载成功哉',
 
 # Special:ListFiles
 'listfiles_search_for'  => '寻图片名字:',
@@ -1252,7 +1246,6 @@ $1",
 # Watchlist
 'watchlist'         => '监控列表',
 'mywatchlist'       => '我个监控列表',
-'watchlistfor'      => "（'''$1'''个监控列表）",
 'nowatchlist'       => '倷个监控列表是空个。',
 'watchnologin'      => '朆登录',
 'addedwatch'        => '加到监控列表哉',
@@ -1523,9 +1516,9 @@ $1",
 'nextdiff'     => '新版→',
 
 # Media information
-'file-info-size'       => '（$1×$2像素，文件大小：$3，MIME类型：$4）',
+'file-info-size'       => '$1×$2像素，文件大小：$3，MIME类型：$4',
 'file-nohires'         => '<small>无更高分辨率可提供。</small>',
-'svg-long-desc'        => '（SVG文件，名义大小：$1×$2像素，文件大小：$3）',
+'svg-long-desc'        => 'SVG文件，名义大小：$1×$2像素，文件大小：$3',
 'show-big-image'       => '完整分辨率',
 'show-big-image-thumb' => '<small>迭幅缩略图个分辨率：$1×$2像素</small>',
 
