@@ -27,7 +27,7 @@ $namespaceNames = array(
 	NS_FILE_TALK        => 'Боомгин_туск_меткән',
 	NS_MEDIAWIKI        => 'MediaWiki',
 	NS_MEDIAWIKI_TALK   => 'MediaWiki_туск_меткән',
-	NS_TEMPLATE         => 'Зура',
+	NS_TEMPLATE         => 'Кевләр',
 	NS_TEMPLATE_TALK    => 'Зуран_туск_меткән',
 	NS_HELP             => 'Цәәлһлһн',
 	NS_HELP_TALK        => 'Цәәлһлһин_туск_меткән',
@@ -44,6 +44,7 @@ $namespaceAliases = array(
 	'Зург'                    => NS_FILE,
 	'Зургин_тускар_ухалвр'    => NS_FILE_TALK,
 	'MediaWiki_тускар_ухалвр' => NS_MEDIAWIKI_TALK,
+	'Зура'     => NS_TEMPLATE,
 	'Зуран_тускар_ухалвр'     => NS_TEMPLATE_TALK,
 	'Цəəлһлһн'                => NS_HELP,
 	'Цəəлһлһин_тускар_ухалвр' => NS_HELP_TALK,
@@ -67,8 +68,7 @@ $messages = array(
 'tog-editsection'             => '«Чиклх» заавр болвчн хүвд үзүлх',
 'tog-editsectiononrightclick' => 'Һарчига барун индстлһар хүвиг чиклх (JavaScript кергтә)',
 'tog-showtoc'                 => 'Һарг үзүлх (3 икәр толһата халхсд)',
-'tog-rememberpassword'        => 'Намаг эн тоолдврд тодлх',
-'tog-editwidth'               => 'Чикллһнә тег цуг харата болулх',
+'tog-rememberpassword'        => 'Намаг эн тоолдврт тодлх ($1 {{PLURAL:$1|өдрт|өдрмүдт}} икәр биш)',
 'tog-watchcreations'          => 'Би эврәннь немгдсн халхс шинҗллһнә сеткүлд немх',
 'tog-watchdefault'            => 'Би эврәннь чиклсн халхс шинҗллһнә сеткүлд немх',
 'tog-watchmoves'              => 'Би эврәннь көндсн халхс шинҗллһнә сеткүлд немх',
@@ -212,31 +212,20 @@ $messages = array(
 'faqpage'        => 'Project:Юм би',
 
 # Vector skin
-'vector-action-addsection'   => 'Төриг немх',
-'vector-action-delete'       => 'Һарһх',
-'vector-action-move'         => 'Көндәх',
-'vector-action-protect'      => 'Харсх',
-'vector-action-undelete'     => 'Һарһх биш',
-'vector-action-unprotect'    => 'Харсх биш',
-'vector-namespace-category'  => 'Әәшл',
-'vector-namespace-help'      => 'Цәәлһлһнә халх',
-'vector-namespace-image'     => 'Боомг',
-'vector-namespace-main'      => 'Халх',
-'vector-namespace-media'     => 'Аһарин халх',
-'vector-namespace-mediawiki' => 'Зәңг',
-'vector-namespace-project'   => 'Төслин халх',
-'vector-namespace-special'   => 'Көдлхнә халх',
-'vector-namespace-talk'      => 'Меткән',
-'vector-namespace-template'  => 'Кевләр',
-'vector-namespace-user'      => 'Демнчна халх',
-'vector-view-create'         => 'Бүтәх',
-'vector-view-edit'           => 'Чиклх',
-'vector-view-history'        => 'Тууҗин хәләвр',
-'vector-view-view'           => 'Умшлһн',
-'vector-view-viewsource'     => 'Темдгллһнә хәләвр',
-'actions'                    => 'Үүлд',
-'namespaces'                 => 'Нернә ус',
-'variants'                   => 'Суңһлтс',
+'vector-action-addsection' => 'Төриг немх',
+'vector-action-delete'     => 'Һарһх',
+'vector-action-move'       => 'Көндәх',
+'vector-action-protect'    => 'Харсх',
+'vector-action-undelete'   => 'Һарһх биш',
+'vector-action-unprotect'  => 'Харсх биш',
+'vector-view-create'       => 'Бүтәх',
+'vector-view-edit'         => 'Чиклх',
+'vector-view-history'      => 'Тууҗин хәләвр',
+'vector-view-view'         => 'Умшлһн',
+'vector-view-viewsource'   => 'Темдгллһнә хәләвр',
+'actions'                  => 'Үүлд',
+'namespaces'               => 'Нернә ус',
+'variants'                 => 'Суңһлтс',
 
 'errorpagetitle'    => 'Эндү',
 'returnto'          => '«$1» тал хәрү ирх.',
@@ -424,7 +413,7 @@ $1',
 'yourname'                => 'Демнчна нернь:',
 'yourpassword'            => 'Нууц үг:',
 'yourpasswordagain'       => 'Нууц үгиг давтн:',
-'remembermypassword'      => 'Мини нерн эн тоолдврд тодлх',
+'remembermypassword'      => 'Намаг эн тоолдврд тодлх ($1 {{PLURAL:$1|өдрт|өдрмүдт}} икәр биш)',
 'yourdomainname'          => 'Тана домен:',
 'login'                   => 'Орлһн',
 'nav-login-createaccount' => 'Харһх / бичгдлһн кех',
@@ -522,7 +511,7 @@ $1',
 'userjsyoucanpreview'              => "'''Селвг:''' тана шин JS боомг шүүҗ хадһлар, «{{int:showpreview}}» товч олзлтн.",
 'usercsspreview'                   => "'''Тана CSS боомгин мел хәләвр бәәдг тускар тодлтн, тер ода чигн хадһлсн уга!'''",
 'userjspreview'                    => "'''Тана JavaScript боомгин мел хәләвр бәәдг тускар тодлтн. Тана сольлһн ода чигн хадһлсн уга!'''",
-'userinvalidcssjstitle'            => "'''Оньг өгтн:''' «$1» гидг нерәдлһтә хувцнь олҗ биш. Күүнә .css болн .js халхс һанцхн бичкн үзгүдтә бичсн кергтә, үлгүрнь «{{ns:user}}:Болвчн/monobook.css»; «{{ns:user}}:Болвчн/Monobook.css» - буру.",
+'userinvalidcssjstitle'            => "'''Оньг өгтн:''' «$1» гидг нерәдлһтә хувцнь олҗ биш. Күүнә .css болн .js халхс һанцхн бичкн үзгүдтә бичсн кергтә, үлгүрнь «{{ns:user}}:Болвчн/vector.css»; «{{ns:user}}:Болвчн/Vector.css» - буру.",
 'updated'                          => '(Шинрүлсн)',
 'note'                             => "'''Аҗгллһн:'''",
 'previewnote'                      => "'''Эн мел хәләвр бәәдг тускар тодлтн.'''
@@ -750,12 +739,8 @@ $1',
 'recentchanges-legend'           => 'Шидрә сольлһна көгүд',
 'recentchangestext'              => 'Эн цагин дараһар бичсн шидрә сольлһн',
 'recentchanges-feed-description' => 'Эн зәңгллһд шидрә хүврһд шинҗлх.',
-'recentchanges-label-legend'     => 'Тәәлвр: $1.',
-'recentchanges-legend-newpage'   => '$1 — шин халх',
 'recentchanges-label-newpage'    => 'Тер үүләр шин халх бүтәв',
-'recentchanges-legend-minor'     => '$1 — баһ сольлһн',
 'recentchanges-label-minor'      => 'Эн баһ чинртә сольлһн',
-'recentchanges-legend-bot'       => '$1 — көдлврә сольлһн',
 'recentchanges-label-bot'        => 'Эн сольлһн көдлвр (робот) кехв',
 'rcnote'                         => "{{PLURAL:$1|'''$1''' шидрә сольлһн|'''$1''' шидрә сольлһн|'''$1''' шидрә сольлһн}}, '''$2''' өдрә,  $5 $4 цагин.",
 'rclistfrom'                     => 'Тер цагас авн сольлһн үзүлх: $1.',
@@ -788,17 +773,17 @@ $1',
 'recentchangeslinked-to'       => 'Зөрүһәр, эн халхд заалдг халхсин хүврлһиг үзүлх',
 
 # Upload
-'upload'            => 'Боомгиг тәвх',
-'uploadbtn'         => 'Боомгиг тәвх',
-'uploadnologintext' => 'Та [[Special:UserLogin|харһх]] кергтә.',
-'uploaderror'       => 'Тәвллһнә эндү',
-'uploadlogpage'     => 'Тәвллһнә сеткүл',
-'filename'          => 'Боомгна нернь',
-'filedesc'          => 'Учр-утх',
-'fileuploadsummary' => 'Учр-утх:',
-'successfulupload'  => 'Йовудта тәвллһн',
-'savefile'          => 'Хадһлх',
-'uploadedimage'     => '«[[$1]]» тәвв',
+'upload'              => 'Боомгиг тәвх',
+'uploadbtn'           => 'Боомгиг тәвх',
+'uploadnologintext'   => 'Та [[Special:UserLogin|харһх]] кергтә.',
+'uploaderror'         => 'Тәвллһнә эндү',
+'uploadlogpage'       => 'Тәвллһнә сеткүл',
+'filename'            => 'Боомгна нернь',
+'filedesc'            => 'Учр-утх',
+'fileuploadsummary'   => 'Учр-утх:',
+'savefile'            => 'Хадһлх',
+'uploadedimage'       => '«[[$1]]» тәвв',
+'upload-success-subj' => 'Йовудта тәвллһн',
 
 'license'        => 'Закан:',
 'license-header' => 'Закан:',
@@ -848,7 +833,6 @@ $1',
 'statistics-edits-average'     => 'Халхарн сольлһна то',
 'statistics-views-total'       => 'Цуг хәләврин то',
 'statistics-views-peredit'     => 'Сольлһарн хәләврин то',
-'statistics-jobqueue'          => '[http://www.mediawiki.org/wiki/Manual:Job_queue Даалһврин дарана] кемҗән',
 'statistics-users'             => 'Бичгдлһтә [[Special:ListUsers|демнчнр]]',
 'statistics-users-active'      => 'Үүлтә демнчнр',
 'statistics-users-active-desc' => '{{PLURAL:$1|$1 өдрт|$1 өдрмүдт|$1 өдрмүдт}} болв чигн үүл кесн демнчнр',
@@ -900,7 +884,6 @@ $1',
 # Watchlist
 'watchlist'         => 'Шинҗллһнә сеткүл',
 'mywatchlist'       => 'Шинҗллһнә сеткүл',
-'watchlistfor'      => "('''$1''' төлә)",
 'addedwatch'        => 'Шинҗллһнә сеткүлд немв.',
 'addedwatchtext'    => "«[[:$1]]» гидг нерәдлһтә халх тана [[Special:Watchlist|шинҗллһнә сеткүлд]] немв.
 Тегәд тер халхна болн терүнә ухалврин сольлһн энд шиҗлсн болх. Эн халх '''тарһн'' үзгәр [[Special:RecentChanges|шидрә сольлһна]] халхд бичсн (амр умшхар) болх.",
@@ -1166,10 +1149,10 @@ $2 шидрә һарһлһна төлә хәләтн.',
 'nextdiff'     => 'Дарук сольлһн →',
 
 # Media information
-'file-info'            => '(боомгин кемҗә: $1, MIME төрл: $2)',
-'file-info-size'       => '($1 × $2 цегтә, боомгин кемҗән: $3, MIME янз: $4)',
+'file-info'            => 'боомгин кемҗә: $1, MIME төрл: $2',
+'file-info-size'       => '$1 × $2 цегтә, боомгин кемҗән: $3, MIME янз: $4',
 'file-nohires'         => '<small>Икәр чинртә янз уга.</small>',
-'svg-long-desc'        => '(SVG боомг, $1 × $2 мет цегтә, боомгин кемҗән: $3)',
+'svg-long-desc'        => 'SVG боомг, $1 × $2 мет цегтә, боомгин кемҗән: $3',
 'show-big-image'       => 'Күцц чинр',
 'show-big-image-thumb' => '<small>Урдаснь хәләврин кемҗән: $1 × $2 цегтә</small>',
 'file-info-gif-looped' => 'билцгсн',
