@@ -7,8 +7,10 @@
  * @ingroup Language
  * @file
  *
- * @author Horacewai2
+ * @author Kuailong
+ * @author PhiLiP
  * @author Philip
+ * @author Shizhao
  * @author Wong128hk
  */
 
@@ -50,8 +52,8 @@ $namespaceAliases = array(
 	'用户讨论' => NS_USER_TALK,
 	'用戶討論' => NS_USER_TALK,
 	# This has never worked so it's unlikely to annoy anyone if I disable it -- TS
-	#'{{SITENAME}}_对话' => NS_PROJECT_TALK
-	#"{{SITENAME}}_對話" => NS_PROJECT_TALK
+	# '{{SITENAME}}_对话' => NS_PROJECT_TALK
+	# "{{SITENAME}}_對話" => NS_PROJECT_TALK
 	'图像' => NS_FILE,
 	'圖像' => NS_FILE,
 	'档案' => NS_FILE,
@@ -88,9 +90,9 @@ $namespaceAliases = array(
 	'幫助討論' => NS_HELP_TALK,
 	'分类'	=> NS_CATEGORY,
 	'分類'  => NS_CATEGORY,
-	'分类对话'=> NS_CATEGORY_TALK,
+	'分类对话' => NS_CATEGORY_TALK,
 	'分類對話' => NS_CATEGORY_TALK,
-	'分类讨论'=> NS_CATEGORY_TALK,
+	'分类讨论' => NS_CATEGORY_TALK,
 	'分類討論' => NS_CATEGORY_TALK,
 );
 
@@ -175,13 +177,17 @@ $messages = array(
 # User preference toggles
 'tog-norollbackdiff' => '進行回退後略過差異比較',
 
+'newpage' => '最新页面',
+
+# Edit pages
+'editing' => '正在编辑 $1',
+
+# Miscellaneous special pages
+'newpages' => '最新页面',
+
 # Move page
 'move-redirect-suppressed' => '已禁止重新定向',
 
-# Patrolling
-'markaspatrolleddiff' => '标记为已巡查',
-'markaspatrolledtext' => '标记此页面为已巡查',
-
 /*
 Short names for language variants used for language conversion links.
 To disable showing a particular link, set it to 'disable', e.g.
@@ -190,12 +196,12 @@ Variants for Chinese language
 */
 'variantname-zh-hans' => '简体',
 'variantname-zh-hant' => '繁體',
-'variantname-zh-cn'   => '大陆',
-'variantname-zh-tw'   => '台灣',
-'variantname-zh-hk'   => '香港',
-'variantname-zh-mo'   => '澳門',
-'variantname-zh-sg'   => '新加坡',
-'variantname-zh-my'   => '大马',
-'variantname-zh'      => '中文原文',
+'variantname-zh-cn'   => '大陆简体',
+'variantname-zh-tw'   => '台灣正體',
+'variantname-zh-hk'   => '香港繁體',
+'variantname-zh-mo'   => '澳門繁體',
+'variantname-zh-sg'   => '新加坡简体',
+'variantname-zh-my'   => '大马简体',
+'variantname-zh'      => '不转换',
 
 );
