@@ -6,7 +6,7 @@
  * @ingroup Maintenance
  */
 
-require_once( dirname(__FILE__) . '/Maintenance.php' );
+require_once( dirname( __FILE__ ) . '/Maintenance.php' );
 
 class DatabaseLag extends Maintenance {
 	public function __construct() {
@@ -19,18 +19,18 @@ class DatabaseLag extends Maintenance {
 		if ( $this->hasOption( 'r' ) ) {
 			$lb = wfGetLB();
 			echo 'time     ';
-			for( $i = 1; $i < $lb->getServerCount(); $i++ ) {
+			for ( $i = 1; $i < $lb->getServerCount(); $i++ ) {
 				$hostname = $lb->getServerName( $i );
 				printf( "%-12s ", $hostname );
 			}
 			echo "\n";
 
-			while( 1 ) {
+			while ( 1 ) {
 				$lb->clearLagTimeCache();
 				$lags = $lb->getLagTimes();
 				unset( $lags[0] );
 				echo gmdate( 'H:i:s' ) . ' ';
-				foreach( $lags as $i => $lag ) {
+				foreach ( $lags as $lag ) {
 					printf( "%-12s " , $lag === false ? 'false' : $lag );
 				}
 				echo "\n";
@@ -39,7 +39,7 @@ class DatabaseLag extends Maintenance {
 		} else {
 			$lb = wfGetLB();
 			$lags = $lb->getLagTimes();
-			foreach( $lags as $i => $lag ) {
+			foreach ( $lags as $i => $lag ) {
 				$name = $lb->getServerName( $i );
 				$this->output( sprintf( "%-20s %s\n" , $name, $lag === false ? 'false' : $lag ) );
 			}
@@ -48,4 +48,4 @@ class DatabaseLag extends Maintenance {
 }
 
 $maintClass = "DatabaseLag";
-require_once( DO_MAINTENANCE );
+require_once( RUN_MAINTENANCE_IF_MAIN );
