@@ -1,27 +1,31 @@
 <?php
+/**
+ * @file
+ * @ingroup Maintenance
+ */
 
-require_once( dirname( __FILE__ ). '/../maintenance/commandLine.inc' );
+require_once( dirname( __FILE__ ) . '/commandLine.inc' );
 
 $wgHooks['BeforeParserFetchTemplateAndtitle'][] = 'PPFuzzTester::templateHook';
 
 class PPFuzzTester {
 	var $hairs = array(
-		'[[', ']]', '{{', '{{', '}}', '}}', '{{{', '}}}', 
+		'[[', ']]', '{{', '{{', '}}', '}}', '{{{', '}}}',
 		'<', '>', '<nowiki', '<gallery', '</nowiki>', '</gallery>', '<nOwIkI>', '</NoWiKi>',
 		'<!--' , '-->',
 		"\n==", "==\n",
 		'|', '=', "\n", ' ', "\t", "\x7f",
 		'~~', '~~~', '~~~~', 'subst:',
-		'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 
+		'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j',
 		'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't',
 
 		// extensions
-		//'<ref>', '</ref>', '<references/>',
+		// '<ref>', '</ref>', '<references/>',
 	);
 	var $minLength = 0;
 	var $maxLength = 20;
 	var $maxTemplates = 5;
-	//var $outputTypes = array( 'OT_HTML', 'OT_WIKI', 'OT_PREPROCESS' );
+	// var $outputTypes = array( 'OT_HTML', 'OT_WIKI', 'OT_PREPROCESS' );
 	var $entryPoints = array( 'testSrvus', 'testPst', 'testPreprocess' );
 	var $verbose = false;
 	static $currentTest = false;
@@ -47,7 +51,7 @@ class PPFuzzTester {
 				$exceptionReport = $e->getText();
 				$hash = md5( $testReport );
 				file_put_contents( "results/ppft-$hash.in", serialize( self::$currentTest ) );
-				file_put_contents( "results/ppft-$hash.fail", 
+				file_put_contents( "results/ppft-$hash.fail",
 					"Input:\n$testReport\n\nException report:\n$exceptionReport\n" );
 				print "Test $hash failed\n";
 				$passed = 'failed';
@@ -95,10 +99,11 @@ class PPFuzzTester {
 			$s .= $this->hairs[$hairIndex];
 		}
 		// Send through the UTF-8 normaliser
-		// This resolves a few differences between the old preprocessor and the 
+		// This resolves a few differences between the old preprocessor and the
 		// XML-based one, which doesn't like illegals and converts line endings.
 		// It's done by the MW UI, so it's a reasonably legitimate thing to do.
-		$s = UtfNormal::cleanUp( $s );
+		global $wgContLang;
+		$s = $wgContLang->normalize( $s );
 		return $s;
 	}
 
@@ -126,16 +131,16 @@ class PPFuzzTest {
 		$this->parent = $tester;
 		$this->mainText = $tester->makeInputText();
 		$this->title = $tester->makeTitle();
-		//$this->outputType = $tester->pickOutputType();
+		// $this->outputType = $tester->pickOutputType();
 		$this->entryPoint = $tester->pickEntryPoint();
-		$this->nickname = $tester->makeInputText( $wgMaxSigChars + 10);
+		$this->nickname = $tester->makeInputText( $wgMaxSigChars + 10 );
 		$this->fancySig = (bool)mt_rand( 0, 1 );
 		$this->templates = array();
 	}
 
 	function templateHook( $title ) {
 		$titleText = $title->getPrefixedDBkey();
-		
+
 		if ( !isset( $this->templates[$titleText] ) ) {
 			$finalTitle = $title;
 			if ( count( $this->templates ) >= $this->parent->maxTemplates ) {
@@ -177,9 +182,9 @@ class PPFuzzTest {
 
 	function getReport() {
 		$s = "Title: " . $this->title->getPrefixedDBkey() . "\n" .
-//			"Output type: {$this->outputType}\n" . 
-			"Entry point: {$this->entryPoint}\n" . 
-			"User: " . ( $this->fancySig ? 'fancy' : 'no-fancy' ) . ' ' . var_export( $this->nickname, true ) . "\n" . 
+//			"Output type: {$this->outputType}\n" .
+			"Entry point: {$this->entryPoint}\n" .
+			"User: " . ( $this->fancySig ? 'fancy' : 'no-fancy' ) . ' ' . var_export( $this->nickname, true ) . "\n" .
 			"Main text: " . var_export( $this->mainText, true ) . "\n";
 		foreach ( $this->templates as $titleText => $template ) {
 			$finalTitle = $template['finalTitle'];
