@@ -1,14 +1,14 @@
 <?php
 
 $optionsWithArgs = RecompressTracked::getOptionsWithArgs();
-require( dirname( __FILE__ ) .'/../commandLine.inc' );
+require( dirname( __FILE__ ) . '/../commandLine.inc' );
 
 if ( count( $args ) < 1 ) {
 	echo "Usage: php recompressTracked.php [options] <cluster> [... <cluster>...]
 Moves blobs indexed by trackBlobs.php to a specified list of destination clusters, and recompresses them in the process. Restartable.
 
-Options: 
-    --procs <procs>         Set the number of child processes (default 1)
+Options:
+	--procs <procs>         Set the number of child processes (default 1)
 	--copy-only             Copy only, do not update the text table. Restart without this option to complete.
 	--debug-log <file>      Log debugging data to the specified file
 	--info-log <file>       Log progress messages to the specified file
@@ -31,11 +31,13 @@ class RecompressTracked {
 	var $copyOnly = false;
 	var $isChild = false;
 	var $slaveId = false;
+	var $noCount = false;
 	var $debugLog, $infoLog, $criticalLog;
 	var $store;
 
 	static $optionsWithArgs = array( 'procs', 'slave-id', 'debug-log', 'info-log', 'critical-log' );
 	static $cmdLineOptionMap = array(
+		'no-count' => 'noCount',
 		'procs' => 'numProcs',
 		'copy-only' => 'copyOnly',
 		'child' => 'isChild',
@@ -97,7 +99,7 @@ class RecompressTracked {
 	}
 
 	function logToFile( $msg, $file ) {
-		$header = '[' . date('d\TH:i:s') . '] ' . wfHostname() . ' ' . posix_getpid();
+		$header = '[' . date( 'd\TH:i:s' ) . '] ' . wfHostname() . ' ' . posix_getpid();
 		if ( $this->slaveId !== false ) {
 			$header .= "({$this->slaveId})";
 		}
@@ -107,8 +109,8 @@ class RecompressTracked {
 
 	/**
 	 * Wait until the selected slave has caught up to the master.
-	 * This allows us to use the slave for things that were committed in a 
-	 * previous part of this batch process. 
+	 * This allows us to use the slave for things that were committed in a
+	 * previous part of this batch process.
 	 */
 	function syncDBs() {
 		$dbw = wfGetDB( DB_MASTER );
@@ -177,14 +179,14 @@ class RecompressTracked {
 				$cmd .= " --$cmdOption";
 			}
 		}
-		$cmd .= ' --child' . 
+		$cmd .= ' --child' .
 			' --wiki ' . wfEscapeShellArg( wfWikiID() ) .
 			' ' . call_user_func_array( 'wfEscapeShellArg', $this->destClusters );
 
 		$this->slavePipes = $this->slaveProcs = array();
 		for ( $i = 0; $i < $this->numProcs; $i++ ) {
 			$pipes = false;
-			$spec = array( 
+			$spec = array(
 				array( 'pipe', 'r' ),
 				array( 'file', 'php://stdout', 'w' ),
 				array( 'file', 'php://stderr', 'w' )
@@ -226,7 +228,7 @@ class RecompressTracked {
 	function dispatch( /*...*/ ) {
 		$args = func_get_args();
 		$pipes = $this->slavePipes;
-		$numPipes = stream_select( $x=array(), $pipes, $y=array(), 3600 );
+		$numPipes = stream_select( $x = array(), $pipes, $y = array(), 3600 );
 		if ( !$numPipes ) {
 			$this->critical( "Error waiting to write to slaves. Aborting" );
 			exit( 1 );
@@ -259,27 +261,31 @@ class RecompressTracked {
 		$dbr = wfGetDB( DB_SLAVE );
 		$i = 0;
 		$startId = 0;
-		$numPages = $dbr->selectField( 'blob_tracking', 
-			'COUNT(DISTINCT bt_page)', 
-			# A condition is required so that this query uses the index
-			array( 'bt_moved' => 0 ),
-			__METHOD__
-		);
+		if ( $this->noCount ) {
+			$numPages = '[unknown]';
+		} else {
+			$numPages = $dbr->selectField( 'blob_tracking',
+				'COUNT(DISTINCT bt_page)',
+				# A condition is required so that this query uses the index
+				array( 'bt_moved' => 0 ),
+				__METHOD__
+			);
+		}
 		if ( $this->copyOnly ) {
 			$this->info( "Copying pages..." );
 		} else {
 			$this->info( "Moving pages..." );
 		}
 		while ( true ) {
-			$res = $dbr->select( 'blob_tracking', 
+			$res = $dbr->select( 'blob_tracking',
 				array( 'bt_page' ),
-				array( 
+				array(
 					'bt_moved' => 0,
 					'bt_page > ' . $dbr->addQuotes( $startId )
 				),
 				__METHOD__,
-				array( 
-					'DISTINCT', 
+				array(
+					'DISTINCT',
 					'ORDER BY' => 'bt_page',
 					'LIMIT' => $this->batchSize,
 				)
@@ -310,7 +316,7 @@ class RecompressTracked {
 		if ( $current == $end || $this->numBatches >= $this->reportingInterval ) {
 			$this->numBatches = 0;
 			$this->info( "$label: $current / $end" );
-			wfWaitForSlaves( 5 );
+			$this->waitForSlaves();
 		}
 	}
 
@@ -321,12 +327,16 @@ class RecompressTracked {
 		$dbr = wfGetDB( DB_SLAVE );
 		$startId = 0;
 		$i = 0;
-		$numOrphans = $dbr->selectField( 'blob_tracking', 
-			'COUNT(DISTINCT bt_text_id)', 
-			array( 'bt_moved' => 0, 'bt_page' => 0 ),
-			__METHOD__ );
-		if ( !$numOrphans ) {
-			return;
+		if ( $this->noCount ) {
+			$numOrphans = '[unknown]';
+		} else {
+			$numOrphans = $dbr->selectField( 'blob_tracking',
+				'COUNT(DISTINCT bt_text_id)',
+				array( 'bt_moved' => 0, 'bt_page' => 0 ),
+				__METHOD__ );
+			if ( !$numOrphans ) {
+				return;
+			}
 		}
 		if ( $this->copyOnly ) {
 			$this->info( "Copying orphans..." );
@@ -404,7 +414,7 @@ class RecompressTracked {
 			case 'quit':
 				return;
 			}
-			wfWaitForSlaves( 5 );
+			$this->waitForSlaves();
 		}
 	}
 
@@ -430,8 +440,8 @@ class RecompressTracked {
 		$trx = new CgzCopyTransaction( $this, $this->pageBlobClass );
 
 		while ( true ) {
-			$res = $dbr->select( 
-				array( 'blob_tracking', 'text' ), 
+			$res = $dbr->select(
+				array( 'blob_tracking', 'text' ),
 				'*',
 				array(
 					'bt_page' => $pageId,
@@ -441,7 +451,7 @@ class RecompressTracked {
 					'bt_text_id=old_id',
 				),
 				__METHOD__,
-				array( 
+				array(
 					'ORDER BY' => 'bt_text_id',
 					'LIMIT' => $this->batchSize
 				)
@@ -469,6 +479,7 @@ class RecompressTracked {
 					$this->debug( "$titleText: committing blob with " . $trx->getSize() . " items" );
 					$trx->commit();
 					$trx = new CgzCopyTransaction( $this, $this->pageBlobClass );
+					$this->waitForSlaves();
 				}
 			}
 			$startId = $row->bt_text_id;
@@ -485,7 +496,7 @@ class RecompressTracked {
 	 *
 	 * This is done in a single transaction to provide restartable behaviour
 	 * without data loss.
-	 * 
+	 *
 	 * The transaction is kept short to reduce locking.
 	 */
 	function moveTextRow( $textId, $url ) {
@@ -525,16 +536,16 @@ class RecompressTracked {
 		$dbr = wfGetDB( DB_SLAVE );
 
 		$startId = 0;
-		$conds = array_merge( $conds, array( 
+		$conds = array_merge( $conds, array(
 			'bt_moved' => 0,
 			'bt_new_url IS NOT NULL'
-		));
+		) );
 		while ( true ) {
 			$res = $dbr->select( 'blob_tracking',
 				'*',
 				array_merge( $conds, array( 'bt_text_id > ' . $dbr->addQuotes( $startId ) ) ),
 				__METHOD__,
-				array( 
+				array(
 					'ORDER BY' => 'bt_text_id',
 					'LIMIT' => $this->batchSize,
 				)
@@ -545,6 +556,9 @@ class RecompressTracked {
 			$this->debug( 'Incomplete: ' . $res->numRows() . ' rows' );
 			foreach ( $res as $row ) {
 				$this->moveTextRow( $row->bt_text_id, $row->bt_new_url );
+				if ( $row->bt_text_id % 10 == 0 ) {
+					$this->waitForSlaves();
+				}
 			}
 			$startId = $row->bt_text_id;
 		}
@@ -578,17 +592,17 @@ class RecompressTracked {
 			$this->finishIncompleteMoves( array( 'bt_text_id' => $textIds ) );
 			$this->syncDBs();
 		}
-		
+
 		$trx = new CgzCopyTransaction( $this, $this->orphanBlobClass );
 
 		$res = wfGetDB( DB_SLAVE )->select(
-			array( 'text', 'blob_tracking' ), 
-			array( 'old_id', 'old_text', 'old_flags' ), 
-			array( 
+			array( 'text', 'blob_tracking' ),
+			array( 'old_id', 'old_text', 'old_flags' ),
+			array(
 				'old_id' => $textIds,
 				'bt_text_id=old_id',
 				'bt_moved' => 0,
-			), 
+			),
 			__METHOD__,
 			array( 'DISTINCT' )
 		);
@@ -596,19 +610,34 @@ class RecompressTracked {
 		foreach ( $res as $row ) {
 			$text = Revision::getRevisionText( $row );
 			if ( $text === false ) {
-				$this->critical( "Error: cannot load revision text for old_id=$textId" );
+				$this->critical( "Error: cannot load revision text for old_id={$row->old_id}" );
 				continue;
 			}
-			
+
 			if ( !$trx->addItem( $text, $row->old_id ) ) {
 				$this->debug( "[orphan]: committing blob with " . $trx->getSize() . " rows" );
 				$trx->commit();
 				$trx = new CgzCopyTransaction( $this, $this->orphanBlobClass );
+				$this->waitForSlaves();
 			}
 		}
 		$this->debug( "[orphan]: committing blob with " . $trx->getSize() . " rows" );
 		$trx->commit();
 	}
+
+	/**
+	 * Wait for slaves (quietly)
+	 */
+	function waitForSlaves() {
+		$lb = wfGetLB();
+		while ( true ) {
+			list( $host, $maxLag ) = $lb->getMaxLag();
+			if ( $maxLag < 2 ) {
+				break;
+			}
+			sleep( 5 );
+		}
+	}
 }
 
 /**
@@ -675,14 +704,14 @@ class CgzCopyTransaction {
 
 		// Check to see if the target text_ids have been moved already.
 		//
-		// We originally read from the slave, so this can happen when a single 
-		// text_id is shared between multiple pages. It's rare, but possible 
+		// We originally read from the slave, so this can happen when a single
+		// text_id is shared between multiple pages. It's rare, but possible
 		// if a delete/move/undelete cycle splits up a null edit.
 		//
 		// We do a locking read to prevent closer-run race conditions.
 		$dbw = wfGetDB( DB_MASTER );
 		$dbw->begin();
-		$res = $dbw->select( 'blob_tracking', 
+		$res = $dbw->select( 'blob_tracking',
 			array( 'bt_text_id', 'bt_moved' ),
 			array( 'bt_text_id' => array_keys( $this->referrers ) ),
 			__METHOD__, array( 'FOR UPDATE' ) );
