@@ -1,12 +1,12 @@
 
-var ProtectionForm = {
+window.ProtectionForm = {
 	'existingMatch': false,
 
 	/**
 	 * Set up the protection chaining interface (i.e. "unlock move permissions" checkbox)
 	 * on the protection form
 	 *
-	 * @param Object opts : parameters with members:
+	 * @param opts Object : parameters with members:
 	 *     tableId              Identifier of the table containing UI bits
 	 *     labelText            Text to use for the checkbox label
 	 *     numTypes             The number of protection types
@@ -20,9 +20,9 @@ var ProtectionForm = {
 		if( !box )
 			return false;
 		
-		var boxbody = box.getElementsByTagName('tbody')[0]
+		var boxbody = box.getElementsByTagName('tbody')[0];
 		var row = document.createElement( 'tr' );
-		boxbody.insertBefore( row, boxbody.firstChild );
+		boxbody.insertBefore( row, boxbody.firstChild.nextSibling );
 
 		this.existingMatch = opts.existingMatch;
 
@@ -76,7 +76,7 @@ var ProtectionForm = {
 
 	/**
 	 * Is this protection level cascadeable?
-	 * @param String level
+	 * @param level String
 	 *
 	 * @return boolean
 	 *
@@ -94,7 +94,7 @@ var ProtectionForm = {
 	 * When protection levels are locked together, update the rest
 	 * when one action's level changes
 	 *
-	 * @param Element source Level selector that changed
+	 * @param source Element Level selector that changed
 	 */
 	'updateLevels': function(source) {
 		if( !this.isUnchained() )
@@ -106,7 +106,7 @@ var ProtectionForm = {
 	 * When protection levels are locked together, update the
 	 * expiries when one changes
 	 *
-	 * @param Element source expiry input that changed
+	 * @param source Element expiry input that changed
 	 */
 
 	'updateExpiry': function(source) {
@@ -133,7 +133,7 @@ var ProtectionForm = {
 	 * When protection levels are locked together, update the
 	 * expiry lists when one changes and clear the custom inputs
 	 *
-	 * @param Element source expiry selector that changed
+	 * @param source Element expiry selector that changed
 	 */
 	'updateExpiryList': function(source) {
 		if( !this.isUnchained() ) {
@@ -221,7 +221,7 @@ var ProtectionForm = {
 	/**
 	 * Protect all actions at the specified level
 	 *
-	 * @param int index Protection level
+	 * @param index int Protection level
 	 */
 	'setAllSelectors': function(index) {
 		this.forEachLevelSelector(function(element) {
@@ -234,7 +234,7 @@ var ProtectionForm = {
 	/**
 	 * Apply a callback to each protection selector
 	 *
-	 * @param callable func Callback function
+	 * @param func callable Callback function
 	 */
 	'forEachLevelSelector': function(func) {
 		var selectors = this.getLevelSelectors();
@@ -263,7 +263,7 @@ var ProtectionForm = {
 	/**
 	 * Apply a callback to each expiry input
 	 *
-	 * @param callable func Callback function
+	 * @param func callable Callback function
 	 */
 	'forEachExpiryInput': function(func) {
 		var inputs = this.getExpiryInputs();
@@ -291,7 +291,7 @@ var ProtectionForm = {
 
 	/**
 	 * Apply a callback to each expiry selector list
-	 * @param callable func Callback function
+	 * @param func callable Callback function
 	 */
 	'forEachExpirySelector': function(func) {
 		var inputs = this.getExpirySelectors();
@@ -320,7 +320,7 @@ var ProtectionForm = {
 	/**
 	 * Enable/disable protection selectors and expiry inputs
 	 *
-	 * @param boolean val Enable?
+	 * @param val boolean Enable?
 	 */
 	'enableUnchainedInputs': function(val) {
 		var first = true;
@@ -348,4 +348,4 @@ var ProtectionForm = {
 			}
 		});
 	}
-}
+};
